@@ -24,9 +24,11 @@
 #include "../GUI/profilemanager.h"
 
 #include <qlayout.h>
-#include <qhbox.h>
 #include <qlabel.h>
 #include <qtoolbutton.h>
+#include <QHBoxLayout>
+#include <QFrame>
+#include <QVBoxLayout>
 #include <klineedit.h>
 #include <qcheckbox.h>
 #include <kiconloader.h>
@@ -44,44 +46,56 @@
 #define EXECUTABLE_ID		0xFFFF
 
 
-AddPlaceholderPopup::AddPlaceholderPopup( QWidget *parent ) : KPopupMenu( parent ) {
+AddPlaceholderPopup::AddPlaceholderPopup( QWidget *parent ) : KMenu( parent ) {
 
-   _activeSub = new KPopupMenu( this );
-   _otherSub = new KPopupMenu( this );
-   _leftSub = new KPopupMenu( this );
-   _rightSub = new KPopupMenu( this );
-   _independentSub = new KPopupMenu( this );
+   _activeSub = new KMenu( i18n( "Active panel" ), this );
+   _otherSub = new KMenu( i18n( "Other panel" ), this );
+   _leftSub = new KMenu( i18n( "Left panel" ), this );
+   _rightSub = new KMenu( i18n( "Right panel" ), this );
+   _independentSub = new KMenu( i18n( "Panel independent" ), this );
 
-   insertItem( i18n( "Active panel" ), _activeSub );
-   insertItem( i18n( "Other panel" ), _otherSub );
-   insertItem( i18n( "Left panel" ), _leftSub );
-   insertItem( i18n( "Right panel" ), _rightSub );
-   insertItem( i18n( "Panel independent" ), _independentSub );
-   _independentSub->insertItem( i18n( "Choose executable..." ), EXECUTABLE_ID );
-   _independentSub->insertSeparator();
+   addMenu( _activeSub );
+   addMenu( _otherSub );
+   addMenu( _leftSub );
+   addMenu( _rightSub );
+   addMenu( _independentSub );
+
+   QAction *chooseExecAct = _independentSub->addAction( i18n( "Choose executable..." ) );
+   chooseExecAct->setData( QVariant( EXECUTABLE_ID ) );
+
+   _independentSub->addSeparator();
 
    // read the expressions array from the user menu and populate menus
    Expander expander;
    for ( int i = 0; i < expander.placeholderCount(); ++i ) {
       if (  expander.placeholder( i )->expression().isEmpty() ) {
          if ( expander.placeholder( i )->needPanel() ) {
-            _activeSub->insertSeparator();
-            _otherSub->insertSeparator();
-            _leftSub->insertSeparator();
-            _rightSub->insertSeparator();
+            _activeSub->addSeparator();
+            _otherSub->addSeparator();
+            _leftSub->addSeparator();
+            _rightSub->addSeparator();
          }
          else
-            _independentSub->insertSeparator();
+            _independentSub->addSeparator();
       }
       else {
+         QAction * action;
+
          if ( expander.placeholder( i )->needPanel() ) {
-            _activeSub->insertItem( i18n( expander.placeholder( i )->description().utf8() ), ( i | ACTIVE_MASK ) );
-            _otherSub->insertItem( i18n( expander.placeholder( i )->description().utf8() ), ( i | OTHER_MASK ) );
-            _leftSub->insertItem( i18n( expander.placeholder( i )->description().utf8() ), ( i | LEFT_MASK ) );
-            _rightSub->insertItem( i18n( expander.placeholder( i )->description().utf8() ), ( i | RIGHT_MASK ) );
+            action = _activeSub->addAction( i18n( expander.placeholder( i )->description().toUtf8() ) );
+            action->setData( QVariant( i | ACTIVE_MASK ) );
+            action = _otherSub->addAction( i18n( expander.placeholder( i )->description().toUtf8() ) );
+            action->setData( QVariant( i | OTHER_MASK ) );
+            action = _leftSub->addAction( i18n( expander.placeholder( i )->description().toUtf8() ) );
+            action->setData( QVariant( i | LEFT_MASK ) );
+            action = _rightSub->addAction( i18n( expander.placeholder( i )->description().toUtf8() ) );
+            action->setData( QVariant( i | RIGHT_MASK ) );
          }
          else
-            _independentSub->insertItem( i18n( expander.placeholder( i )->description().utf8() ), ( i | INDEPENDENT_MASK ) );
+         {
+            action = _independentSub->addAction( i18n( expander.placeholder( i )->description().toUtf8() ) );
+            action->setData( QVariant( i | INDEPENDENT_MASK ) );
+         }
       }
    }
 
@@ -89,42 +103,42 @@ AddPlaceholderPopup::AddPlaceholderPopup( QWidget *parent ) : KPopupMenu( parent
 
 
 QString AddPlaceholderPopup::getPlaceholder( const QPoint& pos ) {
-   int res = exec( pos );
-   if ( res == -1 )
-      return QString::null;
+   QAction *res = exec( pos );
+   if ( res == 0 )
+      return QString();
 
    // add the selected flag to the command line
-   if ( res == EXECUTABLE_ID ) { // did the user need an executable ?
+   if ( res->data().toInt() == EXECUTABLE_ID ) { // did the user need an executable ?
       // select an executable
-      QString filename = KFileDialog::getOpenFileName(QString::null, QString::null, this);
-      if (filename != QString::null)
+      QString filename = KFileDialog::getOpenFileName(QString(), QString(), this);
+      if (filename != QString())
          return filename + " "; // with extra space
          //return filename; // without extra space
    } else { // user selected something from the menus
       Expander expander;
-      const exp_placeholder* currentPlaceholder = expander.placeholder( res & ~( ACTIVE_MASK | OTHER_MASK | LEFT_MASK | RIGHT_MASK | INDEPENDENT_MASK ) );
+      const exp_placeholder* currentPlaceholder = expander.placeholder( res->data().toInt() & ~( ACTIVE_MASK | OTHER_MASK | LEFT_MASK | RIGHT_MASK | INDEPENDENT_MASK ) );
 //       if ( &currentPlaceholder->expFunc == 0 ) {
 //          KMessageBox::sorry( this, "BOFH Excuse #93:\nFeature not yet implemented" );
-//          return QString::null;
+//          return QString();
 //       } 
       ParameterDialog* parameterDialog = new ParameterDialog( currentPlaceholder, this );
       QString panel, parameter = parameterDialog->getParameter();
       delete parameterDialog;
       // indicate the panel with 'a' 'o', 'l', 'r' or '_'.
-      if ( res & ACTIVE_MASK )
+      if ( res->data().toInt() & ACTIVE_MASK )
          panel = "a";
-      else if ( res & OTHER_MASK )
+      else if ( res->data().toInt() & OTHER_MASK )
          panel = "o";
-      else if ( res & LEFT_MASK )
+      else if ( res->data().toInt() & LEFT_MASK )
          panel = "l";
-      else if ( res & RIGHT_MASK )
+      else if ( res->data().toInt() & RIGHT_MASK )
          panel = "r";
-      else if ( res & INDEPENDENT_MASK )
+      else if ( res->data().toInt() & INDEPENDENT_MASK )
          panel = "_";
       //return "%" + panel + currentPlaceholder->expression() + parameter + "% "; // with extra space
       return "%" + panel + currentPlaceholder->expression() + parameter + "%"; // without extra space
    }
-	return QString::null;
+	return QString();
 }
 
 
@@ -132,56 +146,66 @@ QString AddPlaceholderPopup::getPlaceholder( const QPoint& pos ) {
 /////////////////////////////// ParameterDialog ////////////////////////////////////
 ////////////////////////////////////////////////////////////////////////////////////////////
 
-ParameterDialog::ParameterDialog( const exp_placeholder* currentPlaceholder, QWidget *parent ) : KDialogBase( Plain, i18n("User Action Parameter Dialog"), Default | Ok, Ok, parent ) {
+ParameterDialog::ParameterDialog( const exp_placeholder* currentPlaceholder, QWidget *parent ) : KDialog(parent) {
+	//KDialog( Plain, i18n("User Action Parameter Dialog"), Default | Ok, Ok, parent ) {
+	setWindowTitle(i18n("User Action Parameter Dialog"));
+	setButtons(Ok | Default);
+	setDefaultButton(Ok);
    _parameter.clear();
    _parameterCount = currentPlaceholder->parameterCount();
    
-   QVBoxLayout* layout = new QVBoxLayout( plainPage() );
-   layout->setAutoAdd( true );
+   QWidget *page = new QWidget(this);
+   setMainWidget(page);
+   QVBoxLayout* layout = new QVBoxLayout( page );
    layout->setSpacing( 11 );
+   layout->setContentsMargins( 0, 0, 0, 0 );
    
-   new QLabel( i18n("This placeholder allows some parameter:"), plainPage(), "intro" );
+   layout->addWidget( new QLabel( i18n("This placeholder allows some parameter:"), page ) );
    
    for (int i = 0; i < _parameterCount; ++i ) {
       if ( currentPlaceholder->parameter( i ).preset() == "__placeholder" )
-         _parameter.append( new ParameterPlaceholder( currentPlaceholder->parameter( i ), plainPage() ) );
+         _parameter.append( new ParameterPlaceholder( currentPlaceholder->parameter( i ), page ) );
       else if ( currentPlaceholder->parameter( i ).preset() == "__yes" )
-         _parameter.append( new ParameterYes( currentPlaceholder->parameter( i ), plainPage() ) );
+         _parameter.append( new ParameterYes( currentPlaceholder->parameter( i ), page ) );
       else if ( currentPlaceholder->parameter( i ).preset() == "__no" )
-         _parameter.append( new ParameterNo( currentPlaceholder->parameter( i ), plainPage() ) );
+         _parameter.append( new ParameterNo( currentPlaceholder->parameter( i ), page ) );
       else if ( currentPlaceholder->parameter( i ).preset() == "__file" )
-         _parameter.append( new ParameterFile( currentPlaceholder->parameter( i ), plainPage() ) );
-      else if ( currentPlaceholder->parameter( i ).preset().find( "__choose" ) != -1 )
-         _parameter.append( new ParameterChoose( currentPlaceholder->parameter( i ), plainPage() ) );
+         _parameter.append( new ParameterFile( currentPlaceholder->parameter( i ), page ) );
+      else if ( currentPlaceholder->parameter( i ).preset().indexOf( "__choose" ) != -1 )
+         _parameter.append( new ParameterChoose( currentPlaceholder->parameter( i ), page ) );
       else if ( currentPlaceholder->parameter( i ).preset() == "__select" )
-         _parameter.append( new ParameterSelect( currentPlaceholder->parameter( i ), plainPage() ) );
+         _parameter.append( new ParameterSelect( currentPlaceholder->parameter( i ), page ) );
       else if ( currentPlaceholder->parameter( i ).preset() == "__goto" )
-         _parameter.append( new ParameterGoto( currentPlaceholder->parameter( i ), plainPage() ) );
+         _parameter.append( new ParameterGoto( currentPlaceholder->parameter( i ), page ) );
       else if ( currentPlaceholder->parameter( i ).preset() == "__syncprofile" )
-         _parameter.append( new ParameterSyncprofile( currentPlaceholder->parameter( i ), plainPage() ) );
+         _parameter.append( new ParameterSyncprofile( currentPlaceholder->parameter( i ), page ) );
       else if ( currentPlaceholder->parameter( i ).preset() == "__searchprofile" )
-         _parameter.append( new ParameterSearch( currentPlaceholder->parameter( i ), plainPage() ) );
+         _parameter.append( new ParameterSearch( currentPlaceholder->parameter( i ), page ) );
       else if ( currentPlaceholder->parameter( i ).preset() == "__panelprofile" )
-         _parameter.append( new ParameterPanelprofile( currentPlaceholder->parameter( i ), plainPage() ) );
-      else if ( currentPlaceholder->parameter( i ).preset().find( "__int" ) != -1 )
-         _parameter.append( new ParameterInt( currentPlaceholder->parameter( i ), plainPage() ) );
+         _parameter.append( new ParameterPanelprofile( currentPlaceholder->parameter( i ), page ) );
+      else if ( currentPlaceholder->parameter( i ).preset().indexOf( "__int" ) != -1 )
+         _parameter.append( new ParameterInt( currentPlaceholder->parameter( i ), page ) );
       else
-         _parameter.append( new ParameterText( currentPlaceholder->parameter( i ), plainPage() ) );
+         _parameter.append( new ParameterText( currentPlaceholder->parameter( i ), page ) );
+
+      layout->addWidget( _parameter.last() );
    }
    
-   QFrame * line = new QFrame( plainPage() );
+   QFrame * line = new QFrame( page );
    line->setFrameShape( QFrame::HLine );
    line->setFrameShadow( QFrame::Sunken );
+   layout->addWidget( line );
 
-   connect( this, SIGNAL(defaultClicked()), this, SLOT(reset()) );
+   connect( this, SIGNAL( defaultClicked() ), this, SLOT(reset()) );
+   connect( this, SIGNAL( okClicked() ), this, SLOT( slotOk() ) );
 }
 
 QString ParameterDialog::getParameter() {
    if ( _parameterCount == 0 ) // meaning no parameters
-      return QString::null;
+      return QString();
 
   if ( exec() == -1 )
-     return QString::null;
+     return QString();
 
   int lastParameter = _parameterCount;
   while ( --lastParameter > -1 ) {
@@ -190,7 +214,7 @@ QString ParameterDialog::getParameter() {
   }
 
   if ( lastParameter < 0) // all parameters have default-values
-     return QString::null;
+     return QString();
 
   QString parameter = "(";
   for ( int i = 0; i <= lastParameter; ++i ) {
@@ -221,11 +245,11 @@ void ParameterDialog::slotOk() {
 ///////////// ParameterText
 ParameterText::ParameterText( const exp_parameter& parameter, QWidget* parent ) : ParameterBase( parameter, parent ) {
    QVBoxLayout* layout = new QVBoxLayout( this );
-   layout->setAutoAdd( true );
    layout->setSpacing( 6 );
+   layout->setContentsMargins( 0, 0, 0, 0 );
    
-   new QLabel( i18n( parameter.description().utf8() ), this );
-   _lineEdit = new KLineEdit( parameter.preset(), this );
+   layout->addWidget( new QLabel( i18n( parameter.description().toUtf8() ), this ) );
+   layout->addWidget( _lineEdit = new KLineEdit( parameter.preset(), this ) );
    _preset = parameter.preset();
 }
 
@@ -248,15 +272,21 @@ bool ParameterText::valid() {
 ///////////// ParameterPlaceholder
 ParameterPlaceholder::ParameterPlaceholder( const exp_parameter& parameter, QWidget* parent ) : ParameterBase( parameter, parent ) {
    QVBoxLayout* layout = new QVBoxLayout( this );
-   layout->setAutoAdd( true );
    layout->setSpacing( 6 );
+   layout->setContentsMargins( 0, 0, 0, 0 );
    
-   new QLabel( i18n( parameter.description().utf8() ), this );
-   QHBox * hbox = new QHBox( this );
+   layout->addWidget( new QLabel( i18n( parameter.description().toUtf8() ), this ) );
+   QWidget * hboxWidget = new QWidget( this );
+   layout->addWidget( hboxWidget );
+   QHBoxLayout * hbox = new QHBoxLayout( hboxWidget );
+
+   hbox->setContentsMargins( 0, 0, 0, 0 );
    hbox->setSpacing( 6 );
-   _lineEdit = new KLineEdit( hbox );
-   _button = new QToolButton( hbox);
-   _button->setText( i18n("add") );
+   _lineEdit = new KLineEdit( hboxWidget );
+   hbox->addWidget( _lineEdit );
+   _button = new QToolButton( hboxWidget );
+   _button->setText( i18n("list-add") );
+   hbox->addWidget( _button );
    connect( _button, SIGNAL(clicked()), this, SLOT(addPlaceholder()) );
 }
 
@@ -264,10 +294,10 @@ QString ParameterPlaceholder::text() {
    return _lineEdit->text();
 }
 QString ParameterPlaceholder::preset() {
-   return QString::null;
+   return QString();
 } 
 void ParameterPlaceholder::reset() {
-   _lineEdit->setText( QString::null );
+   _lineEdit->setText( QString() );
 } 
 bool ParameterPlaceholder::valid() {
    if ( _lineEdit->text().isEmpty() )
@@ -285,21 +315,21 @@ void ParameterPlaceholder::addPlaceholder() {
 ///////////// ParameterYes
 ParameterYes::ParameterYes( const exp_parameter& parameter, QWidget* parent ) : ParameterBase( parameter, parent ) {
    QVBoxLayout* layout = new QVBoxLayout( this );
-   layout->setAutoAdd( true );
    layout->setSpacing( 6 );
+   layout->setContentsMargins( 0, 0, 0, 0 );
    
-   _checkBox = new QCheckBox( i18n( parameter.description().utf8() ), this );
+   layout->addWidget( _checkBox = new QCheckBox( i18n( parameter.description().toUtf8() ), this ) );
    _checkBox->setChecked( true );
 }
 
 QString ParameterYes::text() {
    if ( _checkBox->isChecked() )
-      return QString::null;
+      return QString();
    else
       return "No";
 } 
 QString ParameterYes::preset() {
-   return QString::null;
+   return QString();
 } 
 void ParameterYes::reset() {
    _checkBox->setChecked( true );
@@ -311,10 +341,10 @@ bool ParameterYes::valid() {
 ///////////// ParameterNo
 ParameterNo::ParameterNo( const exp_parameter& parameter, QWidget* parent ) : ParameterBase( parameter, parent ) {
    QVBoxLayout* layout = new QVBoxLayout( this );
-   layout->setAutoAdd( true );
    layout->setSpacing( 6 );
+   layout->setContentsMargins( 0, 0, 0, 0 );
    
-   _checkBox = new QCheckBox( i18n( parameter.description().utf8() ), this );
+   layout->addWidget( _checkBox = new QCheckBox( i18n( parameter.description().toUtf8() ), this ) );
    _checkBox->setChecked( false );
 }
 
@@ -322,10 +352,10 @@ QString ParameterNo::text() {
    if ( _checkBox->isChecked() )
       return "Yes";
    else
-      return QString::null;
+      return QString();
 } 
 QString ParameterNo::preset() {
-   return QString::null;
+   return QString();
 } 
 void ParameterNo::reset() {
    _checkBox->setChecked( false );
@@ -337,16 +367,23 @@ bool ParameterNo::valid() {
 ///////////// ParameterFile
 ParameterFile::ParameterFile( const exp_parameter& parameter, QWidget* parent ) : ParameterBase( parameter, parent ) {
    QVBoxLayout* layout = new QVBoxLayout( this );
-   layout->setAutoAdd( true );
    layout->setSpacing( 6 );
+   layout->setContentsMargins( 0, 0, 0, 0 );
    
-   new QLabel( i18n( parameter.description().utf8() ), this );
-   QHBox * hbox = new QHBox( this );
+   layout->addWidget( new QLabel( i18n( parameter.description().toUtf8() ), this ) );
+
+   QWidget * hboxWidget = new QWidget( this );
+   layout->addWidget( hboxWidget );
+   QHBoxLayout * hbox = new QHBoxLayout( hboxWidget );
+
+   hbox->setContentsMargins( 0, 0, 0, 0 );
    hbox->setSpacing( 6 );
-   _lineEdit = new KLineEdit( hbox );
-   _button = new QToolButton( hbox);
+   _lineEdit = new KLineEdit( hboxWidget );
+   hbox->addWidget( _lineEdit );
+   _button = new QToolButton( hboxWidget );
+   hbox->addWidget( _button );
    KIconLoader *iconLoader = new KIconLoader();
-  _button->setPixmap( iconLoader->loadIcon( "fileopen", KIcon::Toolbar, 16 ) );
+  _button->setIcon( iconLoader->loadIcon( "document-open", KIconLoader::Toolbar, 16 ) );
    connect( _button, SIGNAL(clicked()), this, SLOT(addFile()) );
 }
 
@@ -354,10 +391,10 @@ QString ParameterFile::text() {
    return _lineEdit->text();
 }
 QString ParameterFile::preset() {
-   return QString::null;
+   return QString();
 } 
 void ParameterFile::reset() {
-   _lineEdit->setText( QString::null );
+   _lineEdit->setText( QString() );
 } 
 bool ParameterFile::valid() {
    if ( _lineEdit->text().isEmpty() )
@@ -366,29 +403,29 @@ bool ParameterFile::valid() {
       return true;
 } 
 void ParameterFile::addFile() {
-   QString filename = KFileDialog::getOpenFileName(QString::null, QString::null, this);
+   QString filename = KFileDialog::getOpenFileName(QString(), QString(), this);
    _lineEdit->insert( filename );
 }
 
 ///////////// ParameterChoose
 ParameterChoose::ParameterChoose( const exp_parameter& parameter, QWidget* parent ) : ParameterBase( parameter, parent ) {
    QVBoxLayout* layout = new QVBoxLayout( this );
-   layout->setAutoAdd( true );
    layout->setSpacing( 6 );
+   layout->setContentsMargins( 0, 0, 0, 0 );
    
-   new QLabel( i18n( parameter.description().utf8() ), this );
-   _combobox = new KComboBox( this );
-   _combobox->insertStringList( QStringList::split( ";", parameter.preset().section(":", 1) ) );
+   layout->addWidget( new QLabel( i18n( parameter.description().toUtf8() ), this ) );
+   layout->addWidget( _combobox = new KComboBox( this ) );
+   _combobox->addItems( parameter.preset().section(":", 1).split( ";" ) );
 }
 
 QString ParameterChoose::text() {
    return _combobox->currentText();
 } 
 QString ParameterChoose::preset() {
-   return _combobox->text( 0 );
+   return _combobox->itemText( 0 );
 } 
 void ParameterChoose::reset() {
-   _combobox->setCurrentItem( 0 );
+   _combobox->setCurrentIndex( 0 );
 } 
 bool ParameterChoose::valid() {
       return true;
@@ -397,20 +434,19 @@ bool ParameterChoose::valid() {
 ///////////// ParameterSelect
 ParameterSelect::ParameterSelect( const exp_parameter& parameter, QWidget* parent ) : ParameterBase( parameter, parent ) {
    QVBoxLayout* layout = new QVBoxLayout( this );
-   layout->setAutoAdd( true );
    layout->setSpacing( 6 );
+   layout->setContentsMargins( 0, 0, 0, 0 );
    
-   new QLabel( i18n( parameter.description().utf8() ), this );
-   _combobox = new KComboBox( this );
+   layout->addWidget( new QLabel( i18n( parameter.description().toUtf8() ), this ) );
+   layout->addWidget( _combobox = new KComboBox( this ) );
    _combobox->setEditable( true );
    
-   krConfig->setGroup( "Private" );
-   QStrList lst;
-   int i = krConfig->readListEntry( "Predefined Selections", lst );
-   if ( i > 0 )
-      _combobox->insertStrList( lst );
+   KConfigGroup group( krConfig, "Private" );
+   QStringList lst = group.readEntry( "Predefined Selections", QStringList() );
+   if ( lst.size() > 0 )
+      _combobox->addItems( lst );
 
-   _combobox->setCurrentText( "*" );
+   _combobox->lineEdit()->setText( "*" );
 }
 
 QString ParameterSelect::text() {
@@ -420,7 +456,7 @@ QString ParameterSelect::preset() {
    return "*";
 } 
 void ParameterSelect::reset() {
-   _combobox->setCurrentText( "*" );
+   _combobox->lineEdit()->setText( "*" );
 } 
 bool ParameterSelect::valid() {
       return true;
@@ -429,31 +465,40 @@ bool ParameterSelect::valid() {
 ///////////// ParameterGoto
 ParameterGoto::ParameterGoto( const exp_parameter& parameter, QWidget* parent ) : ParameterBase( parameter, parent ) {
    QVBoxLayout* layout = new QVBoxLayout( this );
-   layout->setAutoAdd( true );
    layout->setSpacing( 6 );
+   layout->setContentsMargins( 0, 0, 0, 0 );
    
-   new QLabel( i18n( parameter.description().utf8() ), this );
-   QHBox * hbox = new QHBox( this );
+   layout->addWidget( new QLabel( i18n( parameter.description().toUtf8() ), this ) );
+
+   QWidget * hboxWidget = new QWidget( this );
+   QHBoxLayout * hbox = new QHBoxLayout( hboxWidget );
+
+   hbox->setContentsMargins( 0, 0, 0, 0 );
    hbox->setSpacing( 6 );
-   _lineEdit = new KLineEdit( hbox );
-   _lineEdit->setCompletionObject( new KURLCompletion( KURLCompletion::DirCompletion ) );
-   _dirButton = new QToolButton( hbox );
+   _lineEdit = new KLineEdit( hboxWidget );
+   _lineEdit->setCompletionObject( new KUrlCompletion( KUrlCompletion::DirCompletion ) );
+   hbox->addWidget( _lineEdit );
+   _dirButton = new QToolButton( hboxWidget );
+   hbox->addWidget( _dirButton );
    KIconLoader *iconLoader = new KIconLoader();
-  _dirButton->setPixmap( iconLoader->loadIcon( "fileopen", KIcon::Toolbar, 16 ) );
+  _dirButton->setIcon( iconLoader->loadIcon( "document-open", KIconLoader::Toolbar, 16 ) );
    connect( _dirButton, SIGNAL(clicked()), this, SLOT(setDir()) );
-   _placeholderButton = new QToolButton( hbox);
-   _placeholderButton->setText( i18n("add") );
+   _placeholderButton = new QToolButton( hboxWidget );
+   _placeholderButton->setText( i18n("list-add") );
+   hbox->addWidget( _placeholderButton );
    connect( _placeholderButton, SIGNAL(clicked()), this, SLOT(addPlaceholder()) );
+
+   layout->addWidget( hboxWidget );
 }
 
 QString ParameterGoto::text() {
    return _lineEdit->text();
 }
 QString ParameterGoto::preset() {
-   return QString::null;
+   return QString();
 } 
 void ParameterGoto::reset() {
-   _lineEdit->setText( QString::null );
+   _lineEdit->setText( QString() );
 } 
 bool ParameterGoto::valid() {
    if ( _lineEdit->text().isEmpty() )
@@ -462,7 +507,7 @@ bool ParameterGoto::valid() {
       return true;
 } 
 void ParameterGoto::setDir() {
-   QString folder = KFileDialog::getExistingDirectory(QString::null, this);
+   QString folder = KFileDialog::getExistingDirectory(QString(), this);
    _lineEdit->setText( folder );
 }
 void ParameterGoto::addPlaceholder() {
@@ -475,23 +520,23 @@ void ParameterGoto::addPlaceholder() {
 ///////////// ParameterSyncprofile
 ParameterSyncprofile::ParameterSyncprofile( const exp_parameter& parameter, QWidget* parent ) : ParameterBase( parameter, parent ) {
    QVBoxLayout* layout = new QVBoxLayout( this );
-   layout->setAutoAdd( true );
    layout->setSpacing( 6 );
+   layout->setContentsMargins( 0, 0, 0, 0 );
    
-   new QLabel( i18n( parameter.description().utf8() ), this );
-   _combobox = new KComboBox( this );
+   layout->addWidget( new QLabel( i18n( parameter.description().toUtf8() ), this ) );
+   layout->addWidget( _combobox = new KComboBox( this ) );
    
-   _combobox->insertStringList( ProfileManager::availableProfiles("SynchronizerProfile") );
+   _combobox->addItems( ProfileManager::availableProfiles("SynchronizerProfile") );
 }
 
 QString ParameterSyncprofile::text() {
    return _combobox->currentText();
 } 
 QString ParameterSyncprofile::preset() {
-   return _combobox->text( 0 );
+   return _combobox->itemText( 0 );
 } 
 void ParameterSyncprofile::reset() {
-   _combobox->setCurrentItem( 0 );
+   _combobox->setCurrentIndex( 0 );
 } 
 bool ParameterSyncprofile::valid() {
       return true;
@@ -500,23 +545,23 @@ bool ParameterSyncprofile::valid() {
 ///////////// ParameterSearch
 ParameterSearch::ParameterSearch( const exp_parameter& parameter, QWidget* parent ) : ParameterBase( parameter, parent ) {
    QVBoxLayout* layout = new QVBoxLayout( this );
-   layout->setAutoAdd( true );
    layout->setSpacing( 6 );
+   layout->setContentsMargins( 0, 0, 0, 0 );
    
-   new QLabel( i18n( parameter.description().utf8() ), this );
-   _combobox = new KComboBox( this );
+   layout->addWidget( new QLabel( i18n( parameter.description().toUtf8() ), this ) );
+   layout->addWidget( _combobox = new KComboBox( this ) );
    
-   _combobox->insertStringList( ProfileManager::availableProfiles("SearcherProfile") );
+   _combobox->addItems( ProfileManager::availableProfiles("SearcherProfile") );
 }
 
 QString ParameterSearch::text() {
    return _combobox->currentText();
 } 
 QString ParameterSearch::preset() {
-   return _combobox->text( 0 );
+   return _combobox->itemText( 0 );
 } 
 void ParameterSearch::reset() {
-   _combobox->setCurrentItem( 0 );
+   _combobox->setCurrentIndex( 0 );
 } 
 bool ParameterSearch::valid() {
       return true;
@@ -525,23 +570,23 @@ bool ParameterSearch::valid() {
 ///////////// ParameterPanelprofile
 ParameterPanelprofile::ParameterPanelprofile( const exp_parameter& parameter, QWidget* parent ) : ParameterBase( parameter, parent ) {
    QVBoxLayout* layout = new QVBoxLayout( this );
-   layout->setAutoAdd( true );
    layout->setSpacing( 6 );
+   layout->setContentsMargins( 0, 0, 0, 0 );
    
-   new QLabel( i18n( parameter.description().utf8() ), this );
-   _combobox = new KComboBox( this );
+   layout->addWidget( new QLabel( i18n( parameter.description().toUtf8() ), this ) );
+   layout->addWidget( _combobox = new KComboBox( this ) );
    
-   _combobox->insertStringList( ProfileManager::availableProfiles("Panel") );
+   _combobox->addItems( ProfileManager::availableProfiles("Panel") );
 }
 
 QString ParameterPanelprofile::text() {
    return _combobox->currentText();
 } 
 QString ParameterPanelprofile::preset() {
-   return _combobox->text( 0 );
+   return _combobox->itemText( 0 );
 } 
 void ParameterPanelprofile::reset() {
-   _combobox->setCurrentItem( 0 );
+   _combobox->setCurrentIndex( 0 );
 } 
 bool ParameterPanelprofile::valid() {
       return true;
@@ -550,16 +595,16 @@ bool ParameterPanelprofile::valid() {
 ///////////// ParameterInt
 ParameterInt::ParameterInt( const exp_parameter& parameter, QWidget* parent ) : ParameterBase( parameter, parent ) {
    QHBoxLayout* layout = new QHBoxLayout( this );
-   layout->setAutoAdd( true );
    layout->setSpacing( 6 );
+   layout->setContentsMargins( 0, 0, 0, 0 );
    
-   new QLabel( i18n( parameter.description().utf8() ), this );
-   _spinbox = new KIntSpinBox( this );
-   QStringList para = QStringList::split( ";", parameter.preset().section(":", 1) );
+   layout->addWidget( new QLabel( i18n( parameter.description().toUtf8() ), this ) );
+   layout->addWidget( _spinbox = new KIntSpinBox( this ) );
+   QStringList para = parameter.preset().section(":", 1).split( ";" );
    
-   _spinbox->setMinValue( para[0].toInt() );
-   _spinbox->setMaxValue( para[1].toInt() );
-   _spinbox->setLineStep( para[2].toInt() );
+   _spinbox->setMinimum( para[0].toInt() );
+   _spinbox->setMaximum( para[1].toInt() );
+   _spinbox->setSingleStep( para[2].toInt() );
    _spinbox->setValue( para[3].toInt() );
    
    _default = _spinbox->value();
