@@ -2,7 +2,7 @@
 #define KRBOOKMARK_H
 
 #include <kaction.h>
-#include <qptrlist.h>
+#include <qlist.h>
 #include <kurl.h>
 
 class KActionCollection;
@@ -10,15 +10,17 @@ class KActionCollection;
 class KrBookmark: public KAction {
 	Q_OBJECT
 public:
-	KrBookmark(QString name, KURL url, KActionCollection *parent, QString icon = "", QString actionName = QString::null );
+	KrBookmark(QString name, KUrl url, KActionCollection *parent, QString icon = "", QString actionName = QString() );
 	KrBookmark(QString name, QString icon = ""); // creates a folder
+	~KrBookmark();
 	// text() and setText() to change the name of the bookmark
-	// icon() and setIcon() to change icons (by name)
-	inline const KURL& url() const { return _url; }
-	inline void setURL(const KURL& url) { _url = url; }
+	// icon() and setIcon() to change icons
+	inline const QString& iconName() const { return _icon; }
+	inline const KUrl& url() const { return _url; }
+	inline void setURL(const KUrl& url) { _url = url; }
 	inline bool isFolder() const { return _folder; }
 	inline bool isSeparator() const { return _separator; }
-	QPtrList<KrBookmark>& children() { return _children; }
+	QList<KrBookmark *>& children() { return _children; }
 
 	static KrBookmark* getExistingBookmark(QString actionName, KActionCollection *collection);	
 	// ----- special bookmarks
@@ -28,18 +30,19 @@ public:
 	static KrBookmark* separator();
 
 signals:
-	void activated(const KURL& url);
+	void activated(const KUrl& url);
 
 protected slots:
 	void activatedProxy();
 	
 	
 private:
-	KURL _url;
+	KUrl _url;
 	QString _icon;
 	bool _folder;
 	bool _separator;
-	QPtrList<KrBookmark> _children;
+	bool _autoDelete;
+	QList<KrBookmark *> _children;
 };
 
 #endif // KRBOOKMARK_H
