@@ -6,7 +6,9 @@
 #include "../VFS/vfs.h"
 #include <kiconloader.h>
 #include <kmessagebox.h>
-#include <qptrlist.h>
+#include <qtextstream.h>
+#include <QMouseEvent>
+#include <QEvent>
 #include <kactioncollection.h>
 #include <klocale.h>
 #include <kdebug.h>
@@ -19,23 +21,21 @@
 
 // ------------------------ for internal use
 #define BOOKMARKS_FILE	"krusader/krbookmarks.xml"
-#define CONNECT_BM(X)	{ disconnect(X, SIGNAL(activated(const KURL&)), 0, 0); connect(X, SIGNAL(activated(const KURL&)), this, SLOT(slotActivated(const KURL&))); }
+#define CONNECT_BM(X)	{ disconnect(X, SIGNAL(activated(const KUrl&)), 0, 0); connect(X, SIGNAL(activated(const KUrl&)), this, SLOT(slotActivated(const KUrl&))); }
 											
-KrBookmarkHandler::KrBookmarkHandler(): QObject(0), _middleClick(false), _mainBookmarkPopup( 0 ), _specialBookmarkIDs(), _bookmarkIDTable() {
+KrBookmarkHandler::KrBookmarkHandler(): QObject(0), _middleClick(false), _mainBookmarkPopup( 0 ), _specialBookmarks() {
 	// create our own action collection and make the shortcuts apply only to parent
-	_privateCollection = new KActionCollection(krApp, "private collection");
+	_privateCollection = new KActionCollection((QObject *)krApp);
 	_collection = krApp->actionCollection();
 
 	// create _root: father of all bookmarks. it is a dummy bookmark and never shown
 	_root = new KrBookmark(i18n("Bookmarks"));
 	
-	_bookmarkIDTable.setAutoDelete( true );
-	
 	// load bookmarks 
 	importFromFile();
 
 	// hack
-	manager = KBookmarkManager::managerForFile(locateLocal( "data", BOOKMARKS_FILE ), false);
+	manager = KBookmarkManager::managerForFile(KStandardDirs::locateLocal( "data", BOOKMARKS_FILE ), "krusader");
 	connect(manager, SIGNAL(changed(const QString&, const QString& )), this, SLOT(bookmarksChanged(const QString&, const QString& )));
 }
 
@@ -44,18 +44,11 @@ KrBookmarkHandler::~KrBookmarkHandler() {
 	delete _privateCollection;
 }
 
-void KrBookmarkHandler::menuOperation(int id) {
-	switch (id) {
-		case BookmarkCurrent:
-			bookmarkCurrent(ACTIVE_PANEL->virtualPath());
-			break;
-		case ManageBookmarks:
-			manager->slotEditBookmarks();
-			break;
-	}
+void KrBookmarkHandler::slotBookmarkCurrent() {
+	bookmarkCurrent(ACTIVE_PANEL->virtualPath());
 }
 
-void KrBookmarkHandler::bookmarkCurrent(KURL url) {
+void KrBookmarkHandler::bookmarkCurrent(KUrl url) {
 	KrAddBookmarkDlg dlg(krApp, url);
 	if (dlg.exec() == KDialog::Accepted) {
 		KrBookmark *bm = new KrBookmark(dlg.name(), dlg.url(), _collection);
@@ -77,22 +70,24 @@ void KrBookmarkHandler::deleteBookmark(KrBookmark *bm) {
 	if( bm->isFolder() )
 		clearBookmarks( bm ); // remove the child bookmarks
 	removeReferences( _root, bm );
-	bm->unplugAll();
+	foreach (QWidget *w, bm->associatedWidgets())
+		w->removeAction(bm);
 	delete bm;
 	
 	exportToFile();
 }
 
 void KrBookmarkHandler::removeReferences( KrBookmark *root, KrBookmark *bmToRemove ) {
-	int index = root->children().find( bmToRemove );
+	int index = root->children().indexOf( bmToRemove );
 	if( index >= 0 )
-		root->children().take( index );
+		root->children().removeAt( index );
 	
-	KrBookmark *bm = root->children().first();
-	while (bm) {
+	QListIterator<KrBookmark *> it( root->children() );
+	while (it.hasNext())
+	{
+		KrBookmark *bm = it.next();
 		if (bm->isFolder())
 			removeReferences(bm, bmToRemove);
-		bm = root->children().next();
 	}
 }
 
@@ -104,9 +99,9 @@ void KrBookmarkHandler::exportToFileBookmark(QDomDocument &doc, QDomElement &whe
 	else {
 		QDomElement bookmark = doc.createElement("bookmark");
 		// url
-		bookmark.setAttribute("href", bm->url().prettyURL());
+		bookmark.setAttribute("href", bm->url().prettyUrl());
 		// icon
-		bookmark.setAttribute("icon", bm->icon());
+		bookmark.setAttribute("icon", bm->iconName());
 		// title
 		QDomElement title = doc.createElement("title");	
 		title.appendChild(doc.createTextNode(bm->text()));
@@ -117,10 +112,14 @@ void KrBookmarkHandler::exportToFileBookmark(QDomDocument &doc, QDomElement &whe
 }
 
 void KrBookmarkHandler::exportToFileFolder(QDomDocument &doc, QDomElement &parent, KrBookmark *folder) {
-	for (KrBookmark *bm = folder->children().first(); bm; bm = folder->children().next()) {
+	QListIterator<KrBookmark *> it(folder->children());
+	while (it.hasNext())
+	{
+		KrBookmark *bm = it.next();
+		
 		if (bm->isFolder()) {
 			QDomElement newFolder = doc.createElement("folder");
-			newFolder.setAttribute("icon", bm->icon());
+			newFolder.setAttribute("icon", bm->iconName());
 			parent.appendChild(newFolder);
 			QDomElement title = doc.createElement("title");
 			title.appendChild(doc.createTextNode(bm->text()));
@@ -161,15 +160,15 @@ void KrBookmarkHandler::exportToFile() {
 	}
 
 	
-	QString filename = locateLocal( "data", BOOKMARKS_FILE );
+	QString filename = KStandardDirs::locateLocal( "data", BOOKMARKS_FILE );
 	QFile file(filename);
-	if ( file.open( IO_WriteOnly ) ) {
+	if ( file.open( QIODevice::WriteOnly ) ) {
 		QTextStream stream( &file );
-		stream.setEncoding(stream.UnicodeUTF8);
+		stream.setCodec( "UTF-8" );
 		stream << doc.toString();
 		file.close();
 	} else {
-		KMessageBox::error(krApp, i18n("Unable to write to %1").arg(filename), i18n("Error"));
+		KMessageBox::error(krApp, i18n("Unable to write to %1", filename), i18n("Error"));
 	}
 }
 
@@ -198,7 +197,7 @@ bool KrBookmarkHandler::importFromFileBookmark(QDomElement &e, KrBookmark *paren
 	// ok: got name and url, let's add a bookmark
 	KrBookmark *bm = KrBookmark::getExistingBookmark(path+name, _collection);
 	if (!bm) {
-		bm = new KrBookmark(name, vfs::fromPathOrURL( url ), _collection, icon, path+name);
+		bm = new KrBookmark(name, KUrl( url ), _collection, icon, path+name);
 	parent->children().append(bm);
 	}
 
@@ -240,9 +239,9 @@ bool KrBookmarkHandler::importFromFileFolder(QDomNode &first, KrBookmark *parent
 void KrBookmarkHandler::importFromFile() {
 	clearBookmarks(_root);
 	
-	QString filename = locateLocal( "data", BOOKMARKS_FILE );
+	QString filename = KStandardDirs::locateLocal( "data", BOOKMARKS_FILE );
 	QFile file( filename );
-	if ( !file.open(IO_ReadOnly))
+	if ( !file.open(QIODevice::ReadOnly))
 		return; // no bookmarks file
 
 	QString errorMsg;
@@ -258,171 +257,174 @@ void KrBookmarkHandler::importFromFile() {
 		n = n.nextSibling();
 
 	if (n.isNull() || n.toElement().tagName()!="xbel") {
-		errorMsg = i18n("%1 doesn't seem to be a valid Bookmarks file").arg(filename);
+		errorMsg = i18n("%1 doesn't seem to be a valid Bookmarks file", filename);
 		goto ERROR;
 	} else n = n.firstChild(); // skip the xbel part
 	importFromFileFolder(n, _root, "", &errorMsg);
 	goto SUCCESS;
 	
 ERROR:
-	KMessageBox::error(krApp, i18n("Error reading bookmarks file: %1").arg(errorMsg), i18n( "Error" ));
+	KMessageBox::error(krApp, i18n("Error reading bookmarks file: %1", errorMsg), i18n( "Error" ));
 
 SUCCESS:
 	file.close();
 }
 
-void KrBookmarkHandler::populate(KPopupMenu *menu) {
+void KrBookmarkHandler::populate(KMenu *menu) {
 	_mainBookmarkPopup = menu;
 	menu->clear();
-	_bookmarkIDTable.clear();
-	_specialBookmarkIDs.clear();
+	_specialBookmarks.clear();
 	buildMenu(_root, menu);
 }
 
-void KrBookmarkHandler::buildMenu(KrBookmark *parent, KPopupMenu *menu) {
+void KrBookmarkHandler::buildMenu(KrBookmark *parent, KMenu *menu) {
 	static int inSecondaryMenu = 0; // used to know if we're on the top menu
 
 	// run the loop twice, in order to put the folders on top. stupid but easy :-)
 	// note: this code drops the separators put there by the user
-	for (KrBookmark *bm = parent->children().first(); bm; bm = parent->children().next()) {
-		if (!bm->isFolder()) continue;
-		KPopupMenu *newMenu = new KPopupMenu(menu);
-		int id = menu->insertItem(QIconSet(krLoader->loadIcon(bm->icon(), KIcon::Small)),
-									bm->text(), newMenu, -1 /* dummy id */, -1 /* end of list */);
+	QListIterator<KrBookmark *> it( parent->children() );
+	while (it.hasNext())
+	{
+		KrBookmark *bm = it.next();
 		
-		if( !_bookmarkIDTable.find( menu ) )
-			_bookmarkIDTable.insert( menu, new QMap<int, KrBookmark *> );
-		(*_bookmarkIDTable[ menu ])[ id ] = bm;
+		if (!bm->isFolder()) continue;
+		KMenu *newMenu = new KMenu(menu);
+		newMenu->setIcon( QIcon(krLoader->loadIcon(bm->iconName(), KIconLoader::Small)) );
+		newMenu->setTitle( bm->text() );
+		QAction *menuAction = menu->addMenu( newMenu );
+		QVariant v;
+		v.setValue<KrBookmark *>( bm );
+		menuAction->setData( v );
 		
 		++inSecondaryMenu;
 		buildMenu(bm, newMenu);
 		--inSecondaryMenu;
 	}
-	for (KrBookmark *bm = parent->children().first(); bm; bm = parent->children().next()) {
+	
+	it.toFront();
+	while (it.hasNext())
+	{
+		KrBookmark *bm = it.next();
 		if (bm->isFolder()) continue;
 		if (bm->isSeparator() ) {
-			menu->insertSeparator();
+			menu->addSeparator();
 			continue;
 		}
-		int itemIndex = bm->plug(menu, -1 /* end of list */);
+		menu->addAction( bm );
 		CONNECT_BM(bm);
-		
-		int id = bm->itemId( itemIndex );
-		if( !_bookmarkIDTable.find( menu ) )
-			_bookmarkIDTable.insert( menu, new QMap<int, KrBookmark *> );
-		(*_bookmarkIDTable[ menu ])[ id ] = bm;
 	}
 
 	if (!inSecondaryMenu) {
-		krConfig->setGroup( "Private" );
-		bool hasPopularURLs = krConfig->readBoolEntry( "BM Popular URLs", true );
-		bool hasDevices     = krConfig->readBoolEntry( "BM Devices",      true );
-		bool hasLan         = krConfig->readBoolEntry( "BM Lan",          true );
-		bool hasVirtualFS   = krConfig->readBoolEntry( "BM Virtual FS",   true );
-		bool hasJumpback    = krConfig->readBoolEntry( "BM Jumpback",     true );
-		
-		int itemIndex;
+		KConfigGroup group( krConfig, "Private" );
+		bool hasPopularURLs = group.readEntry( "BM Popular URLs", true );
+		bool hasDevices     = group.readEntry( "BM Devices",      true );
+		bool hasLan         = group.readEntry( "BM Lan",          true );
+		bool hasVirtualFS   = group.readEntry( "BM Virtual FS",   true );
+		bool hasJumpback    = group.readEntry( "BM Jumpback",     true );
 		
 		if( hasPopularURLs ) {
-			menu->insertSeparator();
+			menu->addSeparator();
 			
 			// add the popular links submenu
-			KPopupMenu *newMenu = new KPopupMenu(menu);
-			itemIndex = menu->insertItem(QIconSet(krLoader->loadIcon("bookmark_folder", KIcon::Small)),
-										i18n("Popular URLs"), newMenu, -1 /* dummy id */, -1 /* end of list */);
-			_specialBookmarkIDs.append( itemIndex );
+			KMenu *newMenu = new KMenu(menu);
+			newMenu->setTitle( i18n("Popular URLs") );
+			newMenu->setIcon( QIcon(krLoader->loadIcon("folder-bookmarks", KIconLoader::Small)) );
+			QAction *bmfAct  = menu->addMenu( newMenu );
+			_specialBookmarks.append( bmfAct );
 			// add the top 15 urls
 			#define MAX 15
-			KURL::List list = krApp->popularUrls->getMostPopularUrls(MAX);
-			KURL::List::Iterator it;
+			KUrl::List list = krApp->popularUrls->getMostPopularUrls(MAX);
+			KUrl::List::Iterator it;
 			for (it = list.begin(); it != list.end(); ++it) {
 				QString name;
 				if ((*it).isLocalFile()) name = (*it).path();
-				else name = (*it).prettyURL();
+				else name = (*it).prettyUrl();
 				// note: these bookmark are put into the private collection
 				// as to not spam the general collection
 				KrBookmark *bm = KrBookmark::getExistingBookmark(name, _privateCollection);
 				if (!bm)
 					bm = new KrBookmark(name, *it, _privateCollection);
-				bm->plug(newMenu);
+				newMenu->addAction( bm );
 				CONNECT_BM(bm);
 			}
 			
-			newMenu->insertSeparator();
-			krPopularUrls->plug(newMenu);
+			newMenu->addSeparator();
+			newMenu->addAction( krPopularUrls );
 			newMenu->installEventFilter(this);
 		}
 		
 		// do we need to add special bookmarks?
 		if (SPECIAL_BOOKMARKS) {
 			if( hasDevices || hasLan || hasVirtualFS || hasJumpback )
-				menu->insertSeparator();
+				menu->addSeparator();
 			
 			KrBookmark *bm;
 			
 			// note: special bookmarks are not kept inside the _bookmarks list and added ad-hoc
 			if( hasDevices ) {
 				bm = KrBookmark::devices(_collection);
-				itemIndex = bm->plug(menu);
-				_specialBookmarkIDs.append( bm->itemId( itemIndex ) );
+				menu->addAction(bm);
+				_specialBookmarks.append( bm );
 				CONNECT_BM(bm);
 			}
 			
 			if( hasLan ) {
 				bm = KrBookmark::lan(_collection);
-				itemIndex = bm->plug(menu);
-				_specialBookmarkIDs.append( bm->itemId( itemIndex ) );
+				menu->addAction(bm);
+				_specialBookmarks.append( bm );
 				CONNECT_BM(bm);
 			}
 			
 			if( hasVirtualFS ) {
 				bm = KrBookmark::virt(_collection);
-				itemIndex = bm->plug(menu);
-				_specialBookmarkIDs.append( bm->itemId( itemIndex ) );
+				menu->addAction(bm);
+				_specialBookmarks.append( bm );
 				CONNECT_BM(bm);
 			}
 			
 			if( hasJumpback ) {
 				// add the jump-back button
-				itemIndex = krJumpBack->plug(menu);
-				_specialBookmarkIDs.append( krJumpBack->itemId( itemIndex ) );
-				menu->insertSeparator();
-				itemIndex = krSetJumpBack->plug(menu);
-				_specialBookmarkIDs.append( krSetJumpBack->itemId( itemIndex ) );
+				menu->addAction(krJumpBack);
+				_specialBookmarks.append( krJumpBack );
+				menu->addSeparator();
+				menu->addAction(krSetJumpBack);
+				_specialBookmarks.append( krSetJumpBack );
 			}
 		} 
 		
 		if( !hasJumpback )
-			menu->insertSeparator();
+			menu->addSeparator();
 		
-		itemIndex = menu->insertItem(krLoader->loadIcon("bookmark_add", KIcon::Small),
-			i18n("Bookmark Current"), BookmarkCurrent);
-		_specialBookmarkIDs.append( itemIndex );
-		itemIndex = menu->insertItem(krLoader->loadIcon("bookmark", KIcon::Small),
-			i18n("Manage Bookmarks"), ManageBookmarks);
-		_specialBookmarkIDs.append( itemIndex );
+		QAction *bmAddAct = menu->addAction(krLoader->loadIcon("bookmark-new", KIconLoader::Small),
+			i18n("Bookmark Current"), this, SLOT( slotBookmarkCurrent() ) );
+		_specialBookmarks.append( bmAddAct );
+		QAction *bmAct = menu->addAction(krLoader->loadIcon("bookmark", KIconLoader::Small),
+			i18n("Manage Bookmarks"), manager, SLOT( slotEditBookmarks() ) );
+		_specialBookmarks.append( bmAct );
 	
 		// make sure the menu is connected to us
-		disconnect(menu, SIGNAL(activated(int)), 0, 0);
-		connect(menu, SIGNAL(activated(int)), this, SLOT(menuOperation(int)));
+		disconnect(menu, SIGNAL(triggered(QAction *)), 0, 0);
 	}
 
 	menu->installEventFilter(this);
 }
 
 void KrBookmarkHandler::clearBookmarks(KrBookmark *root) {
-	KrBookmark *bm = root->children().first();
-	while (bm) {	
+	QList<KrBookmark *>::iterator it = root->children().begin();
+	while ( it != root->children().end() )
+	{
+		KrBookmark *bm = *it;
+		
 		if (bm->isFolder())
 			clearBookmarks(bm);
 		else {
-			bm->unplugAll();
+			foreach (QWidget *w, bm->associatedWidgets())
+				w->removeAction(bm);
 			delete bm;
 		}
-
-		bm = root->children().next();
+		
+		it = root->children().erase( it );
 	}
-	root->children().clear();
 }
 
 void KrBookmarkHandler::bookmarksChanged(const QString&, const QString&) {
@@ -432,29 +434,30 @@ void KrBookmarkHandler::bookmarksChanged(const QString&, const QString&) {
 bool KrBookmarkHandler::eventFilter( QObject *obj, QEvent *ev ) {
 	if (ev->type() == QEvent::MouseButtonRelease) {
 		switch (static_cast<QMouseEvent*>(ev)->button()) {
-			case RightButton:
+			case Qt::RightButton:
 				_middleClick = false;
-				if( obj->inherits( "QPopupMenu" ) ) {
-					int id = static_cast<QPopupMenu*>(obj)->idAt( static_cast<QMouseEvent*>(ev)->pos() );
+				if( obj->inherits( "QMenu" ) ) {
+					QMenu * menu = static_cast<QMenu*>(obj);
+					QAction * act = menu->actionAt( static_cast<QMouseEvent*>(ev)->pos() );
 					
-					if( obj == _mainBookmarkPopup && _specialBookmarkIDs.contains( id ) ) {
+					if( obj == _mainBookmarkPopup && _specialBookmarks.contains( act ) ) {
 						rightClickOnSpecialBookmark();
 						return true;
 					}
 					
-					if( _bookmarkIDTable.find( obj ) ) {
-						QMap<int, KrBookmark*> * table = _bookmarkIDTable[ obj ];
-						if( table && table->count( id ) ) {
-							KrBookmark *bm = (*table)[ id ];
-							rightClicked( static_cast<QPopupMenu*>(obj), id, bm );
-							return true;
-						}
+					KrBookmark * bm = dynamic_cast<KrBookmark*>( act );
+					if( bm != 0 ) {
+						rightClicked( menu, bm );
+						return true;
+					} else if( act && act->data().canConvert<KrBookmark *>() ){
+						KrBookmark * bm = act->data().value<KrBookmark *> ();
+						rightClicked( menu, bm );
 					}
 				}
-			case LeftButton:
+			case Qt::LeftButton:
 				_middleClick = false;
 				break;
-			case MidButton:
+			case Qt::MidButton:
 				_middleClick = true;
 				break;
 			default:
@@ -471,51 +474,64 @@ bool KrBookmarkHandler::eventFilter( QObject *obj, QEvent *ev ) {
 #define JUMP_BACK_ID           100104
 
 void KrBookmarkHandler::rightClickOnSpecialBookmark() {
-	krConfig->setGroup( "Private" );
-	bool hasPopularURLs = krConfig->readBoolEntry( "BM Popular URLs", true );
-	bool hasDevices     = krConfig->readBoolEntry( "BM Devices",      true );
-	bool hasLan         = krConfig->readBoolEntry( "BM Lan",          true );
-	bool hasVirtualFS   = krConfig->readBoolEntry( "BM Virtual FS",   true );
-	bool hasJumpback    = krConfig->readBoolEntry( "BM Jumpback",     true );
+	KConfigGroup group( krConfig, "Private" );
+	bool hasPopularURLs = group.readEntry( "BM Popular URLs", true );
+	bool hasDevices     = group.readEntry( "BM Devices",      true );
+	bool hasLan         = group.readEntry( "BM Lan",          true );
+	bool hasVirtualFS   = group.readEntry( "BM Virtual FS",   true );
+	bool hasJumpback    = group.readEntry( "BM Jumpback",     true );
 	
-	QPopupMenu menu( _mainBookmarkPopup );
-	menu.setCaption( i18n( "Enable special bookmarks" ) );
-	menu.setCheckable( true );
+	QMenu menu( _mainBookmarkPopup );
+	menu.setTitle( i18n( "Enable special bookmarks" ) );
 	
-	menu.insertItem( i18n( "Popular URLs" ), POPULAR_URLS_ID );
-	menu.setItemChecked( POPULAR_URLS_ID, hasPopularURLs );
-	menu.insertItem( i18n( "Devices" ), DEVICES_ID );
-	menu.setItemChecked( DEVICES_ID, hasDevices );
-	menu.insertItem( i18n( "Local Network" ), LAN_ID );
-	menu.setItemChecked( LAN_ID, hasLan );
-	menu.insertItem( i18n( "Virtual Filesystem" ), VIRTUAL_FS_ID );
-	menu.setItemChecked( VIRTUAL_FS_ID, hasVirtualFS );
-	menu.insertItem( i18n( "Jump back" ), JUMP_BACK_ID );
-	menu.setItemChecked( JUMP_BACK_ID, hasJumpback );
+	QAction *act;
+	
+	act = menu.addAction( i18n( "Popular URLs" ) );
+	act->setData( QVariant( POPULAR_URLS_ID ) );
+	act->setCheckable( true );
+	act->setChecked( hasPopularURLs );
+	act = menu.addAction( i18n( "Devices" ) );
+	act->setData( QVariant( DEVICES_ID ) );
+	act->setCheckable( true );
+	act->setChecked( hasDevices );
+	act = menu.addAction( i18n( "Local Network" ) );
+	act->setData( QVariant( LAN_ID ) );
+	act->setCheckable( true );
+	act->setChecked( hasLan );
+	act = menu.addAction( i18n( "Virtual Filesystem" ) );
+	act->setData( QVariant( VIRTUAL_FS_ID ) );
+	act->setCheckable( true );
+	act->setChecked( hasVirtualFS );
+	act = menu.addAction( i18n( "Jump back" ) );
+	act->setData( QVariant( JUMP_BACK_ID ) );
+	act->setCheckable( true );
+	act->setChecked( hasJumpback );
 	
 	connect( _mainBookmarkPopup, SIGNAL( highlighted( int ) ), &menu, SLOT( close() ) );
 	connect( _mainBookmarkPopup, SIGNAL( activated( int ) ), &menu, SLOT( close() ) );
 	
-	int result = menu.exec( QCursor::pos() );
-	bool doCloseMain = true;
+	int result = -1;
+	QAction *res = menu.exec( QCursor::pos() );
+	if( res && res->data().canConvert<int>() )
+		result = res->data().toInt();
 	
-	krConfig->setGroup( "Private" );
+	bool doCloseMain = true;
 	
 	switch( result ) {
 	case POPULAR_URLS_ID:
-		krConfig->writeEntry( "BM Popular URLs", !hasPopularURLs );
+		group.writeEntry( "BM Popular URLs", !hasPopularURLs );
 		break;
 	case DEVICES_ID:
-		krConfig->writeEntry( "BM Devices", !hasDevices );
+		group.writeEntry( "BM Devices", !hasDevices );
 		break;
 	case LAN_ID:
-		krConfig->writeEntry( "BM Lan", !hasLan );
+		group.writeEntry( "BM Lan", !hasLan );
 		break;
 	case VIRTUAL_FS_ID:
-		krConfig->writeEntry( "BM Virtual FS", !hasVirtualFS );
+		group.writeEntry( "BM Virtual FS", !hasVirtualFS );
 		break;
 	case JUMP_BACK_ID:
-		krConfig->writeEntry( "BM Jumpback", !hasJumpback );
+		group.writeEntry( "BM Jumpback", !hasJumpback );
 		break;
 	default:
 		doCloseMain = false;
@@ -532,18 +548,28 @@ void KrBookmarkHandler::rightClickOnSpecialBookmark() {
 #define OPEN_NEW_TAB_ID   100201
 #define DELETE_ID         100202
 
-void KrBookmarkHandler::rightClicked( QPopupMenu *menu, int /*id*/, KrBookmark * bm ) {
-	QPopupMenu popup( _mainBookmarkPopup );
+void KrBookmarkHandler::rightClicked( QMenu *menu, KrBookmark * bm ) {
+	QMenu popup( _mainBookmarkPopup );
+	QAction * act;
 	
-	popup.insertItem( krLoader->loadIcon( "fileopen", KIcon::Panel ), i18n( "Open" ), OPEN_ID );
-	popup.insertItem( krLoader->loadIcon( "tab_new", KIcon::Panel ), i18n( "Open in a new tab" ), OPEN_NEW_TAB_ID );
-	popup.insertSeparator();
-	popup.insertItem( krLoader->loadIcon( "editdelete", KIcon::Panel ), i18n( "Delete" ), DELETE_ID );
+	if( !bm->isFolder() )
+	{
+		act = popup.addAction( krLoader->loadIcon( "document-open", KIconLoader::Panel ), i18n( "Open" ));
+		act->setData( QVariant( OPEN_ID ) );
+		act = popup.addAction( krLoader->loadIcon( "tab-new", KIconLoader::Panel ), i18n( "Open in a new tab" ) );
+		act->setData( QVariant( OPEN_NEW_TAB_ID ) );
+		popup.addSeparator();
+	}
+	act = popup.addAction( krLoader->loadIcon( "edit-delete", KIconLoader::Panel ), i18n( "Delete" ) );
+	act->setData( QVariant( DELETE_ID ) );
 	
 	connect( menu, SIGNAL( highlighted( int ) ), &popup, SLOT( close() ) );
 	connect( menu, SIGNAL( activated( int ) ), &popup, SLOT( close() ) );
 	
-	int result = popup.exec( QCursor::pos() );
+	int result = -1;
+	QAction *res = popup.exec( QCursor::pos() );
+	if( res && res->data().canConvert<int> () )
+		result = res->data().toInt();
 	
 	popup.close();
 	if( _mainBookmarkPopup && result >= OPEN_ID && result <= DELETE_ID ) {
@@ -566,7 +592,9 @@ void KrBookmarkHandler::rightClicked( QPopupMenu *menu, int /*id*/, KrBookmark *
 // used to monitor middle clicks. if mid is found, then the
 // bookmark is opened in a new tab. ugly, but easier than overloading
 // KAction and KActionCollection.
-void KrBookmarkHandler::slotActivated(const KURL& url) {
+void KrBookmarkHandler::slotActivated(const KUrl& url) {
+	if( _mainBookmarkPopup && !_mainBookmarkPopup->isHidden() )
+		_mainBookmarkPopup->close();
 	if (_middleClick)
 		SLOTS->newTab(url);
 	else SLOTS->refresh(url);
