@@ -3,11 +3,10 @@
 
 #include "krbookmark.h"
 #include <qobject.h>
-#include <qguardedptr.h>
-#include <kpopupmenu.h>
+#include <qpointer.h>
+#include <QEvent>
+#include <kmenu.h>
 #include <kurl.h>
-#include <qptrdict.h>
-#include <qvaluelist.h>
 #include <qdom.h>
 #include <qmap.h>
 
@@ -21,9 +20,9 @@ class KrBookmarkHandler: public QObject {
 public:
 	KrBookmarkHandler();
 	~KrBookmarkHandler();
-	void populate(KPopupMenu *menu);
+	void populate(KMenu *menu);
 	void addBookmark(KrBookmark *bm, KrBookmark *parent = 0);
-	void bookmarkCurrent(KURL url);
+	void bookmarkCurrent(KUrl url);
 
 protected:
 	void deleteBookmark(KrBookmark *bm);
@@ -34,19 +33,19 @@ protected:
 	void exportToFileFolder(QDomDocument &doc, QDomElement &parent, KrBookmark *folder);
 	void exportToFileBookmark(QDomDocument &doc, QDomElement &where, KrBookmark *bm);
 	void clearBookmarks(KrBookmark *root);
-	void buildMenu(KrBookmark *parent, KPopupMenu *menu);
+	void buildMenu(KrBookmark *parent, KMenu *menu);
 
 	bool eventFilter( QObject *obj, QEvent *ev );
 	
-	void rightClicked( QPopupMenu *menu, int id, KrBookmark *bm );
+	void rightClicked( QMenu *menu, KrBookmark *bm );
 	void rightClickOnSpecialBookmark();
 	
 	void removeReferences( KrBookmark *root, KrBookmark *bmToRemove );
 	
 protected slots:
-	void menuOperation(int id);
+	void slotBookmarkCurrent();
 	void bookmarksChanged(const QString&, const QString&);
-	void slotActivated(const KURL& url);
+	void slotActivated(const KUrl& url);
 
 private:
 	KActionCollection *_collection, *_privateCollection;
@@ -55,9 +54,10 @@ private:
 	KBookmarkManager *manager;
 	bool _middleClick; // if true, the user clicked the middle button to open the bookmark
 	
-	QGuardedPtr<KPopupMenu>            _mainBookmarkPopup; // main bookmark popup menu
-	QValueList<int>                    _specialBookmarkIDs; // the ID list of the special bookmarks
-	QPtrDict<QMap<int,KrBookmark*> >   _bookmarkIDTable;    // the IDs of the bookmarks
+	QPointer<KMenu>            _mainBookmarkPopup; // main bookmark popup menu
+	QList<QAction *>           _specialBookmarks; // the action list of the special bookmarks
 };
 
+Q_DECLARE_METATYPE(KrBookmark *);
+
 #endif // KRBOOKMARK_HANDLER_H
