@@ -1,25 +1,24 @@
 #ifndef CHECKSUMDLG_H
 #define CHECKSUMDLG_H
 
-#include <kdialogbase.h>
-#include <qvaluelist.h>
+#include <kdialog.h>
 
-class KTempFile;
+class KTemporaryFile;
 extern void initChecksumModule();
 
-class CreateChecksumDlg: public KDialogBase {
+class CreateChecksumDlg: public KDialog {
 public:
 	CreateChecksumDlg(const QStringList& files, bool containFolders, const QString& path);
 
 private:
-	KTempFile *tmpOut, *tmpErr;
+	KTemporaryFile *tmpOut, *tmpErr;
 };
 
 
-class MatchChecksumDlg: public KDialogBase {
+class MatchChecksumDlg: public KDialog {
 public:
 	MatchChecksumDlg(const QStringList& files, bool containFolders, 
-		const QString& path, const QString& checksumFile=QString::null);
+		const QString& path, const QString& checksumFile=QString());
 
 	static QString checksumTypesFilter;
 
@@ -27,11 +26,11 @@ protected:
 	bool verifyChecksumFile(QString path, QString& extension);
 
 private:
-	KTempFile *tmpOut, *tmpErr;
+	KTemporaryFile *tmpOut, *tmpErr;
 };
 
 
-class ChecksumResultsDlg: public KDialogBase {
+class ChecksumResultsDlg: public KDialog {
 public:
 	ChecksumResultsDlg(const QStringList& stdOut, const QStringList& stdErr,
 		const QString& suggestedFilename, const QString& binary, const QString& type,
@@ -46,7 +45,7 @@ private:
 };
 
 
-class VerifyResultDlg: public KDialogBase {
+class VerifyResultDlg: public KDialog {
 public:
 	VerifyResultDlg(const QStringList& failed);
 };
