@@ -36,7 +36,9 @@
 #include <qwidget.h>
 #include <qapplication.h>
 #include <qfontmetrics.h>
-#include <qtooltip.h>
+#include <QFrame>
+#include <QLabel>
+#include <QVBoxLayout>
 // KDE includes
 #include <klocale.h>
 #include <kurlcompletion.h>
@@ -48,7 +50,6 @@
 #include <kdeversion.h>
 #include <qcheckbox.h>
 #include <krecentdocument.h>
-#include <qhbox.h>
 // Krusader includes
 #include "../krusader.h"
 #include "../resources.h"
@@ -56,17 +57,17 @@
 #include "../defaults.h"
 #include <qdir.h>
 
-KURL KChooseDir::getDir(QString text,const KURL& url, const KURL& cwd) {
-	KURLRequesterDlg *dlg = new KURLRequesterDlg( vfs::pathOrURL( url, 1 ),text,krApp,"");
+KUrl KChooseDir::getDir(QString text,const KUrl& url, const KUrl& cwd) {
+	KUrlRequesterDialog *dlg = new KUrlRequesterDialog( vfs::pathOrUrl( url, KUrl::AddTrailingSlash ),text,krApp);
 	dlg->urlRequester()->completionObject()->setDir(cwd.url());
-	KURL u;
+	KUrl u;
 	if (dlg->exec() == QDialog::Accepted) {
-		u = vfs::fromPathOrURL(dlg->urlRequester()->completionObject()->replacedPath(
+		u = KUrl(dlg->urlRequester()->completionObject()->replacedPath(
 			dlg->urlRequester()->lineEdit()->text()));
-		if (u.isRelativeURL(u.url())) {
-			KURL temp = u;
+		if (u.isRelativeUrl(u.url())) {
+			KUrl temp = u;
 			u = cwd;
-			u.addPath(temp.url());
+			u.addPath(temp.path());
 			u.cleanPath();
 			if( u.protocol() == "zip" || u.protocol() == "krarc" || u.protocol() == "tar" || u.protocol() == "iso" ) {
 				if( QDir( u.path() ).exists() )
@@ -78,17 +79,17 @@ KURL KChooseDir::getDir(QString text,const KURL& url, const KURL& cwd) {
 	return u;
 }
 
-KURL KChooseDir::getDir(QString text,const KURL& url, const KURL& cwd, bool &preserveAttrs ) {
-	KURLRequesterDlgForCopy *dlg = new KURLRequesterDlgForCopy( vfs::pathOrURL( url, 1 ),text, preserveAttrs, krApp,"" );
+KUrl KChooseDir::getDir(QString text,const KUrl& url, const KUrl& cwd, bool &queue, bool &preserveAttrs ) {
+	KUrlRequesterDlgForCopy *dlg = new KUrlRequesterDlgForCopy( vfs::pathOrUrl( url, KUrl::AddTrailingSlash ),text, preserveAttrs, krApp );
 	dlg->urlRequester()->completionObject()->setDir(cwd.url());
-	KURL u;
+	KUrl u;
 	if (dlg->exec() == QDialog::Accepted) {
-		u = vfs::fromPathOrURL(dlg->urlRequester()->completionObject()->replacedPath(
+		u = KUrl(dlg->urlRequester()->completionObject()->replacedPath(
 			dlg->urlRequester()->lineEdit()->text()));
-		if (u.isRelativeURL(u.url())) {
-			KURL temp = u;
+		if (u.isRelativeUrl(u.url())) {
+			KUrl temp = u;
 			u = cwd;
-			u.addPath(temp.url());
+			u.addPath(temp.path());
 			u.cleanPath();
 			if( u.protocol() == "zip" || u.protocol() == "krarc" || u.protocol() == "tar" || u.protocol() == "iso" ) {
 				if( QDir( u.path() ).exists() )
@@ -97,21 +98,22 @@ KURL KChooseDir::getDir(QString text,const KURL& url, const KURL& cwd, bool &pre
 		}
 	}
 	preserveAttrs = dlg->preserveAttrs();
+	queue = dlg->enqueue();
 	delete dlg;
 	return u;
 }
 
-KURL KChooseDir::getDir(QString text,const KURL& url, const KURL& cwd, bool &preserveAttrs, KURL &baseURL ) {
-	KURLRequesterDlgForCopy *dlg = new KURLRequesterDlgForCopy( vfs::pathOrURL( url, 1 ),text, preserveAttrs, krApp,"", true, baseURL );
+KUrl KChooseDir::getDir(QString text,const KUrl& url, const KUrl& cwd, bool &queue, bool &preserveAttrs, KUrl &baseURL ) {
+	KUrlRequesterDlgForCopy *dlg = new KUrlRequesterDlgForCopy( vfs::pathOrUrl( url, KUrl::AddTrailingSlash ),text, preserveAttrs, krApp, true, baseURL );
 	dlg->urlRequester()->completionObject()->setDir(cwd.url());
-	KURL u;
+	KUrl u;
 	if (dlg->exec() == QDialog::Accepted) {
-		u = vfs::fromPathOrURL(dlg->urlRequester()->completionObject()->replacedPath(
+		u = KUrl(dlg->urlRequester()->completionObject()->replacedPath(
 			dlg->urlRequester()->lineEdit()->text()));
-		if (u.isRelativeURL(u.url())) {
-			KURL temp = u;
+		if (u.isRelativeUrl(u.url())) {
+			KUrl temp = u;
 			u = cwd;
-			u.addPath(temp.url());
+			u.addPath(temp.path());
 			u.cleanPath();
 			if( u.protocol() == "zip" || u.protocol() == "krarc" || u.protocol() == "tar" || u.protocol() == "iso" ) {
 				if( QDir( u.path() ).exists() )
@@ -122,114 +124,151 @@ KURL KChooseDir::getDir(QString text,const KURL& url, const KURL& cwd, bool &pre
 		if( dlg->copyDirStructure() ) {
 			baseURL = dlg->baseURL();
 		} else {
-			baseURL = KURL();
+			baseURL = KUrl();
 		}
 	}
 	preserveAttrs = dlg->preserveAttrs();
+	queue = dlg->enqueue();
 	delete dlg;
 	return u;
 }
 
-KURLRequesterDlgForCopy::KURLRequesterDlgForCopy( const QString& urlName, const QString& _text, bool presAttrs, QWidget *parent,
-                                                  const char *name, bool modal, KURL baseURL )
-			:   KDialogBase( Plain, QString::null, Ok|Cancel|User1, Ok, parent, name, modal, true, KStdGuiItem::clear() ),
-			baseUrlCombo( 0 ), copyDirStructureCB( 0 ) {
+KUrlRequesterDlgForCopy::KUrlRequesterDlgForCopy( const QString& urlName, const QString& _text, bool presAttrs, QWidget *parent,
+                                                  bool modal, KUrl baseURL )
+		:   KDialog( parent ), baseUrlCombo( 0 ), copyDirStructureCB( 0 ), queue( false ) {
 	
-	QVBoxLayout * topLayout = new QVBoxLayout( plainPage(), 0, spacingHint() );
+	setButtons( KDialog::Ok | KDialog::User1 | KDialog::User2 | KDialog::Cancel );
+	setDefaultButton( KDialog::Ok );
+	setButtonGuiItem( KDialog::User1, KGuiItem( i18n("F2 Queue") ) );
+	setButtonGuiItem( KDialog::User2, KStandardGuiItem::clear() );
+	setWindowModality( modal ? Qt::WindowModal : Qt::NonModal );
+	showButtonSeparator( true );
 
-	QLabel * label = new QLabel( _text, plainPage() );
+	QWidget * widget = new QWidget( this );
+	QVBoxLayout * topLayout = new QVBoxLayout( widget );
+	topLayout->setContentsMargins( 0, 0, 0, 0 );
+	topLayout->setSpacing( spacingHint() );
+
+	QLabel * label = new QLabel( _text, widget );
 	topLayout->addWidget( label );
 
-	urlRequester_ = new KURLRequester( urlName, plainPage(), "urlRequester" );
+	urlRequester_ = new KUrlRequester( urlName, widget );
 	urlRequester_->setMinimumWidth( urlRequester_->sizeHint().width() * 3 );
 	topLayout->addWidget( urlRequester_ );
-	preserveAttrsCB = new QCheckBox(i18n("Preserve attributes (only for local targets)"), plainPage());
+	preserveAttrsCB = new QCheckBox(i18n("Preserve attributes (only for local targets)"), widget);
 	preserveAttrsCB->setChecked( presAttrs );
 	topLayout->addWidget( preserveAttrsCB );
 	if( !baseURL.isEmpty() ) {
-		QFrame *line = new QFrame( plainPage(), "sepLine" );
+		QFrame *line = new QFrame( widget );
 		line->setFrameStyle( QFrame::HLine | QFrame::Sunken );
 		topLayout->addWidget( line );
-		copyDirStructureCB = new QCheckBox(i18n("Keep virtual directory structure"), plainPage());
+		copyDirStructureCB = new QCheckBox(i18n("Keep virtual directory structure"), widget);
 		connect( copyDirStructureCB, SIGNAL( toggled( bool ) ), this, SLOT( slotDirStructCBChanged() ) );
 		copyDirStructureCB->setChecked( false );
 		topLayout->addWidget( copyDirStructureCB );
-		QHBox * hbox = new QHBox( plainPage(), "copyDirStructure" );
-		new QLabel( i18n("Base URL:"),  hbox, "baseURLLabel" );
+		QWidget *hboxWidget = new QWidget( widget );
+		QHBoxLayout * hbox = new QHBoxLayout( hboxWidget );
+		QLabel * lbl = new QLabel( i18n("Base URL:"),  hboxWidget );
+		hbox->addWidget( lbl );
 		
-		baseUrlCombo = new QComboBox( hbox, "baseUrlRequester" );
+		baseUrlCombo = new QComboBox( hboxWidget );
 		baseUrlCombo->setMinimumWidth( baseUrlCombo->sizeHint().width() * 3 );
 		baseUrlCombo->setEnabled( copyDirStructureCB->isChecked() );
-		KURL temp = baseURL, tempOld;
-		do {
-			QString baseURLText = vfs::pathOrURL( temp );
-			baseUrlCombo->insertItem( baseURLText );
-			tempOld = temp;
-			temp = temp.upURL();
-		}while( !tempOld.equals( temp, true ) );
-		baseUrlCombo->setCurrentItem( 0 );
+		hbox->addWidget( baseUrlCombo );
 		
-		topLayout->addWidget( hbox );
+		KUrl temp = baseURL, tempOld;
+		do {
+			QString baseURLText = temp.pathOrUrl();
+			baseUrlCombo->addItem( baseURLText );
+			tempOld = temp;
+			temp = temp.upUrl();
+		}while( !tempOld.equals( temp, KUrl::CompareWithoutTrailingSlash ) );
+		baseUrlCombo->setCurrentIndex( 0 );
+		
+		topLayout->addWidget( hboxWidget );
 	}
+	widget->setLayout( topLayout );
+	setMainWidget( widget );
+
 	urlRequester_->setFocus();
 	connect( urlRequester_->lineEdit(), SIGNAL(textChanged(const QString&)),
 		SLOT(slotTextChanged(const QString&)) );
 	bool state = !urlName.isEmpty();
-	enableButtonOK( state );
-	enableButton( KDialogBase::User1, state );
-	connect( this, SIGNAL( user1Clicked() ), SLOT( slotClear() ) );
+	enableButtonOk( state );
+	enableButton( KDialog::User2, state );
+	connect( this, SIGNAL( user2Clicked() ), SLOT( slotClear() ) );
+	connect( this, SIGNAL( user1Clicked() ), SLOT( slotQueue() ) );
 }
 
-KURLRequesterDlgForCopy::KURLRequesterDlgForCopy() {
+KUrlRequesterDlgForCopy::KUrlRequesterDlgForCopy() {
 }
 
-bool KURLRequesterDlgForCopy::preserveAttrs() {
+void KUrlRequesterDlgForCopy::keyPressEvent( QKeyEvent *e )
+{
+	switch ( e->key() )
+	{
+	case Qt::Key_F2:
+		slotQueue();
+		return;
+	default:
+		QDialog::keyPressEvent( e );
+	}
+}
+
+bool KUrlRequesterDlgForCopy::preserveAttrs() {
 	return preserveAttrsCB->isChecked();
 }
 
-bool KURLRequesterDlgForCopy::copyDirStructure() {
+bool KUrlRequesterDlgForCopy::copyDirStructure() {
 	if( copyDirStructureCB == 0 )
 		return false;
 	return copyDirStructureCB->isChecked();
 }
 
-void KURLRequesterDlgForCopy::slotTextChanged(const QString & text) {
-	bool state = !text.stripWhiteSpace().isEmpty();
-	enableButtonOK( state );
-	enableButton( KDialogBase::User1, state );
+void KUrlRequesterDlgForCopy::slotTextChanged(const QString & text) {
+	bool state = !text.trimmed().isEmpty();
+	enableButtonOk( state );
+	enableButton( KDialog::User2, state );
 }
 
-void KURLRequesterDlgForCopy::slotClear() {
+void KUrlRequesterDlgForCopy::slotQueue() {
+	queue = true;
+	accept();
+}
+
+void KUrlRequesterDlgForCopy::slotClear() {
 	urlRequester_->clear();
 }
 
-void KURLRequesterDlgForCopy::slotDirStructCBChanged() {
+void KUrlRequesterDlgForCopy::slotDirStructCBChanged() {
 	baseUrlCombo->setEnabled( copyDirStructureCB->isChecked() );
 }
 
-KURL KURLRequesterDlgForCopy::selectedURL() const {
+KUrl KUrlRequesterDlgForCopy::selectedURL() const {
 	if ( result() == QDialog::Accepted ) {
-		KURL url = KURL::fromPathOrURL( urlRequester_->url() );
+		KUrl url = urlRequester_->url();
 		if( url.isValid() )
 			KRecentDocument::add(url);                                
 		return url;
 	}        
 	else
-		return KURL();
+		return KUrl();
 }
 
-KURLRequester * KURLRequesterDlgForCopy::urlRequester() {
+KUrlRequester * KUrlRequesterDlgForCopy::urlRequester() {
 	return urlRequester_;
 }
 
-KURL KURLRequesterDlgForCopy::baseURL() const {
+KUrl KUrlRequesterDlgForCopy::baseURL() const {
 	if( baseUrlCombo == 0 )
-		return KURL();
-	return vfs::fromPathOrURL( baseUrlCombo->currentText() );
+		return KUrl();
+	return KUrl( baseUrlCombo->currentText() );
 }
 
-KRGetDate::KRGetDate(QDate date, QWidget *parent, const char *name) : KDialog(parent, name,true,WStyle_DialogBorder) {
-  dateWidget = new KDatePicker(this, date);
+KRGetDate::KRGetDate(QDate date, QWidget *parent) : KDialog(parent,Qt::MSWindowsFixedSizeDialogHint) {
+  setWindowModality( Qt::WindowModal );
+  dateWidget = new KDatePicker(this);
+  dateWidget->setDate( date );
   dateWidget->resize(dateWidget->sizeHint());
   setMinimumSize(dateWidget->sizeHint());
   setMaximumSize(dateWidget->sizeHint());
