@@ -28,17 +28,17 @@
  *                                                                         *
  ***************************************************************************/
 #include "krmaskchoice.h"
+#include "../GUI/krlistwidget.h"
 
 #include <qcombobox.h>
 #include <qgroupbox.h>
 #include <qlabel.h>
-#include <qlistbox.h>
 #include <qpushbutton.h>
 #include <qlayout.h>
 #include <qvariant.h>
-#include <qtooltip.h>
-#include <qwhatsthis.h>
 #include <qmessagebox.h>
+#include <QHBoxLayout>
+#include <QVBoxLayout>
 #include <klocale.h>
 #include <qlineedit.h>
 
@@ -49,89 +49,91 @@
  *  The dialog will by default be modeless, unless you set 'modal' to
  *  TRUE to construct a modal dialog.
  */
-KRMaskChoice::KRMaskChoice( QWidget* parent,  const char* name, bool modal, WFlags fl )
-    : QDialog( parent, name, modal, fl )
+KRMaskChoice::KRMaskChoice( QWidget* parent )
+    : QDialog( parent )
 {
-    if ( !name )
-	setName( "KRMaskChoice" );
+    setModal( true );
     resize( 401, 314 );
-    setCaption( i18n( "Choose Files"  ) );
-    setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)5 ) );
+    setWindowTitle( i18n( "Choose Files"  ) );
+    setSizePolicy( QSizePolicy( QSizePolicy::Preferred, QSizePolicy::Preferred ) );
 
-    selection = new QComboBox( FALSE, this, "selection" );
+    selection = new QComboBox( this );
     int height = QFontMetrics( selection->font() ).height();
     height =  height + 5*(height > 14) + 6;
     selection->setGeometry( QRect( 12, 48, 377, height) );
     selection->setEditable( TRUE );
-    selection->setInsertionPolicy( QComboBox::AtTop );
+    selection->setInsertPolicy( QComboBox::InsertAtTop );
     selection->setAutoCompletion( TRUE );
 
-    QWidget* Layout7 = new QWidget( this, "Layout7" );
+    QWidget* Layout7 = new QWidget( this );
     Layout7->setGeometry( QRect( 10, 10, 380, 30 ) ); 
     hbox = new QHBoxLayout( Layout7 );
     hbox->setSpacing( 6 );
-    hbox->setMargin( 0 );
+    hbox->setContentsMargins( 0, 0, 0, 0 );
 
-    PixmapLabel1 = new QLabel( Layout7, "PixmapLabel1" );
+    PixmapLabel1 = new QLabel( Layout7 );
     PixmapLabel1->setScaledContents( TRUE );
     PixmapLabel1->setMaximumSize( QSize( 31, 31 ) );
 	// now, add space for the pixmap    
     hbox->addWidget( PixmapLabel1 );
 
-    label = new QLabel( Layout7, "label" );
+    label = new QLabel( Layout7 );
     label->setText( i18n( "Select the following files:"  ) );
     hbox->addWidget( label );
 
-    GroupBox1 = new QGroupBox( this, "GroupBox1" );
+    GroupBox1 = new QGroupBox( this );
     GroupBox1->setGeometry( QRect( 11, 77, 379, 190 ) );
     GroupBox1->setTitle( i18n( "Predefined Selections"  ) );
+    QHBoxLayout * gbLayout = new QHBoxLayout( GroupBox1 );
+
+    QWidget* Layout6 = new QWidget( GroupBox1 );
+    gbLayout->addWidget( Layout6 );
 
-    QWidget* Layout6 = new QWidget( GroupBox1, "Layout6" );
     Layout6->setGeometry( QRect( 10, 20, 360, 160 ) ); 
     hbox_2 = new QHBoxLayout( Layout6 ); 
     hbox_2->setSpacing( 6 );
-    hbox_2->setMargin( 0 );
+    hbox_2->setContentsMargins( 0, 0, 0, 0 );
 
-    preSelections = new QListBox( Layout6, "preSelections" );
-    preSelections->setVScrollBarMode( QListBox::AlwaysOn );
-    QWhatsThis::add(  preSelections, i18n( "A predefined selection is a file-mask which you use often.\nSome examples are: \"*.c, *.h\", \"*.c, *.o\", etc.\nYou can add these masks to the list by typing them and pressing the Add button.\nDelete removes a predefined selection and Clear removes all of them.\nNotice that the line in which you edit the mask has it's own history, you can scroll it, if needed." ) );
+    preSelections = new KrListWidget( Layout6 );
+    preSelections->setVerticalScrollBarPolicy( Qt::ScrollBarAlwaysOn );
+    preSelections->setWhatsThis( i18n( "A predefined selection is a file-mask which you use often.\nSome examples are: \"*.c, *.h\", \"*.c, *.o\", etc.\nYou can add these masks to the list by typing them and pressing the Add button.\nDelete removes a predefined selection and Clear removes all of them.\nNotice that the line in which you edit the mask has it's own history, you can scroll it, if needed." ) );
     hbox_2->addWidget( preSelections );
 
     vbox = new QVBoxLayout; 
     vbox->setSpacing( 6 );
-    vbox->setMargin( 0 );
+    vbox->setContentsMargins( 0, 0, 0, 0 );
 
-    PushButton7 = new QPushButton( Layout6, "PushButton7" );
+    PushButton7 = new QPushButton( Layout6 );
     PushButton7->setText( i18n( "Add"  ) );
-    QToolTip::add(  PushButton7, i18n( "Adds the selection in the line-edit to the list" ) );
+    PushButton7->setToolTip( i18n( "Adds the selection in the line-edit to the list" ) );
     vbox->addWidget( PushButton7 );
 
-    PushButton7_2 = new QPushButton( Layout6, "PushButton7_2" );
+    PushButton7_2 = new QPushButton( Layout6 );
     PushButton7_2->setText( i18n( "Delete"  ) );
-    QToolTip::add(  PushButton7_2, i18n( "Delete the marked selection from the list" ) );
+    PushButton7_2->setToolTip( i18n( "Delete the marked selection from the list" ) );
     vbox->addWidget( PushButton7_2 );
 
-    PushButton7_3 = new QPushButton( Layout6, "PushButton7_3" );
+    PushButton7_3 = new QPushButton( Layout6 );
     PushButton7_3->setText( i18n( "Clear"  ) );
-    QToolTip::add(  PushButton7_3, i18n( "Clears the entire list of selections" ) );
+    PushButton7_3->setToolTip( i18n( "Clears the entire list of selections" ) );
     vbox->addWidget( PushButton7_3 );
     QSpacerItem* spacer = new QSpacerItem( 20, 54, QSizePolicy::Fixed, QSizePolicy::Expanding );
     vbox->addItem( spacer );
     hbox_2->addLayout( vbox );
 
-    QWidget* Layout18 = new QWidget( this, "Layout18" );
+    QWidget* Layout18 = new QWidget( this );
     Layout18->setGeometry( QRect( 10, 280, 379, 30 ) ); 
     hbox_3 = new QHBoxLayout( Layout18 ); 
     hbox_3->setSpacing( 6 );
-    hbox_3->setMargin( 0 );
+    hbox_3->setContentsMargins( 0, 0, 0, 0 );
     QSpacerItem* spacer_2 = new QSpacerItem( 205, 20, QSizePolicy::Expanding, QSizePolicy::Fixed );
     hbox_3->addItem( spacer_2 );
 
-    PushButton3 = new QPushButton( Layout18, "PushButton3" );
+    PushButton3 = new QPushButton( Layout18 );
     PushButton3->setText( i18n( "OK"  ) );
     hbox_3->addWidget( PushButton3 );
 
-    PushButton3_2 = new QPushButton( Layout18, "PushButton3_2" );
+    PushButton3_2 = new QPushButton( Layout18 );
     PushButton3_2->setText( i18n( "Cancel"  ) );
     hbox_3->addWidget( PushButton3_2 );
 
@@ -143,9 +145,8 @@ KRMaskChoice::KRMaskChoice( QWidget* parent,  const char* name, bool modal, WFla
     connect( PushButton7_3, SIGNAL( clicked() ), this, SLOT( clearSelections() ) );
     connect( selection, SIGNAL( activated(const QString&) ), selection, SLOT( setEditText(const QString &) ) );
     connect( selection->lineEdit(), SIGNAL( returnPressed() ), this, SLOT( accept() ));
-    connect( preSelections, SIGNAL( doubleClicked(QListBoxItem*) ), this, SLOT( acceptFromList(QListBoxItem *) ) );
-    connect( preSelections, SIGNAL( highlighted(const QString&) ), selection, SLOT( setEditText(const QString &) ) );
-    connect( preSelections, SIGNAL( returnPressed(QListBoxItem*) ), this, SLOT( acceptFromList(QListBoxItem *) ) );
+    connect( preSelections, SIGNAL( currentItemChanged ( QListWidgetItem *, QListWidgetItem * ) ), this, SLOT( currentItemChanged( QListWidgetItem * ) ) );
+    connect( preSelections, SIGNAL( itemActivated(QListWidgetItem*) ), this, SLOT( acceptFromList(QListWidgetItem *) ) );
 }
 
 /*  
@@ -171,9 +172,14 @@ void KRMaskChoice::deleteSelection()
     qWarning( "KRMaskChoice::deleteSelection(): Not implemented yet!" );
 }
 
-void KRMaskChoice::acceptFromList(QListBoxItem *)
+void KRMaskChoice::acceptFromList(QListWidgetItem *)
 {
-    qWarning( "KRMaskChoice::acceptFromList(QListBoxItem *): Not implemented yet!" );
+    qWarning( "KRMaskChoice::acceptFromList(QListWidgetItem *): Not implemented yet!" );
+}
+
+void KRMaskChoice::currentItemChanged(QListWidgetItem *)
+{
+    qWarning( "KRMaskChoice::currentItemChanged(QListWidgetItem *): Not implemented yet!" );
 }
 
 #include "krmaskchoice.moc"
