@@ -33,10 +33,10 @@
 
 #include <qprogressdialog.h>
 #include <qtimer.h>
-#include <qguardedptr.h>
+#include <qpointer.h>
+#include <QCloseEvent>
 #include <kio/jobclasses.h>
 
-class KProcess;
 class KRPleaseWait;
 
 class KRPleaseWaitHandler : public QObject {
@@ -51,13 +51,12 @@ public slots:
   void stopWait();
   void cycleProgress();
   void incProgress(int i);
-  void incProgress( KProcess *, char *buffer, int buflen );
   void killJob();
   void setJob(KIO::Job* j);
   bool wasCancelled() const { return _wasCancelled; }
 
 private:
-  QGuardedPtr<KIO::Job> job;
+  QPointer<KIO::Job> job;
   KRPleaseWait * dlg;
   bool cycle, cycleMutex, incMutex, _wasCancelled;
 };
