@@ -40,6 +40,9 @@ A
 #include <klocale.h>
 #include <klineedit.h>
 #include <kdebug.h>
+#include <QKeyEvent>
+#include <QPaintEvent>
+#include <kcolorscheme.h>
 
 /////////////////////////////////////////////////////////////////////////////
 /////////////////////// Pie related widgets /////////////////////////////////
@@ -68,7 +71,11 @@ KRFSDisplay::KRFSDisplay( QWidget *parent, QString _alias, QString _realName,
                           KIO::filesize_t _total, KIO::filesize_t _free ) : QWidget( parent ), totalSpace( _total ),
       freeSpace( _free ), alias( _alias ), realName( _realName ), mounted( true ),
 empty( false ), supermount( false ) {
-   resize( 150, 200 );
+
+   int leftMargin, topMargin, rightMargin, bottomMargin;
+   getContentsMargins ( &leftMargin, &topMargin, &rightMargin, &bottomMargin );
+   resize( 150 + leftMargin + rightMargin, 200 + topMargin + bottomMargin);
+   setMinimumSize( 150 + leftMargin + rightMargin, 200 + topMargin + bottomMargin);
    show();
 }
 
@@ -76,14 +83,22 @@ empty( false ), supermount( false ) {
 KRFSDisplay::KRFSDisplay( QWidget *parent, QString _alias, QString _realName, bool sm ) :
       QWidget( parent ), alias( _alias ), realName( _realName ), mounted( false ),
 empty( false ), supermount( sm ) {
-   resize( 150, 200 );
+
+   int leftMargin, topMargin, rightMargin, bottomMargin;
+   getContentsMargins ( &leftMargin, &topMargin, &rightMargin, &bottomMargin );
+   resize( 150 + leftMargin + rightMargin, 200 + topMargin + bottomMargin);
+   setMinimumSize( 150 + leftMargin + rightMargin, 200 + topMargin + bottomMargin);
    show();
 }
 
 // This is used only when an empty widget needs to be displayed (for example:
 // when filesystem statistics haven't been calculated yet)
 KRFSDisplay::KRFSDisplay( QWidget *parent ) : QWidget( parent ), empty( true ) {
-   resize( 150, 200 );
+
+   int leftMargin, topMargin, rightMargin, bottomMargin;
+   getContentsMargins ( &leftMargin, &topMargin, &rightMargin, &bottomMargin );
+   resize( 150 + leftMargin + rightMargin, 200 + topMargin + bottomMargin);
+   setMinimumSize( 150 + leftMargin + rightMargin, 200 + topMargin + bottomMargin);
    show();
 }
 
@@ -92,53 +107,55 @@ KRFSDisplay::KRFSDisplay( QWidget *parent ) : QWidget( parent ), empty( true ) {
 void KRFSDisplay::paintEvent( QPaintEvent * ) {
    QPainter paint( this );
    if ( !empty ) {
+      int leftMargin, topMargin, rightMargin, bottomMargin;
+      getContentsMargins ( &leftMargin, &topMargin, &rightMargin, &bottomMargin );
       // create the text
       // first, name and location
       paint.setFont( QFont( "helvetica", 12, QFont::Bold ) );
-      paint.drawText( 10, 20, alias );
+      paint.drawText( leftMargin + 10, topMargin + 20, alias );
       paint.setFont( QFont( "helvetica", 12, QFont::Normal ) );
-      paint.drawText( 10, 37, "(" + realName + ")" );
+      paint.drawText( leftMargin + 10, topMargin + 37, "(" + realName + ")" );
       if ( mounted ) {  // incase the filesystem is already mounted
          // second, the capacity
-         paint.drawText( 10, 70, i18n( "Capacity: " ) + KIO::convertSizeFromKB( totalSpace ) );
+         paint.drawText( leftMargin + 10, topMargin + 70, i18n( "Capacity: " ) + KIO::convertSizeFromKiB( totalSpace ) );
          // third, the 2 boxes (used, free)
          QPen systemPen = paint.pen();
          paint.setPen( Qt::black );
-         paint.drawRect( 10, 90, 10, 10 );
-         paint.fillRect( 11, 91, 8, 8, QBrush( Qt::gray ) );
-         paint.drawRect( 10, 110, 10, 10 );
-         paint.fillRect( 11, 111, 8, 8, QBrush( Qt::white ) );
+         paint.drawRect( leftMargin + 10, topMargin + 90, 10, 10 );
+         paint.fillRect( leftMargin + 11, topMargin + 91, 8, 8, QBrush( Qt::gray ) );
+         paint.drawRect( leftMargin + 10, topMargin + 110, 10, 10 );
+         paint.fillRect( leftMargin + 11, topMargin + 111, 8, 8, QBrush( Qt::white ) );
          // now, the text for the boxes
          paint.setPen( systemPen );
-         paint.drawText( 25, 100, i18n( "Used: " ) + KIO::convertSizeFromKB( totalSpace - freeSpace ) );
-         paint.drawText( 25, 120, i18n( "Free: " ) + KIO::convertSizeFromKB( freeSpace ) );
+         paint.drawText( leftMargin + 25, topMargin + 100, i18n( "Used: " ) + KIO::convertSizeFromKiB( totalSpace - freeSpace ) );
+         paint.drawText( leftMargin + 25, topMargin + 120, i18n( "Free: " ) + KIO::convertSizeFromKiB( freeSpace ) );
          // first, create the empty pie
          // bottom...
          paint.setPen( Qt::black );
          paint.setBrush( Qt::white );
-         paint.drawPie( LEFT, BOTTOM, WIDTH, HEIGHT, STARTANGLE, DEG( 360 ) );
+         paint.drawPie( leftMargin + LEFT, topMargin + BOTTOM, WIDTH, HEIGHT, STARTANGLE, DEG( 360 ) );
          // body...
          paint.setPen( Qt::lightGray );
          for ( int i = 1; i < Z_HEIGHT; ++i )
-            paint.drawPie( LEFT, BOTTOM - i, WIDTH, HEIGHT, STARTANGLE, DEG( 360 ) );
+            paint.drawPie( leftMargin + LEFT, topMargin + BOTTOM - i, WIDTH, HEIGHT, STARTANGLE, DEG( 360 ) );
          // side lines...
          paint.setPen( Qt::black );
-         paint.drawLine( LEFT, BOTTOM + HEIGHT / 2, LEFT, BOTTOM + HEIGHT / 2 - Z_HEIGHT );
-         paint.drawLine( LEFT + WIDTH, BOTTOM + HEIGHT / 2, LEFT + WIDTH, BOTTOM + HEIGHT / 2 - Z_HEIGHT );
+         paint.drawLine( leftMargin + LEFT, topMargin + BOTTOM + HEIGHT / 2, LEFT, BOTTOM + HEIGHT / 2 - Z_HEIGHT );
+         paint.drawLine( leftMargin + LEFT + WIDTH, topMargin + BOTTOM + HEIGHT / 2, LEFT + WIDTH, BOTTOM + HEIGHT / 2 - Z_HEIGHT );
          // top of the pie
-         paint.drawPie( LEFT, BOTTOM - Z_HEIGHT, WIDTH, HEIGHT, STARTANGLE, DEG( 360 ) );
+         paint.drawPie( leftMargin + LEFT, topMargin + BOTTOM - Z_HEIGHT, WIDTH, HEIGHT, STARTANGLE, DEG( 360 ) );
          // the "used space" slice
          float i = ( ( float ) ( totalSpace - freeSpace ) / ( totalSpace ) ) * 360.0;
          paint.setBrush( Qt::gray );
-         paint.drawPie( LEFT, BOTTOM - Z_HEIGHT, WIDTH, HEIGHT, STARTANGLE, ( int ) DEG( i ) );
+         paint.drawPie( leftMargin + LEFT, topMargin + BOTTOM - Z_HEIGHT, WIDTH, HEIGHT, STARTANGLE, ( int ) DEG( i ) );
          // if we need to draw a 3d stripe ...
          if ( i > 180.0 ) {
             for ( int j = 1; j < Z_HEIGHT; ++j )
-               paint.drawArc( LEFT, BOTTOM - j, WIDTH, HEIGHT, STARTANGLE - 16 * 180, ( int ) ( DEG( i - 180.0 ) ) );
+               paint.drawArc( leftMargin + LEFT, topMargin + BOTTOM - j, WIDTH, HEIGHT, STARTANGLE - 16 * 180, ( int ) ( DEG( i - 180.0 ) ) );
          }
       } else {  // if the filesystem is unmounted...
          paint.setFont( QFont( "helvetica", 12, QFont::Bold ) );
-         paint.drawText( 10, 60, i18n( "Not mounted." ) );
+         paint.drawText( leftMargin + 10, topMargin + 60, i18n( "Not mounted." ) );
       }
    } else {  // if the widget is in empty situation...
 
@@ -146,9 +163,8 @@ void KRFSDisplay::paintEvent( QPaintEvent * ) {
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-KRPie::KRPie( KIO::filesize_t _totalSize, QWidget *parent ) : QWidget( parent, 0 ), totalSize( _totalSize ) {
-   slices.setAutoDelete( true ); // kill items when they are removed
-   slices.append( new KRPieSlice( 100, Qt::yellow, "DEFAULT" ) );
+KRPie::KRPie( KIO::filesize_t _totalSize, QWidget *parent ) : QWidget( parent ), totalSize( _totalSize ) {
+   slices.push_back( KRPieSlice( 100, Qt::yellow, "DEFAULT" ) );
    sizeLeft = totalSize;
    resize( 300, 300 );
 }
@@ -156,13 +172,12 @@ KRPie::KRPie( KIO::filesize_t _totalSize, QWidget *parent ) : QWidget( parent, 0
 void KRPie::paintEvent( QPaintEvent * ) {
    QPainter paint( this );
    // now create the slices
-   KRPieSlice *slice;
    float sAngle = STARTANGLE;
-   for ( slice = slices.first(); slice != 0; slice = slices.next() ) {
-      paint.setBrush( slice->getColor() );
-      paint.setPen( slice->getColor() );
+   for ( int ndx=0; ndx != slices.count(); ndx++ ) {
+      paint.setBrush( slices[ndx].getColor() );
+      paint.setPen( slices[ndx].getColor() );
       // angles are negative to create a clock-wise drawing of slices
-      float angle = -( slice->getPerct() / 100 * 360 ) * 16;
+      float angle = -( slices[ndx].getPerct() / 100 * 360 ) * 16;
       for ( int i = 1; i < Z_HEIGHT; ++i )
          paint.drawPie( LEFT, BOTTOM + i, WIDTH, HEIGHT, ( int ) sAngle, ( int ) angle );
       sAngle += angle;
@@ -172,11 +187,11 @@ void KRPie::paintEvent( QPaintEvent * ) {
    // for (int i=1; i<Z_HEIGHT; ++i)
    //  paint.drawPie(LEFT,BOTTOM+i,WIDTH,HEIGHT,sAngle,360*16-(STARTANGLE-sAngle));
    sAngle = STARTANGLE;
-   for ( slice = slices.first(); slice != 0; slice = slices.next() ) {
-      paint.setBrush( slice->getColor() );
-      paint.setPen( slice->getColor() );
+   for ( int ndx=0; ndx != slices.count(); ndx++ ) {
+      paint.setBrush( slices[ndx].getColor() );
+      paint.setPen( slices[ndx].getColor() );
       // angles are negative to create a clock-wise drawing of slices
-      float angle = -( slice->getPerct() / 100 * 360 ) * 16;
+      float angle = -( slices[ndx].getPerct() / 100 * 360 ) * 16;
       paint.drawPie( LEFT, BOTTOM, WIDTH, HEIGHT, ( int ) sAngle, ( int ) angle );
       sAngle += angle;
    }
@@ -196,37 +211,40 @@ void KRPie::paintEvent( QPaintEvent * ) {
 void KRPie::addSlice( KIO::filesize_t size, QString label ) {
    int i = ( slices.count() % 12 );
    slices.removeLast();
-   slices.append( new KRPieSlice( size * 100 / totalSize, colors[ i ], label ) );
+   slices.push_back( KRPieSlice( size * 100 / totalSize, colors[ i ], label ) );
    sizeLeft -= size;
-   slices.append( new KRPieSlice( sizeLeft * 100 / totalSize, Qt::yellow, "DEFAULT" ) );
+   slices.push_back( KRPieSlice( sizeLeft * 100 / totalSize, Qt::yellow, "DEFAULT" ) );
 }
 
 ////////////////////////////////////////////////////
 /////////////////// KrQuickSearch  /////////////////
 ////////////////////////////////////////////////////
-KrQuickSearch::KrQuickSearch( QWidget *parent, const char * name ) : KLineEdit( parent, name ) {}
+KrQuickSearch::KrQuickSearch( QWidget *parent ) : KLineEdit( parent )
+{
+   setMatch( true );
+}
 
 void KrQuickSearch::myKeyPressEvent( QKeyEvent *e ) {
    switch ( e->key() ) {
-         case Key_Escape:
+         case Qt::Key_Escape:
          emit stop( 0 );
          break;
-         case Key_Return:
-         case Key_Enter:
-         case Key_Tab:
-         case Key_Right:
-         case Key_Left:
+         case Qt::Key_Return:
+         case Qt::Key_Enter:
+         case Qt::Key_Tab:
+         case Qt::Key_Right:
+         case Qt::Key_Left:
          emit stop( e );
          break;
-         case Key_Down:
+         case Qt::Key_Down:
          otherMatching( text(), 1 );
          break;
-         case Key_Up:
+         case Qt::Key_Up:
          otherMatching( text(), -1 );
          break;
-         case Key_Insert:
-         case Key_Home:
-         case Key_End:
+         case Qt::Key_Insert:
+         case Qt::Key_Home:
+         case Qt::Key_End:
          process( e );
          break;
          default:
@@ -234,6 +252,39 @@ void KrQuickSearch::myKeyPressEvent( QKeyEvent *e ) {
    }
 }
 
+void KrQuickSearch::setMatch( bool match ) {
+   KConfigGroup gc( krConfig, "Colors");
 
+   QString foreground, background;
+   QColor  fore, back;
+
+   if( match )
+   {
+      foreground = "Quicksearch Match Foreground";
+      background = "Quicksearch Match Background";
+      fore = Qt::black;
+      back = QColor( 192, 255, 192 );
+   } else {
+      foreground = "Quicksearch Non-match Foreground";
+      background = "Quicksearch Non-match Background";
+      fore = Qt::black;
+      back = QColor(255,192,192);
+   }
+
+   if( gc.readEntry( foreground, QString() ) == "KDE default" )
+      fore = KColorScheme(QPalette::Active, KColorScheme::View).foreground().color();
+   else if( !gc.readEntry( foreground, QString() ).isEmpty() )
+      fore = gc.readEntry( foreground, fore );
+
+   if( gc.readEntry( background, QString() ) == "KDE default" )
+      back = KColorScheme(QPalette::Active, KColorScheme::View).background().color();
+   else if( !gc.readEntry( background, QString() ).isEmpty() )
+      back = gc.readEntry( background, back );
+
+   QPalette pal = palette();
+   pal.setColor( QPalette::Base, back);
+   pal.setColor( QPalette::Text, fore);
+   setPalette( pal );
+}
 
 #include "krspecialwidgets.moc"
