@@ -35,7 +35,8 @@ A
 #include <qwidget.h>
 #include <qpainter.h>
 #include <qcolor.h>
-#include <qptrlist.h>
+#include <QKeyEvent>
+#include <QPaintEvent>
 #include <klineedit.h>
 #include <qevent.h>
 #include <kio/global.h>
@@ -103,17 +104,12 @@ class KRPieSlice {
 class KrQuickSearch: public KLineEdit {
       Q_OBJECT
    public:
-      KrQuickSearch(QWidget *parent, const char * name = 0);
+      KrQuickSearch(QWidget *parent);
       void addText(const QString &str) { setText(text()+str); }
       void myKeyPressEvent(QKeyEvent *e);
-      void myIMStartEvent(QIMEvent* e) {
-        imStartEvent(e);
-      }
-      void myIMEndEvent(QIMEvent* e) {
-        imEndEvent(e);
-      }
-      void myIMComposeEvent(QIMEvent* e) {
-        imComposeEvent(e);
+      void setMatch( bool match );
+      void myInputMethodEvent(QInputMethodEvent* e) {
+        inputMethodEvent(e);
       }
 
    signals:
