@@ -1,10 +1,16 @@
 #include "krsqueezedtextlabel.h"
 #include <kstringhandler.h>
-#include <kurldrag.h>
 #include <qtooltip.h>
+#include <QMouseEvent>
+#include <QDropEvent>
+#include <QDragEnterEvent>
+#include <QLabel>
+#include <QPainter>
+#include <kurl.h>
 
-KrSqueezedTextLabel::KrSqueezedTextLabel(QWidget *parent, const char *name):
-  KSqueezedTextLabel(parent, name), acceptDrops( false ), _index(-1), _length(-1) {
+KrSqueezedTextLabel::KrSqueezedTextLabel(QWidget *parent):
+  KSqueezedTextLabel(parent), acceptDrops( false ), _index(-1), _length(-1) {
+  setAutoFillBackground( true );
 }
 
 
@@ -26,8 +32,10 @@ void KrSqueezedTextLabel::dropEvent(QDropEvent *e) {
 }
 
 void KrSqueezedTextLabel::dragEnterEvent(QDragEnterEvent *e) {
-  if( acceptDrops )
-    e->accept( KURLDrag::canDecode( e ) );
+  if( acceptDrops ) {
+    KUrl::List URLs = KUrl::List::fromMimeData( e->mimeData() );
+    e->setAccepted( !URLs.isEmpty() );
+  }
   else
     KSqueezedTextLabel::dragEnterEvent( e );
 }
@@ -47,24 +55,24 @@ void KrSqueezedTextLabel::squeezeTextToLabel(int index, int length) {
 			
 			// remove as much as possible from the left, and then from the right
 			if (index>3) {
-				delta=QMIN(index, numOfExtraChars);
+				delta=qMin(index, numOfExtraChars);
 				numOfExtraChars -= delta;
 				sqtext.replace(0, delta, "...");
 			}
 			
 			if (numOfExtraChars>0 && ((int)sqtext.length() > length+3)) {
-				delta = QMIN(numOfExtraChars, (int)sqtext.length() - (length+3));
+				delta = qMin(numOfExtraChars, (int)sqtext.length() - (length+3));
 				sqtext.replace(sqtext.length()-delta, delta, "...");
 			}
 			QLabel::setText(sqtext);
 
-			QToolTip::remove( this );
-			QToolTip::add( this, fullText );
+			setToolTip( QString::null );
+			setToolTip( fullText );
 		} else {
 			QLabel::setText(fullText);
 
-			QToolTip::remove( this );
-			QToolTip::hide();
+			setToolTip( QString::null );
+			QToolTip::hideText();
 		}
 	}
 }
@@ -73,8 +81,20 @@ void KrSqueezedTextLabel::setText( const QString &text, int index, int length )
 	_index=index;
 	_length=length;
 	fullText = text;
+	KSqueezedTextLabel::setText( fullText );
 	squeezeTextToLabel(_index,_length);
 }
 
+void KrSqueezedTextLabel::paintEvent( QPaintEvent * e ) {
+	{
+		QPainter painter( this );
+		
+		QRect cr = contentsRect();
+		painter.fillRect( cr, palette().brush( backgroundRole() ) );
+	}
+	
+	KSqueezedTextLabel::paintEvent( e );
+}
+
 #include "krsqueezedtextlabel.moc"
 
