@@ -2,10 +2,15 @@
 #define KRSQUEEZEDTEXTLABEL_H
 
 #include <ksqueezedtextlabel.h>
+#include <QResizeEvent>
+#include <QMouseEvent>
+#include <QDropEvent>
+#include <QDragEnterEvent>
 
 class QMouseEvent;
 class QDropEvent;
 class QDragEnterEvent;
+class QPaintEvent;
 
 /**
 This class overloads KSqueezedTextLabel and simply adds a clicked signal,
@@ -17,7 +22,7 @@ NEW: a special setText() method allows to choose which part of the string should
 class KrSqueezedTextLabel : public KSqueezedTextLabel {
 Q_OBJECT
   public:
-    KrSqueezedTextLabel(QWidget *parent = 0, const char *name = 0);
+    KrSqueezedTextLabel(QWidget *parent = 0);
     ~KrSqueezedTextLabel();
 
     void enableDrops( bool flag );
@@ -34,8 +39,11 @@ Q_OBJECT
     virtual void mousePressEvent(QMouseEvent *e);
     virtual void dropEvent(QDropEvent *e);
     virtual void dragEnterEvent(QDragEnterEvent *e);
+    virtual void paintEvent( QPaintEvent * e );
     void squeezeTextToLabel(int index=-1, int length=-1);
 
+   QString fullText;
+
   private:
     bool  acceptDrops;
     int _index, _length;
