@@ -32,8 +32,9 @@
 #define __KURLLISTREQUESTER_H__
 
 #include <qwidget.h>
-#include <qlistbox.h>
+#include "../GUI/krlistwidget.h"
 #include <qtoolbutton.h>
+#include <QKeyEvent>
 #include <klineedit.h>
 #include <kurl.h>
 #include <kurlcompletion.h>
@@ -43,34 +44,35 @@ class KURLListRequester : public QWidget
   Q_OBJECT
   
 public:
-  KURLListRequester( QWidget *parent = 0, const char * name = 0 );  
+  KURLListRequester( QWidget *parent = 0 );  
   
-  KURL::List   urlList();
-  void         setUrlList( KURL::List );
+  KUrl::List   urlList();
+  void         setUrlList( KUrl::List );
   
-  KLineEdit   *lineEdit()    {return urlLineEdit;}
-  QListBox    *listBox()     {return urlListBox;}
+  KLineEdit    *lineEdit()    {return urlLineEdit;}
+  KrListWidget *listBox()     {return urlListBox;}
   
   void         setCompletionDir( QString dir ) { completion.setDir( dir ); }
 
 signals:
   void         checkValidity( QString &text, QString &error );
+  void         changed();
   
 protected slots:
   void         slotAdd();
   void         slotBrowse();
-  void         slotRightClicked( QListBoxItem * );
+  void         slotRightClicked( QListWidgetItem *, const QPoint & );
   
 protected:
   virtual void keyPressEvent(QKeyEvent *e);
   void         deleteSelectedItems();
   
   KLineEdit    *urlLineEdit;
-  QListBox     *urlListBox;
+  KrListWidget *urlListBox;
   QToolButton  *urlAddBtn;
   QToolButton  *urlBrowseBtn;
   
-  KURLCompletion completion;
+  KUrlCompletion completion;
 };
 
 #endif /* __KURLLISTREQUESTER_H__ */
