@@ -37,6 +37,8 @@
 #include <qstringlist.h>
 #include <qlabel.h>
 #include <qpushbutton.h>
+#include <qcombobox.h>
+#include <khistorycombobox.h>
 
 #define PS(x) lst.contains(x)>0
 
@@ -44,44 +46,49 @@
 QString PackGUI::filename=0;
 QString PackGUI::destination=0;
 QString PackGUI::type=0;
-bool    PackGUI::moveIntoArchive=false;
+QMap<QString, QString> PackGUI::extraProps;
 
 PackGUI::PackGUI(QString defaultName, QString defaultPath, int noOfFiles, QString filename) :
-    PackGUIBase(0,0,true) {
+    PackGUIBase(0) {
   // first, fill the WhatToPack textfield with information
   if(noOfFiles == 1)
-    TextLabel1->setText( i18n("Pack %1").arg(filename) );
+    TextLabel1->setText( i18n("Pack %1", filename) );
   else
-    TextLabel1->setText( i18n("Pack %n file", "Pack %n files", noOfFiles) );
+    TextLabel1->setText( i18np("Pack %1 file", "Pack %1 files", noOfFiles) );
 
   // now, according to the Konfigurator, fill the combobox with the information
   // about what kind of packing we can do
-  krConfig->setGroup("Archives");
-  QStringList lst=krConfig->readListEntry("Supported Packers");
+  KConfigGroup group( krConfig, "Archives");
+  QStringList lst=group.readEntry("Supported Packers", QStringList());
   // now, clear the type combo and begin...
   typeData->clear();
-  if (PS("tar")) typeData->insertItem("tar");
-  if (PS("tar") && PS("gzip")) typeData->insertItem("tar.gz");
-  if (PS("tar") && PS("bzip2")) typeData->insertItem("tar.bz2");
-  if (PS("zip")) typeData->insertItem("zip");
-  if (PS("rar")) typeData->insertItem("rar");
-  if (PS("lha")) typeData->insertItem("lha");
-  if (PS("arj")) typeData->insertItem("arj");
+  if (PS("tar")) typeData->addItem("tar");
+  if (PS("tar") && PS("gzip")) typeData->addItem("tar.gz");
+  if (PS("tar") && PS("bzip2")) typeData->addItem("tar.bz2");
+  if (PS("tar") && PS("lzma")) typeData->addItem("tar.lzma");
+  if (PS("zip")) typeData->addItem("zip");
+  if (PS("rar")) typeData->addItem("rar");
+  if (PS("lha")) typeData->addItem("lha");
+  if (PS("arj")) typeData->addItem("arj");
+  if (PS("7z")) typeData->addItem("7z");
   // set the last used packer as the top one
-  QString tmp=krConfig->readEntry("lastUsedPacker",QString::null);
-  if (tmp!=QString::null) {
-    for (unsigned int i=0; i< typeData->listBox()->count(); ++i)
-      if (typeData->listBox()->item(i)->text() == tmp) {
-        typeData->listBox()->removeItem(i);
-        typeData->listBox()->insertItem(tmp,0);
+  QString tmp=group.readEntry("lastUsedPacker",QString());
+  if (tmp!=QString()) {
+    for (int i=0; i< typeData->count(); ++i)
+      if (typeData->itemText( i ) == tmp) {
+        typeData->removeItem(i);
+        typeData->insertItem(0, tmp);
+        typeData->setCurrentIndex( 0 );
         break;
       }
   }
+  checkConsistency();
+
   // and go on with the normal stuff
   dirData->setText(defaultPath);
   nameData->setText(defaultName);
   nameData->setFocus();
-  if (typeData->listBox()->count()==0) // if no packers are availble
+  if (typeData->count()==0) // if no packers are availble
     okButton->setEnabled(false);
   setGeometry(krApp->x()+krApp->width()/2-width()/2,krApp->y()+krApp->height()/2-height()/2,width(),height());
 	exec();
@@ -89,27 +96,28 @@ PackGUI::PackGUI(QString defaultName, QString defaultPath, int noOfFiles, QStrin
 
 void PackGUI::browse() {
   QString temp=KFileDialog::getExistingDirectory(dirData->text(),0,i18n("Please select a directory"));
-  if (temp != QString::null)
+  if (temp != QString())
 			dirData->setText(temp);
 }
 
 void PackGUI::accept() {
+  if( !extraProperties( extraProps ) )
+    return;
+
   filename=nameData->text();
   destination=dirData->text();
   type=typeData->currentText();
-  moveIntoArchive=false;//moveCheckbox->isChecked();
   // write down the packer chosen, to be lastUsedPacker
-  krConfig->setGroup("Archives");
-  krConfig->writeEntry("lastUsedPacker",type);
+  KConfigGroup group( krConfig, "Archives");
+  group.writeEntry("lastUsedPacker",type);
   krConfig->sync();
   PackGUIBase::accept();
 }
 
 void PackGUI::reject() {
-  filename=QString::null;
-  destination=QString::null;
-  type=QString::null;
-  moveIntoArchive=false;
+  filename=QString();
+  destination=QString();
+  type=QString();
   PackGUIBase::reject();
 }
 
