@@ -27,6 +27,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
+#include "../defaults.h"
 #include "packguibase.h"
 
 #include <qcheckbox.h>
@@ -37,19 +38,20 @@
 #include <qtoolbutton.h>
 #include <qlayout.h>
 #include <qvariant.h>
-#include <qtooltip.h>
-#include <qwhatsthis.h>
 #include <qimage.h>
 #include <qpixmap.h>
 #include <qspinbox.h>
 #include <qslider.h>
-#include <qhbox.h>
-#include <qvbox.h>
+#include <QHBoxLayout>
+#include <QGridLayout>
+#include <QFrame>
+#include <QVBoxLayout>
 #include <kiconloader.h>
-#include <kglobalsettings.h>
+#include <kcolorscheme.h>
 #include <kcombobox.h>
 #include <kmessagebox.h>
 #include <kio/global.h>
+#include <khistorycombobox.h>
 #include "../krusader.h"
 
 /* 
@@ -59,30 +61,31 @@
  *  The dialog will by default be modeless, unless you set 'modal' to
  *  TRUE to construct a modal dialog.
  */
-PackGUIBase::PackGUIBase( QWidget* parent,  const char* name, bool modal, WFlags fl )
-    : QDialog( parent, name, modal, fl ), expanded( false )
+PackGUIBase::PackGUIBase( QWidget* parent )
+    : QDialog( parent ), expanded( false )
 {
-    if ( !name )
-	setName( "PackGUIBase" );
+    KConfigGroup group( krConfig, "Archives");
+
+    setModal( true );
     resize( 430, 140 );
-    setCaption( i18n( "Pack" ) );
+    setWindowTitle( i18n( "Pack" ) );
     grid = new QGridLayout( this );
     grid->setSpacing( 6 );
-    grid->setMargin( 11 );
+    grid->setContentsMargins( 11, 11, 11, 11 );
 
     hbox = new QHBoxLayout;
     hbox->setSpacing( 6 );
-    hbox->setMargin( 0 );
+    hbox->setContentsMargins( 0, 0, 0, 0 );
 
-    TextLabel3 = new QLabel( this, "TextLabel3" );
+    TextLabel3 = new QLabel( this );
     TextLabel3->setText( i18n( "To archive"  ) );
     hbox->addWidget( TextLabel3 );
 
-    nameData = new QLineEdit( this, "nameData" );
+    nameData = new QLineEdit( this );
     hbox->addWidget( nameData );
 
-    typeData = new QComboBox( FALSE, this, "typeData" );
-    typeData->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)1, (QSizePolicy::SizeType)0 ) );
+    typeData = new QComboBox( this );
+    typeData->setSizePolicy( QSizePolicy( QSizePolicy::Minimum, QSizePolicy::Fixed ) );
     connect( typeData, SIGNAL( activated( const QString & ) ), this,  SLOT( checkConsistency() ) );
     connect( typeData, SIGNAL( highlighted( const QString & ) ), this,  SLOT( checkConsistency() ) );
     hbox->addWidget( typeData );
@@ -91,17 +94,17 @@ PackGUIBase::PackGUIBase( QWidget* parent,  const char* name, bool modal, WFlags
 
     hbox_2 = new QHBoxLayout;
     hbox_2->setSpacing( 6 );
-    hbox_2->setMargin( 0 );
+    hbox_2->setContentsMargins( 0, 0, 0, 0 );
 
-    TextLabel5 = new QLabel( this, "TextLabel5" );
+    TextLabel5 = new QLabel( this );
     TextLabel5->setText( i18n( "In directory"  ) );
     hbox_2->addWidget( TextLabel5 );
 
-    dirData = new QLineEdit( this, "dirData" );
+    dirData = new QLineEdit( this );
     hbox_2->addWidget( dirData );
 
-    browseButton = new QToolButton( this, "browseButton" );
-    browseButton->setIconSet( SmallIcon( "fileopen" ) );
+    browseButton = new QToolButton( this );
+    browseButton->setIcon( SmallIcon( "document-open" ) );
     hbox_2->addWidget( browseButton );
     QSpacerItem* spacer = new QSpacerItem( 48, 20, QSizePolicy::Fixed, QSizePolicy::Fixed );
     hbox_2->addItem( spacer );
@@ -110,15 +113,15 @@ PackGUIBase::PackGUIBase( QWidget* parent,  const char* name, bool modal, WFlags
 
     hbox_3 = new QHBoxLayout;
     hbox_3->setSpacing( 6 );
-    hbox_3->setMargin( 0 );
+    hbox_3->setContentsMargins( 0, 0, 0, 0 );
 
-    PixmapLabel1 = new QLabel( this, "PixmapLabel1" );
-    PixmapLabel1->setPixmap( krLoader->loadIcon("package", KIcon::Desktop, 32) );
+    PixmapLabel1 = new QLabel( this );
+    PixmapLabel1->setPixmap( krLoader->loadIcon("package", KIconLoader::Desktop, 32) );
     PixmapLabel1->setScaledContents( TRUE );
-    PixmapLabel1->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0 ) );
+    PixmapLabel1->setSizePolicy( QSizePolicy( QSizePolicy::Fixed, QSizePolicy::Fixed ) );
     hbox_3->addWidget( PixmapLabel1 );
 
-    TextLabel1 = new QLabel( this, "TextLabel1" );
+    TextLabel1 = new QLabel( this );
     TextLabel1->setText( i18n( "Pack"  ) );
     hbox_3->addWidget( TextLabel1 );
 
@@ -127,24 +130,24 @@ PackGUIBase::PackGUIBase( QWidget* parent,  const char* name, bool modal, WFlags
 
     hbox_4 = new QHBoxLayout;
     hbox_4->setSpacing( 6 );
-    hbox_4->setMargin( 0 );
+    hbox_4->setContentsMargins( 0, 0, 0, 0 );
 
     QSpacerItem* spacer_3 = new QSpacerItem( 20, 26, QSizePolicy::Fixed, QSizePolicy::Expanding );
     hbox_4->addItem( spacer_3 );
     grid->addLayout( hbox_4, 3, 0 );
 
-    advancedWidget = new QWidget( this, "advancedWidget" );
+    advancedWidget = new QWidget( this );
 
     hbox_5 = new QGridLayout( advancedWidget );
     hbox_5->setSpacing( 6 );
-    hbox_5->setMargin( 0 );
+    hbox_5->setContentsMargins( 0, 0, 0, 0 );
 
 
     QVBoxLayout *compressLayout = new QVBoxLayout;
     compressLayout->setSpacing( 6 );
-    compressLayout->setMargin( 0 );
+    compressLayout->setContentsMargins( 0, 0, 0, 0 );
 
-    multipleVolume = new QCheckBox( i18n( "Multiple volume archive" ), advancedWidget, "multipleVolume" );
+    multipleVolume = new QCheckBox( i18n( "Multiple volume archive" ), advancedWidget );
     connect( multipleVolume, SIGNAL( toggled( bool ) ), this, SLOT( checkConsistency() ) );
     compressLayout->addWidget( multipleVolume, 0, 0 );
 
@@ -153,25 +156,28 @@ PackGUIBase::PackGUIBase( QWidget* parent,  const char* name, bool modal, WFlags
     QSpacerItem* spacer_5 = new QSpacerItem( 20, 26, QSizePolicy::Fixed, QSizePolicy::Fixed );
     volumeHbox->addItem( spacer_5 );
 
-    TextLabel7 = new QLabel( i18n("Size:" ), advancedWidget, "TextLabel7" );
+    TextLabel7 = new QLabel( i18n("Size:" ), advancedWidget );
     volumeHbox->addWidget( TextLabel7 );
     
-    volumeSpinBox = new QSpinBox( advancedWidget, "volumeSpinBox" );
-    volumeSpinBox->setMinValue( 1 );
-    volumeSpinBox->setMaxValue( 9999 );
+    volumeSpinBox = new QSpinBox( advancedWidget );
+    volumeSpinBox->setMinimum( 1 );
+    volumeSpinBox->setMaximum( 9999 );
     volumeSpinBox->setValue( 1440 );
     volumeHbox->addWidget( volumeSpinBox );
 
-    volumeUnitCombo = new QComboBox( FALSE, advancedWidget, "volumeUnitCombo" );
-    volumeUnitCombo->insertItem( "B" );
-    volumeUnitCombo->insertItem( "KB" );
-    volumeUnitCombo->insertItem( "MB" );
-    volumeUnitCombo->setCurrentItem( 1 );
+    volumeUnitCombo = new QComboBox( advancedWidget );
+    volumeUnitCombo->addItem( "B" );
+    volumeUnitCombo->addItem( "KB" );
+    volumeUnitCombo->addItem( "MB" );
+    volumeUnitCombo->setCurrentIndex( 1 );
     volumeHbox->addWidget( volumeUnitCombo );
 
     compressLayout->addLayout ( volumeHbox );
 
-    setCompressionLevel = new QCheckBox( i18n( "Set compression level" ), advancedWidget, "multipleVolume" );
+    int level = group.readEntry( "Compression level", _defaultCompressionLevel );
+    setCompressionLevel = new QCheckBox( i18n( "Set compression level" ), advancedWidget );
+    if ( level != _defaultCompressionLevel )
+        setCompressionLevel->setChecked( true );
     connect( setCompressionLevel, SIGNAL( toggled( bool ) ), this, SLOT( checkConsistency() ) );
     compressLayout->addWidget( setCompressionLevel, 0, 0 );
 
@@ -180,24 +186,37 @@ PackGUIBase::PackGUIBase( QWidget* parent,  const char* name, bool modal, WFlags
     QSpacerItem* spacer_6 = new QSpacerItem( 20, 26, QSizePolicy::Fixed, QSizePolicy::Fixed );
     sliderHbox->addItem( spacer_6 );
 
-    QVBox * sliderVBox = new QVBox( advancedWidget );
+    QWidget * sliderVBoxWidget = new QWidget( advancedWidget );
+    QVBoxLayout *sliderVBox = new QVBoxLayout( sliderVBoxWidget );
 
-    compressionSlider = new QSlider( 1, 9, 1, 5, Qt::Horizontal, sliderVBox, "compressionSlider" );
-    compressionSlider->setTickmarks( QSlider::Below );
+    compressionSlider = new QSlider(Qt::Horizontal, sliderVBoxWidget);
+    compressionSlider->setMinimum(1);
+    compressionSlider->setMaximum(9);
+    compressionSlider->setPageStep(1);
+    compressionSlider->setValue( level );
+    compressionSlider->setTickPosition( QSlider::TicksBelow );
+    sliderVBox->addWidget( compressionSlider );
 
-    QHBox * minmaxHBox = new QHBox( sliderVBox );
-    minLabel = new QLabel( i18n("MIN"), minmaxHBox );
-    maxLabel = new QLabel( i18n("MAX"), minmaxHBox );
+    QWidget * minmaxWidget = new QWidget( sliderVBoxWidget );
+    sliderVBox->addWidget( minmaxWidget );
+
+    QHBoxLayout * minmaxHbox = new QHBoxLayout( minmaxWidget );
+
+    minLabel = new QLabel( i18n("MIN"), minmaxWidget );
+    maxLabel = new QLabel( i18n("MAX"), minmaxWidget );
     maxLabel->setSizePolicy( QSizePolicy::Fixed, QSizePolicy::Fixed );
 
-    sliderHbox->addWidget( sliderVBox );
+    minmaxHbox->addWidget( minLabel );
+    minmaxHbox->addWidget( maxLabel );
+
+    sliderHbox->addWidget( sliderVBoxWidget );
 
     compressLayout->addLayout( sliderHbox );
 
     compressLayout->addStretch( 0 );
     hbox_5->addLayout( compressLayout, 0, 0 );
 
-    QFrame *vline = new QFrame( advancedWidget, "vline" );
+    QFrame *vline = new QFrame( advancedWidget );
     vline->setFrameStyle( QFrame::VLine | QFrame::Sunken );
     vline->setMinimumWidth( 20 );
     hbox_5->addWidget( vline, 0, 1 );
@@ -205,23 +224,23 @@ PackGUIBase::PackGUIBase( QWidget* parent,  const char* name, bool modal, WFlags
 
     QGridLayout * passwordGrid = new QGridLayout;
     passwordGrid->setSpacing( 6 );
-    passwordGrid->setMargin( 0 );
+    passwordGrid->setContentsMargins( 0, 0, 0, 0 );
 
-    TextLabel4 = new QLabel( advancedWidget, "TextLabel4" );
+    TextLabel4 = new QLabel( advancedWidget );
     TextLabel4->setText( i18n( "Password"  ) );
     passwordGrid->addWidget( TextLabel4, 0, 0 );
 
-    password = new QLineEdit( advancedWidget, "password" );
+    password = new QLineEdit( advancedWidget );
     password->setEchoMode( QLineEdit::Password );
     connect( password, SIGNAL( textChanged ( const QString & ) ), this, SLOT( checkConsistency() ) );
 
     passwordGrid->addWidget( password, 0, 1 );
 
-    TextLabel6 = new QLabel( advancedWidget, "TextLabel6" );
+    TextLabel6 = new QLabel( advancedWidget );
     TextLabel6->setText( i18n( "Again"  ) );
     passwordGrid->addWidget( TextLabel6, 1, 0 );
 
-    passwordAgain = new QLineEdit( advancedWidget, "password" );
+    passwordAgain = new QLineEdit( advancedWidget );
     passwordAgain->setEchoMode( QLineEdit::Password );
     connect( passwordAgain, SIGNAL( textChanged ( const QString & ) ), this, SLOT( checkConsistency() ) );
 
@@ -232,12 +251,12 @@ PackGUIBase::PackGUIBase( QWidget* parent,  const char* name, bool modal, WFlags
     QSpacerItem* spacer_cons = new QSpacerItem( 48, 20, QSizePolicy::Expanding, QSizePolicy::Fixed );
     consistencyHbox->addItem( spacer_cons );
 
-    passwordConsistencyLabel = new QLabel( advancedWidget, "passwordConsistencyLabel" );
+    passwordConsistencyLabel = new QLabel( advancedWidget );
     consistencyHbox->addWidget( passwordConsistencyLabel );
-    passwordGrid->addMultiCellLayout ( consistencyHbox, 2, 2, 0, 1 );
+    passwordGrid->addLayout ( consistencyHbox, 2, 0, 1, 2 );
 
-    encryptHeaders = new QCheckBox( i18n( "Encrypt headers" ), advancedWidget, "encryptHeaders" );
-    passwordGrid->addMultiCellWidget ( encryptHeaders, 3, 3, 0, 1 );
+    encryptHeaders = new QCheckBox( i18n( "Encrypt headers" ), advancedWidget );
+    passwordGrid->addWidget ( encryptHeaders, 3, 0, 1, 2 );
 
     QSpacerItem* spacer_psw = new QSpacerItem( 20, 20, QSizePolicy::Fixed, QSizePolicy::Expanding );
     passwordGrid->addItem( spacer_psw, 4, 0 );
@@ -246,22 +265,21 @@ PackGUIBase::PackGUIBase( QWidget* parent,  const char* name, bool modal, WFlags
 
     hbox_7 = new QHBoxLayout;
     hbox_7->setSpacing( 6 );
-    hbox_7->setMargin( 0 );
+    hbox_7->setContentsMargins( 0, 0, 0, 0 );
 
-    TextLabel8 = new QLabel( i18n( "Command line switches:" ), advancedWidget, "TextLabel8" );
+    TextLabel8 = new QLabel( i18n( "Command line switches:" ), advancedWidget );
     TextLabel8->setSizePolicy( QSizePolicy::Fixed, QSizePolicy::Fixed );
     hbox_7->addWidget( TextLabel8 );
 
-    commandLineSwitches = new KHistoryCombo( advancedWidget, "commandLineSwitches" );
+    commandLineSwitches = new KHistoryComboBox( advancedWidget );
     commandLineSwitches->setMaxCount(25);  // remember 25 items
     commandLineSwitches->setDuplicatesEnabled(false);
-    krConfig->setGroup("Archives");
-    QStringList list = krConfig->readListEntry("Command Line Switches");
+    QStringList list = group.readEntry("Command Line Switches", QStringList() );
     commandLineSwitches->setHistoryItems(list);
 
     hbox_7->addWidget( commandLineSwitches );
     
-    hbox_5->addMultiCellLayout( hbox_7, 1, 1, 0, 2 );
+    hbox_5->addLayout( hbox_7, 1, 0, 1, 3 );
 
 
     advancedWidget->hide();
@@ -271,21 +289,21 @@ PackGUIBase::PackGUIBase( QWidget* parent,  const char* name, bool modal, WFlags
     
     hbox_6 = new QHBoxLayout;
     hbox_6->setSpacing( 6 );
-    hbox_6->setMargin( 0 );
+    hbox_6->setContentsMargins( 0, 0, 0, 0 );
 
-    advancedButton = new QPushButton( this, "advancedButton" );
+    advancedButton = new QPushButton( this );
     advancedButton->setText( i18n( "&Advanced" ) + " >>" );
     hbox_6->addWidget( advancedButton );
 
     QSpacerItem* spacer_2 = new QSpacerItem( 140, 20, QSizePolicy::Expanding, QSizePolicy::Fixed );
     hbox_6->addItem( spacer_2 );
 
-    okButton = new QPushButton( this, "okButton" );
+    okButton = new QPushButton( this );
     okButton->setText( i18n( "Ok"  ) );
     okButton->setDefault( true );
     hbox_6->addWidget( okButton );
 
-    cancelButton = new QPushButton( this, "cancelButton" );
+    cancelButton = new QPushButton( this );
     cancelButton->setText( i18n( "Cancel"  ) );
     hbox_6->addWidget( cancelButton );
 
@@ -328,19 +346,21 @@ void PackGUIBase::expand() {
 }
 
 void PackGUIBase::checkConsistency() {
+    QPalette pal = passwordConsistencyLabel->palette();
     if( password->text().isEmpty() && passwordAgain->text().isEmpty()) {
-      passwordConsistencyLabel->setPaletteForegroundColor( KGlobalSettings::textColor() );
+      pal.setColor( passwordConsistencyLabel->foregroundRole(), KColorScheme(QPalette::Active, KColorScheme::View).foreground().color() );
       passwordConsistencyLabel->setText( i18n( "No password specified" ) );
     }
     else
     if( password->text() == passwordAgain->text() ) {
-      passwordConsistencyLabel->setPaletteForegroundColor( KGlobalSettings::textColor() );
+      pal.setColor( passwordConsistencyLabel->foregroundRole(), KColorScheme(QPalette::Active, KColorScheme::View).foreground().color() );
       passwordConsistencyLabel->setText( i18n( "The passwords are equal" ) );
     }
     else {
-      passwordConsistencyLabel->setPaletteForegroundColor( Qt::red );
+      pal.setColor( passwordConsistencyLabel->foregroundRole(), Qt::red );
       passwordConsistencyLabel->setText( i18n( "The passwords are different" ) );
     }
+    passwordConsistencyLabel->setPalette( pal );
 
     QString packer = typeData->currentText();
 
@@ -374,6 +394,8 @@ void PackGUIBase::checkConsistency() {
 bool PackGUIBase::extraProperties( QMap<QString,QString> & inMap ) {
     inMap.clear();
 
+    KConfigGroup group( krConfig, "Archives");
+
     if( password->isEnabled() && passwordAgain->isEnabled() ) {
       if( password->text() != passwordAgain->text() ) {
         KMessageBox::error( this, i18n( "Cannot pack! The passwords are different!" ) );
@@ -391,7 +413,7 @@ bool PackGUIBase::extraProperties( QMap<QString,QString> & inMap ) {
     if( multipleVolume->isEnabled() && multipleVolume->isChecked() ) {
       KIO::filesize_t size = volumeSpinBox->value();
 
-      switch( volumeUnitCombo->currentItem() ) {
+      switch( volumeUnitCombo->currentIndex() ) {
       case 2:
         size *= 1000;
       case 1:
@@ -413,14 +435,16 @@ bool PackGUIBase::extraProperties( QMap<QString,QString> & inMap ) {
 
     if( setCompressionLevel->isEnabled() && setCompressionLevel->isChecked() ) {
       inMap[ "CompressionLevel" ] = QString("%1").arg( compressionSlider->value() );
+      int level = compressionSlider->value();
+      group.writeEntry( "Compression level", level );
     }
 
-    QString cmdArgs = commandLineSwitches->currentText().stripWhiteSpace();
+    QString cmdArgs = commandLineSwitches->currentText().trimmed();
     if( !cmdArgs.isEmpty() ) {
       bool firstChar = true;
       QChar quote = '\0';
       
-      for( unsigned i=0; i < cmdArgs.length(); i++ ) {
+      for( int i=0; i < cmdArgs.length(); i++ ) {
          QChar ch( cmdArgs[ i ] );
          if( ch.isSpace() )
            continue;
@@ -457,8 +481,7 @@ bool PackGUIBase::extraProperties( QMap<QString,QString> & inMap ) {
 
       commandLineSwitches->addToHistory( cmdArgs );
       QStringList list = commandLineSwitches->historyItems();
-      krConfig->setGroup("Archives");
-      krConfig->writeEntry("Command Line Switches", list);
+      group.writeEntry("Command Line Switches", list);
 
       inMap[ "CommandLineSwitches" ] = cmdArgs;      
     }
