@@ -33,6 +33,10 @@
 #include <klocale.h>
 #include <qdialog.h>
 #include <qmap.h>
+#include <QGridLayout>
+#include <QHBoxLayout>
+#include <QVBoxLayout>
+#include <QLabel>
 
 
 class QVBoxLayout; 
@@ -46,14 +50,14 @@ class QPushButton;
 class QToolButton;
 class QSpinBox;
 class QSlider;
-class KHistoryCombo;
+class KHistoryComboBox;
 
 class PackGUIBase : public QDialog
 { 
     Q_OBJECT
 
 public:
-    PackGUIBase( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
+    PackGUIBase( QWidget* parent = 0 );
     ~PackGUIBase();
 
     QLabel* TextLabel3;
@@ -83,7 +87,7 @@ public:
     QComboBox* volumeUnitCombo;
     QCheckBox* setCompressionLevel;
     QSlider*   compressionSlider;
-    KHistoryCombo *commandLineSwitches;
+    KHistoryComboBox *commandLineSwitches;
 
 public slots:
     virtual void browse();
