@@ -30,19 +30,27 @@
 
 #include <time.h>
 #include <qlayout.h>
+#include <QKeyEvent>
+#include <QLabel>
+#include <QGridLayout>
+#include <QPixmap>
+#include <QFrame>
+#include <QResizeEvent>
+#include <QEvent>
+#include <QHash>
 #include <klocale.h>
-#include <kpopupmenu.h>
+#include <kmenu.h>
 #include <kmimetype.h>
 #include <kmessagebox.h>
 #include <kglobalsettings.h>
 #include <kio/job.h>
+#include <kio/deletejob.h>
 #include <qpushbutton.h>
-#include <qhbox.h>
 #include <qapplication.h>
 #include <qcursor.h>
 #include <qpixmapcache.h>
 #include <qgroupbox.h>
-#include <qguardedptr.h>
+#include <qpointer.h>
 #include "diskusage.h"
 #include "../VFS/krpermhandler.h"
 #include "../VFS/krvfshandler.h"
@@ -76,119 +84,112 @@
 
 #define MAX_FILENUM         100
 
-LoaderWidget::LoaderWidget( QWidget *parent, const char *name ) : QScrollView( parent, name ), cancelled( false )
+LoaderWidget::LoaderWidget( QWidget *parent ) : QScrollArea( parent ), cancelled( false )
 {
-  viewport()->setEraseColor( Qt::white );
+  QPalette palette = viewport()->palette();
+  palette.setColor(viewport()->backgroundRole(), Qt::white);
+  viewport()->setPalette(palette);
+
   widget = new QWidget( parent );
 
   QGridLayout *loaderLayout = new QGridLayout( widget );
   loaderLayout->setSpacing( 0 );
-  loaderLayout->setMargin( 0 );
+  loaderLayout->setContentsMargins( 0, 0, 0, 0 );
 
-  QGroupBox *loaderBox = new QGroupBox( widget, "loaderGroupBox" );
-  loaderBox->setFrameShape( QGroupBox::Box );
-  loaderBox->setFrameShadow( QGroupBox::Sunken );
-  loaderBox->setColumnLayout(0, Qt::Vertical );
-  loaderBox->layout()->setSpacing( 0 );
-  loaderBox->layout()->setMargin( 0 );
+  QFrame *loaderBox = new QFrame( widget );
+  loaderBox->setFrameShape( QFrame::Box );
+  loaderBox->setFrameShadow( QFrame::Sunken );
   loaderBox->setSizePolicy( QSizePolicy::Fixed, QSizePolicy::Fixed );
   loaderBox->setFrameStyle( QFrame::Panel + QFrame::Raised );
   loaderBox->setLineWidth( 2 );
 
-  QGridLayout *synchGrid = new QGridLayout( loaderBox->layout() );
+  QGridLayout *synchGrid = new QGridLayout( loaderBox );
   synchGrid->setSpacing( 6 );
-  synchGrid->setMargin( 11 );
+  synchGrid->setContentsMargins( 11, 11, 11, 11 );
 
-  QLabel *titleLabel = new QLabel( i18n( "Loading Usage Information" ), loaderBox, "titleLabel" );
+  QLabel *titleLabel = new QLabel( i18n( "Loading Usage Information" ), loaderBox );
   titleLabel->setAlignment( Qt::AlignHCenter );
-  synchGrid->addMultiCellWidget( titleLabel, 0, 0, 0, 1 );
+  synchGrid->addWidget( titleLabel, 0, 0, 1, 2 );
 
-  QLabel *filesLabel = new QLabel( i18n( "Files:" ), loaderBox, "filesLabel" );
+  QLabel *filesLabel = new QLabel( i18n( "Files:" ), loaderBox );
   filesLabel->setFrameShape( QLabel::StyledPanel );
   filesLabel->setFrameShadow( QLabel::Sunken );
   synchGrid->addWidget( filesLabel, 1, 0 );
 
-  QLabel *directoriesLabel = new QLabel( i18n( "Directories:" ), loaderBox, "directoriesLabel" );
+  QLabel *directoriesLabel = new QLabel( i18n( "Directories:" ), loaderBox );
   directoriesLabel->setFrameShape( QLabel::StyledPanel );
   directoriesLabel->setFrameShadow( QLabel::Sunken );
   synchGrid->addWidget( directoriesLabel, 2, 0 );
 
-  QLabel *totalSizeLabel = new QLabel( i18n( "Total Size:" ), loaderBox, "totalSizeLabel" );
+  QLabel *totalSizeLabel = new QLabel( i18n( "Total Size:" ), loaderBox );
   totalSizeLabel->setFrameShape( QLabel::StyledPanel );
   totalSizeLabel->setFrameShadow( QLabel::Sunken );
   synchGrid->addWidget( totalSizeLabel, 3, 0 );
 
-  files = new QLabel( loaderBox, "files" );
+  files = new QLabel( loaderBox );
   files->setFrameShape( QLabel::StyledPanel );
   files->setFrameShadow( QLabel::Sunken );
   files->setAlignment( Qt::AlignRight );
   synchGrid->addWidget( files, 1, 1 );
 
-  directories = new QLabel( loaderBox, "directories" );
+  directories = new QLabel( loaderBox );
   directories->setFrameShape( QLabel::StyledPanel );
   directories->setFrameShadow( QLabel::Sunken );
   directories->setAlignment( Qt::AlignRight );
   synchGrid->addWidget( directories, 2, 1 );
 
-  totalSize = new QLabel( loaderBox, "totalSize" );
+  totalSize = new QLabel( loaderBox );
   totalSize->setFrameShape( QLabel::StyledPanel );
   totalSize->setFrameShadow( QLabel::Sunken );
   totalSize->setAlignment( Qt::AlignRight );
   synchGrid->addWidget( totalSize, 3, 1 );
 
   int width;
-  searchedDirectory = new KSqueezedTextLabel( loaderBox, "searchedDirectory" );
+  searchedDirectory = new KSqueezedTextLabel( loaderBox );
   searchedDirectory->setFrameShape( QLabel::StyledPanel );
   searchedDirectory->setFrameShadow( QLabel::Sunken );
   searchedDirectory->setMinimumWidth( width = QFontMetrics(searchedDirectory->font()).width("W") * 30 );
   searchedDirectory->setMaximumWidth( width );
-  synchGrid->addMultiCellWidget( searchedDirectory, 4, 4, 0, 1 );
+  synchGrid->addWidget( searchedDirectory, 4, 0, 1, 2 );
 
-  QFrame *line = new QFrame( loaderBox, "duLine" );
+  QFrame *line = new QFrame( loaderBox );
   line->setFrameStyle( QFrame::HLine | QFrame::Sunken );
-  synchGrid->addMultiCellWidget( line, 5, 5, 0, 1 );
+  synchGrid->addWidget( line, 5, 0, 1, 2 );
+
+  QWidget *hboxWidget = new QWidget( loaderBox );
+  QHBoxLayout * hbox = new QHBoxLayout( hboxWidget );
 
-  QHBox *hbox = new QHBox( loaderBox, "hbox" );
   QSpacerItem* spacer = new QSpacerItem( 0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding );
-  hbox->layout()->addItem( spacer );
-  QPushButton *cancelButton = new QPushButton( hbox, "cancelButton" );
+  hbox->addItem( spacer );
+  QPushButton *cancelButton = new QPushButton( hboxWidget );
   cancelButton->setText( i18n( "Cancel"  ) );
-  synchGrid->addWidget( hbox, 6, 1 );
+  hbox->addWidget( cancelButton );
+
+  synchGrid->addWidget( hboxWidget, 6, 1 );
 
   loaderLayout->addWidget( loaderBox, 0, 0 );
 
-  addChild( widget );
+  setWidget( widget );
+  setAlignment( Qt::AlignCenter );
 
   connect( cancelButton, SIGNAL( clicked() ), this, SLOT( slotCancelled() ) );
 }
 
-void LoaderWidget::resizeEvent ( QResizeEvent *e )
-{
-  QScrollView::resizeEvent( e );
-
-  int x = ( viewport()->width() - widget->width() ) / 2;
-  int y = ( viewport()->height() - widget->height() ) / 2;
-  if( x < 0 ) x=0;
-  if( y < 0 ) y=0;
-
-  moveChild( widget, x, y );
-}
-
 void LoaderWidget::init()
 {
   cancelled = false;
 }
 
-void LoaderWidget::setCurrentURL( KURL url )
+void LoaderWidget::setCurrentURL( KUrl url )
 {
-  searchedDirectory->setText( vfs::pathOrURL( url, 1) );
+  searchedDirectory->setText( vfs::pathOrUrl( url, KUrl::AddTrailingSlash) );
 }
 
 void LoaderWidget::setValues( int fileNum, int dirNum, KIO::filesize_t total )
 {
   files->setText( QString("%1").arg( fileNum ) );
   directories->setText( QString("%1").arg( dirNum ) );
-  totalSize->setText( QString("%1").arg( KRpermHandler::parseSize( total ).stripWhiteSpace() ) );
+  totalSize->setText( QString("%1").arg( KRpermHandler::parseSize( total ).trimmed() ) );
 }
 
 void LoaderWidget::slotCancelled()
@@ -196,14 +197,14 @@ void LoaderWidget::slotCancelled()
   cancelled = true;
 }
 
-DiskUsage::DiskUsage( QString confGroup, QWidget *parent, char *name ) : QWidgetStack( parent, name ),
+DiskUsage::DiskUsage( QString confGroup, QWidget *parent ) : QStackedWidget( parent ),
                       currentDirectory( 0 ), root( 0 ), configGroup( confGroup ), loading( false ),
                       abortLoading( false ), clearAfterAbort( false ), deleting( false ), searchVfs( 0 )
 {
-  listView = new DUListView( this, "DU ListView" );
-  lineView = new DULines( this, "DU LineView" );
-  filelightView = new DUFilelight( this, "Filelight canvas" );
-  loaderView = new LoaderWidget( this, "Loading view" );
+  listView = new DUListView( this );
+  lineView = new DULines( this );
+  filelightView = new DUFilelight( this );
+  loaderView = new LoaderWidget( this );
 
   addWidget( listView );
   addWidget( lineView );
@@ -213,7 +214,6 @@ DiskUsage::DiskUsage( QString confGroup, QWidget *parent, char *name ) : QWidget
   setView( VIEW_LINES );
 
   Filelight::Config::read();
-  propertyMap.setAutoDelete( true );
 
   connect( &loadingTimer, SIGNAL( timeout() ), this, SLOT( slotLoadDirectory() ) );
 }
@@ -229,9 +229,13 @@ DiskUsage::~DiskUsage()
     delete lineView;
   if( filelightView )
     delete filelightView;
+
+  QHashIterator< File *, Properties * > lit( propertyMap );
+  while( lit.hasNext() )
+    delete lit.next().value();
 }
 
-void DiskUsage::load( KURL baseDir )
+void DiskUsage::load( KUrl baseDir )
 {
   if( searchVfs && !searchVfs->vfs_canDelete() ) {
     return;
@@ -245,9 +249,9 @@ void DiskUsage::load( KURL baseDir )
   clear();
 
   baseURL = baseDir;
-  baseURL.setPath( baseDir.path( -1 ) );
+  baseURL.setPath( baseDir.path( KUrl::RemoveTrailingSlash ) );
 
-  root = new Directory( baseURL.fileName(), vfs::pathOrURL( baseDir ) );
+  root = new Directory( baseURL.fileName(), baseDir.pathOrUrl() );
 
   directoryStack.clear();
   parentStack.clear();
@@ -283,13 +287,15 @@ void DiskUsage::load( KURL baseDir )
   loaderView->setCurrentURL( baseURL );
   loaderView->setValues( fileNum, dirNum, currentSize );
 
-  loadingTimer.start( 0, true );
+  loadingTimer.setSingleShot( true );
+  loadingTimer.start( 0 );
 }
 
 void DiskUsage::slotLoadDirectory()
 {
   if( searchVfs && !searchVfs->vfs_canDelete() ) { // recursive call from slotLoadDirectory?
-    loadingTimer.start( 100, true );               // as it can cause crash, ignore it and wait while
+    loadingTimer.setSingleShot( true );
+    loadingTimer.start( 100 );                     // as it can cause crash, ignore it and wait while
     return;                                        // the recursion finishes
   }
   if( ( currentVfile == 0 && directoryStack.isEmpty() ) || loaderView->wasCancelled() || abortLoading )
@@ -327,7 +333,7 @@ void DiskUsage::slotLoadDirectory()
 
         contentMap.insert( dirToCheck, currentParent );
 
-        KURL url = baseURL;
+        KUrl url = baseURL;
 
         if( !dirToCheck.isEmpty() )
           url.addPath( dirToCheck );
@@ -380,7 +386,8 @@ void DiskUsage::slotLoadDirectory()
     }
 
     loaderView->setValues( fileNum, dirNum, currentSize );
-    loadingTimer.start( 0, true );
+    loadingTimer.setSingleShot( true );
+    loadingTimer.start( 0 );
   }
 }
 
@@ -406,14 +413,13 @@ void DiskUsage::dirUp()
       changeDirectory( (Directory *)(currentDirectory->parent()) );
     else
     {
-      KURL up = baseURL.upURL();
+      KUrl up = baseURL.upUrl();
 
       if( KMessageBox::questionYesNo( this, i18n( "Stepping into the parent directory requires "
                                                   "loading the content of the \"%1\" URL. Do you wish "
-                                                  "to continue?" )
-                                            .arg( vfs::pathOrURL( up ) ),
-                                            i18n( "Krusader::DiskUsage" ), KStdGuiItem::yes(),
-                                            KStdGuiItem::no(), "DiskUsageLoadParentDir"
+                                                  "to continue?", up.pathOrUrl() ),
+                                            i18n( "Krusader::DiskUsage" ), KStandardGuiItem::yes(),
+                                            KStandardGuiItem::no(), "DiskUsageLoadParentDir"
                                             ) == KMessageBox::Yes )
         load( up );
     }
@@ -428,7 +434,9 @@ Directory * DiskUsage::getDirectory( QString dir )
   if( dir.isEmpty() )
     return root;
 
-  return contentMap.find( dir );
+  if( contentMap.find( dir ) == contentMap.end() )
+    return 0;
+  return contentMap[ dir ];
 }
 
 File * DiskUsage::getFile( QString path )
@@ -438,7 +446,7 @@ File * DiskUsage::getFile( QString path )
 
   QString dir = path;
 
-  int ndx = path.findRev( '/' );
+  int ndx = path.lastIndexOf( '/' );
   QString file = path.mid( ndx + 1 );
 
   if( ndx == -1 )
@@ -459,8 +467,13 @@ File * DiskUsage::getFile( QString path )
 
 void DiskUsage::clear()
 {
-  baseURL = KURL();
+  baseURL = KUrl();
   emit clearing();
+
+  QHashIterator< File *, Properties * > lit( propertyMap );
+  while( lit.hasNext() )
+    delete lit.next().value();
+
   propertyMap.clear();
   contentMap.clear();
   if( root )
@@ -582,21 +595,21 @@ int DiskUsage::del( File *file, bool calcPercents, int depth )
   if( file == root )
     return 0;
 
-  krConfig->setGroup( "General" );
-  bool trash = krConfig->readBoolEntry( "Move To Trash", _MoveToTrash );
-  KURL url = vfs::fromPathOrURL( file->fullPath() );
+  KConfigGroup gg( krConfig, "General" );
+  bool trash = gg.readEntry( "Move To Trash", _MoveToTrash );
+  KUrl url = KUrl( file->fullPath() );
 
   if( calcPercents )
   {
     // now ask the user if he want to delete:
-    krConfig->setGroup( "Advanced" );
-    if ( krConfig->readBoolEntry( "Confirm Delete", _ConfirmDelete ) ) {
+    KConfigGroup ga( krConfig, "Advanced" );
+    if ( ga.readEntry( "Confirm Delete", _ConfirmDelete ) ) {
       QString s, b;
       if ( trash && url.isLocalFile() ) {
-        s = i18n( "Do you really want to move this item to the trash?" );
+        s = i18nc( "singularOnly", "Do you really want to move this item to the trash?" );
         b = i18n( "&Trash" );
       } else {
-        s = i18n( "Do you really want to delete this item?" );
+        s = i18nc( "singularOnly", "Do you really want to delete this item?" );
         b = i18n( "&Delete" );
       }
 
@@ -604,11 +617,11 @@ int DiskUsage::del( File *file, bool calcPercents, int depth )
       name.append( file->fullPath() );
       // show message
       // note: i'm using continue and not yes/no because the yes/no has cancel as default button
-      if ( KMessageBox::warningContinueCancelList( krApp, s, name, i18n( "Warning" ), b ) != KMessageBox::Continue )
+      if ( KMessageBox::warningContinueCancelList( krApp, s, name, i18n( "Warning" ), KGuiItem( b ) ) != KMessageBox::Continue )
         return 0;
     }
 
-    emit status( i18n( "Deleting %1..." ).arg( file->name() ) );
+    emit status( i18n( "Deleting %1...", file->name() ) );
   }
 
   if( file == currentDirectory )
@@ -637,28 +650,24 @@ int DiskUsage::del( File *file, bool calcPercents, int depth )
   emit deleted( file );
   deleteNr++;
 
-  QGuardedPtr<KIO::Job> job;
+  KIO::Job *job;
 
   if( trash )
   {
-#if KDE_IS_VERSION(3,4,0)
-    job = KIO::trash( url, true );
-#else
-    job = new KIO::CopyJob( url,KGlobalSettings::trashPath(),KIO::CopyJob::Move,false,true );
-#endif
-    connect(job,SIGNAL(result(KIO::Job*)),krApp,SLOT(changeTrashIcon()));
+    job = KIO::trash( url );
+    connect(job,SIGNAL(result(KJob*)),krApp,SLOT(changeTrashIcon()));
   }
   else
   {
-    job = new KIO::DeleteJob( vfs::fromPathOrURL( file->fullPath() ), false, false);
+    job = KIO::del( KUrl( file->fullPath() ), KIO::HideProgressInfo);
   }
 
   deleting = true;    // during qApp->processEvent strange things can occur
   grabMouse();        // that's why we disable the mouse and keyboard events
   grabKeyboard();
 
-  while( !job.isNull() )
-    qApp->processEvents();
+  job->exec();
+  delete job;
 
   releaseMouse();
   releaseKeyboard(); 
@@ -686,30 +695,38 @@ int DiskUsage::del( File *file, bool calcPercents, int depth )
 
 void * DiskUsage::getProperty( File *item, QString key )
 {
-  Properties * props = propertyMap.find( item );
-  if( props == 0 )
+  QHash< File *, Properties *>::iterator itr = propertyMap.find( item );
+  if( itr == propertyMap.end() )
     return 0;
-  return props->find( key );
+
+  QHash<QString, void *>::iterator it = (*itr)->find( key );
+  if( it == (*itr)->end() )
+    return 0;
+
+  return it.value();
 }
 
 void DiskUsage::addProperty( File *item, QString key, void * prop )
 {
-  Properties * props = propertyMap.find( item );
-  if( props == 0 )
+  Properties *props;
+  QHash< File *, Properties *>::iterator itr = propertyMap.find( item );
+  if( itr == propertyMap.end() )
   {
     props = new Properties();
     propertyMap.insert( item, props );
-  }
+  } else
+    props = *itr;
+
   props->insert( key, prop );
 }
 
 void DiskUsage::removeProperty( File *item, QString key )
 {
-  Properties * props = propertyMap.find( item );
-  if( props == 0 )
+  QHash< File *, Properties *>::iterator itr = propertyMap.find( item );
+  if( itr == propertyMap.end() )
     return;
-  props->remove( key );
-  if( props->count() == 0 )
+  (*itr)->remove( key );
+  if( (*itr)->count() == 0 )
     propertyMap.remove( item );
 }
 
@@ -720,14 +737,14 @@ void DiskUsage::createStatus()
   if( dirEntry == 0 )
     return;
 
-  KURL url = baseURL;
+  KUrl url = baseURL;
   if( dirEntry != root )
       url.addPath( dirEntry->directory() );
 
-  emit status( i18n( "Current directory:%1,  Total size:%2,  Own size:%3" )
-               .arg( vfs::pathOrURL( url, -1 ) )
-               .arg( " "+KRpermHandler::parseSize( dirEntry->size() ) )
-               .arg( " "+KRpermHandler::parseSize( dirEntry->ownSize() ) ) );
+  emit status( i18n( "Current directory:%1,  Total size:%2,  Own size:%3",
+                     vfs::pathOrUrl( url, KUrl::RemoveTrailingSlash ),
+                     " "+KRpermHandler::parseSize( dirEntry->size() ),
+                     " "+KRpermHandler::parseSize( dirEntry->ownSize() ) ) );
 }
 
 void DiskUsage::changeDirectory( Directory *dir )
@@ -746,59 +763,85 @@ Directory* DiskUsage::getCurrentDir()
   return currentDirectory;
 }
 
-void DiskUsage::rightClickMenu( File *fileItem, KPopupMenu *addPopup, QString addPopupName )
+void DiskUsage::rightClickMenu( const QPoint & pos, File *fileItem, KMenu *addPopup, QString addPopupName )
 {
-  KPopupMenu popup( this );
+  KMenu popup( this );
 
-  popup.insertTitle( i18n("Disk Usage"));
+  popup.setTitle( i18n("Disk Usage"));
+
+  QHash<void *, int> actionHash;
 
   if( fileItem != 0 )
   {
-    popup.insertItem(  i18n("Delete"),          DELETE_ID);
-    popup.setAccel( Key_Delete, DELETE_ID );
-    popup.insertItem(  i18n("Exclude"),         EXCLUDE_ID);
-    popup.setAccel( CTRL + Key_E, EXCLUDE_ID );
-    popup.insertSeparator();
+    QAction * actDelete = popup.addAction( i18n("Delete") );
+    actionHash[ actDelete ] = DELETE_ID;
+    actDelete->setShortcut( Qt::Key_Delete );
+    QAction * actExclude = popup.addAction( i18n("Exclude") );
+    actionHash[ actExclude ] = EXCLUDE_ID;
+    actExclude->setShortcut( Qt::CTRL + Qt::Key_E );
+    popup.addSeparator();
   }
 
-  popup.insertItem(  i18n("Up one directory"),  PARENT_DIR_ID);
-  popup.setAccel( SHIFT + Key_Up, PARENT_DIR_ID );
-  popup.insertItem(  i18n("New search"),        NEW_SEARCH_ID);
-  popup.setAccel( CTRL + Key_N, NEW_SEARCH_ID );
-  popup.insertItem(  i18n("Refresh"),           REFRESH_ID);
-  popup.setAccel( CTRL + Key_R, REFRESH_ID );
-  popup.insertItem(  i18n("Include all"),       INCLUDE_ALL_ID);
-  popup.setAccel( CTRL + Key_I, INCLUDE_ALL_ID );
-  popup.insertItem(  i18n("Step into"),         STEP_INTO_ID);
-  popup.setAccel( SHIFT + Key_Down, STEP_INTO_ID );
-  popup.insertSeparator();
+  QAction * myAct = popup.addAction( i18n("Up one directory") );
+  actionHash[ myAct ] = PARENT_DIR_ID;
+  myAct->setShortcut( Qt::SHIFT + Qt::Key_Up );
+
+  myAct = popup.addAction( i18n("New search") );
+  actionHash[ myAct ] = NEW_SEARCH_ID;
+  myAct->setShortcut( Qt::CTRL + Qt::Key_N );
+
+  myAct = popup.addAction( i18n("Refresh") );
+  actionHash[ myAct ] = REFRESH_ID;
+  myAct->setShortcut( Qt::CTRL + Qt::Key_R );
+
+  myAct = popup.addAction( i18n("Include all") );
+  actionHash[ myAct ] = INCLUDE_ALL_ID;
+  myAct->setShortcut( Qt::CTRL + Qt::Key_I);
+
+  myAct = popup.addAction( i18n("Step into") );
+  actionHash[ myAct ] = STEP_INTO_ID;
+  myAct->setShortcut( Qt::SHIFT + Qt::Key_Down );
+
+  popup.addSeparator();
 
 
   if( addPopup != 0 )
   {
-    popup.insertItem( QPixmap(), addPopup, ADDITIONAL_POPUP_ID );
-    popup.changeItem( ADDITIONAL_POPUP_ID, addPopupName );
+    QAction * menu = popup.addMenu( addPopup );
+    menu->setText( addPopupName );
   }
 
-  KPopupMenu viewPopup;
-  viewPopup.insertItem(i18n("Lines"),      LINES_VIEW_ID);
-  viewPopup.setAccel( CTRL + Key_L, LINES_VIEW_ID );
-  viewPopup.insertItem(i18n("Detailed"),   DETAILED_VIEW_ID);
-  viewPopup.setAccel( CTRL + Key_D, DETAILED_VIEW_ID );
-  viewPopup.insertItem(i18n("Filelight"),  FILELIGHT_VIEW_ID);
-  viewPopup.setAccel( CTRL + Key_F, FILELIGHT_VIEW_ID );
-  viewPopup.insertSeparator();
-  viewPopup.insertItem(i18n("Next"),       NEXT_VIEW_ID);
-  viewPopup.setAccel( SHIFT + Key_Right, NEXT_VIEW_ID );
-  viewPopup.insertItem(i18n("Previous"),   PREVIOUS_VIEW_ID);
-  viewPopup.setAccel( SHIFT + Key_Left, PREVIOUS_VIEW_ID );
+  KMenu viewPopup;
 
-  popup.insertItem( QPixmap(), &viewPopup, VIEW_POPUP_ID );
-  popup.changeItem( VIEW_POPUP_ID, i18n( "View" ) );
+  myAct = viewPopup.addAction( i18n("Lines") );
+  actionHash[ myAct ] = LINES_VIEW_ID;
+  myAct->setShortcut( Qt::CTRL + Qt::Key_L );
 
-  int result=popup.exec(QCursor::pos());
+  myAct = viewPopup.addAction( i18n("Detailed") );
+  actionHash[ myAct ] = DETAILED_VIEW_ID;
+  myAct->setShortcut( Qt::CTRL + Qt::Key_D );
 
-  executeAction( result, fileItem );
+  myAct = viewPopup.addAction( i18n("Filelight") );
+  actionHash[ myAct ] = FILELIGHT_VIEW_ID;
+  myAct->setShortcut( Qt::CTRL + Qt::Key_F );
+
+  viewPopup.addSeparator();
+
+  myAct = viewPopup.addAction( i18n("Next") );
+  actionHash[ myAct ] = NEXT_VIEW_ID;
+  myAct->setShortcut( Qt::SHIFT + Qt::Key_Right );
+
+  myAct = viewPopup.addAction( i18n("Previous") );
+  actionHash[ myAct ] = PREVIOUS_VIEW_ID;
+  myAct->setShortcut( Qt::SHIFT + Qt::Key_Left );
+
+  QAction * menu = popup.addMenu( &viewPopup );
+  menu->setText( i18n( "View" ) );
+
+  QAction * res = popup.exec( pos );
+
+  if( actionHash.contains( res ) )
+    executeAction( actionHash[ res ], fileItem );
 }
 
 void DiskUsage::executeAction( int action, File * fileItem )
@@ -833,7 +876,7 @@ void DiskUsage::executeAction( int action, File * fileItem )
         uri = fileItem->fullPath();
       else
         uri = currentDirectory->fullPath();
-      ACTIVE_FUNC->openUrl(vfs::fromPathOrURL( uri ));
+      ACTIVE_FUNC->openUrl(KUrl( uri ));
     }
     break;
   case LINES_VIEW_ID:
@@ -852,7 +895,7 @@ void DiskUsage::executeAction( int action, File * fileItem )
     setView( ( activeView + 2 ) % 3 );
     break;
   }
-  visibleWidget()->setFocus();
+  currentWidget()->setFocus();
 }
 
 void DiskUsage::keyPressEvent( QKeyEvent *e )
@@ -861,93 +904,93 @@ void DiskUsage::keyPressEvent( QKeyEvent *e )
   {
     switch ( e->key() )
     {
-    case Key_E:
-      if( e->state() == ControlButton )
+    case Qt::Key_E:
+      if( e->modifiers() == Qt::ControlModifier )
       {
         executeAction( EXCLUDE_ID, getCurrentFile() );
         return;
       }
-    case Key_D:
-      if( e->state() == ControlButton )
+    case Qt::Key_D:
+      if( e->modifiers() == Qt::ControlModifier )
       {
         executeAction( DETAILED_VIEW_ID );
         return;
       }
-    case Key_F:
-      if( e->state() == ControlButton )
+    case Qt::Key_F:
+      if( e->modifiers() == Qt::ControlModifier )
       {
         executeAction( FILELIGHT_VIEW_ID );
         return;
       }
-    case Key_I:
-      if( e->state() == ControlButton )
+    case Qt::Key_I:
+      if( e->modifiers() == Qt::ControlModifier )
       {
         executeAction( INCLUDE_ALL_ID );
         return;
       }
       break;
-    case Key_L:
-      if( e->state() == ControlButton )
+    case Qt::Key_L:
+      if( e->modifiers() == Qt::ControlModifier )
       {
         executeAction( LINES_VIEW_ID );
         return;
       }
-    case Key_N:
-      if( e->state() == ControlButton )
+    case Qt::Key_N:
+      if( e->modifiers() == Qt::ControlModifier )
       {
         executeAction( NEW_SEARCH_ID );
         return;
       }
       break;
-    case Key_R:
-      if( e->state() == ControlButton )
+    case Qt::Key_R:
+      if( e->modifiers() == Qt::ControlModifier )
       {
         executeAction( REFRESH_ID );
         return;
       }
       break;
-    case Key_Up:
-      if( e->state() == ShiftButton )
+    case Qt::Key_Up:
+      if( e->modifiers() == Qt::ShiftModifier )
       {
         executeAction( PARENT_DIR_ID );
         return;
       }
       break;
-    case Key_Down:
-      if( e->state() == ShiftButton )
+    case Qt::Key_Down:
+      if( e->modifiers() == Qt::ShiftModifier )
       {
         executeAction( STEP_INTO_ID );
         return;
       }
       break;
-    case Key_Left:
-      if( e->state() == ShiftButton )
+    case Qt::Key_Left:
+      if( e->modifiers() == Qt::ShiftModifier )
       {
         executeAction( PREVIOUS_VIEW_ID );
         return;
       }
       break;
-    case Key_Right:
-      if( e->state() == ShiftButton )
+    case Qt::Key_Right:
+      if( e->modifiers() == Qt::ShiftModifier )
       {
         executeAction( NEXT_VIEW_ID );
         return;
       }
       break;
-    case Key_Delete:
-      if( !e->state() )
+    case Qt::Key_Delete:
+      if( !e->modifiers() )
       {
         executeAction( DELETE_ID, getCurrentFile() );
         return;
       }
-    case Key_Plus:
+    case Qt::Key_Plus:
       if( activeView == VIEW_FILELIGHT )
       {
         filelightView->zoomIn();
         return;
       }
       break;
-    case Key_Minus:
+    case Qt::Key_Minus:
       if( activeView == VIEW_FILELIGHT )
       {
         filelightView->zoomOut();
@@ -956,7 +999,7 @@ void DiskUsage::keyPressEvent( QKeyEvent *e )
       break;
     }
   }
-  QWidgetStack::keyPressEvent( e );
+  QStackedWidget::keyPressEvent( e );
 }
 
 QPixmap DiskUsage::getIcon( QString mime )
@@ -967,9 +1010,15 @@ QPixmap DiskUsage::getIcon( QString mime )
   {
     // get the icon.
     if ( mime == "Broken Link !" )
-      icon = FL_LOADICON( "file_broken" );
+      icon = FL_LOADICON( "file-broken" );
     else
-      icon = FL_LOADICON( KMimeType::mimeType( mime ) ->icon( QString::null, true ) );
+    {
+      KMimeType::Ptr mt = KMimeType::mimeType( mime );
+      if( mt )
+         icon = FL_LOADICON( mt->iconName() );
+      else
+         icon = FL_LOADICON( "file-broken" );
+    }
 
     // insert it into the cache
     QPixmapCache::insert( mime, icon );
@@ -1020,7 +1069,9 @@ int DiskUsage::calculatePercents( bool emitSig, Directory *dirEntry, int depth )
 QString DiskUsage::getToolTip( File *item )
 {
   KMimeType::Ptr mimePtr = KMimeType::mimeType( item->mime() );
-  QString mime = mimePtr->comment();
+  QString mime;
+  if( mimePtr )
+    mime = mimePtr->comment();
 
   time_t tma = item->time();
   struct tm* t=localtime((time_t *)&tma);
@@ -1047,20 +1098,20 @@ void DiskUsage::setView( int view )
   switch( view )
   {
   case VIEW_LINES:
-    raiseWidget( lineView );
+    setCurrentWidget( lineView );
     break;
   case VIEW_DETAILED:
-    raiseWidget( listView );
+    setCurrentWidget( listView );
     break;
   case VIEW_FILELIGHT:
-    raiseWidget( filelightView );
+    setCurrentWidget( filelightView );
     break;
   case VIEW_LOADER:
-    raiseWidget( loaderView );
+    setCurrentWidget( loaderView );
     break;
   }
 
-  visibleWidget()->setFocus();
+  currentWidget()->setFocus();
   emit viewChanged( activeView = view );
 }
 
@@ -1100,48 +1151,48 @@ bool DiskUsage::event( QEvent * e )
     }
   }
 
-  if ( e->type() == QEvent::AccelOverride )
+  if ( e->type() == QEvent::ShortcutOverride )
   {
     QKeyEvent* ke = (QKeyEvent*) e;
 
-    if ( ke->state() == NoButton || ke->state() == Keypad )
+    if ( ke->modifiers() == Qt::NoModifier || ke->modifiers() == Qt::KeypadModifier )
     {
       switch ( ke->key() )
       {
-        case Key_Delete:
-        case Key_Plus:
-        case Key_Minus:
+        case Qt::Key_Delete:
+        case Qt::Key_Plus:
+        case Qt::Key_Minus:
           ke->accept();
           break;
       }
-    }else if( ke->state() == ShiftButton )
+    }else if( ke->modifiers() == Qt::ShiftModifier )
     {
       switch ( ke->key() )
       {
-        case Key_Left:
-        case Key_Right:
-        case Key_Up:
-        case Key_Down:
+        case Qt::Key_Left:
+        case Qt::Key_Right:
+        case Qt::Key_Up:
+        case Qt::Key_Down:
           ke->accept();
           break;
       }
-    }else if ( ke->state() & ControlButton )
+    }else if ( ke->modifiers() & Qt::ControlModifier )
     {
       switch ( ke->key() )
       {
-        case Key_D:
-        case Key_E:
-        case Key_F:
-        case Key_I:
-        case Key_L:
-        case Key_N:
-        case Key_R:
+        case Qt::Key_D:
+        case Qt::Key_E:
+        case Qt::Key_F:
+        case Qt::Key_I:
+        case Qt::Key_L:
+        case Qt::Key_N:
+        case Qt::Key_R:
           ke->accept();
           break;
       }
     }
   }
-  return QWidgetStack::event( e );
+  return QStackedWidget::event( e );
 }
 
 #include "diskusage.moc"
