@@ -8,23 +8,23 @@
 #include <kglobal.h>
 #include <kglobalsettings.h>
 #include <klocale.h>
-#include <kpixmapeffect.h>
 #include <qpainter.h>
 #include <qtooltip.h>        //for its palette
+#include <QEvent>
 
 
 
 namespace RadialMap {
 
 SegmentTip::SegmentTip( uint h )
-  : QWidget( 0, 0, WNoAutoErase | WStyle_Customize | WStyle_NoBorder | WStyle_Tool | WStyle_StaysOnTop | WX11BypassWM )
+  : QWidget( 0, Qt::FramelessWindowHint | Qt::Tool | Qt::WindowStaysOnTopHint | Qt::X11BypassWindowManagerHint )
   , m_cursorHeight( -h )
 {
-   setBackgroundMode( Qt::NoBackground );
+   setAttribute(Qt::WA_NoSystemBackground, true);
 }
 
 void
-SegmentTip::moveto( QPoint p, const QWidget &canvas, bool placeAbove )
+SegmentTip::moveto( QPoint p, QWidget &canvas, bool placeAbove )
 {
   //**** this function is very slow and seems to be visibly influenced by operations like mapFromGlobal() (who knows why!)
   //  ** so any improvements are much desired
@@ -57,26 +57,34 @@ SegmentTip::moveto( QPoint p, const QWidget &canvas, bool placeAbove )
   const QRect alphaMaskRect( canvas.mapFromGlobal( p ), size() );
   const QRect intersection( alphaMaskRect.intersect( canvas.rect() ) );
 
-  m_pixmap.resize( size() ); //move to updateTip once you are sure it can never be null
-  bitBlt( &m_pixmap, offset, &canvas, intersection, Qt::CopyROP );
+  m_pixmap = QPixmap( size() ); //move to updateTip once you are sure it can never be null
+  //bitBlt( &m_pixmap, offset, &canvas, intersection, Qt::CopyROP );
+  QPainter( &m_pixmap ).drawPixmap( offset, QPixmap::grabWidget( &canvas, intersection ));
+
+  QColor col = QToolTip::palette().color( QPalette::Active, QPalette::Window );
+  col.setAlpha( 153 ); // 0.6
+
+  QRect rct = rect();
+  if( rct.width() )
+    rct.setWidth( rct.width() - 1 );
+  if( rct.height() )
+    rct.setHeight( rct.height() - 1 );
 
   QPainter paint( &m_pixmap );
     paint.setPen( Qt::black );
-    paint.setBrush( Qt::NoBrush );
-    paint.drawRect( rect() );
+    paint.setBrush( col );
+    paint.drawRect( rct );
     paint.end();
 
-  m_pixmap = KPixmapEffect::fade( m_pixmap, 0.6, QToolTip::palette().color( QPalette::Active, QColorGroup::Background ) );
-
   paint.begin( &m_pixmap );
-  paint.drawText( rect(), AlignCenter, m_text );
+  paint.drawText( rect(), Qt::AlignCenter, m_text );
   paint.end();
 
   p += screen.topLeft(); //for Xinerama users
 
   move( x, y );
   show();
-  update();
+  repaint();
 }
 
 void
@@ -100,7 +108,7 @@ SegmentTip::updateTip( const File* const file, const Directory* const root )
     {
         double files  = static_cast<const Directory*>(file)->fileCount();
         const uint pc = uint((100 * files) / (double)root->fileCount());
-        QString s3    = i18n( "Files: %1" ).arg( loc->formatNumber( files, 0 ) );
+        QString s3    = i18n( "Files: %1", loc->formatNumber( files, 0 ) );
 
         if( pc > 0 ) s3 += QString( " (%1%)" ).arg( loc->formatNumber( pc, 0 ) );
 
@@ -130,8 +138,8 @@ SegmentTip::event( QEvent *e )
         break;
     case QEvent::Paint:
     {
-        //QPainter( this ).drawPixmap( 0, 0, m_pixmap );
-        bitBlt( this, 0, 0, &m_pixmap );
+        // bitBlt( this, 0, 0, &m_pixmap );
+        QPainter( this ).drawPixmap( 0, 0, m_pixmap );
         return true;
     }
     default:
