@@ -1,6 +1,7 @@
 //Author:    Max Howell <max.howell@methylblue.com>, (C) 2003-4
 //Copyright: See COPYING file that comes with this distribution
 
+#include "fileTree.h"
 #include <kcursor.h>        //ctor
 #include <klocale.h>
 #include <kurl.h>
@@ -8,23 +9,27 @@
 #include <qbitmap.h>        //ctor - finding cursor size
 #include <qcursor.h>        //slotPostMouseEvent()
 #include <qtimer.h>         //member
+#include <QEvent>
+#include <QMouseEvent>
+#include <QPalette>
 
 #include "Config.h"
 #include "debug.h"
-#include "fileTree.h"
 #include "radialMap.h" //constants
 #include "widget.h"
 
 
 
-RadialMap::Widget::Widget( QWidget *parent, const char *name )
-   : QWidget( parent, name, Qt::WNoAutoErase )
+RadialMap::Widget::Widget( QWidget *parent )
+   : QWidget( parent )
    , m_tree( 0 )
    , m_focus( 0 )
-   , m_tip( KCursor::handCursor().bitmap()->height() ) //needs to know cursor height
+   , m_tip( QFontMetrics( font() ).height() ) //needs to know cursor height
    , m_rootSegment( 0 ) //TODO we don't delete it, *shrug*
 {
-   setBackgroundColor( Qt::white );
+   QPalette pal = palette();
+   pal.setColor(backgroundRole(), Qt::white );
+   setPalette(pal);
 
    connect( this, SIGNAL(created( const Directory* )), SLOT(sendFakeMouseEvent()) );
    connect( this, SIGNAL(created( const Directory* )), SLOT(update()) );
@@ -35,17 +40,17 @@ QString
 RadialMap::Widget::path() const
 {
    if( m_tree == 0 )
-      return QString::null;
+      return QString();
    return m_tree->fullPath();
 }
 
-KURL
+KUrl
 RadialMap::Widget::url( File const * const file ) const
 {
    if( file == 0 && m_tree == 0 )
-      return KURL();
+      return KUrl();
 
-   return KURL::fromPathOrURL( file ? file->fullPath() : m_tree->fullPath() );
+   return KUrl( file ? file->fullPath() : m_tree->fullPath() );
 }
 
 void
@@ -59,7 +64,7 @@ RadialMap::Widget::invalidate( const bool b )
       //disable mouse tracking
       setMouseTracking( false );
 
-      KURL urlInv = url();
+      KUrl urlInv = url();
 
       //ensure this class won't think we have a map still
       m_tree  = 0;
@@ -116,7 +121,7 @@ RadialMap::Widget::createFromCache( const Directory *tree )
 void
 RadialMap::Widget::sendFakeMouseEvent() //slot
 {
-   QMouseEvent me( QEvent::MouseMove, mapFromGlobal( QCursor::pos() ), Qt::NoButton, Qt::NoButton );
+   QMouseEvent me( QEvent::MouseMove, mapFromGlobal( QCursor::pos() ), Qt::NoButton, Qt::NoButton, Qt::NoModifier );
    QApplication::sendEvent( this, &me );
 }
 
@@ -196,4 +201,4 @@ RadialMap::Segment::~Segment()
       delete m_file; //created by us in Builder::build()
 }
 
-#include "widget.moc"
+//#include "widget.moc"
