@@ -32,7 +32,7 @@
 #define FILTERTABS_H
 
 #include <qtabwidget.h>
-#include <qptrlist.h>
+#include <QList>
 
 #include "filterbase.h"
 
@@ -54,7 +54,7 @@ class FilterTabs : public QObject
     };
 
     static FilterTabs * addTo( QTabWidget *tabWidget, int props = FilterTabs::Default );
-    static KRQuery      getQuery( QWidget *parent = 0, const char *name = 0 );
+    static KRQuery      getQuery( QWidget *parent = 0 );
 
     FilterBase *get( QString name );
 
@@ -71,8 +71,8 @@ class FilterTabs : public QObject
     FilterTabs( int properties, QTabWidget *tabWidget, QObject *parent );
     void  acceptQuery();
 
-    QPtrList<FilterBase> filterList;
-    QValueList<int>      pageNumbers;
+    QList<FilterBase *> filterList;
+    QList<int>      pageNumbers;
 
     QTabWidget * tabWidget;
 };
