@@ -19,64 +19,75 @@
 #include "dirhistoryqueue.h"
 
 #include "../VFS/vfs.h"
-#include <qpopupmenu.h>
+#include <qmenu.h>
 #include <qdir.h>
+#include <QPixmap>
 #include <klocale.h>
 #include <kiconloader.h>
 
 #include <kdebug.h>
 
-DirHistoryButton::DirHistoryButton( DirHistoryQueue* hQ, QWidget *parent, const char *name ) : QToolButton( parent, name ) {
+DirHistoryButton::DirHistoryButton( DirHistoryQueue* hQ, QWidget *parent ) : QToolButton( parent ) {
 	KIconLoader * iconLoader = new KIconLoader();
-	QPixmap icon = iconLoader->loadIcon( "history", KIcon::Toolbar, 16 );
+	QPixmap icon = iconLoader->loadIcon( "history", KIconLoader::Toolbar, 16 );
 
 	setFixedSize( icon.width() + 4, icon.height() + 4 );
-	setPixmap( icon );
-	setTextLabel( i18n( "Open the directory history list" ), true );
-	setPopupDelay( 10 ); // 0.01 seconds press
+	setIcon( QIcon( icon ) );
+	setText( i18n( "Open the directory history list" ) );
+	setToolTip( i18n( "Open the directory history list" ) );
+	setPopupMode( QToolButton::InstantPopup );
 	setAcceptDrops( false );
 
-	popupMenu = new QPopupMenu( this );
+	popupMenu = new QMenu( this );
 	Q_CHECK_PTR( popupMenu );
 
-	setPopup( popupMenu );
-	popupMenu->setCheckable( true );
+	setMenu( popupMenu );
 
 	historyQueue = hQ;
 
 	connect( popupMenu, SIGNAL( aboutToShow() ), this, SLOT( slotAboutToShow() ) );
-	connect( popupMenu, SIGNAL( activated( int ) ), this, SLOT( slotPopupActivated( int ) ) );
+	connect( popupMenu, SIGNAL( triggered( QAction * ) ), this, SLOT( slotPopupActivated( QAction * ) ) );
 }
 
 DirHistoryButton::~DirHistoryButton() {}
 
-void DirHistoryButton::openPopup() {
-	QPopupMenu * pP = popup();
+void DirHistoryButton::showMenu() {
+	QMenu * pP = menu();
 	if ( pP ) {
-		popup() ->exec( mapToGlobal( QPoint( 0, height() ) ) );
+		menu() ->exec( mapToGlobal( QPoint( 0, height() ) ) );
 	}
 }
 /** No descriptions */
 void DirHistoryButton::slotPopup() {
-	//  kdDebug() << "History slot" << endl;
+	//  kDebug() << "History slot" << endl;
 }
 /** No descriptions */
 void DirHistoryButton::slotAboutToShow() {
-	//  kdDebug() << "about to show" << endl;
+	emit aboutToShow();
+	//  kDebug() << "about to show" << endl;
 	popupMenu->clear();
-	KURL::List::iterator it;
+	KUrl::List::iterator it;
 
+	QAction * first = 0;
 	int id = 0;
 	for ( it = historyQueue->urlQueue.begin(); it != historyQueue->urlQueue.end(); ++it ) {
-		popupMenu->insertItem( (*it).prettyURL(), id++ );
+		QAction * act = popupMenu->addAction( (*it).prettyUrl() );
+		if( id == 0 )
+			first = act;
+		act->setData( QVariant( id++ ) );
 	}
-	if ( id > 0 ) {
-		popupMenu->setItemChecked( 0, true );
+	if ( first ) {
+		first->setCheckable( true );
+		first->setChecked( true );
 	}
 }
 /** No descriptions */
-void DirHistoryButton::slotPopupActivated( int id ) {
-	emit openUrl( historyQueue->urlQueue[ id ] );
+void DirHistoryButton::slotPopupActivated( QAction * action ) {
+	if( action && action->data().canConvert<int>() )
+	{
+		int id = action->data().toInt();
+		emit openUrl( historyQueue->urlQueue[ id ] );
+	}
 }
 
 #include "dirhistorybutton.moc"
