@@ -33,9 +33,11 @@
 #include "stdlib.h"
 #include <unistd.h>
 #include <qmessagebox.h>
-#include <kprocess.h>
-#include <qiconset.h>
-#include <qwhatsthis.h>
+#include <QGridLayout>
+#include <QFrame>
+#include <QLabel>
+#include <QKeyEvent>
+#include <qicon.h>
 #include <unistd.h>
 #include "../krusader.h"
 #include "../kicons.h"
@@ -55,13 +57,13 @@
 #include <qimage.h>
 #include <qstringlist.h>
 #include <qsizepolicy.h>
-#include <ktempfile.h> 
 
-KCMDLine::KCMDLine( QWidget *parent, const char *name ) : QWidget( parent, name ) {
-  QGridLayout * layout = new QGridLayout( this, 1, 4 );
+KCMDLine::KCMDLine( QWidget *parent ) : QWidget( parent ) {
+  QGridLayout * layout = new QGridLayout( this );
+  layout->setSpacing( 0 );
+  layout->setContentsMargins( 0, 0, 0, 0 );
   path = new QLabel( this );
-  QWhatsThis::add
-    ( path, i18n( "Name of directory where command will be processed." ) );
+  path->setWhatsThis( i18n( "Name of directory where command will be processed." ) );
   path->setAlignment( Qt::AlignRight );
   path->setFrameStyle( QFrame::Box | QFrame::Sunken );
   path->setLineWidth( 1 );
@@ -73,7 +75,7 @@ KCMDLine::KCMDLine( QWidget *parent, const char *name ) : QWidget( parent, name
   layout->addWidget( path, 0, 0 );
 
   // and editable command line
-  completion.setMode( KURLCompletion::FileCompletion );
+  completion.setMode( KUrlCompletion::FileCompletion );
   cmdLine = new KrHistoryCombo( this );
   cmdLine->setMaxCount(100);  // remember 100 commands
   cmdLine->setDuplicatesEnabled( false );
@@ -82,24 +84,23 @@ KCMDLine::KCMDLine( QWidget *parent, const char *name ) : QWidget( parent, name
   cmdLine->setCompletionObject( &completion );
   cmdLine->setSizePolicy(QSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed));
   // load the history
-  KConfigGroupSaver grpSvr( krConfig, "Private" );
-  QStringList list = krConfig->readListEntry( "cmdline history" );
+  KConfigGroup grpSvr( krConfig, "Private" );
+  QStringList list = grpSvr.readEntry( "cmdline history", QStringList() );
   cmdLine->setHistoryItems( list );
 
   connect( cmdLine, SIGNAL( returnPressed(const QString &) ), this, SLOT( slotRun() ) );
-  connect( cmdLine, SIGNAL( returnPressed(const QString &) ), cmdLine, SLOT( clearEdit() ) );
+  connect( cmdLine, SIGNAL( returnPressed(const QString &) ), cmdLine->lineEdit(), SLOT( clear() ) );
   connect( cmdLine, SIGNAL( returnToPanel() ), this, SLOT( slotReturnFocus() ));
 
-  QWhatsThis::add
-    ( cmdLine, i18n( "<qt><p>Well, it's actually quite simple: You type your command here and Krusader obeys.</p><p><b>Tip</b>: Move within command line history with &lt;Up&gt; and &lt;Down&gt; arrows.</p></qt>" ) );
+  cmdLine->setWhatsThis( i18n( "<qt><p>Well, it's actually quite simple: You type your command here and Krusader obeys.</p><p><b>Tip</b>: Move within command line history with &lt;Up&gt; and &lt;Down&gt; arrows.</p></qt>" ) );
   layout->addWidget( cmdLine, 0, 1 );
 
-  buttonAddPlaceholder = new QToolButton( this, "ButtonAddPlaceholder" );
+  buttonAddPlaceholder = new QToolButton( this );
   buttonAddPlaceholder->setFixedSize(22,20);
   buttonAddPlaceholder->adjustSize();
-  buttonAddPlaceholder->setPixmap( SmallIcon( "add" ) );
+  buttonAddPlaceholder->setIcon( SmallIcon( "list-add" ) );
   connect( buttonAddPlaceholder, SIGNAL( clicked() ), this, SLOT( addPlaceholder() ) );
-  QWhatsThis::add( buttonAddPlaceholder, i18n( "Add <b>Placeholders</b> for the selected files in the panel." ) );
+  buttonAddPlaceholder->setWhatsThis( i18n( "Add <b>Placeholders</b> for the selected files in the panel." ) );
 
   layout->addWidget( buttonAddPlaceholder, 0, 2 );
 
@@ -138,14 +139,14 @@ void KCMDLine::setCurrent( const QString &p ) {
   completion.setDir( p );
   // make sure our command is executed in the right directory
   // This line is important for Krusader overall functions -> do not remove !
-  chdir( p.local8Bit() );
+  QDir::setCurrent( p );
 }
 
 KCMDLine::~KCMDLine() {
-   KConfigGroupSaver grpSvr( krConfig, "Private" );
+   KConfigGroup grpSvr( krConfig, "Private" );
    QStringList list = cmdLine->historyItems();
    //krOut << list[0] << endl;
-   krConfig->writeEntry( "cmdline history", list );
+   grpSvr.writeEntry( "cmdline history", list );
    krConfig->sync();
 }
 
@@ -157,17 +158,17 @@ void KCMDLine::slotRun() {
 
   cmdLine->addToHistory(command1);
 
-  if ( command1.simplifyWhiteSpace().left( 3 ) == "cd " ) { // cd command effect the active panel
-    QString dir = command1.right( command1.length() - command1.find( " " ) ).stripWhiteSpace();
+  if ( command1.simplified().left( 3 ) == "cd " ) { // cd command effect the active panel
+    QString dir = command1.right( command1.length() - command1.indexOf( " " ) ).trimmed();
     if ( dir == "~" )
-      dir = QDir::homeDirPath();
+      dir = QDir::homePath();
     else
       if ( dir.left( 1 ) != "/" && !dir.contains( ":/" ) )
         dir = panelPath + ( panelPath == "/" ? "" : "/" ) + dir;
     SLOTS->refresh( dir );
   } else {
     exec();
-    cmdLine->clearEdit();
+    cmdLine->clearEditText();
   }
 }
 
@@ -190,7 +191,7 @@ QString KCMDLine::command() const {
 
 KrActionBase::ExecType KCMDLine::execType() const {
   KConfigGroup grp( krConfig, "Private" );
-  int i = grp.readNumEntry("Command Execution Mode",0);
+  int i = grp.readEntry("Command Execution Mode", (int)0);
   return execModesMenu[i];
 }
 
@@ -219,33 +220,42 @@ bool KCMDLine::doSubstitution() const {
 }
 
 void KCMDLine::setText(QString text) {
-	cmdLine->setCurrentText( text );
+	cmdLine->lineEdit()->setText( text );
 }
  
 void KrHistoryCombo::keyPressEvent( QKeyEvent *e ) {
    switch (e->key()) {
-      case Key_Enter:
-      case Key_Return:
-         if (e->state() & ControlButton) {
-           SLOTS->insertFileName( ( e->state() & ShiftButton ) != 0 );
+      case Qt::Key_Enter:
+      case Qt::Key_Return:
+         if (e->modifiers() & Qt::ControlModifier) {
+           SLOTS->insertFileName( ( e->modifiers() & Qt::ShiftModifier ) != 0 );
            break;
          }
-         KHistoryCombo::keyPressEvent(e);
+         KHistoryComboBox::keyPressEvent(e);
          break;
-      case Key_Down:
-         if (e->state()  == ( ControlButton | ShiftButton ) ) {
+      case Qt::Key_Down:
+         if (e->modifiers()  == ( Qt::ControlModifier | Qt::ShiftModifier ) ) {
             MAIN_VIEW->focusTerminalEmulator();
             return;
          } else
-            KHistoryCombo::keyPressEvent(e);
+            KHistoryComboBox::keyPressEvent(e);
          break;
-      case Key_Up:
-         if (e->state() == ControlButton || e->state() == ( ControlButton | ShiftButton ) ) {
+      case Qt::Key_Up:
+         if (e->modifiers() == Qt::ControlModifier || e->modifiers() == ( Qt::ControlModifier | Qt::ShiftModifier ) ) {
             emit returnToPanel();
             return;
-         }
+         } else
+            KHistoryComboBox::keyPressEvent(e);
+         break;
+      case Qt::Key_Escape:
+         if (e->modifiers() == 0 ) {
+            emit returnToPanel();
+            return;
+         } else
+            KHistoryComboBox::keyPressEvent(e);
+         break;
       default:
-      KHistoryCombo::keyPressEvent(e);
+      KHistoryComboBox::keyPressEvent(e);
    }
 }
 
