@@ -35,23 +35,24 @@
 #include <kurl.h>
 #include <qlayout.h>
 #include <qlabel.h>
+#include <QGridLayout>
 
 class DiskUsageViewer : public QWidget
 {
   Q_OBJECT
   
 public:
-  DiskUsageViewer( QWidget *parent = 0, char *name = 0 );
+  DiskUsageViewer( QWidget *parent = 0 );
   ~DiskUsageViewer();
   
-  void openURL( KURL url );
-  void closeURL();
+  void openUrl( KUrl url );
+  void closeUrl();
   void setStatusLabel( QLabel *statLabel, QString pref );
 
   inline DiskUsage * getWidget() { return diskUsage; }
   
 signals:
-  void openURLRequest(const KURL &);
+  void openUrlRequest(const KUrl &);
   
 protected slots:
   void slotUpdateStatus( QString status = QString() );
