@@ -11,8 +11,11 @@
 #include <qlabel.h>
 #include <qcombobox.h>
 #include <qcheckbox.h>
-#include <qwhatsthis.h>
 #include <qtimer.h>
+#include <QPixmap>
+#include <QResizeEvent>
+#include <QVBoxLayout>
+#include <QFrame>
 
 #include <kapplication.h>
 #include <kglobal.h>
@@ -32,7 +35,8 @@
 KrusaderImageFilePreview::KrusaderImageFilePreview( QWidget *parent )
 		: KPreviewWidgetBase( parent ),
 m_job( 0L ) {
-	QVBoxLayout *vb = new QVBoxLayout( this, KDialog::marginHint() );
+	QVBoxLayout *vb = new QVBoxLayout( this );
+	vb->setContentsMargins( KDialog::marginHint(), KDialog::marginHint(), KDialog::marginHint(), KDialog::marginHint() );
 
 	imageLabel = new QLabel( this );
 	imageLabel->setFrameStyle( QFrame::Panel | QFrame::Sunken );
@@ -48,21 +52,21 @@ m_job( 0L ) {
 
 KrusaderImageFilePreview::~KrusaderImageFilePreview() {
 	if ( m_job )
-		m_job->kill();
+		m_job->kill( KJob::EmitResult );
 }
 
 void KrusaderImageFilePreview::showPreview() {
 	// Pass a copy since clearPreview() will clear currentURL
-	KURL url = currentURL;
+	KUrl url = currentURL;
 	showPreview( url, true );
 }
 
 // called via KPreviewWidgetBase interface
-void KrusaderImageFilePreview::showPreview( const KURL& url ) {
+void KrusaderImageFilePreview::showPreview( const KUrl& url ) {
 	showPreview( url, false );
 }
 
-void KrusaderImageFilePreview::showPreview( const KURL &url, bool force ) {
+void KrusaderImageFilePreview::showPreview( const KUrl &url, bool force ) {
 	if ( !url.isValid() ) {
 		clearPreview();
 		return ;
@@ -76,61 +80,58 @@ void KrusaderImageFilePreview::showPreview( const KURL &url, bool force ) {
 		int h = imageLabel->contentsRect().height() - 4;
 
 		m_job = createJob( url, w, h );
-		connect( m_job, SIGNAL( result( KIO::Job * ) ),
-		         this, SLOT( slotResult( KIO::Job * ) ) );
-		connect( m_job, SIGNAL( gotPreview( const KFileItem*,
+		connect( m_job, SIGNAL( result( KJob * ) ),
+		         this, SLOT( slotResult( KJob * ) ) );
+		connect( m_job, SIGNAL( gotPreview( const KFileItem&,
 		                                    const QPixmap& ) ),
-		         SLOT( gotPreview( const KFileItem*, const QPixmap& ) ) );
+		         SLOT( gotPreview( const KFileItem&, const QPixmap& ) ) );
 
-		connect( m_job, SIGNAL( failed( const KFileItem* ) ),
-		         this, SLOT( slotFailed( const KFileItem* ) ) );
+		connect( m_job, SIGNAL( failed( const KFileItem& ) ),
+		         this, SLOT( slotFailed( const KFileItem& ) ) );
 	}
 }
 
 void KrusaderImageFilePreview::resizeEvent( QResizeEvent * ) {
-	timer->start( 100, true ); // forces a new preview
+	timer->setSingleShot( true );
+	timer->start( 100 ); // forces a new preview
 }
 
 QSize KrusaderImageFilePreview::sizeHint() const {
 	return QSize( 20, 200 ); // otherwise it ends up huge???
 }
 
-KIO::PreviewJob * KrusaderImageFilePreview::createJob( const KURL& url, int w, int h ) {
-	KURL::List urls;
+KIO::PreviewJob * KrusaderImageFilePreview::createJob( const KUrl& url, int w, int h ) {
+	KUrl::List urls;
 	urls.append( url );
 	return KIO::filePreview( urls, w, h, 0, 0, true, false );
 }
 
-void KrusaderImageFilePreview::gotPreview( const KFileItem* item, const QPixmap& pm ) {
-	if ( item->url() == currentURL )   // should always be the case
+void KrusaderImageFilePreview::gotPreview( const KFileItem& item, const QPixmap& pm ) {
+	if ( item.url() == currentURL )   // should always be the case
 		imageLabel->setPixmap( pm );
 }
 
-void KrusaderImageFilePreview::slotFailed( const KFileItem* item ) {
-	if ( item->isDir() )
+void KrusaderImageFilePreview::slotFailed( const KFileItem& item ) {
+	if ( item.isDir() )
 		imageLabel->clear();
-	else if ( item->url() == currentURL )   // should always be the case
-		imageLabel->setPixmap( SmallIcon( "file_broken", KIcon::SizeLarge,
-		                                  KIcon::DisabledState ) );
+	else if ( item.url() == currentURL )   // should always be the case
+		imageLabel->setPixmap( SmallIcon( "file-broken", KIconLoader::SizeLarge,
+		                                  KIconLoader::DisabledState ) );
 }
 
-void KrusaderImageFilePreview::slotResult( KIO::Job *job ) {
+void KrusaderImageFilePreview::slotResult( KJob *job ) {
 	if ( job == m_job )
 		m_job = 0L;
 }
 
 void KrusaderImageFilePreview::clearPreview() {
 	if ( m_job ) {
-		m_job->kill();
+		m_job->kill( KJob::EmitResult );
 		m_job = 0L;
 	}
 
 	imageLabel->clear();
-	currentURL = KURL();
-}
-
-void KrusaderImageFilePreview::virtual_hook( int id, void* data ) {
-	KPreviewWidgetBase::virtual_hook( id, data );
+	currentURL = KUrl();
 }
 
 #include "kimagefilepreview.moc"
