@@ -14,6 +14,8 @@
 #define KrusaderImageFilePreview_H
 
 #include <qpixmap.h>
+#include <QResizeEvent>
+#include <QLabel>
 
 #include <kurl.h>
 #include <kpreviewwidgetbase.h>
@@ -36,32 +38,30 @@ class KrusaderImageFilePreview : public KPreviewWidgetBase {
 		virtual QSize sizeHint() const;
 
 	public slots:
-		virtual void showPreview( const KURL &url );
+		virtual void showPreview( const KUrl &url );
 		virtual void clearPreview();
 
 	protected slots:
 		void showPreview();
-		void showPreview( const KURL& url, bool force );
+		void showPreview( const KUrl& url, bool force );
 
-		virtual void gotPreview( const KFileItem*, const QPixmap& );
+		virtual void gotPreview( const KFileItem&, const QPixmap& );
 
 	protected:
 		virtual void resizeEvent( QResizeEvent *e );
-		virtual KIO::PreviewJob * createJob( const KURL& url,
+		virtual KIO::PreviewJob * createJob( const KUrl& url,
 		                                     int w, int h );
 
 	private slots:
-		void slotResult( KIO::Job * );
-		virtual void slotFailed( const KFileItem* );
+		void slotResult( KJob * );
+		virtual void slotFailed( const KFileItem& );
 
 	private:
-		KURL currentURL;
+		KUrl currentURL;
 		QTimer *timer;
 		QLabel *imageLabel;
 		QLabel *infoLabel;
 		KIO::PreviewJob *m_job;
-	protected:
-		virtual void virtual_hook( int id, void* data );
 	private:
 		class KrusaderImageFilePreviewPrivate;
 		KrusaderImageFilePreviewPrivate *d;
