@@ -17,8 +17,9 @@
 // Qt includes
 #include <qdatastream.h>
 #include <qfile.h>
-#include <qpopupmenu.h> 
 #include <qtimer.h>
+#include <QKeyEvent>
+#include <QEvent>
 // KDE includes
 #include <kmenubar.h>
 #include <kmimetype.h>
@@ -33,10 +34,11 @@
 #include <kio/job.h>
 #include <kstatusbar.h>
 #include <kdebug.h>
-#include <klargefile.h>
+#include <kde_file.h>
 #include <khtml_part.h>
 #include <kprocess.h>
 #include <kfileitem.h> 
+#include <ktoolbar.h>
 // Krusader includes
 #include "krviewer.h"
 #include "../krusader.h"
@@ -45,24 +47,21 @@
 
 #include "panelviewer.h"
 
-#define VIEW_ICON     "viewmag"
+#define VIEW_ICON     "zoom-original"
 #define EDIT_ICON     "edit"
-#define MODIFIED_ICON "filesaveas"
+#define MODIFIED_ICON "document-save-as"
 
 
-QPtrList<KrViewer> KrViewer::viewers;
+QList<KrViewer *> KrViewer::viewers;
 
-KrViewer::KrViewer( QWidget *parent, const char *name ) :
-KParts::MainWindow( parent, name ), manager( this, this ), tabBar( this ), returnFocusTo( 0 ), returnFocusTab( 0 ),
-                                    reservedKeys(), reservedKeyIDs() {
+KrViewer::KrViewer( QWidget *parent ) :
+KParts::MainWindow( parent, (Qt::WindowFlags)KDE_DEFAULT_WINDOWFLAGS ), manager( this, this ), tabBar( this ), returnFocusTo( 0 ), returnFocusTab( 0 ),
+                                    reservedKeys(), reservedKeyActions(), sizeX( -1 ), sizeY( -1 ) {
 
-	//setWFlags(WType_TopLevel | WDestructiveClose);
+	//setWFlags(Qt::WType_TopLevel | WDestructiveClose);
 	setXMLFile( "krviewer.rc" ); // kpart-related xml file
 	setHelpMenuEnabled( false );
 
-	setAutoSaveSettings( "KrViewerWindow", true );
-	tmpFile.setAutoDelete( true );
-
 	connect( &manager, SIGNAL( activePartChanged( KParts::Part* ) ),
 	         this, SLOT( createGUI( KParts::Part* ) ) );
 	connect( &tabBar, SIGNAL( currentChanged( QWidget *) ),
@@ -71,41 +70,64 @@ KParts::MainWindow( parent, name ), manager( this, this ), tabBar( this ), retur
 	         this, SLOT( tabCloseRequest(QWidget*) ) );
 
 	tabBar.setTabReorderingEnabled(false);
-#if KDE_IS_VERSION(3,4,0)
 	tabBar.setAutomaticResizeTabs(true);
-#endif
 //	"edit"
-//	"filesaveas"
+//	"document-save-as"
 	setCentralWidget( &tabBar );
 
-	printAction = KStdAction::print( this, SLOT( print() ), 0, 0 );
-	copyAction = KStdAction::copy( this, SLOT( copy() ), 0, 0 );
+	printAction = KStandardAction::print( this, SLOT( print() ), 0 );
+	copyAction = KStandardAction::copy( this, SLOT( copy() ), 0 );
 
-	viewerMenu = new QPopupMenu( this );
-	viewerMenu->insertItem( i18n( "&Generic viewer" ), this, SLOT( viewGeneric() ), CTRL + SHIFT + Key_G, 1 );
-	viewerMenu->insertItem( i18n( "&Text viewer" ), this, SLOT( viewText() ), CTRL + SHIFT + Key_T, 2 );
-	viewerMenu->insertItem( i18n( "&Hex viewer" ), this, SLOT( viewHex() ), CTRL + SHIFT + Key_H, 3 );
-	viewerMenu->insertSeparator();
-	viewerMenu->insertItem( i18n( "Text &editor" ), this, SLOT( editText() ), CTRL + SHIFT + Key_E, 4 );
-	viewerMenu->insertSeparator();
-	viewerMenu->insertItem( i18n( "&Next tab" ), this, SLOT( nextTab() ), ALT+Key_Right );
-	viewerMenu->insertItem( i18n( "&Previous tab" ), this, SLOT( prevTab() ), ALT+Key_Left );
+	viewerMenu = new QMenu( this );
+	viewerMenu->addAction( i18n( "&Generic viewer" ), this, SLOT( viewGeneric() ))->setShortcut( Qt::CTRL + Qt::SHIFT + Qt::Key_G );
+	viewerMenu->addAction( i18n( "&Text viewer" ), this, SLOT( viewText() ))->setShortcut( Qt::CTRL + Qt::SHIFT + Qt::Key_T );
+	viewerMenu->addAction( i18n( "&Hex viewer" ), this, SLOT( viewHex() ))->setShortcut( Qt::CTRL + Qt::SHIFT + Qt::Key_H );
+	viewerMenu->addSeparator();
+	viewerMenu->addAction( i18n( "Text &editor" ), this, SLOT( editText() ))->setShortcut( Qt::CTRL + Qt::SHIFT + Qt::Key_E );
+	viewerMenu->addSeparator();
+	viewerMenu->addAction( i18n( "&Next tab" ), this, SLOT( nextTab() ))->setShortcut( Qt::ALT+Qt::Key_Right );
+	viewerMenu->addAction( i18n( "&Previous tab" ), this, SLOT( prevTab() ))->setShortcut( Qt::ALT+Qt::Key_Left );
 
-	detachActionIndex = viewerMenu->insertItem( i18n( "&Detach tab" ), this, SLOT( detachTab() ), CTRL + SHIFT + Key_D );
+	detachAction = viewerMenu->addAction( i18n( "&Detach tab" ), this, SLOT( detachTab() ));
+	detachAction->setShortcut( Qt::META + Qt::Key_D );
 	//no point in detaching only one tab..
-	viewerMenu->setItemEnabled(detachActionIndex,false);	
-	viewerMenu->insertSeparator();
-	viewerMenu->insertItem( printAction->text(), this, SLOT( print() ), printAction->shortcut() );
-	viewerMenu->insertItem( copyAction->text(), this, SLOT( copy() ), copyAction->shortcut() );
-	viewerMenu->insertSeparator();
-	tabCloseID = viewerMenu->insertItem( i18n( "&Close current tab" ), this, SLOT( tabCloseRequest() ), Key_Escape );
-	closeID = viewerMenu->insertItem( i18n( "&Quit" ), this, SLOT( close() ), CTRL + Key_Q );
+	detachAction->setEnabled(false);	
+	viewerMenu->addSeparator();
+	QList<QAction *> actList = menuBar()->actions();
+	bool hasPrint = false, hasCopy = false;
+	foreach( QAction *a, actList ) {
+	    if( a->shortcut().matches( printAction->shortcut().primary() ) != QKeySequence::NoMatch )
+		hasPrint = true;
+	    if( a->shortcut().matches( copyAction->shortcut().primary() ) != QKeySequence::NoMatch )
+		hasCopy = true;
+	}
+	QAction *printAct = viewerMenu->addAction( printAction->icon(), printAction->text(), this, SLOT( print() ));
+	if( hasPrint )
+	    printAct->setShortcut( printAction->shortcut().primary() );
+	QAction *copyAct = viewerMenu->addAction( copyAction->icon(), copyAction->text(), this, SLOT( copy() ));
+	if( hasCopy )
+	    copyAct->setShortcut( copyAction->shortcut().primary() );
+	viewerMenu->addSeparator();
+	( tabClose = viewerMenu->addAction( i18n( "&Close current tab" ), this, SLOT( tabCloseRequest() )))->setShortcut( Qt::Key_Escape );
+	( closeAct = viewerMenu->addAction( i18n( "&Quit" ), this, SLOT( close() )))->setShortcut( Qt::CTRL + Qt::Key_Q );
 
-	//toolBar() ->insertLined("Edit:",1,"",this,"",true ,i18n("Enter an URL to edit and press enter"));
-	
 	tabBar.setHoverCloseButton(true);
 
 	checkModified();
+
+	KConfigGroup group( krConfig, "KrViewerWindow");
+	int sx = group.readEntry( "Window Width", -1 );
+	int sy = group.readEntry( "Window Height", -1 );
+	
+	if( sx != -1 && sy != -1 )
+		resize( sx, sy );
+	else
+		resize( 900, 700 );
+	
+	if( group.readEntry( "Window Maximized",  false ) )
+		showMaximized();
+	else
+		show();
 }
 
 KrViewer::~KrViewer() {
@@ -113,12 +135,13 @@ KrViewer::~KrViewer() {
 	disconnect( &manager, SIGNAL( activePartChanged( KParts::Part* ) ),
 	            this, SLOT( createGUI( KParts::Part* ) ) );
 
-	viewers.remove( this );
+	viewers.removeAll( this );
 	delete printAction;
 	delete copyAction;
 }
 
 void KrViewer::createGUI( KParts::Part* part ) {
+	/* TODO: fix the toolbar bugs */
 	if ( part == 0 )   /*     KHTMLPart calls this function with 0 at destruction.    */
 		return ;        /*   Can cause crash after JavaScript self.close() if removed  */
 
@@ -128,7 +151,6 @@ void KrViewer::createGUI( KParts::Part* part ) {
 	         this, SLOT( slotSetStatusBarText( const QString& ) ) );
 
 	KParts::MainWindow::createGUI( part );
-	toolBar() ->insertLineSeparator(0);
 
 	PanelViewerBase *pvb = getPanelViewerBase( part );
 	if( pvb )
@@ -140,23 +162,33 @@ void KrViewer::createGUI( KParts::Part* part ) {
 	// the KParts part may override the viewer shortcuts. We prevent it
 	// by installing an event filter on the menuBar() and the part
 	reservedKeys.clear();
-	reservedKeyIDs.clear();
+	reservedKeyActions.clear();
 	
+	QList<QAction *> list = viewerMenu->actions();
 	// getting the key sequences of the viewer menu
-	for( unsigned w=0; w != viewerMenu->count(); w++ )
+	for( int w=0; w != list.count(); w++ )
 	{
-		int id = viewerMenu->idAt( w );
-		QKeySequence sequence = viewerMenu->accel( id );
-		if( sequence.count() > 0 )
+		QAction *act = list[ w ];
+		QList<QKeySequence> sequences = act->shortcuts();
+		if( !sequences.isEmpty() )
 		{
-			reservedKeys.push_back( sequence[ 0 ] );
-			reservedKeyIDs.push_back( id );
+			for( int i=0; i != sequences.count(); i++ )
+			{
+				reservedKeys.push_back( sequences[ i ] );
+				reservedKeyActions.push_back( act );
+			}
 		}
 	}
 	
 	// and "fix" the menubar
-	menuBar() ->removeItem( 70 );
-	menuBar() ->insertItem( i18n( "&KrViewer" ), viewerMenu, 70 );
+	QList<QAction *> actList = menuBar()->actions();
+	foreach( QAction * a, actList ) {
+		if( a->data().canConvert<int>() && a->data().toInt() == 70 )
+			menuBar()->removeAction( a );
+	}
+	viewerMenu->setTitle( i18n( "&KrViewer" ) );
+	QAction * act = menuBar() ->addMenu( viewerMenu );
+	act->setData( QVariant( 70 ) );
 	menuBar() ->show();
 	
 	// filtering out the key events
@@ -166,25 +198,24 @@ void KrViewer::createGUI( KParts::Part* part ) {
 
 bool KrViewer::eventFilter (  QObject * /* watched */, QEvent * e )
 {
-	if( e->type() == QEvent::AccelOverride )
+	if( e->type() == QEvent::ShortcutOverride )
 	{
 		QKeyEvent* ke = (QKeyEvent*) e;
 		if( reservedKeys.contains( ke->key() ) )
 		{
 			ke->accept();
 			
-			int id = reservedKeyIDs[ reservedKeys.findIndex( ke->key() ) ];
-			if( id != -1 )
+			QAction *act = reservedKeyActions[ reservedKeys.indexOf( ke->key() ) ];
+			if( act != 0 )
 			{
 				// don't activate the close functions immediately!
 				// it can cause crash
-				if( id == tabCloseID )
+				if( act == tabClose )
 					QTimer::singleShot( 0, this, SLOT( tabCloseRequest() ) );
-				else if( id == closeID )
+				else if( act == closeAct )
 					QTimer::singleShot( 0, this, SLOT( close() ) );
 				else {
-					int index = viewerMenu->indexOf( id );
-					viewerMenu->activateItemAt( index );
+					act->activate( QAction::Trigger );
 				}
 			}
 			return true;
@@ -203,10 +234,10 @@ bool KrViewer::eventFilter (  QObject * /* watched */, QEvent * e )
 }
 void KrViewer::keyPressEvent( QKeyEvent *e ) {
 	switch ( e->key() ) {
-		case Key_F10:
+		case Qt::Key_F10:
 			close();
 			break;
-		case Key_Escape:
+		case Qt::Key_Escape:
 			tabCloseRequest();
 			break;
 		default:
@@ -217,14 +248,14 @@ void KrViewer::keyPressEvent( QKeyEvent *e ) {
 
 KrViewer* KrViewer::getViewer(bool new_window){
 	if( !new_window ){
-		if( !viewers.first() ){	
+		if( viewers.isEmpty() ){	
 			viewers.prepend( new KrViewer() ); // add to first (active)
 		}
 		else {
 			if( viewers.first()->isMinimized() ) // minimized? -> show it again
 				viewers.first()->showNormal();
 			viewers.first()->raise();
-			viewers.first()->setActiveWindow();
+			viewers.first()->activateWindow();
 		}
 		return viewers.first();
 	}
@@ -235,14 +266,14 @@ KrViewer* KrViewer::getViewer(bool new_window){
 	}
 }	
 
-void KrViewer::view( KURL url, QWidget * parent ) {
+void KrViewer::view( KUrl url, QWidget * parent ) {
 	Mode defaultMode = Generic;
 	bool defaultWindow = false;
 
-	krConfig->setGroup( "General" );
-	defaultWindow = krConfig->readBoolEntry( "View In Separate Window",_ViewInSeparateWindow );
+	KConfigGroup group( krConfig, "General" );
+	defaultWindow = group.readEntry( "View In Separate Window",_ViewInSeparateWindow );
 
-	QString modeString = krConfig->readEntry( "Default Viewer Mode","generic" );
+	QString modeString = group.readEntry( "Default Viewer Mode", QString( "generic" ) );
 
 	if( modeString == "generic" ) defaultMode = Generic;
 	else if( modeString == "text" ) defaultMode = Text;
@@ -251,36 +282,37 @@ void KrViewer::view( KURL url, QWidget * parent ) {
 	view(url,defaultMode,defaultWindow, parent );
 }
 
-void KrViewer::view( KURL url, Mode mode,  bool new_window, QWidget * parent ) {
+void KrViewer::view( KUrl url, Mode mode,  bool new_window, QWidget * parent ) {
 	KrViewer* viewer = getViewer(new_window);
 
 	PanelViewerBase* viewWidget = new PanelViewer(&viewer->tabBar);
-	KParts::Part* part = viewWidget->openURL(url,mode);
+	KParts::Part* part = viewWidget->openUrl(url,mode);
 	viewer->addTab(viewWidget,i18n( "Viewing" ),VIEW_ICON,part);
 
 	viewer->returnFocusTo = parent;
 	viewer->returnFocusTab = viewWidget;
 }
 
-void KrViewer::edit( KURL url, QWidget * parent ) {
+void KrViewer::edit( KUrl url, QWidget * parent ) {
 	edit( url, Text, -1, parent );
 }
 
-void KrViewer::edit( KURL url, Mode mode, int new_window, QWidget * parent ) {
-	krConfig->setGroup( "General" );
-	QString edit = krConfig->readEntry( "Editor", _Editor );
+void KrViewer::edit( KUrl url, Mode mode, int new_window, QWidget * parent ) {
+	KConfigGroup group( krConfig, "General" );
+	QString edit = group.readEntry( "Editor", _Editor );
 	
 	if( new_window == -1 )
-		new_window = krConfig->readBoolEntry( "View In Separate Window",_ViewInSeparateWindow );
+		new_window = group.readEntry( "View In Separate Window",_ViewInSeparateWindow );
 
 	if ( edit != "internal editor" ) {
 		KProcess proc;
 		// if the file is local, pass a normal path and not a url. this solves
 		// the problem for editors that aren't url-aware
 		if ( url.isLocalFile() )
-			proc << QStringList::split( ' ', edit ) << url.path();
-		else proc << QStringList::split( ' ', edit ) << url.prettyURL();
-		if ( !proc.start( KProcess::DontCare ) )
+			proc << edit.split( ' ' ) << url.path();
+		else
+			proc << edit.split( ' ' ) << url.prettyUrl();
+		if ( !proc.startDetached() )
 			KMessageBox::sorry( krApp, i18n( "Can't open " ) + "\"" + edit + "\"" );
 		return ;
 	}
@@ -288,7 +320,7 @@ void KrViewer::edit( KURL url, Mode mode, int new_window, QWidget * parent ) {
 	KrViewer* viewer = getViewer(new_window);
 
 	PanelViewerBase* editWidget = new PanelEditor(&viewer->tabBar);
-	KParts::Part* part = editWidget->openURL(url,mode);
+	KParts::Part* part = editWidget->openUrl(url,mode);
 	viewer->addTab(editWidget,i18n("Editing"),EDIT_ICON,part);
 	
 	viewer->returnFocusTo = parent;
@@ -298,39 +330,47 @@ void KrViewer::edit( KURL url, Mode mode, int new_window, QWidget * parent ) {
 void KrViewer::addTab(PanelViewerBase* pvb, QString msg, QString iconName ,KParts::Part* part){
 	if( !part ) return;
 
-	KURL url = pvb->url();
-	setCaption( msg+": " + url.prettyURL() );
+	KUrl url = pvb->url();
+	setWindowTitle( msg+": " + url.prettyUrl() );
 
-	QIconSet icon = QIconSet(krLoader->loadIcon(iconName,KIcon::Small));
+	QIcon icon = QIcon(krLoader->loadIcon(iconName,KIconLoader::Small));
 
 	manager.addPart( part, this );
-	manager.setActivePart( part );
-	tabBar.insertTab(pvb,icon,url.fileName()+"("+msg+")");	
-	tabBar.setCurrentPage(tabBar.indexOf(pvb));
-	tabBar.setTabToolTip(pvb,msg+": " + url.prettyURL());
+	if( isValidPart( part ) )
+		manager.setActivePart( part );
+	tabBar.addTab(pvb,icon,url.fileName()+"("+msg+")");	
+	tabBar.setCurrentIndex(tabBar.indexOf(pvb));
+	tabBar.setTabToolTip(tabBar.indexOf( pvb ),msg+": " + url.prettyUrl());
 
 	updateActions( pvb );
 
 	// now we can offer the option to detach tabs (we have more than one)
 	if( tabBar.count() > 1 ){
-		viewerMenu->setItemEnabled(detachActionIndex,true);	
+		detachAction->setEnabled(true);	
 	}
 
 	show();
 	tabBar.show();
 	
-	connect( pvb, SIGNAL( urlChanged( PanelViewerBase *, const KURL & ) ), 
-	         this,  SLOT( tabURLChanged(PanelViewerBase *, const KURL & ) ) );
+	connect( pvb, SIGNAL( urlChanged( PanelViewerBase *, const KUrl & ) ), 
+	         this,  SLOT( tabURLChanged(PanelViewerBase *, const KUrl & ) ) );
+	
+	if( part->widget() )
+		part->widget()->setFocus();
 }
 
-void KrViewer::tabURLChanged( PanelViewerBase *pvb, const KURL & url ) {
+void KrViewer::tabURLChanged( PanelViewerBase *pvb, const KUrl & url ) {
 	QString msg = pvb->isEditor() ? i18n( "Editing" ) : i18n( "Viewing" );
-	tabBar.setTabLabel( pvb, url.fileName()+"("+msg+")" );
-	tabBar.setTabToolTip(pvb,msg+": " + url.prettyURL());
+	tabBar.setTabText( tabBar.indexOf( pvb ), url.fileName()+"("+msg+")" );
+	tabBar.setTabToolTip(tabBar.indexOf( pvb ),msg+": " + url.prettyUrl());
 }
 
 void KrViewer::tabChanged(QWidget* w){
-	manager.setActivePart( static_cast<PanelViewerBase*>(w)->part() );
+	if( w == 0 )
+		return;
+	
+	if( isValidPart( static_cast<PanelViewerBase*>(w)->part() ) )
+		manager.setActivePart( static_cast<PanelViewerBase*>(w)->part() );
 	
 	if( static_cast<PanelViewerBase*>(w) != returnFocusTab ) {
 		returnFocusTo = 0;
@@ -338,7 +378,7 @@ void KrViewer::tabChanged(QWidget* w){
 	}
 	
 	// set this viewer to be the main viewer
-	if( viewers.remove( this ) ) viewers.prepend( this ); // move to first
+	if( viewers.removeAll( this ) ) viewers.prepend( this ); // move to first
 }
 
 void KrViewer::tabCloseRequest(QWidget *w){
@@ -352,45 +392,53 @@ void KrViewer::tabCloseRequest(QWidget *w){
 	if( !pvb->queryClose() )
 		return;
 		
-	manager.removePart(pvb->part());
+	if( pvb->part() && isValidPart( pvb->part() ) )
+		manager.removePart(pvb->part());
 	
-	pvb->closeURL();
+	pvb->closeUrl();
 	
 	tabBar.removePage(w);
 
 	if( tabBar.count() <= 0 ){
 		if( returnFocusToThisWidget ){ 
 			returnFocusToThisWidget->raise();
-			returnFocusToThisWidget->setActiveWindow();
+			returnFocusToThisWidget->activateWindow();
 		}
 		else {
 			krApp->raise();
-			krApp->setActiveWindow();
+			krApp->activateWindow();
 		}
-		delete this;
+		this->close();
+		this->deleteLater();
 		return;
 	} else if( tabBar.count() == 1 ){
 		//no point in detaching only one tab..
-		viewerMenu->setItemEnabled(detachActionIndex,false);
+		detachAction->setEnabled(false);
 	}
 
 	if( returnFocusToThisWidget ){ 
 		returnFocusToThisWidget->raise();
-		returnFocusToThisWidget->setActiveWindow();
+		returnFocusToThisWidget->activateWindow();
 	}
 }
 
 void KrViewer::tabCloseRequest(){
-	tabCloseRequest( tabBar.currentPage() ); 
+	tabCloseRequest( tabBar.currentWidget() ); 
 }
 
 bool KrViewer::queryClose() {
+	KConfigGroup group( krConfig, "KrViewerWindow");
+	
+	group.writeEntry("Window Width", sizeX );
+	group.writeEntry("Window Height", sizeY );
+	group.writeEntry("Window Maximized", isMaximized() );
+
 	for( int i=0; i != tabBar.count(); i++ ) {
-		PanelViewerBase* pvb = static_cast<PanelViewerBase*>( tabBar.page( i ) );
+		PanelViewerBase* pvb = static_cast<PanelViewerBase*>( tabBar.widget( i ) );
 		if( !pvb )
 			continue;
 		
-		tabBar.setCurrentPage( i );
+		tabBar.setCurrentIndex( i );
 		
 		if( !pvb->queryClose() )
 			return false;
@@ -403,99 +451,105 @@ bool KrViewer::queryExit() {
 }
 
 void KrViewer::viewGeneric(){
-	PanelViewerBase* pvb = static_cast<PanelViewerBase*>( tabBar.currentPage() );
+	PanelViewerBase* pvb = static_cast<PanelViewerBase*>( tabBar.currentWidget() );
 	if( !pvb ) return;
 
 	PanelViewerBase* viewerWidget = new PanelViewer(&tabBar);
-	KParts::Part* part = viewerWidget->openURL(pvb->url(),Generic);
+	KParts::Part* part = viewerWidget->openUrl(pvb->url(),Generic);
 	addTab(viewerWidget,i18n("Viewing"),VIEW_ICON,part);
 }
 
 void KrViewer::viewText(){
-	PanelViewerBase* pvb = static_cast<PanelViewerBase*>( tabBar.currentPage() );
+	PanelViewerBase* pvb = static_cast<PanelViewerBase*>( tabBar.currentWidget() );
 	if( !pvb ) return;
 
 	PanelViewerBase* viewerWidget = new PanelViewer(&tabBar);
-	KParts::Part* part = viewerWidget->openURL(pvb->url(),Text);
+	KParts::Part* part = viewerWidget->openUrl(pvb->url(),Text);
 	addTab(viewerWidget,i18n("Viewing"),VIEW_ICON,part);
 }
 
 void KrViewer::viewHex(){
-	PanelViewerBase* pvb = static_cast<PanelViewerBase*>( tabBar.currentPage() );
+	PanelViewerBase* pvb = static_cast<PanelViewerBase*>( tabBar.currentWidget() );
 	if( !pvb ) return;
 
 	PanelViewerBase* viewerWidget = new PanelViewer(&tabBar);
-	KParts::Part* part = viewerWidget->openURL(pvb->url(),Hex);
+	KParts::Part* part = viewerWidget->openUrl(pvb->url(),Hex);
 	addTab(viewerWidget,i18n("Viewing"),VIEW_ICON,part);
 }
 
 void KrViewer::editText(){
-	PanelViewerBase* pvb = static_cast<PanelViewerBase*>( tabBar.currentPage() );
+	PanelViewerBase* pvb = static_cast<PanelViewerBase*>( tabBar.currentWidget() );
 	if( !pvb ) return;
 
 	PanelViewerBase* editWidget = new PanelEditor(&tabBar);
-	KParts::Part* part = editWidget->openURL(pvb->url(),Text);
+	KParts::Part* part = editWidget->openUrl(pvb->url(),Text);
 	addTab(editWidget,i18n("Editing"),EDIT_ICON,part);
 }
 
 void KrViewer::checkModified(){
 	QTimer::singleShot( 1000, this, SLOT(checkModified()) );
 
-	PanelViewerBase* pvb = static_cast<PanelViewerBase*>( tabBar.currentPage() );
-	if( !pvb ) return;
+	PanelViewerBase* pvb = static_cast<PanelViewerBase*>( tabBar.currentWidget() );
+	if( !pvb || !pvb->part() ) return;
 
-	if( !pvb->part()->url().equals( pvb->url(), true ) ) {
+	if( !pvb->part()->url().equals( pvb->url(), KUrl::CompareWithoutTrailingSlash ) ) {
 		pvb->setUrl( pvb->part()->url() );
 	}
 
-	// add a * to modified files.
-	if( pvb->isModified() ){
-		QString label = tabBar.tabLabel(pvb);
-		if( !label.startsWith("*" + pvb->part()->url().fileName() ) ){
-			label.prepend("*");
-			QIconSet icon = QIconSet(krLoader->loadIcon(MODIFIED_ICON,KIcon::Small));
+	bool lastModified = false;
+	QVariant lastModProp = pvb->property( "LastModified" );
+	if( lastModProp.type() == QVariant::Bool )
+		lastModified = lastModProp.toBool();
+	pvb->setProperty( "LastModified", QVariant( pvb->isModified() ) );
 
-			tabBar.changeTab(pvb,icon,label);
-		}
+	// add a * to modified files.
+	if( pvb->isModified() && !lastModified ){
+		int ndx = tabBar.indexOf( pvb );
+		QString label = tabBar.tabText( ndx );
+		label.prepend("*");
+		QIcon icon = QIcon(krLoader->loadIcon(MODIFIED_ICON,KIconLoader::Small));
+		tabBar.setTabText( ndx,label );
+		tabBar.setTabIcon( ndx,icon );
 	}
 	// remove the * from previously modified files.
-	else {
-		QString label = tabBar.tabLabel(pvb);
-		if( label.startsWith("*" + pvb->part()->url().fileName() ) ){
-			label = label.mid( 1 );
-			QIconSet icon = QIconSet(krLoader->loadIcon(EDIT_ICON,KIcon::Small));
-
-			tabBar.changeTab(pvb,icon,label);
-		}		
+	else if( !pvb->isModified() && lastModified ) {
+		int ndx = tabBar.indexOf( pvb );
+		QString label = tabBar.tabText( tabBar.indexOf( pvb ) );
+		label = label.mid( 1 );
+		QIcon icon = QIcon(krLoader->loadIcon(EDIT_ICON,KIconLoader::Small));
+		tabBar.setTabText( ndx,label );
+		tabBar.setTabIcon( ndx,icon );
 	}
 }
 
 void KrViewer::nextTab(){
-	int index = (tabBar.currentPageIndex()+1)%tabBar.count();
-	tabBar.setCurrentPage( index );
+	int index = (tabBar.currentIndex()+1)%tabBar.count();
+	tabBar.setCurrentIndex( index );
 }
 
 void KrViewer::prevTab(){
-	int index = (tabBar.currentPageIndex()-1)%tabBar.count();
+	int index = (tabBar.currentIndex()-1)%tabBar.count();
 	while( index < 0 ) index+=tabBar.count();
-	tabBar.setCurrentPage( index );
+	tabBar.setCurrentIndex( index );
 }
 
 void KrViewer::detachTab(){
-	PanelViewerBase* pvb = static_cast<PanelViewerBase*>( tabBar.currentPage() );
+	PanelViewerBase* pvb = static_cast<PanelViewerBase*>( tabBar.currentWidget() );
 	if( !pvb ) return;
 
 	KrViewer* viewer = getViewer(true);
 
-	manager.removePart(pvb->part());
+	if( pvb->part() && isValidPart( pvb->part() ) )
+		manager.removePart(pvb->part());
 	tabBar.removePage(pvb);
 	
 	if( tabBar.count() == 1 ) {
 		//no point in detaching only one tab..
-		viewerMenu->setItemEnabled(detachActionIndex,false);
+		detachAction->setEnabled(false);
 	}
 	
-	pvb->reparent(&viewer->tabBar,QPoint(0,0));
+	pvb->setParent(&viewer->tabBar);
+	pvb->move(QPoint(0,0));
 
 	if( pvb->isEditor() )
 		viewer->addTab(pvb,i18n( "Editing" ),EDIT_ICON,pvb->part());
@@ -505,12 +559,12 @@ void KrViewer::detachTab(){
 
 void KrViewer::windowActivationChange ( bool /* oldActive */ ) {
 	if( isActiveWindow() )
-		if( viewers.remove( this ) ) viewers.prepend( this ); // move to first
+		if( viewers.removeAll( this ) ) viewers.prepend( this ); // move to first
 }
 
 void KrViewer::print() {
-	PanelViewerBase* pvb = static_cast<PanelViewerBase*>( tabBar.currentPage() );
-	if( !pvb ) return;
+	PanelViewerBase* pvb = static_cast<PanelViewerBase*>( tabBar.currentWidget() );
+	if( !pvb || !pvb->part() ) return;
 	
 	KParts::BrowserExtension * ext = KParts::BrowserExtension::childObject( pvb->part() );
 	if( ext && ext->isActionEnabled( "print" ) )
@@ -518,8 +572,8 @@ void KrViewer::print() {
 }
 
 void KrViewer::copy() {
-	PanelViewerBase* pvb = static_cast<PanelViewerBase*>( tabBar.currentPage() );
-	if( !pvb ) return;
+	PanelViewerBase* pvb = static_cast<PanelViewerBase*>( tabBar.currentWidget() );
+	if( !pvb || !pvb->part() ) return;
 	
 	KParts::BrowserExtension * ext = KParts::BrowserExtension::childObject( pvb->part() );
 	if( ext && ext->isActionEnabled( "copy" ) )
@@ -528,7 +582,7 @@ void KrViewer::copy() {
 
 PanelViewerBase * KrViewer::getPanelViewerBase( KParts::Part * part ) {
 	for( int i=0; i != tabBar.count(); i++ ) {
-		PanelViewerBase *pvb = static_cast<PanelViewerBase*>( tabBar.page( i ) );
+		PanelViewerBase *pvb = static_cast<PanelViewerBase*>( tabBar.widget( i ) );
 		if( pvb && pvb->part() == part )
 			return pvb;
 	}
@@ -536,22 +590,44 @@ PanelViewerBase * KrViewer::getPanelViewerBase( KParts::Part * part ) {
 }
 
 void KrViewer::updateActions( PanelViewerBase * pvb ) {
-	if( pvb->isEditor() ) {
-		printAction->unplugAll();
-		copyAction->unplugAll();
-	}
-	else {
-		if( !printAction->isPlugged( toolBar() ) )
-			printAction->plug( toolBar(), 0 );
-		if( !copyAction->isPlugged( toolBar() ) )
-			copyAction->plug( toolBar(), 1 );
+	QList<QAction *> actList = toolBar()->actions();
+	bool hasPrint = false, hasCopy = false;
+	foreach( QAction *a, actList ) {
+		if( a->text() == printAction->text() )
+			hasPrint = true;
+		if( a->text() == copyAction->text() )
+			hasCopy = true;
 	}
+	if( !hasPrint )
+		toolBar()->addAction( printAction->icon(), printAction->text(), this, SLOT( print() ));
+	if( !hasCopy )
+		toolBar()->addAction( copyAction->icon(), copyAction->text(), this, SLOT( copy() ) );
 }
 
+bool KrViewer::isValidPart( KParts::Part* part) {
+	return manager.parts().contains( part );
+}
+
+void KrViewer::partDestroyed( PanelViewerBase * pvb ) {
+	/* not yet used */
+}
+
+void KrViewer::resizeEvent( QResizeEvent *e )
+{
+  if( !isMaximized() )
+  {
+    sizeX = e->size().width();
+    sizeY = e->size().height();
+  }
+
+  KParts::MainWindow::resizeEvent( e );
+}
+
+
 #if 0
-bool KrViewer::editGeneric( QString mimetype, KURL _url ) {
+bool KrViewer::editGeneric( QString mimetype, KUrl _url ) {
 	KParts::ReadWritePart * kedit_part = 0L;
-	KLibFactory *factory = 0;
+	KPluginFactory *factory = 0;
 	KTrader::OfferList offers = KTrader::self() ->query( mimetype );
 
 	// in theory, we only care about the first one.. but let's try all
@@ -562,12 +638,12 @@ bool KrViewer::editGeneric( QString mimetype, KURL _url ) {
 		// we now know that our offer can handle mimetype and is a part.
 		// since it is a part, it must also have a library... let's try to
 		// load that now
-		factory = KLibLoader::self() ->factory( ptr->library().latin1() );
+		factory = KLibLoader::self() ->factory( ptr->library().toLatin1() );
 		if ( factory ) {
 			kedit_part = static_cast<KParts::ReadWritePart *>( factory->create( this,
-			             ptr->name().latin1(), "KParts::ReadWritePart" ) );
+			             ptr->name().toLatin1(), "KParts::ReadWritePart" ) );
 			if ( kedit_part )
-				if ( kedit_part->openURL( _url ) ) break;
+				if ( kedit_part->openUrl( _url ) ) break;
 				else {
 					delete kedit_part;
 					kedit_part = 0L;
@@ -598,23 +674,23 @@ bool KrViewer::editText( bool create ) {
 }
 
 bool KrViewer::viewGeneric() {
-	QString mimetype = KMimeType::findByURL( url ) ->name();
+	QString mimetype = KMimeType::findByUrl( url ) ->name();
 	// ugly hack: don't try to get a part for an XML file, it usually don't work
 	if ( mimetype == "text/xml" ) return false;
-	if ( url.prettyURL().startsWith( "man:" ) ) mimetype = "text/html";
+	if ( url.prettyUrl().startsWith( "man:" ) ) mimetype = "text/html";
 	if ( mimetype == "text/plain" )
 		viewerMenu->setItemEnabled( 1, false );
 
 	if ( !generic_part ) {
 		if ( mimetype.contains( "html" ) ) {
 			KHTMLPart * p = new KHTMLPart( this, 0, 0, 0, KHTMLPart::BrowserViewGUI );
-			connect( p->browserExtension(), SIGNAL( openURLRequest( const KURL &, const KParts::URLArgs & ) ),
-			         this, SLOT( handleOpenURLRequest( const KURL &, const KParts::URLArgs & ) ) );
+			connect( p->browserExtension(), SIGNAL( openUrlRequest( const KUrl &, const KParts::URLArgs & ) ),
+			         this, SLOT( handleOpenUrlRequest( const KUrl &, const KParts::URLArgs & ) ) );
 			/* At JavaScript self.close() the KHTMLPart destroys itself.  */
 			/* After destruction, just close the window */
 			connect( p, SIGNAL( destroyed() ), this, SLOT( close() ) );
 
-			p-> openURL( url );
+			p-> openUrl( url );
 			generic_part = p;
 		} else {
 			generic_part = static_cast<KParts::ReadOnlyPart*>( getPart( url, mimetype, true ) );
@@ -654,10 +730,10 @@ void KrViewer::viewHex() {
 
 		// create a hex file
 		QFile f_in( file );
-		f_in.open( IO_ReadOnly );
+		f_in.open( QIODevice::ReadOnly );
 		QDataStream in( &f_in );
 
-		FILE *out = KDE_fopen( tmpFile.name().local8Bit(), "w" );
+		FILE *out = KDE_fopen( tmpFile.name().toLocal8Bit(), "w" );
 
 		KIO::filesize_t fileSize = f_in.size();
 		KIO::filesize_t address = 0;
