@@ -19,14 +19,16 @@
 #define KRVIEWER_H
 
 #include <qwidget.h>
-#include <qptrlist.h>
+#include <QEvent>
+#include <QList>
+#include <QKeyEvent>
+#include <QFocusEvent>
 #include <kparts/mainwindow.h>
-#include <ktempfile.h>
 #include <kparts/partmanager.h>
 #include <kparts/browserextension.h>
-#include <qguardedptr.h>
+#include <qpointer.h>
 #include <ktabwidget.h>
-
+#include <ktemporaryfile.h>
 #include "../krusader.h"
 
 
@@ -34,7 +36,6 @@
   *@author Shie Erlich & Rafi Yanai
   */
 
-class QPopupMenu;
 class PanelViewerBase;
 
 class KrViewer : public KParts::MainWindow {
@@ -44,10 +45,10 @@ public:
 	
 	enum Mode{Generic,Text,Hex};
 
-	static void view( KURL url, QWidget * parent = krApp );
-	static void view( KURL url, Mode mode, bool new_window, QWidget * parent = krApp );
-	static void edit( KURL url, QWidget * parent );
-	static void edit( KURL url, Mode mode=Text, int new_window=-1, QWidget * parent = krApp );
+	static void view( KUrl url, QWidget * parent = krApp );
+	static void view( KUrl url, Mode mode, bool new_window, QWidget * parent = krApp );
+	static void edit( KUrl url, QWidget * parent );
+	static void edit( KUrl url, Mode mode=Text, int new_window=-1, QWidget * parent = krApp );
 	
 	virtual bool eventFilter ( QObject * watched, QEvent * e );
 
@@ -64,9 +65,10 @@ public slots:
 	void copy();
 
 	void tabChanged(QWidget* w);
-	void tabURLChanged( PanelViewerBase * pvb, const KURL &url );
+	void tabURLChanged( PanelViewerBase * pvb, const KUrl &url );
 	void tabCloseRequest(QWidget *w);
 	void tabCloseRequest();
+	void partDestroyed( PanelViewerBase * );
 
 	void nextTab();
 	void prevTab();
@@ -78,35 +80,40 @@ protected:
 	virtual bool queryClose();
 	virtual bool queryExit();
 	virtual void windowActivationChange ( bool oldActive );
+	virtual void resizeEvent( QResizeEvent *e );
 
-	virtual void focusInEvent( QFocusEvent * ){ if( viewers.remove( this ) ) viewers.prepend( this ); } // move to first
+	virtual void focusInEvent( QFocusEvent * ){ if( viewers.removeAll( this ) ) viewers.prepend( this ); } // move to first
 
 private:
-	KrViewer( QWidget *parent = 0, const char *name = 0 );
+	KrViewer( QWidget *parent = 0 );
 	void addTab(PanelViewerBase* pvb, QString msg,QString iconName, KParts::Part* part);
 	PanelViewerBase * getPanelViewerBase( KParts::Part* part);
 	void updateActions( PanelViewerBase * base );
+	bool isValidPart( KParts::Part* part);
 	
 	static KrViewer* getViewer(bool new_window);	
 
 	KParts::PartManager manager;
-	QPopupMenu* viewerMenu;
-	KTempFile tmpFile;
+	QMenu* viewerMenu;
+	KTemporaryFile tmpFile;
 	KTabWidget tabBar;
-	QGuardedPtr<QWidget> returnFocusTo;
+	QPointer<QWidget> returnFocusTo;
 	PanelViewerBase * returnFocusTab;
 	
-	int detachActionIndex;
+	QAction *detachAction;
 
 	KAction *printAction;
 	KAction *copyAction;
 
-	int tabCloseID;
-	int closeID;
+	QAction *tabClose;
+	QAction *closeAct;
 
-	static QPtrList<KrViewer> viewers; // the first viewer is the active one
-	QValueList<int>    reservedKeys;   // the reserved key sequences
-	QValueList<int>    reservedKeyIDs; // the IDs of the reserved keys
+	static QList<KrViewer *> viewers; // the first viewer is the active one
+	QList<int>    reservedKeys;   // the reserved key sequences
+	QList<QAction *> reservedKeyActions; // the IDs of the reserved keys
+	
+	int sizeX;
+	int sizeY;
 };
 
 class Invoker : public QObject {
