@@ -1,22 +1,23 @@
 #include <kurl.h>
 #include <qstring.h>
-#include <qwidgetstack.h>
+#include <qstackedwidget.h>
 #include <qapplication.h>
 #include <kparts/part.h>
 #include <kparts/browserextension.h>
 #include <kmessagebox.h>
-#include <qdict.h>
+#include <qhash.h>
 #include <qlabel.h>
 #include <kmimetype.h>
-#include <ktempfile.h>
+#include <ktemporaryfile.h>
 #include <klocale.h>
 #include <klibloader.h>
-#include <kuserprofile.h>
+#include <kservicetypeprofile.h>
+#include <kmimetypetrader.h>
 #include <kdebug.h>
 #include <kfileitem.h>
 #include <kio/netaccess.h>
 #include <qfile.h>
-#include <klargefile.h>
+#include <kde_file.h>
 #include "panelviewer.h"
 
 #define DICTSIZE 211
@@ -24,21 +25,27 @@
 /* ----==={ PanelViewerBase }===---- */
 
 PanelViewerBase::PanelViewerBase( QWidget *parent ) :
-QWidgetStack( parent ), mimes( 0 ), cpart( 0 ) {
+QStackedWidget( parent ), mimes( 0 ), cpart( 0 ) {
 	setSizePolicy( QSizePolicy( QSizePolicy::Preferred, QSizePolicy::Ignored ) );
-
-	mimes = new QDict<KParts::ReadOnlyPart>( DICTSIZE, false );
-	mimes->setAutoDelete( true );
+	
+	mimes = new QHash<QString, QPointer<KParts::ReadOnlyPart> >();
 	cpart = 0;
 	fallback = new QLabel( i18n( "No file selected or selected file can't be displayed." ), this );
-	fallback->setAlignment( AlignCenter | ExpandTabs | WordBreak );
+	fallback->setAlignment( Qt::Alignment( QFlag( Qt::AlignCenter | Qt::TextExpandTabs ) ) );
+	fallback->setWordWrap( true );
 	addWidget( fallback );
-	raiseWidget( fallback );
+	setCurrentWidget( fallback );
 }
 
 PanelViewerBase::~PanelViewerBase() {
 //	cpart->queryClose();
-	closeURL();
+	closeUrl();
+	QHashIterator< QString, QPointer<KParts::ReadOnlyPart> > lit( *mimes );
+	while( lit.hasNext() ) {
+		QPointer<KParts::ReadOnlyPart> p = lit.next().value();
+		if( p )
+			delete p;
+	}
 	mimes->clear();
 	delete mimes;
 	delete fallback;
@@ -53,21 +60,28 @@ PanelViewerBase( parent ) {
 PanelViewer::~PanelViewer() {
 }
 
-KParts::ReadOnlyPart* PanelViewer::openURL( const KURL &url, KrViewer::Mode mode ) {
+KParts::ReadOnlyPart* PanelViewer::openUrl( const KUrl &url, KrViewer::Mode mode ) {
 	emit urlChanged( this, url );
-	closeURL();
+	closeUrl();
 	curl = url;
 
 	if( mode == KrViewer::Generic ){
-		cmimetype = KMimeType::findByURL( curl ) ->name();
-		cpart = ( *mimes ) [ cmimetype ];
-		if ( !cpart ){
+		KMimeType::Ptr mt = KMimeType::findByUrl( curl );
+		cmimetype = mt ? mt->name() : QString();
+		// KDE 4 HACK : START
+		// KDE 4 crashes at viewing directories
+		if( cmimetype == "inode/directory" )
+			return 0;
+		// KDE 4 HACK : END
+		if( mimes->find( cmimetype ) == mimes->end() ) {
 			cpart = getPart( cmimetype );
 			mimes->insert( cmimetype, cpart );
 		}
+		else
+			cpart = ( *mimes ) [ cmimetype ];
 	}
 
-	KTempFile tmpFile;
+	KTemporaryFile tmpFile;
 
 	if( mode == KrViewer::Hex ){
 		if ( !cpart ) cpart = getHexPart();
@@ -79,21 +93,22 @@ KParts::ReadOnlyPart* PanelViewer::openURL( const KURL &url, KrViewer::Mode mode
 
 	if ( cpart ) {
 		addWidget( cpart->widget() );
-		raiseWidget( cpart->widget() );
+		setCurrentWidget( cpart->widget() );
 	}
-	if ( cpart && cpart->openURL( curl ) ){
+	if ( cpart && cpart->openUrl( curl ) ){
 		curl = url; /* needed because of the oldHexViewer */
+		connect( cpart, SIGNAL( destroyed() ), this, SLOT( slotCPartDestroyed() ) );
 		return cpart;
 	}
 	else {
-		raiseWidget( fallback );
+		setCurrentWidget( fallback );
 		return 0;
 	}
 }
 
-bool PanelViewer::closeURL() {
-	raiseWidget( fallback );
-	if ( cpart && cpart->closeURL() ) {
+bool PanelViewer::closeUrl() {
+	setCurrentWidget( fallback );
+	if ( cpart && cpart->closeUrl() ) {
 		cpart = 0;
 		return true;
 	}
@@ -102,30 +117,34 @@ bool PanelViewer::closeURL() {
 
 KParts::ReadOnlyPart* PanelViewer::getPart( QString mimetype ) {
 	KParts::ReadOnlyPart * part = 0L;
-	KLibFactory *factory = 0;
-	KService::Ptr ptr = KServiceTypeProfile::preferredService( mimetype, "KParts/ReadOnlyPart" );
+	KPluginFactory *factory = 0;
+	KService::Ptr ptr = KMimeTypeTrader::self()->preferredService( mimetype, "KParts/ReadOnlyPart" );
 	if ( ptr ) {
 		QStringList args;
 		QVariant argsProp = ptr->property( "X-KDE-BrowserView-Args" );
 		if ( argsProp.isValid() ) {
 			QString argStr = argsProp.toString();
-			args = QStringList::split( " ", argStr );
+			args = argStr.split( " " );
 		}
 		QVariant prop = ptr->property( "X-KDE-BrowserView-AllowAsDefault" );
 		if ( !prop.isValid() || prop.toBool() )   // defaults to true
 		{
-			factory = KLibLoader::self() ->factory( ptr->library().latin1() );
+			factory = KLibLoader::self() ->factory( ptr->library().toLatin1() );
 			if ( factory ) {
-				part = static_cast<KParts::ReadOnlyPart *>( factory->create( this,
-				        ptr->name().latin1(), QString( "KParts::ReadOnlyPart" ).latin1(), args ) );
+				if( ptr->serviceTypes().contains( "Browser/View" ) )
+					part = static_cast<KParts::ReadOnlyPart *>( factory->create( this,
+					        QString( "Browser/View" ).toLatin1(), args ) );
+				if( !part )
+					part = static_cast<KParts::ReadOnlyPart *>( factory->create( this,
+					        QString( "KParts::ReadOnlyPart" ).toLatin1(), args ) );
 			}
 		}
 	}
 	if ( part ) {
 		KParts::BrowserExtension * ext = KParts::BrowserExtension::childObject( part );
 		if ( ext ) {
-			connect( ext, SIGNAL( openURLRequestDelayed( const KURL &, const KParts::URLArgs & ) ), this, SLOT( openURL( const KURL & ) ) );
-			connect( ext, SIGNAL( openURLRequestDelayed( const KURL &, const KParts::URLArgs & ) ), this, SIGNAL( openURLRequest( const KURL & ) ) );
+			connect( ext, SIGNAL( openUrlRequestDelayed( const KUrl &, const KParts::OpenUrlArguments&, const KParts::BrowserArguments& ) ), this, SLOT( openUrl( const KUrl & ) ) );
+			connect( ext, SIGNAL( openUrlRequestDelayed( const KUrl &, const KParts::OpenUrlArguments&, const KParts::BrowserArguments& ) ), this, SIGNAL( openUrlRequest( const KUrl & ) ) );
 		}
 	}
 	return part;
@@ -134,16 +153,16 @@ KParts::ReadOnlyPart* PanelViewer::getPart( QString mimetype ) {
 KParts::ReadOnlyPart* PanelViewer::getHexPart(){
 	KParts::ReadOnlyPart * part = 0L;
 
-	KLibFactory * factory = KLibLoader::self() ->factory( "libkhexedit2part" );
+	KPluginFactory * factory = KLibLoader::self() ->factory( "libkhexedit2part" );
 	if ( factory ) {
 		// Create the part
-		part = ( KParts::ReadOnlyPart * ) factory->create( this, "hexedit2part","KParts::ReadOnlyPart" );
+		part = ( KParts::ReadOnlyPart * ) factory->create( this, "KParts::ReadOnlyPart" );
 	}
 
 	return part;
 }
 
-void PanelViewer::oldHexViewer(KTempFile& tmpFile) {
+void PanelViewer::oldHexViewer(KTemporaryFile& tmpFile) {
 	QString file;
 	// files that are not local must first be downloaded
 	if ( !curl.isLocalFile() ) {
@@ -156,24 +175,25 @@ void PanelViewer::oldHexViewer(KTempFile& tmpFile) {
 
 	// create a hex file
 	QFile f_in( file );
-	f_in.open( IO_ReadOnly );
+	f_in.open( QIODevice::ReadOnly );
 	QDataStream in( &f_in );
 
-	FILE *out = KDE_fopen( tmpFile.name().local8Bit(), "w" );
+  tmpFile.open(); // else there is no filename
+	FILE *out = KDE_fopen( tmpFile.fileName().toLocal8Bit(), "w" ); // TODO get rid of FILE*
 
 	KIO::filesize_t fileSize = f_in.size();
 	KIO::filesize_t address = 0;
 	char buf[ 16 ];
-	unsigned int* pBuff = ( unsigned int* ) buf;
+	unsigned char* pBuff = ( unsigned char* ) buf;
 
 	while ( address < fileSize ) {
 		memset( buf, 0, 16 );
 		int bufSize = ( ( fileSize - address ) > 16 ) ? 16 : ( fileSize - address );
-		in.readRawBytes( buf, bufSize );
+		in.readRawData( buf, bufSize );
 		fprintf( out, "0x%8.8llx: ", address );
-		for ( int i = 0; i < 4; ++i ) {
-			if ( i < ( bufSize / 4 ) ) fprintf( out, "%8.8x ", pBuff[ i ] );
-			else fprintf( out, "         " );
+		for ( int i = 0; i < 16; ++i ) {
+			if ( i < bufSize  ) fprintf( out, "%2.2x ", pBuff[ i ] );
+			else fprintf( out, "   " );
 		}
 		fprintf( out, "| " );
 
@@ -191,7 +211,7 @@ void PanelViewer::oldHexViewer(KTempFile& tmpFile) {
 	if ( !curl.isLocalFile() )
 	KIO::NetAccess::removeTempFile( file );
 
-	curl = tmpFile.name();
+	curl = tmpFile.fileName();
 }
 
 /* ----==={ PanelEditor }===---- */
@@ -203,18 +223,20 @@ PanelViewerBase( parent ) {
 PanelEditor::~PanelEditor() {
 }
 
-KParts::ReadOnlyPart* PanelEditor::openURL( const KURL &url, KrViewer::Mode mode ) {
+KParts::ReadOnlyPart* PanelEditor::openUrl( const KUrl &url, KrViewer::Mode mode ) {
 	emit urlChanged( this, url );
-	closeURL();
+	closeUrl();
 	curl = url;
 
 	if( mode == KrViewer::Generic ){
-		cmimetype = KMimeType::findByURL( curl ) ->name();
-		cpart = ( *mimes ) [ cmimetype ];
-		if ( !cpart ){ 
+		KMimeType::Ptr mt = KMimeType::findByUrl( curl );
+		cmimetype = mt ? mt->name() : QString();
+		if( mimes->find( cmimetype ) == mimes->end() ) {
 			cpart = getPart( cmimetype );
 			mimes->insert( cmimetype, cpart );
 		}
+		else
+			cpart = ( *mimes ) [ cmimetype ];
 	}
 
 	if ( !cpart ) cpart = getPart( "text/plain" );
@@ -222,86 +244,92 @@ KParts::ReadOnlyPart* PanelEditor::openURL( const KURL &url, KrViewer::Mode mode
 
 	if ( cpart ) {
 		addWidget( cpart->widget() );
-		raiseWidget( cpart->widget() );
+		setCurrentWidget( cpart->widget() );
 	}
 	else {
-		raiseWidget( fallback );
+		setCurrentWidget( fallback );
 		return 0;
 	}
 
 	bool create = true;
 	KIO::StatJob* statJob = KIO::stat( url, false );
-	connect( statJob, SIGNAL( result( KIO::Job* ) ), this, SLOT( slotStatResult( KIO::Job* ) ) );
+	connect( statJob, SIGNAL( result( KJob* ) ), this, SLOT( slotStatResult( KJob* ) ) );
 	busy = true;
 	while ( busy ) qApp->processEvents();
-	if( !entry.isEmpty() ) {
+	if( entry.count() != 0 ) {
 		KFileItem file( entry, url );
 		if( file.isReadable() ) create = false;
 	}
 	
 	if( create ){
-		if( static_cast<KParts::ReadWritePart *>(cpart)->saveAs( curl ) ) return cpart;
+		if( static_cast<KParts::ReadWritePart *>((KParts::ReadOnlyPart *)cpart)->saveAs( curl ) ) {
+			connect( cpart, SIGNAL( destroyed() ), this, SLOT( slotCPartDestroyed() ) );
+			return cpart;
+		}
 	}
 	else {
-		if ( cpart->openURL( curl ) ) return cpart;
+		if ( cpart->openUrl( curl ) ) {
+			connect( cpart, SIGNAL( destroyed() ), this, SLOT( slotCPartDestroyed() ) );
+			return cpart;
+		}
 	}
 	return 0;
 }
 
 bool PanelEditor::queryClose() {
 	if ( !cpart ) return true;
-	return static_cast<KParts::ReadWritePart *>(cpart)->queryClose();
+	return static_cast<KParts::ReadWritePart *>((KParts::ReadOnlyPart *)cpart)->queryClose();
 }
 
-bool PanelEditor::closeURL() {
+bool PanelEditor::closeUrl() {
 	if ( !cpart ) return false;
 	
-	static_cast<KParts::ReadWritePart *>(cpart)->closeURL( false );
+	static_cast<KParts::ReadWritePart *>((KParts::ReadOnlyPart *)cpart)->closeUrl( false );
 	
-	raiseWidget( fallback );
+	setCurrentWidget( fallback );
 	cpart = 0;
 	return true;
 }
 
 KParts::ReadWritePart* PanelEditor::getPart( QString mimetype ) {
 	KParts::ReadWritePart * part = 0L;
-	KLibFactory *factory = 0;
-	KService::Ptr ptr = KServiceTypeProfile::preferredService( mimetype, "KParts/ReadWritePart" );
+	KPluginFactory *factory = 0;
+	KService::Ptr ptr = KMimeTypeTrader::self()->preferredService( mimetype, "KParts/ReadWritePart" );
 	if ( ptr ) {
 		QStringList args;
 		QVariant argsProp = ptr->property( "X-KDE-BrowserView-Args" );
 		if ( argsProp.isValid() ) {
 			QString argStr = argsProp.toString();
-			args = QStringList::split( " ", argStr );
+			args = argStr.split( " " );
 		}
 		QVariant prop = ptr->property( "X-KDE-BrowserView-AllowAsDefault" );
 		if ( !prop.isValid() || prop.toBool() )  // defaults to true
 		{
-			factory = KLibLoader::self() ->factory( ptr->library().latin1() );
+			factory = KLibLoader::self() ->factory( ptr->library().toLatin1() );
 			if ( factory ) {
 				part = static_cast<KParts::ReadWritePart *>( factory->create( this,
-				        ptr->name().latin1(), QString( "KParts::ReadWritePart" ).latin1(), args ) );
+				        QString( "KParts::ReadWritePart" ).toLatin1(), args ) );
 			}
 		}
 	}
 	if ( part ) {
 		KParts::BrowserExtension * ext = KParts::BrowserExtension::childObject( part );
 		if ( ext ) {
-			connect( ext, SIGNAL( openURLRequestDelayed( const KURL &, const KParts::URLArgs & ) ), this, SLOT( openURL( const KURL & ) ) );
-			connect( ext, SIGNAL( openURLRequestDelayed( const KURL &, const KParts::URLArgs & ) ), this, SIGNAL( openURLRequest( const KURL & ) ) );
+			connect( ext, SIGNAL( openUrlRequestDelayed( const KUrl &, const KParts::OpenUrlArguments&, const KParts::BrowserArguments& ) ), this, SLOT( openUrl( const KUrl & ) ) );
+			connect( ext, SIGNAL( openUrlRequestDelayed( const KUrl &, const KParts::OpenUrlArguments&, const KParts::BrowserArguments& ) ), this, SIGNAL( openUrlRequest( const KUrl & ) ) );
 		}
 	}
 	return part;
 }
 
-void PanelEditor::slotStatResult( KIO::Job* job ) {
+void PanelEditor::slotStatResult( KJob* job ) {
   if( !job || job->error() ) entry = KIO::UDSEntry();
   else entry = static_cast<KIO::StatJob*>(job)->statResult();
   busy = false;
 }
 
 bool PanelEditor::isModified(){
-	return static_cast<KParts::ReadWritePart *>(cpart)->isModified();
+	return static_cast<KParts::ReadWritePart *>((KParts::ReadOnlyPart *)cpart)->isModified();
 }
 
 #include "panelviewer.moc"
