@@ -29,9 +29,10 @@
  ***************************************************************************/
 
 #include <qlabel.h>
-#include <qhbox.h>
-#include <qvbox.h>
 #include <qfontmetrics.h>
+#include <QGridLayout>
+#include <QFrame>
+#include <QPixmap>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kinputdialog.h>
@@ -41,19 +42,22 @@
 #include "../krusader.h"
 #include "../kicons.h"
 
-KgGeneral::KgGeneral( bool first, QWidget* parent,  const char* name ) :
-      KonfiguratorPage( first, parent, name )
+KgGeneral::KgGeneral( bool first, QWidget* parent ) :
+      KonfiguratorPage( first, parent )
 {
 if( first )  
     slotFindTools();
 
-  QGridLayout *kgGeneralLayout = new QGridLayout( parent );
+  QWidget *innerWidget = new QFrame( this );
+  setWidget( innerWidget );
+  setWidgetResizable( true );
+  QGridLayout *kgGeneralLayout = new QGridLayout( innerWidget );
   kgGeneralLayout->setSpacing( 6 );
 
   //  -------------------------- GENERAL GROUPBOX ----------------------------------
 
-  QGroupBox *generalGrp = createFrame( i18n( "General" ), parent, "kgGenGeneralGrp" );
-  QGridLayout *generalGrid = createGridLayout( generalGrp->layout() );
+  QGroupBox *generalGrp = createFrame( i18n( "General" ), innerWidget );
+  QGridLayout *generalGrid = createGridLayout( generalGrp );
 
   KONFIGURATOR_NAME_VALUE_TIP deleteMode[] =
   //            name            value    tooltip
@@ -61,112 +65,136 @@ if( first )
      { i18n( "Move to trash" ), "true",  i18n( "Files will be moved to trash when deleted." ) }};
 
   KonfiguratorRadioButtons *trashRadio = createRadioButtonGroup( "General", "Move To Trash",
-      _MoveToTrash ? "true" : "false", 2, 0, deleteMode, 2, generalGrp, "myRadio", false );
-  generalGrid->addMultiCellWidget( trashRadio, 0, 0, 0, 1 );
+      _MoveToTrash ? "true" : "false", 2, 0, deleteMode, 2, generalGrp, false );
+  generalGrid->addWidget( trashRadio, 0, 0, 1, 2 );
 
   KonfiguratorCheckBox *checkBox = createCheckBox( "General", "Mimetype Magic", _MimetypeMagic,
                      i18n( "Use mimetype magic" ), generalGrp, false,
                      i18n( "Mimetype magic allows better distinction of file types, but is slower." ) );
-  generalGrid->addMultiCellWidget( checkBox, 1, 1, 0, 1 );
+  generalGrid->addWidget( checkBox, 1, 0, 1, 2 );
 
-  QFrame *line1 = createLine( generalGrp, "line1" );
-  generalGrid->addMultiCellWidget( line1, 2, 2, 0, 1 );
+  QFrame *line1 = createLine( generalGrp );
+  generalGrid->addWidget( line1, 2, 0, 1, 2 );
 
   // editor
-  QLabel *label1 = new QLabel( i18n( "Editor:" ), generalGrp, "EditorLabel" );
+  QLabel *label1 = new QLabel( i18n( "Editor:" ), generalGrp );
   generalGrid->addWidget( label1, 3, 0 );
   KonfiguratorURLRequester *urlReq = createURLRequester( "General", "Editor", "internal editor",
                                       generalGrp, false );
   generalGrid->addWidget( urlReq, 3, 1 );
 
-  QLabel *label2 = new QLabel( i18n( "Hint: use 'internal editor' if you want to use Krusader's fast built-in editor" ), generalGrp, "EditorLabel" );
-  generalGrid->addMultiCellWidget( label2, 4, 4, 0, 1 );
+  QLabel *label2 = new QLabel( i18n( "Hint: use 'internal editor' if you want to use Krusader's fast built-in editor" ), generalGrp );
+  generalGrid->addWidget( label2, 4, 0, 1, 2 );
 
-QFrame *line2 = createLine( generalGrp, "line2" );
-  generalGrid->addMultiCellWidget( line2, 5, 5, 0, 1 );
+  QFrame *line2 = createLine( generalGrp );
+  generalGrid->addWidget( line2, 5, 0, 1, 2 );
 
   // viewer
 
-  QHBox * hbox2 = new QHBox( generalGrp );
-  QVBox * vbox = new QVBox( hbox2 );
+  QWidget * hboxWidget2 = new QWidget( generalGrp );
+  QHBoxLayout * hbox2 = new QHBoxLayout( hboxWidget2 );
 
-  new QLabel( i18n("Default viewer mode:"), vbox);
+  QWidget * vboxWidget = new QWidget( hboxWidget2 );
+  QVBoxLayout * vbox = new QVBoxLayout( vboxWidget );
+
+  vbox->addWidget( new QLabel( i18n("Default viewer mode:"), vboxWidget) );
   
   KONFIGURATOR_NAME_VALUE_TIP viewMode[] =
   //            name            value    tooltip
     {{ i18n( "Generic mode" ),  "generic", i18n( "Use the system's default viewer" ) },
      { i18n( "Text mode" ), "text",  i18n( "View the file in text-only mode" ) }, 
      { i18n( "Hex mode" ), "hex",  i18n( "View the file in hex-mode (better for binary files)" ) } };
-  createRadioButtonGroup( "General", "Default Viewer Mode",
-      "generic", 0, 3, viewMode, 3, vbox, "myRadio2", false );
+  
+  vbox->addWidget( createRadioButtonGroup( "General", "Default Viewer Mode",
+      "generic", 0, 3, viewMode, 3, vboxWidget, false ) );
 
-  createCheckBox( "General", "View In Separate Window", _ViewInSeparateWindow,
-                     i18n( "Internal editor and viewer opens each file in a separate window" ), vbox, false,
-                     i18n( "If checked, each file will open in a separate window, otherwise, the viewer will work in a single, tabbed mode" ) );
+  vbox->addWidget( createCheckBox( "General", "View In Separate Window", _ViewInSeparateWindow,
+                     i18n( "Internal editor and viewer opens each file in a separate window" ), vboxWidget, false,
+                     i18n( "If checked, each file will open in a separate window, otherwise, the viewer will work in a single, tabbed mode" ) ) );
 
-  generalGrid->addMultiCellWidget(hbox2, 6, 8, 0, 1);
+  hbox2->addWidget( vboxWidget );
+  generalGrid->addWidget(hboxWidget2, 6, 0, 3, 2);
 
   // atomic extensions
-  QFrame * frame21 = createLine( hbox2, "line2.1", true );
+  QFrame * frame21 = createLine( hboxWidget2, true );
   frame21->setMinimumWidth( 15 );
-  QVBox * vbox2 = new QVBox( hbox2 );
+  hbox2->addWidget( frame21 );
 
-  QHBox * hbox3 = new QHBox( vbox2 );
-  QLabel * atomLabel = new QLabel( i18n("Atomic extensions:"), hbox3);
+  QWidget * vboxWidget2 = new QWidget( hboxWidget2 );
+  QVBoxLayout * vbox2 = new QVBoxLayout( vboxWidget2 );
+
+  hbox2->addWidget( vboxWidget2 );
+
+  QWidget * hboxWidget3 = new QWidget( vboxWidget2 );
+  vbox2->addWidget( hboxWidget3 );
+
+  QHBoxLayout * hbox3 = new QHBoxLayout( hboxWidget3 );
+
+  QLabel * atomLabel = new QLabel( i18n("Atomic extensions:"), hboxWidget3);
+  hbox3->addWidget( atomLabel );
 
   int size = QFontMetrics( atomLabel->font() ).height();
 
-  QToolButton *addButton = new QToolButton( hbox3, "addBtnList" );
-  QPixmap icon = krLoader->loadIcon("add",KIcon::Desktop, size );
+  QToolButton *addButton = new QToolButton( hboxWidget3 );
+  hbox3->addWidget( addButton );
+
+  QPixmap icon = krLoader->loadIcon("list-add",KIconLoader::Desktop, size );
   addButton->setFixedSize( icon.width() + 4, icon.height() + 4 );
-  addButton->setPixmap( icon );
+  addButton->setIcon( QIcon( icon ) );
   connect( addButton, SIGNAL( clicked() ), this, SLOT( slotAddExtension() ) );
 
-  QToolButton *removeButton = new QToolButton( hbox3, "removeBtnList" );
-  icon = krLoader->loadIcon("remove",KIcon::Desktop, size );
+  QToolButton *removeButton = new QToolButton( hboxWidget3 );
+  hbox3->addWidget( removeButton );
+
+  icon = krLoader->loadIcon("list-remove",KIconLoader::Desktop, size );
   removeButton->setFixedSize( icon.width() + 4, icon.height() + 4 );
-  removeButton->setPixmap( icon );
+  removeButton->setIcon( QIcon( icon ) );
   connect( removeButton, SIGNAL( clicked() ), this, SLOT( slotRemoveExtension() ) );
 
   QStringList defaultAtomicExtensions;
   defaultAtomicExtensions += ".tar.gz";
   defaultAtomicExtensions += ".tar.bz2";
+  defaultAtomicExtensions += ".tar.lzma";
   defaultAtomicExtensions += ".moc.cpp";
 
   listBox = createListBox( "Look&Feel", "Atomic Extensions", 
-      defaultAtomicExtensions, vbox2, true, false );
+      defaultAtomicExtensions, vboxWidget2, true, false );
+  vbox2->addWidget( listBox );
 
-  QFrame *line3 = createLine( generalGrp, "line3" );
-  generalGrid->addMultiCellWidget( line3, 9, 9, 0, 1 );
+  QFrame *line3 = createLine( generalGrp );
+  generalGrid->addWidget( line3, 9, 0, 1, 2 );
 
 	// terminal
-  QLabel *label3 = new QLabel( i18n( "Terminal:" ), generalGrp, "TerminalLabel" );
+  QLabel *label3 = new QLabel( i18n( "Terminal:" ), generalGrp );
   generalGrid->addWidget( label3, 10, 0 );
-  KonfiguratorURLRequester *urlReq2 = createURLRequester( "General", "Terminal", "konsole",
+  KonfiguratorURLRequester *urlReq2 = createURLRequester( "General", "Terminal", _Terminal,
                                       generalGrp, false );
   generalGrid->addWidget( urlReq2, 10, 1 );
 
   KonfiguratorCheckBox *checkBox1 = createCheckBox( "General", "Send CDs", _SendCDs,
                      i18n( "Terminal Emulator sends Chdir on panel change" ), generalGrp, false,
                      i18n( "When checked, whenever the panel is changed (for example, by pressing TAB), krusader changes the current directory in the terminal emulator." ) );
-  generalGrid->addMultiCellWidget( checkBox1, 11, 11, 0, 1 );
+  generalGrid->addWidget( checkBox1, 11, 0, 1, 2 );
 
-  QFrame *line31 = createLine( generalGrp, "line4" );
-  generalGrid->addMultiCellWidget( line31, 12, 12, 0, 1 );
+  QFrame *line31 = createLine( generalGrp );
+  generalGrid->addWidget( line31, 12, 0, 1, 2 );
 
 	// temp dir
-  QHBox *hbox = new QHBox( generalGrp, "hbox" );
-  new QLabel( i18n( "Temp Directory:" ), hbox, "TempDirectory" );
+  QWidget *hboxWidget = new QWidget( generalGrp );
+  QHBoxLayout * hbox = new QHBoxLayout( hboxWidget );
+
+  hbox->addWidget( new QLabel( i18n( "Temp Directory:" ), hboxWidget ) );
   KonfiguratorURLRequester *urlReq3 = createURLRequester( "General", "Temp Directory", "/tmp/krusader.tmp",
-                                      hbox, false );
+                                      hboxWidget, false );
   urlReq3->setMode( KFile::Directory );
   connect( urlReq3->extension(), SIGNAL( applyManually(QObject *,QString, QString) ),
            this, SLOT( applyTempDir(QObject *,QString, QString) ) );
-  generalGrid->addMultiCellWidget( hbox, 13, 13, 0, 1 );
+  hbox->addWidget( urlReq3 );
+  generalGrid->addWidget( hboxWidget, 13, 0, 1, 2 );
 
   QLabel *label4 = new QLabel( i18n( "Note: you must have full permissions for the temporary directory!" ),
-                               generalGrp, "NoteLabel"  );
-  generalGrid->addMultiCellWidget( label4, 14, 14, 0, 1 );
+                               generalGrp  );
+  generalGrid->addWidget( label4, 14, 0, 1, 2 );
 
 
   kgGeneralLayout->addWidget( generalGrp, 0 ,0 );
@@ -175,10 +203,9 @@ QFrame *line2 = createLine( generalGrp, "line2" );
 void KgGeneral::applyTempDir(QObject *obj,QString cls, QString name)
 {
   KonfiguratorURLRequester *urlReq = (KonfiguratorURLRequester *)obj;
-  QString value = QDir(urlReq->url()).path();
+  QString value = QDir(urlReq->url().prettyUrl()).path();
 
-  krConfig->setGroup( cls );
-  krConfig->writeEntry( name, value );
+  KConfigGroup( krConfig, cls ).writeEntry( name, value );
 }
 
 void KgGeneral::slotFindTools()
@@ -192,11 +219,11 @@ void KgGeneral::slotAddExtension()
 {
   bool ok;
   QString atomExt =
-    KInputDialog::getText( i18n( "Add new atomic extension" ), i18n( "Extension: " ), QString::null, &ok );
+    KInputDialog::getText( i18n( "Add new atomic extension" ), i18n( "Extension: " ), QString(), &ok );
 
   if( ok )
   {
-    if( !atomExt.startsWith( "." ) || atomExt.find( '.', 1 ) == -1 )
+    if( !atomExt.startsWith( "." ) || atomExt.indexOf( '.', 1 ) == -1 )
       KMessageBox::error(krApp, i18n("Atomic extensions must start with '.'\n and must contain at least one more '.' character"), i18n("Error"));
     else
       listBox->addItem( atomExt );
@@ -205,9 +232,10 @@ void KgGeneral::slotAddExtension()
 
 void KgGeneral::slotRemoveExtension()
 {
-  QListBoxItem * item = listBox->selectedItem();
-  if( item )
-    listBox->removeItem( item->text() );
+  QList<QListWidgetItem *> list = listBox->selectedItems();
+
+  for( int i=0; i != list.count(); i++ )
+    listBox->removeItem( list[ i ]->text() );
 }
 
 #include "kggeneral.moc"
