@@ -33,29 +33,35 @@
 #include "../defaults.h"
 #include "../Dialogs/krdialogs.h"
 #include <qtabwidget.h>
+#include <QFrame>
+#include <QGridLayout>
+#include <QLabel>
+#include <QVBoxLayout>
 #include <klocale.h>
-#include <qwhatsthis.h>
 #include <qvalidator.h>
-#include <qlistview.h>
 #include <kmessagebox.h>
 #include <kfiledialog.h>
 #include <kglobal.h>
 #include <kstandarddirs.h>
+#include "../GUI/krtreewidget.h"
 #include "../Panel/krselectionmode.h"
 #include "../Panel/listpanel.h"
+#include "../Panel/krview.h"
+#include "../Panel/krviewfactory.h"
 
 #define PAGE_OPERATION     0
 #define PAGE_PANEL         1
 #define PAGE_PANELTOOLBAR  2
 #define PAGE_MOUSE  3
 
-KgLookFeel::KgLookFeel( bool first, QWidget* parent,  const char* name ) :
-      KonfiguratorPage( first, parent, name )
+KgLookFeel::KgLookFeel( bool first, QWidget* parent ) :
+      KonfiguratorPage( first, parent )
 {
-  QGridLayout *kgLookAndFeelLayout = new QGridLayout( parent );
+  QWidget *innerWidget = this;
+  QGridLayout *kgLookAndFeelLayout = new QGridLayout( innerWidget );
   kgLookAndFeelLayout->setSpacing( 6 );
 
-  tabWidget = new QTabWidget( parent, "tabWidget" );
+  tabWidget = new QTabWidget( innerWidget );
 
   setupOperationTab();
   setupPanelTab();
@@ -69,16 +75,20 @@ KgLookFeel::KgLookFeel( bool first, QWidget* parent,  const char* name ) :
 //  ---------------------------- OPERATION TAB -------------------------------------
 // ---------------------------------------------------------------------------------------
 void KgLookFeel::setupOperationTab() {
-  QWidget *tab = new QWidget( tabWidget, "tab_operation" );
-  tabWidget->insertTab( tab, i18n( "Operation" ) );
+  QScrollArea *scrollArea = new QScrollArea( tabWidget );
+  QWidget *tab = new QWidget( scrollArea );
+  scrollArea->setFrameStyle( QFrame::NoFrame );
+  scrollArea->setWidget( tab );
+  scrollArea->setWidgetResizable( true );
+  tabWidget->addTab( scrollArea, i18n( "Operation" ) );
 
   QGridLayout *lookAndFeelLayout = new QGridLayout( tab );
   lookAndFeelLayout->setSpacing( 6 );
-  lookAndFeelLayout->setMargin( 11 );
+  lookAndFeelLayout->setContentsMargins( 11, 11, 11, 11 );
 
   // -------------- General -----------------
-  QGroupBox *lookFeelGrp = createFrame( i18n( "Look && Feel" ), tab, "kgLookAndFeelGrp" );
-  QGridLayout *lookFeelGrid = createGridLayout( lookFeelGrp->layout() );
+  QGroupBox *lookFeelGrp = createFrame( i18n( "Look && Feel" ), tab );
+  QGridLayout *lookFeelGrid = createGridLayout( lookFeelGrp );
 
   KONFIGURATOR_CHECKBOX_PARAM settings[] =
     { //   cfg_class  cfg_name                default             text                              restart tooltip
@@ -90,14 +100,14 @@ void KgLookFeel::setupOperationTab() {
      {"Look&Feel","Fullscreen Terminal Emulator", false, i18n( "Fullscreen terminal (mc-style)"  ), false,  i18n( "Terminal is shown instead of the Krusader window (full screen).") },
     };
 
-  cbs = createCheckBoxGroup( 2, 0, settings, 6 /*count*/, lookFeelGrp, 0, PAGE_OPERATION );
+  cbs = createCheckBoxGroup( 2, 0, settings, 6 /*count*/, lookFeelGrp, PAGE_OPERATION );
   lookFeelGrid->addWidget( cbs, 0, 0 );
 
   lookAndFeelLayout->addWidget( lookFeelGrp, 0, 0 );
 
   // -------------- Quicksearch -----------------
-  QGroupBox *quicksearchGroup = createFrame( i18n( "Quicksearch" ), tab, "kgQuicksearchGrp" );
-  QGridLayout *quicksearchGrid = createGridLayout( quicksearchGroup->layout() );
+  QGroupBox *quicksearchGroup = createFrame( i18n( "Quicksearch" ), tab );
+  QGridLayout *quicksearchGrid = createGridLayout( quicksearchGroup );
 
   KONFIGURATOR_CHECKBOX_PARAM quicksearch[] =
    { //   cfg_class  cfg_name                default             text                              restart tooltip
@@ -105,7 +115,7 @@ void KgLookFeel::setupOperationTab() {
      {"Look&Feel","Case Sensitive Quicksearch",  _CaseSensitiveQuicksearch, i18n( "Case sensitive quicksearch" ), false,  i18n( "All files beginning with capital letters appear before files beginning with non-capital letters (UNIX default)." ) },
     };
 
-  quicksearchCheckboxes = createCheckBoxGroup( 2, 0, quicksearch, 2 /*count*/, quicksearchGroup, 0, PAGE_OPERATION );
+  quicksearchCheckboxes = createCheckBoxGroup( 2, 0, quicksearch, 2 /*count*/, quicksearchGroup, PAGE_OPERATION );
   quicksearchGrid->addWidget( quicksearchCheckboxes, 0, 0 );
   connect( quicksearchCheckboxes->find( "New Style Quicksearch" ), SIGNAL( stateChanged( int ) ), this, SLOT( slotDisable() ) );
   slotDisable();
@@ -117,65 +127,137 @@ void KgLookFeel::setupOperationTab() {
 //  ---------------------------- PANEL TAB -------------------------------------
 // ----------------------------------------------------------------------------------
 void KgLookFeel::setupPanelTab() {
-  QWidget* tab_panel = new QWidget( tabWidget, "tab_panel" );
-  tabWidget->insertTab( tab_panel, i18n( "Panel" ) );
+  QScrollArea *scrollArea = new QScrollArea( tabWidget );
+  QWidget *tab_panel = new QWidget( scrollArea );
+  scrollArea->setFrameStyle( QFrame::NoFrame );
+  scrollArea->setWidget( tab_panel );
+  scrollArea->setWidgetResizable( true );
+  tabWidget->addTab( scrollArea, i18n( "Panel" ) );
 
   QGridLayout *panelLayout = new QGridLayout( tab_panel );
   panelLayout->setSpacing( 6 );
-  panelLayout->setMargin( 11 );
-  QGroupBox *panelGrp = createFrame( i18n( "Panel settings" ), tab_panel, "kgPanelGrp" );
-  QGridLayout *panelGrid = createGridLayout( panelGrp->layout() );
+  panelLayout->setContentsMargins( 11, 11, 11, 11 );
+  QGroupBox *panelGrp = createFrame( i18n( "Panel settings" ), tab_panel );
+  QGridLayout *panelGrid = createGridLayout( panelGrp );
 
-  QHBox *hbox = new QHBox( panelGrp, "lookAndFeelHBox1" );
-  new QLabel( i18n( "Panel font:" ), hbox, "lookAndFeelLabel" );
-  createFontChooser( "Look&Feel", "Filelist Font", _FilelistFont, hbox, true, PAGE_PANEL );
-  createSpacer ( hbox );
-  panelGrid->addWidget( hbox, 0, 0 );
+  QWidget *hboxWidget = new QWidget( panelGrp );
+  QHBoxLayout * hbox = new QHBoxLayout( hboxWidget );
 
-  QHBox *hbox2 = new QHBox( panelGrp, "lookAndFeelHBox2" );
-  QLabel *lbl1 = new QLabel( i18n( "Filelist icon size:" ), hbox2, "lookAndFeelLabel2" );
-  lbl1->setMinimumWidth( 230 );
-  KONFIGURATOR_NAME_VALUE_PAIR iconSizes[] =
-    {{ i18n( "16" ),  "16" },
-     { i18n( "22" ),  "22" },
-     { i18n( "32" ),  "32" },
-     { i18n( "48" ),  "48" }};
-  KonfiguratorComboBox *iconCombo = createComboBox( "Look&Feel", "Filelist Icon Size", _FilelistIconSize, iconSizes, 4, hbox2, true, true, PAGE_PANEL );
-  iconCombo->lineEdit()->setValidator( new QRegExpValidator( QRegExp( "[1-9]\\d{0,1}" ), iconCombo ) );
-  createSpacer ( hbox2 );
-  panelGrid->addWidget( hbox2, 1, 0 );
-
-  panelGrid->addWidget( createLine( panelGrp, "lookSep3" ), 2, 0 );
-
-  KONFIGURATOR_CHECKBOX_PARAM panelSettings[] =
-  //   cfg_class  cfg_name                default text                                  restart tooltip
-    {
-	 {"Look&Feel","With Icons",           _WithIcons,   i18n( "Use icons in the filenames" ), true ,  i18n( "Show the icons for filenames and folders." ) },
-	 {"Look&Feel","Human Readable Size",  _HumanReadableSize, i18n( "Use human-readable file size" ), true ,  i18n( "File sizes are displayed in B, KB, MB and GB, not just in bytes." ) },
-	 {"Look&Feel","Show Hidden",          _ShowHidden,        i18n( "Show hidden files" ),      false,  i18n( "Display files beginning with a dot." ) },
-	 {"Look&Feel","Case Sensative Sort",  _CaseSensativeSort, i18n( "Case sensitive sorting" ), true ,  i18n( "All files beginning with capital letters appear before files beginning with non-capital letters (UNIX default)." ) },
-	 {"Look&Feel","Always sort dirs by name",  false, i18n( "Always sort dirs by name"  ), true,  i18n( "Directories are sorted by name, regardless of the sort column.") },
-	 {"Look&Feel","Numeric permissions",  _NumericPermissions, i18n( "Numeric Permissions"  ), true,  i18n( "Show octal numbers (0755) instead of the standard permissions (rwxr-xr-x) in the permission column.") },
-    };
-
-  KonfiguratorCheckBoxGroup *panelSett = createCheckBoxGroup( 2, 0, panelSettings, 6 /*count*/, panelGrp, 0, PAGE_PANEL );
-  
-  panelGrid->addWidget( panelSett, 3, 0 );
-  
 // ----------------------------------------------------------------------------------
 //  ---------------------------- DEFAULT PANEL TYPE -------------------------------------
 // ----------------------------------------------------------------------------------
   
-  panelGrid->addWidget( createLine( panelGrp, "lookSep4" ), 4, 0 );
+  QWidget *hboxWidget3 = new QWidget( panelGrp );
+  QHBoxLayout * hbox3 = new QHBoxLayout( hboxWidget3 );
+
+  QLabel *lbl3 = new QLabel( i18n( "Default panel type:" ), hboxWidget );
+  hbox3->addWidget( lbl3 );
+
+  QList<KrViewInstance *> views = KrViewFactory::registeredViews();
+  KONFIGURATOR_NAME_VALUE_PAIR panelTypes[ views.count() ];
+
+  QString defType = "0";
+
+  for( int i=0; i != views.count(); i++ ) {
+    KrViewInstance * inst = views[ i ];
+    panelTypes[ i ].text = i18n( inst->description().toUtf8() );
+    panelTypes[ i ].text.replace( "&", "" );
+    panelTypes[ i ].value = QString( "%1" ).arg( inst->id() );
+    if( inst->id() == KrViewFactory::defaultViewId() )
+      defType = QString( "%1" ).arg( inst->id() );
+  }
+
+  KonfiguratorComboBox * cmb3 = createComboBox( "Look&Feel", "Default Panel Type", defType, panelTypes, views.count(), hboxWidget3, false, false, PAGE_PANEL );
+  hbox3->addWidget( cmb3 );
+  QWidget * spcr3 = createSpacer ( hboxWidget3 );
+  hbox3->addWidget( spcr3 );
+
+  panelGrid->addWidget( hboxWidget3, 0, 0 );
+
+  QLabel *lbl = new QLabel( i18n( "Panel font:" ), hboxWidget );
+  hbox->addWidget( lbl );
+
+  KonfiguratorFontChooser * chsr = createFontChooser( "Look&Feel", "Filelist Font", _FilelistFont, hboxWidget, true, PAGE_PANEL );
+  hbox->addWidget( chsr );
+
+  QWidget *spcr = createSpacer ( hboxWidget );
+  hbox->addWidget( spcr );
+
+  panelGrid->addWidget( hboxWidget, 1, 0 );
+
+  QWidget *hboxWidget2 = new QWidget( panelGrp );
+  QHBoxLayout * hbox2 = new QHBoxLayout( hboxWidget2 );
+
+  QLabel *lbl1 = new QLabel( i18n( "Filelist icon size:" ), hboxWidget2 );
+  lbl1->setMinimumWidth( 230 );
+  hbox2->addWidget( lbl1 );
+
+  KONFIGURATOR_NAME_VALUE_PAIR iconSizes[] =
+    {{ i18n( "12" ),  "12" },
+     { i18n( "16" ),  "16" },
+     { i18n( "22" ),  "22" },
+     { i18n( "32" ),  "32" },
+     { i18n( "48" ),  "48" }};
+  KonfiguratorComboBox *iconCombo = createComboBox( "Look&Feel", "Filelist Icon Size", _FilelistIconSize, iconSizes, 5, hboxWidget2, true, true, PAGE_PANEL );
+  iconCombo->lineEdit()->setValidator( new QRegExpValidator( QRegExp( "[1-9]\\d{0,1}" ), iconCombo ) );
+  hbox2->addWidget( iconCombo );
+
+  QWidget * spcr2 = createSpacer ( hboxWidget2 );
+  hbox2->addWidget( spcr2 );
+
+  panelGrid->addWidget( hboxWidget2, 2, 0 );
+
+  panelGrid->addWidget( createLine( panelGrp ), 3, 0 );
+
+  KONFIGURATOR_CHECKBOX_PARAM panelSettings[] =
+  //   cfg_class  cfg_name                default text                                  restart tooltip
+    {
+	 {"Look&Feel","With Icons",                     _WithIcons,              i18n( "Use icons in the filenames" ), true ,  i18n( "Show the icons for filenames and folders." ) },
+	 {"Look&Feel","Load User Defined Folder Icons", _UserDefinedFolderIcons, i18n( "Load the user defined folder icons" ), true ,  i18n( "Load the user defined folder icons (can cause decrease in performance)." ) },
+	 {"Look&Feel","Human Readable Size",            _HumanReadableSize,      i18n( "Use human-readable file size" ), true ,  i18n( "File sizes are displayed in B, KB, MB and GB, not just in bytes." ) },
+	 {"Look&Feel","Show Hidden",                    _ShowHidden,             i18n( "Show hidden files" ),      false,  i18n( "Display files beginning with a dot." ) },
+	 {"Look&Feel","Numeric permissions",            _NumericPermissions,     i18n( "Numeric Permissions"  ), true,  i18n( "Show octal numbers (0755) instead of the standard permissions (rwxr-xr-x) in the permission column.") },
+    };
+
+  KonfiguratorCheckBoxGroup *panelSett = createCheckBoxGroup( 2, 0, panelSettings, 5 /*count*/, panelGrp, PAGE_PANEL );
   
-  QHBox *hbox3 = new QHBox( panelGrp, "lookAndFeelHBox3" );
-  QLabel *lbl2 = new QLabel( i18n( "Default panel type:" ), hbox3, "lookAndFeelLabel3" );
-  KONFIGURATOR_NAME_VALUE_PAIR panelTypes[] =
-    {{ i18n( "Detailed" ),  "Detailed" },
-     { i18n( "Brief" ),     "Brief" }};
-  KonfiguratorComboBox *panelCombo = createComboBox( "Look&Feel", "Default Panel Type", _DefaultPanelType, panelTypes, 2, hbox3, false, false, PAGE_PANEL );
-  createSpacer ( hbox3 );
-  panelGrid->addWidget( hbox3, 5, 0 );  
+  panelGrid->addWidget( panelSett, 4, 0, 1, 2 );
+  
+
+// ----------------------------------------------------------------------------------
+//  ---------------------------- SORT METHOD ----------------------------------------
+// ----------------------------------------------------------------------------------
+  panelGrid->addWidget( createLine( panelGrp ), 5, 0 );
+  
+  QWidget *hboxWidget4 = new QWidget( panelGrp );
+  QHBoxLayout *hbox4 = new QHBoxLayout( hboxWidget4 );
+  QLabel *lbl4 = new QLabel( i18n( "Sort method:" ), hboxWidget4 );
+  hbox4->addWidget( lbl4 );
+
+  KONFIGURATOR_NAME_VALUE_PAIR sortMethods[] =
+    {{ i18n( "Alphabetical" ),                QString::number( KrViewProperties::Alphabetical ) },
+     { i18n( "Alphabetical and numbers" ),    QString::number( KrViewProperties::AlphabeticalNumbers ) },
+     { i18n( "Character code" ),              QString::number( KrViewProperties::CharacterCode ) },
+     { i18n( "Character code and numbers" ),  QString::number( KrViewProperties::CharacterCodeNumbers ) },
+     { i18n( "Krusader" ),                    QString::number( KrViewProperties::Krusader ) } };
+  KonfiguratorComboBox *sortMethodCombo = createComboBox( "Look&Feel", "Sort method",
+     QString::number( _DefaultSortMethod ), sortMethods, 5, hboxWidget4, true, false, PAGE_PANEL );
+  hbox4->addWidget( sortMethodCombo);
+  QWidget * spcr4 = createSpacer ( hboxWidget4 );
+  hbox4->addWidget( spcr4 );
+  panelGrid->addWidget( hboxWidget4, 6, 0 );
+
+  KONFIGURATOR_CHECKBOX_PARAM sortSettings[] =
+  //   cfg_class  cfg_name                default text                                  restart tooltip
+    {
+	 {"Look&Feel","Case Sensative Sort",            _CaseSensativeSort,      i18n( "Case sensitive sorting" ), true ,  i18n( "All files beginning with capital letters appear before files beginning with non-capital letters (UNIX default)." ) },
+	 {"Look&Feel","Always sort dirs by name",       false,                   i18n( "Always sort dirs by name"  ), true,  i18n( "Directories are sorted by name, regardless of the sort column.") },
+    };
+
+  KonfiguratorCheckBoxGroup *sortSett = createCheckBoxGroup( 2, 0, sortSettings,
+     2 /*count*/, panelGrp, PAGE_PANEL );
+  
+  panelGrid->addWidget( sortSett, 7, 0, 1, 2 );
 
   panelLayout->addWidget( panelGrp, 0, 0 );
 }
@@ -184,28 +266,31 @@ void KgLookFeel::setupPanelTab() {
 //  -------------------------- Panel Toolbar TAB ----------------------------------
 // -----------------------------------------------------------------------------------
 void KgLookFeel::setupPanelToolbarTab() {
-  QWidget     *tab_4 = new QWidget( tabWidget, "tab_4" );
-  tabWidget->insertTab( tab_4, i18n( "Panel Toolbar" ) );
+  QScrollArea *scrollArea = new QScrollArea( tabWidget );
+  QWidget *tab_4 = new QWidget( scrollArea );
+  scrollArea->setFrameStyle( QFrame::NoFrame );
+  scrollArea->setWidget( tab_4 );
+  scrollArea->setWidgetResizable( true );
+  tabWidget->addTab( scrollArea, i18n( "Panel Toolbar" ) );
 
   QBoxLayout * panelToolbarVLayout = new QVBoxLayout( tab_4 );
   panelToolbarVLayout->setSpacing( 6 );
-  panelToolbarVLayout->setMargin( 11 );
+  panelToolbarVLayout->setContentsMargins( 11, 11, 11, 11 );
 
   KONFIGURATOR_CHECKBOX_PARAM panelToolbarActiveCheckbox[] = 
   //   cfg_class    cfg_name                default        text                          restart tooltip
     {{"Look&Feel", "Panel Toolbar visible", _PanelToolBar, i18n( "Show Panel Toolbar" ), true,   i18n( "The panel toolbar will be visible." ) }
   };
 
-  panelToolbarActive = createCheckBoxGroup( 1, 0, panelToolbarActiveCheckbox, 1, tab_4, "panelToolbarActive", PAGE_PANELTOOLBAR);
+  panelToolbarActive = createCheckBoxGroup( 1, 0, panelToolbarActiveCheckbox, 1, tab_4, PAGE_PANELTOOLBAR);
   connect( panelToolbarActive->find( "Panel Toolbar visible" ), SIGNAL( stateChanged( int ) ), this, SLOT( slotEnablePanelToolbar() ) );
     
-  QGroupBox * panelToolbarGrp = createFrame( i18n( "Visible Panel Toolbar buttons" ), tab_4, "panelToolbarGrp");
-  QGridLayout * panelToolbarGrid = createGridLayout( panelToolbarGrp->layout() );
+  QGroupBox * panelToolbarGrp = createFrame( i18n( "Visible Panel Toolbar buttons" ), tab_4 );
+  QGridLayout * panelToolbarGrid = createGridLayout( panelToolbarGrp );
 
   KONFIGURATOR_CHECKBOX_PARAM panelToolbarCheckboxes[] = 
     {
   //   cfg_class    cfg_name                default             text                       restart tooltip
-     {"Look&Feel",  "Clear Location Bar Visible",  _ClearLocation,      i18n( "Clear location bar button" ),    true ,  i18n( "Clears the location bar" ) },
      {"Look&Feel",  "Open Button Visible",  _Open,      i18n( "Open button" ),     true ,  i18n( "Opens the directory browser." ) },
      {"Look&Feel",  "Equal Button Visible", _cdOther,   i18n( "Equal button (=)" ),true ,  i18n( "Changes the panel directory to the other panel directory." ) },
      {"Look&Feel",  "Up Button Visible",    _cdUp,      i18n( "Up button (..)" ),  true ,  i18n( "Changes the panel directory to the parent directory." ) },
@@ -215,8 +300,9 @@ void KgLookFeel::setupPanelToolbarTab() {
     };
   
   
-  pnlcbs = createCheckBoxGroup(1, 0, panelToolbarCheckboxes, 7,
-                                       panelToolbarGrp, "panelToolbarChecks", PAGE_PANELTOOLBAR);
+  pnlcbs = createCheckBoxGroup(1, 0, panelToolbarCheckboxes,
+                                     sizeof(panelToolbarCheckboxes)/sizeof(*panelToolbarCheckboxes),
+                                       panelToolbarGrp, PAGE_PANELTOOLBAR);
   
   panelToolbarVLayout->addWidget( panelToolbarActive, 0, 0 );
   panelToolbarGrid->addWidget( pnlcbs, 0, 0 );
@@ -230,17 +316,21 @@ void KgLookFeel::setupPanelToolbarTab() {
 //  -------------------------- Mouse TAB ----------------------------------
 // ---------------------------------------------------------------------------
 void KgLookFeel::setupMouseModeTab() {
-  QWidget *tab_mouse = new QWidget( tabWidget, "tab_mouse" );
-  tabWidget->insertTab( tab_mouse, i18n( "Selection Mode" ) );
+  QScrollArea *scrollArea = new QScrollArea( tabWidget );
+  QWidget *tab_mouse = new QWidget( scrollArea );
+  scrollArea->setFrameStyle( QFrame::NoFrame );
+  scrollArea->setWidget( tab_mouse );
+  scrollArea->setWidgetResizable( true );
+  tabWidget->addTab( scrollArea, i18n( "Selection Mode" ) );
   QGridLayout *mouseLayout = new QGridLayout( tab_mouse );
   mouseLayout->setSpacing( 6 );
-  mouseLayout->setMargin( 11 );
+  mouseLayout->setContentsMargins( 11, 11, 11, 11 );
 
   // -------------- General -----------------
-  QGroupBox *mouseGeneralGroup = createFrame( i18n( "General" ), tab_mouse, "mouseGeneralGroup" );
-  QGridLayout *mouseGeneralGrid = createGridLayout( mouseGeneralGroup->layout() );
+  QGroupBox *mouseGeneralGroup = createFrame( i18n( "General" ), tab_mouse );
+  QGridLayout *mouseGeneralGrid = createGridLayout( mouseGeneralGroup );
   mouseGeneralGrid->setSpacing( 0 );
-  mouseGeneralGrid->setMargin( 5 );
+  mouseGeneralGrid->setContentsMargins( 5, 5, 5, 5 );
 
   KONFIGURATOR_NAME_VALUE_TIP mouseSelection[] =
     {
@@ -248,20 +338,23 @@ void KgLookFeel::setupMouseModeTab() {
     	{ i18n( "Krusader Mode" ), "0", i18n( "Both keys allow selecting files. To select more than one file, hold the Ctrl key and click the left mouse button. Right-click menu is invoked using a short click on the right mouse button." ) },
      	{ i18n( "Konqueror Mode" ), "1", i18n( "Pressing the left mouse button selects files - you can click and select multiple files. Right-click menu is invoked using a short click on the right mouse button." ) },
      	{ i18n( "Total-Commander Mode" ), "2", i18n( "The left mouse button does not select, but sets the current file without affecting the current selection. The right mouse button selects multiple files and the right-click menu is invoked by pressing and holding the right mouse button." ) },
+    	{ i18n( "Ergonomic Mode" ), "4", i18n( "The left mouse button does not select, but sets the current file without affecting the current selection. The right mouse button invokes the context-menu. You can select with Ctrl key and the left button." ) },
      	{ i18n( "Custom Selection Mode" ), "3", i18n( "Design your own selection mode!" ) }
      };
-  mouseRadio = createRadioButtonGroup( "Look&Feel", "Mouse Selection", "0", 2, 2, mouseSelection, 4, mouseGeneralGroup, "myLook&FeelRadio", true, PAGE_MOUSE );
-  mouseRadio->layout()->setMargin( 0 );
+  mouseRadio = createRadioButtonGroup( "Look&Feel", "Mouse Selection", "0", 1, 5, mouseSelection, 5, mouseGeneralGroup, true, PAGE_MOUSE );
+  mouseRadio->layout()->setContentsMargins( 0, 0, 0, 0 );
   mouseGeneralGrid->addWidget( mouseRadio, 0, 0 );
-  connect( mouseRadio, SIGNAL( clicked(int) ), SLOT( slotSelectionModeChanged() ) );
 
-  mouseLayout->addMultiCellWidget( mouseGeneralGroup, 0,0, 0,1 );
+  for( int i = 0; i != mouseRadio->count(); i++ )
+    connect( mouseRadio->find( i ), SIGNAL( clicked() ), SLOT( slotSelectionModeChanged() ) );
+
+  mouseLayout->addWidget( mouseGeneralGroup, 0, 0 );
 
   // -------------- Details -----------------
-  QGroupBox *mouseDetailGroup = createFrame( i18n( "Details" ), tab_mouse, "mouseDetailGroup" );
-  QGridLayout *mouseDetailGrid = createGridLayout( mouseDetailGroup->layout() );
+  QGroupBox *mouseDetailGroup = createFrame( i18n( "Details" ), tab_mouse );
+  QGridLayout *mouseDetailGrid = createGridLayout( mouseDetailGroup );
   mouseDetailGrid->setSpacing( 0 );
-  mouseDetailGrid->setMargin( 5 );
+  mouseDetailGrid->setContentsMargins( 5, 5, 5, 5 );
 
    KONFIGURATOR_NAME_VALUE_TIP singleOrDoubleClick[] =
     {
@@ -269,8 +362,8 @@ void KgLookFeel::setupMouseModeTab() {
     	{ i18n( "Double-click selects (classic)" ), "0", i18n( "A single click on a file will select and focus, a double click opens the file or steps into the directory." ) },
     	{ i18n( "Obey KDE's global selection policy" ), "1", i18n( "<p>Use KDE's global setting:</p><p><i>KDE Control Center -> Peripherals -> Mouse</i></p>" ) }
     };
-  KonfiguratorRadioButtons *clickRadio = createRadioButtonGroup( "Look&Feel", "Single Click Selects", "0", 1, 0, singleOrDoubleClick, 2, mouseDetailGroup, "myLook&FeelRadio0", true, PAGE_MOUSE );
-  clickRadio->layout()->setMargin( 0 );
+  KonfiguratorRadioButtons *clickRadio = createRadioButtonGroup( "Look&Feel", "Single Click Selects", "0", 1, 0, singleOrDoubleClick, 2, mouseDetailGroup, true, PAGE_MOUSE );
+  clickRadio->layout()->setContentsMargins( 0, 0, 0, 0 );
   mouseDetailGrid->addWidget( clickRadio, 0, 0 );
   
   KONFIGURATOR_CHECKBOX_PARAM mouseCheckboxesParam[] = 
@@ -314,23 +407,26 @@ void KgLookFeel::setupMouseModeTab() {
     };
   
   
-  mouseCheckboxes = createCheckBoxGroup(1, 0, mouseCheckboxesParam, 11 /*count*/, mouseDetailGroup, "customMouseModeChecks", PAGE_MOUSE);
+  mouseCheckboxes = createCheckBoxGroup(1, 0, mouseCheckboxesParam, 11 /*count*/, mouseDetailGroup, PAGE_MOUSE);
   mouseDetailGrid->addWidget( mouseCheckboxes, 1, 0 );
 
-  mouseLayout->addWidget( mouseDetailGroup, 1,0 );
+  for ( int i = 0; i < mouseCheckboxes->count(); i++ )
+     connect( mouseCheckboxes->find( i ), SIGNAL( clicked() ), SLOT( slotMouseCheckBoxChanged() ) );
+
+  mouseLayout->addWidget( mouseDetailGroup, 0, 1, 2, 1 );
 
   // Disable the details-button if not in custom-mode
   slotSelectionModeChanged();
 
   // -------------- Preview -----------------
-  QGroupBox *mousePreviewGroup = createFrame( i18n( "Preview" ), tab_mouse, "mousePreviewGroup" );
-  QGridLayout *mousePreviewGrid = createGridLayout( mousePreviewGroup->layout() );
+  QGroupBox *mousePreviewGroup = createFrame( i18n( "Preview" ), tab_mouse );
+  QGridLayout *mousePreviewGrid = createGridLayout( mousePreviewGroup );
   // TODO preview
-  mousePreview = new QListView( mousePreviewGroup, "mousePreview" );
+  mousePreview = new KrTreeWidget( mousePreviewGroup );
   mousePreviewGrid->addWidget( mousePreview, 0 ,0 );
   mousePreviewGroup->setEnabled(false); // TODO re-enable once the preview is implemented
   // ------------------------------------------
-  mouseLayout->addWidget( mousePreviewGroup, 1,1 );
+  mouseLayout->addWidget( mousePreviewGroup, 1, 0  );
 }
 
 void KgLookFeel::slotDisable()
@@ -351,22 +447,31 @@ void KgLookFeel::slotEnablePanelToolbar()
 }
 
 void KgLookFeel::slotSelectionModeChanged() {
-  bool enable = mouseRadio->find( i18n("Custom Selection Mode") )->isChecked();
-  mouseCheckboxes->find( "QT Selection" )->setEnabled( enable );
-  mouseCheckboxes->find( "Left Selects" )->setEnabled( enable );
-  mouseCheckboxes->find( "Left Preserves" )->setEnabled( enable );
-  mouseCheckboxes->find( "ShiftCtrl Left Selects" )->setEnabled( enable );
-  mouseCheckboxes->find( "Right Selects" )->setEnabled( enable );
-  mouseCheckboxes->find( "Right Preserves" )->setEnabled( enable );
-  mouseCheckboxes->find( "ShiftCtrl Right Selects" )->setEnabled( enable );
-  mouseCheckboxes->find( "Space Moves Down" )->setEnabled( enable );
-  mouseCheckboxes->find( "Space Calc Space" )->setEnabled( enable );
-  mouseCheckboxes->find( "Insert Moves Down" )->setEnabled( enable );
-  mouseCheckboxes->find( "Immediate Context Menu" )->setEnabled( enable );
+  KrSelectionMode *selectionMode =
+      KrSelectionMode::getSelectionHandlerForMode( mouseRadio->selectedValue() );
+  if ( selectionMode == NULL ) //User mode
+    return;
+  selectionMode->init();
+  mouseCheckboxes->find( "QT Selection" )->setChecked( selectionMode->useQTSelection() );
+  mouseCheckboxes->find( "Left Selects" )->setChecked( selectionMode->leftButtonSelects() );
+  mouseCheckboxes->find( "Left Preserves" )->setChecked( selectionMode->leftButtonPreservesSelection() );
+  mouseCheckboxes->find( "ShiftCtrl Left Selects" )->setChecked( selectionMode->shiftCtrlLeftButtonSelects() );
+  mouseCheckboxes->find( "Right Selects" )->setChecked( selectionMode->rightButtonSelects() );
+  mouseCheckboxes->find( "Right Preserves" )->setChecked( selectionMode->rightButtonPreservesSelection() );
+  mouseCheckboxes->find( "ShiftCtrl Right Selects" )->setChecked( selectionMode->shiftCtrlRightButtonSelects() );
+  mouseCheckboxes->find( "Space Moves Down" )->setChecked( selectionMode->spaceMovesDown() );
+  mouseCheckboxes->find( "Space Calc Space" )->setChecked( selectionMode->spaceCalculatesDiskSpace() );
+  mouseCheckboxes->find( "Insert Moves Down" )->setChecked( selectionMode->insertMovesDown() );
+  mouseCheckboxes->find( "Immediate Context Menu" )->setChecked( selectionMode->showContextMenu() == -1 );
+}
+
+void KgLookFeel::slotMouseCheckBoxChanged()
+{
+  mouseRadio->selectButton( "3" );  //custom selection mode
 }
 
 int KgLookFeel::activeSubPage() {
-	return tabWidget->currentPageIndex();
+	return tabWidget->currentIndex();
 }
 
 #include "kglookfeel.moc"
