@@ -34,29 +34,33 @@
 #include "../krusader.h"
 #include <klocale.h>
 #include <klineedit.h>
-#include <qwhatsthis.h>
+#include <QGridLayout>
+#include <QLabel>
 
-KgStartup::KgStartup( bool first, QWidget* parent,  const char* name ) :
-  KonfiguratorPage( first, parent, name ), profileCombo( 0 )
+KgStartup::KgStartup( bool first, QWidget* parent ) :
+  KonfiguratorPage( first, parent ), profileCombo( 0 )
 {
-  QGridLayout *kgStartupLayout = new QGridLayout( parent );
+  QWidget *innerWidget = new QFrame( this );
+  setWidget( innerWidget );
+  setWidgetResizable( true );
+  QGridLayout *kgStartupLayout = new QGridLayout( innerWidget );
   kgStartupLayout->setSpacing( 6 );
 
   //  --------------------------- PANELS GROUPBOX ----------------------------------
 
-  QGroupBox *panelsGrp = createFrame( i18n( "General" ), parent, "panelsGrp" );
-  QGridLayout *panelsGrid = createGridLayout( panelsGrp->layout() );
+  QGroupBox *panelsGrp = createFrame( i18n( "General" ), innerWidget );
+  QGridLayout *panelsGrid = createGridLayout( panelsGrp );
 
   QString s = "<p><img src='toolbar|kr_profile'></p>" + i18n( "Defines the panel profile used at startup. A panel profile contains:<ul><li>all the tabs paths</li><li>the current tab</li><li>the active panel</li></ul><b>&lt;Last session&gt;</b> is a special panel profile which is saved automatically when Krusader is closed.");
-  QLabel *label = addLabel( panelsGrid, 0, 0, i18n( "Startup profile:" ), panelsGrp, "Startup session" );
-  QWhatsThis::add( label, s );
-  QWhatsThis::add( panelsGrp, s );
+  QLabel *label = addLabel( panelsGrid, 0, 0, i18n( "Startup profile:" ), panelsGrp );
+  label->setWhatsThis( s );
+  panelsGrp->setWhatsThis( s );
 
   QStringList profileList = ProfileManager::availableProfiles( "Panel" );
   profileList.push_front( "<" + i18n( "Last session" ) + ">" );
 
   KONFIGURATOR_NAME_VALUE_PAIR comboItems[ profileList.count() ];
-  for(unsigned int i=0; i != profileList.count(); i++ )
+  for(int i=0; i != profileList.count(); i++ )
     comboItems[ i ].text = comboItems[ i ].value = profileList [ i ];    
   comboItems[ 0 ].value = "";
 
@@ -65,7 +69,7 @@ KgStartup::KgStartup( bool first, QWidget* parent,  const char* name ) :
   panelsGrid->addWidget( profileCombo, 0, 1 );
 
   //------------------------------------------------
-  panelsGrid->addMultiCellWidget( createLine( panelsGrp, "lookSep3" ), 1, 1, 0, 1 );
+  panelsGrid->addWidget( createLine( panelsGrp ), 1, 0, 1, 2 );
 
   KONFIGURATOR_CHECKBOX_PARAM settings[] =
     { //   cfg_class  cfg_name                default             text                              restart tooltip
@@ -74,14 +78,14 @@ KgStartup::KgStartup( bool first, QWidget* parent,  const char* name ) :
     };
 
   KonfiguratorCheckBoxGroup* cbs = createCheckBoxGroup( 2, 0, settings, 2 /* settings count */, panelsGrp );
-  panelsGrid->addMultiCellWidget( cbs, 2, 2, 0, 1 );
+  panelsGrid->addWidget( cbs, 2, 0, 1, 2 );
 
   kgStartupLayout->addWidget( panelsGrp, 0, 0 );
 
   //  ------------------------ USERINTERFACE GROUPBOX ------------------------------
 
-  QGroupBox *uiGrp = createFrame( i18n( "User Interface" ), parent, "uiGrp" );
-  QGridLayout *uiGrid = createGridLayout( uiGrp->layout() );
+  QGroupBox *uiGrp = createFrame( i18n( "User Interface" ), innerWidget );
+  QGridLayout *uiGrid = createGridLayout( uiGrp );
 
   KONFIGURATOR_CHECKBOX_PARAM uiCheckBoxes[] =
     { //   cfg_class  cfg_name                default               text                                   restart ToolTip
