@@ -31,9 +31,12 @@
 #include "konfiguratoritems.h"
 #include "../krusader.h"
 #include <klocale.h>
+#include <klineedit.h>
 #include <qpainter.h>
 #include <qpen.h>
 #include <qcolordialog.h>
+#include <QPixmap>
+#include <QLabel>
 #include <kiconloader.h>
 
 KonfiguratorExtension::KonfiguratorExtension( QObject *obj, QString cfgClass, QString cfgName, bool rst, int pg) :
@@ -92,7 +95,7 @@ bool KonfiguratorExtension::isChanged()
 ///////////////////////////////
 
 KonfiguratorCheckBox::KonfiguratorCheckBox( QString cls, QString name, bool dflt, QString text,
-    QWidget *parent, const char *widgetName, bool rst, int pg ) : QCheckBox( text, parent, widgetName ),
+    QWidget *parent, bool rst, int pg ) : QCheckBox( text, parent ),
     defaultValue( dflt )
 {
   ext = new KonfiguratorExtension( this, cls, name, rst, pg );
@@ -111,15 +114,14 @@ KonfiguratorCheckBox::~KonfiguratorCheckBox()
 
 void KonfiguratorCheckBox::loadInitialValue()
 {
-  krConfig->setGroup( ext->getCfgClass() );
-  setChecked( krConfig->readBoolEntry( ext->getCfgName(), defaultValue ) );
+  KConfigGroup group( krConfig, ext->getCfgClass() );
+  setChecked( group.readEntry( ext->getCfgName(), defaultValue ) );
   ext->setChanged( false );
 }
 
 void KonfiguratorCheckBox::slotApply(QObject *,QString cls, QString name)
 {
-  krConfig->setGroup( cls );
-  krConfig->writeEntry( name, isChecked() );
+  KConfigGroup( krConfig, cls ).writeEntry( name, isChecked() );
 }
 
 void KonfiguratorCheckBox::slotSetDefaults(QObject *)
@@ -132,7 +134,7 @@ void KonfiguratorCheckBox::slotSetDefaults(QObject *)
 ///////////////////////////////
 
 KonfiguratorSpinBox::KonfiguratorSpinBox( QString cls, QString name, int dflt, int min, int max,
-    QWidget *parent, const char *widgetName, bool rst, int pg ) : QSpinBox( parent, widgetName ),
+    QWidget *parent, bool rst, int pg ) : QSpinBox( parent ),
     defaultValue( dflt )
 {
   ext = new KonfiguratorExtension( this, cls, name, rst, pg );
@@ -142,8 +144,8 @@ KonfiguratorSpinBox::KonfiguratorSpinBox( QString cls, QString name, int dflt, i
 
   connect( this, SIGNAL( valueChanged(int) ), ext, SLOT( setChanged() ) );
 
-  setMinValue( min );
-  setMaxValue( max );
+  setMinimum( min );
+  setMaximum( max );
 
   loadInitialValue();
 }
@@ -155,15 +157,14 @@ KonfiguratorSpinBox::~KonfiguratorSpinBox()
 
 void KonfiguratorSpinBox::loadInitialValue()
 {
-  krConfig->setGroup( ext->getCfgClass() );
-  setValue( krConfig->readNumEntry( ext->getCfgName(), defaultValue ) );
+  KConfigGroup group( krConfig, ext->getCfgClass() );
+  setValue( group.readEntry( ext->getCfgName(), defaultValue ) );
   ext->setChanged( false );
 }
 
 void KonfiguratorSpinBox::slotApply(QObject *,QString cls, QString name)
 {
-  krConfig->setGroup( cls );
-  krConfig->writeEntry( name, value() );
+  KConfigGroup( krConfig, cls ).writeEntry( name, value() );
 }
 
 void KonfiguratorSpinBox::slotSetDefaults(QObject *)
@@ -182,18 +183,20 @@ void KonfiguratorCheckBoxGroup::add( KonfiguratorCheckBox *checkBox )
 
 KonfiguratorCheckBox * KonfiguratorCheckBoxGroup::find( int index )
 {
+  if( index < 0 || index >= checkBoxList.count() )
+    return 0;
   return checkBoxList.at( index );
 }
 
 KonfiguratorCheckBox * KonfiguratorCheckBoxGroup::find( QString name )
 {
-  KonfiguratorCheckBox *checkBox = checkBoxList.first();
-
-  while( checkBox )
+  QListIterator<KonfiguratorCheckBox *> it(checkBoxList);
+  while (it.hasNext())
   {
+    KonfiguratorCheckBox * checkBox = it.next();
+
     if( checkBox->extension()->getCfgName() == name )
       return checkBox;
-    checkBox = checkBoxList.next();
   }
 
   return 0;
@@ -204,8 +207,8 @@ KonfiguratorCheckBox * KonfiguratorCheckBoxGroup::find( QString name )
 ///////////////////////////////
 
 KonfiguratorRadioButtons::KonfiguratorRadioButtons( QString cls, QString name,
-    QString dflt, QWidget *parent, const char *widgetName, bool rst, int pg ) :
-    QButtonGroup( parent, widgetName ), defaultValue( dflt )
+    QString dflt, QWidget *parent, bool rst, int pg ) :
+    QWidget( parent ), defaultValue( dflt )
 {
   ext = new KonfiguratorExtension( this, cls, name, rst, pg );
   connect( ext, SIGNAL( applyAuto(QObject *,QString, QString) ), this, SLOT( slotApply(QObject *,QString, QString) ) );
@@ -224,17 +227,20 @@ void KonfiguratorRadioButtons::addRadioButton( QRadioButton *radioWidget, QStrin
   radioNames.push_back( name );
   radioValues.push_back( value );
 
-  connect( radioWidget, SIGNAL( stateChanged(int) ), ext, SLOT( setChanged() ) );
+  connect( radioWidget, SIGNAL( toggled( bool ) ), ext, SLOT( setChanged() ) );
 }
 
 QRadioButton * KonfiguratorRadioButtons::find( int index )
 {
+  if( index < 0 || index >= radioButtons.count() )
+    return 0;
+
   return radioButtons.at( index );
 }
 
 QRadioButton * KonfiguratorRadioButtons::find( QString name )
 {
-  int index = radioNames.findIndex( name );
+  int index = radioNames.indexOf( name );
   if( index == -1 )
     return 0;
 
@@ -244,50 +250,59 @@ QRadioButton * KonfiguratorRadioButtons::find( QString name )
 void KonfiguratorRadioButtons::selectButton( QString value )
 {
   int cnt = 0;
-  QRadioButton *btn  = radioButtons.first();
 
-  while( btn )
+  QListIterator<QRadioButton *> it(radioButtons);
+  while (it.hasNext())
   {
+    QRadioButton * btn = it.next();
+
     if( value == radioValues[ cnt ] )
     {
       btn->setChecked( true );
       return;
     }
 
-    btn = radioButtons.next();
     cnt++;
   }
 
-  if( radioButtons.first() )
+  if( !radioButtons.isEmpty() )
     radioButtons.first()->setChecked( true );
 }
 
 void KonfiguratorRadioButtons::loadInitialValue()
 {
-  krConfig->setGroup( ext->getCfgClass() );
-  QString initValue = krConfig->readEntry( ext->getCfgName(), defaultValue );
+  KConfigGroup group( krConfig, ext->getCfgClass() );
+  QString initValue = group.readEntry( ext->getCfgName(), defaultValue );
 
   selectButton( initValue );
   ext->setChanged( false );
 }
 
-void KonfiguratorRadioButtons::slotApply(QObject *,QString cls, QString name)
+QString KonfiguratorRadioButtons::selectedValue()
 {
-  QRadioButton *btn  = radioButtons.first();
   int cnt = 0;
 
-  while( btn )
+  QListIterator<QRadioButton *> it(radioButtons);
+  while (it.hasNext())
   {
+    QRadioButton * btn = it.next();
+
     if( btn->isChecked() )
     {
-      krConfig->setGroup( cls );
-      krConfig->writeEntry( name, radioValues[ cnt ] );
-      break;
+      return radioValues[ cnt ];
     }
 
-    btn = radioButtons.next();
     cnt++;
   }
+  return QString();
+}
+
+void KonfiguratorRadioButtons::slotApply(QObject *,QString cls, QString name)
+{
+  QString value = selectedValue();
+
+  if (!value.isEmpty())
+    KConfigGroup( krConfig, cls ).writeEntry( name, value );
 }
 
 void KonfiguratorRadioButtons::slotSetDefaults(QObject *)
@@ -299,7 +314,7 @@ void KonfiguratorRadioButtons::slotSetDefaults(QObject *)
 ///////////////////////////////
 
 KonfiguratorEditBox::KonfiguratorEditBox( QString cls, QString name, QString dflt,
-    QWidget *parent, const char *widgetName, bool rst, int pg ) : QLineEdit( parent, widgetName ),
+    QWidget *parent, bool rst, int pg ) : QLineEdit( parent ),
     defaultValue( dflt )
 {
   ext = new KonfiguratorExtension( this, cls, name, rst, pg );
@@ -319,15 +334,14 @@ KonfiguratorEditBox::~KonfiguratorEditBox()
 
 void KonfiguratorEditBox::loadInitialValue()
 {
-  krConfig->setGroup( ext->getCfgClass() );
-  setText( krConfig->readEntry( ext->getCfgName(), defaultValue ) );
+  KConfigGroup group( krConfig, ext->getCfgClass() );
+  setText( group.readEntry( ext->getCfgName(), defaultValue ) );
   ext->setChanged( false );
 }
 
 void KonfiguratorEditBox::slotApply(QObject *,QString cls, QString name)
 {
-  krConfig->setGroup( cls );
-  krConfig->writeEntry( name, text() );
+  KConfigGroup( krConfig, cls ).writeEntry( name, text() );
 }
 
 void KonfiguratorEditBox::slotSetDefaults(QObject *)
@@ -341,7 +355,7 @@ void KonfiguratorEditBox::slotSetDefaults(QObject *)
 ///////////////////////////////
 
 KonfiguratorURLRequester::KonfiguratorURLRequester( QString cls, QString name, QString dflt,
-    QWidget *parent, const char *widgetName, bool rst, int pg ) : KURLRequester( parent, widgetName ),
+    QWidget *parent, bool rst, int pg ) : KUrlRequester( parent ),
     defaultValue( dflt )
 {
   ext = new KonfiguratorExtension( this, cls, name, rst, pg );
@@ -351,7 +365,7 @@ KonfiguratorURLRequester::KonfiguratorURLRequester( QString cls, QString name, Q
 
   connect( this, SIGNAL( textChanged(const QString &) ), ext, SLOT( setChanged() ) );
 
-  button()->setIconSet( SmallIcon( "fileopen" ) );
+  button()->setIcon( KIcon( SmallIcon( "document-open" ) ) );
   loadInitialValue();
 }
 
@@ -362,30 +376,31 @@ KonfiguratorURLRequester::~KonfiguratorURLRequester()
 
 void KonfiguratorURLRequester::loadInitialValue()
 {
-  krConfig->setGroup( ext->getCfgClass() );
-  setURL( krConfig->readEntry( ext->getCfgName(), defaultValue ) );
+  KConfigGroup group( krConfig, ext->getCfgClass() );
+  lineEdit()->setText( group.readEntry( ext->getCfgName(), defaultValue ) );
   ext->setChanged( false );
 }
 
 void KonfiguratorURLRequester::slotApply(QObject *,QString cls, QString name)
 {
-  krConfig->setGroup( cls );
-  krConfig->writeEntry( name, url() );
+  KConfigGroup( krConfig, cls ).writeEntry( name, url().pathOrUrl() );
 }
 
 void KonfiguratorURLRequester::slotSetDefaults(QObject *)
 {
   if( url() != defaultValue )
-    setURL( defaultValue );
+    lineEdit()->setText( defaultValue );
 }
 
 // KonfiguratorFontChooser class
 ///////////////////////////////
 
 KonfiguratorFontChooser::KonfiguratorFontChooser( QString cls, QString name, QFont *dflt,
-  QWidget *parent, const char *widgetName, bool rst, int pg ) : QHBox ( parent, widgetName ),
+  QWidget *parent, bool rst, int pg ) : QWidget ( parent ),
     defaultValue( dflt )
 {
+  QHBoxLayout *layout = new QHBoxLayout( this );
+
   ext = new KonfiguratorExtension( this, cls, name, rst, pg );
   connect( ext, SIGNAL( applyAuto(QObject *,QString, QString) ), this, SLOT( slotApply(QObject *,QString, QString) ) );
   connect( ext, SIGNAL( setDefaultsAuto(QObject *) ), this, SLOT( slotSetDefaults(QObject *) ) );
@@ -393,11 +408,14 @@ KonfiguratorFontChooser::KonfiguratorFontChooser( QString cls, QString name, QFo
 
   pLabel = new QLabel( this );
   pLabel->setMinimumWidth( 150 );
+  layout->addWidget( pLabel );
+
   pToolButton = new QToolButton( this );
 
   connect( pToolButton, SIGNAL( clicked() ), this, SLOT( slotBrowseFont() ) );
 
-  pToolButton->setIconSet( SmallIcon( "fileopen" ) );
+  pToolButton->setIcon( SmallIcon( "document-open" ) );
+  layout->addWidget( pToolButton );
 
   loadInitialValue();
 }
@@ -409,8 +427,8 @@ KonfiguratorFontChooser::~KonfiguratorFontChooser()
 
 void KonfiguratorFontChooser::loadInitialValue()
 {
-  krConfig->setGroup( ext->getCfgClass() );
-  font = krConfig->readFontEntry( ext->getCfgName(), defaultValue );
+  KConfigGroup group( krConfig, ext->getCfgClass() );
+  font = group.readEntry( ext->getCfgName(), *defaultValue );
   ext->setChanged( false );
   setFont();
 }
@@ -423,8 +441,7 @@ void KonfiguratorFontChooser::setFont()
 
 void KonfiguratorFontChooser::slotApply(QObject *,QString cls, QString name)
 {
-  krConfig->setGroup( cls );
-  krConfig->writeEntry( name, font );
+  KConfigGroup( krConfig, cls ).writeEntry( name, font );
 }
 
 void KonfiguratorFontChooser::slotSetDefaults(QObject *)
@@ -447,7 +464,7 @@ void KonfiguratorFontChooser::slotBrowseFont()
 
 KonfiguratorComboBox::KonfiguratorComboBox( QString cls, QString name, QString dflt,
     KONFIGURATOR_NAME_VALUE_PAIR *listIn, int listInLen, QWidget *parent,
-    const char *widgetName, bool rst, bool editable, int pg ) : QComboBox ( parent, widgetName ),
+    bool rst, bool editable, int pg ) : QComboBox ( parent ),
     defaultValue( dflt ), listLen( listInLen )
 {
   list = new KONFIGURATOR_NAME_VALUE_PAIR[ listInLen ];
@@ -455,7 +472,7 @@ KonfiguratorComboBox::KonfiguratorComboBox( QString cls, QString name, QString d
   for( int i=0; i != listLen; i++ )
   {
     list[i] = listIn[i];
-    insertItem( list[i].text );
+    addItem( list[i].text );
   }
 
   ext = new KonfiguratorExtension( this, cls, name, rst, pg );
@@ -479,15 +496,15 @@ KonfiguratorComboBox::~KonfiguratorComboBox()
 
 void KonfiguratorComboBox::loadInitialValue()
 {
-  krConfig->setGroup( ext->getCfgClass() );
-  QString select = krConfig->readEntry( ext->getCfgName(), defaultValue );
+  KConfigGroup group( krConfig, ext->getCfgClass() );
+  QString select = group.readEntry( ext->getCfgName(), defaultValue );
   selectEntry( select );
   ext->setChanged( false );
 }
 
 void KonfiguratorComboBox::slotApply(QObject *,QString cls, QString name)
 {
-  QString text = editable() ? lineEdit()->text() : currentText();
+  QString text = isEditable() ? lineEdit()->text() : currentText();
   QString value = text;
   
   for( int i=0; i != listLen; i++ )
@@ -496,8 +513,7 @@ void KonfiguratorComboBox::slotApply(QObject *,QString cls, QString name)
       break;
     }
   
-  krConfig->setGroup( cls );
-  krConfig->writeEntry( name, value );
+  KConfigGroup( krConfig, cls ).writeEntry( name, value );
 }
 
 void KonfiguratorComboBox::selectEntry( QString entry )
@@ -505,14 +521,14 @@ void KonfiguratorComboBox::selectEntry( QString entry )
   for( int i=0; i != listLen; i++ )
     if( list[i].value == entry )
     {
-      setCurrentItem( i );
+      setCurrentIndex( i );
       return;
     }
 
-  if( editable() )
+  if( isEditable() )
     lineEdit()->setText( entry );
   else
-    setCurrentItem( 0 );
+    setCurrentIndex( 0 );
 }
 
 void KonfiguratorComboBox::slotSetDefaults(QObject *)
@@ -525,8 +541,8 @@ void KonfiguratorComboBox::slotSetDefaults(QObject *)
 ///////////////////////////////
 
 KonfiguratorColorChooser::KonfiguratorColorChooser( QString cls, QString name, QColor dflt,
-    QWidget *parent, const char *widgetName, bool rst, ADDITIONAL_COLOR *addColPtr,
-    int addColNum, int pg ) : QComboBox ( parent, widgetName ),
+    QWidget *parent, bool rst, ADDITIONAL_COLOR *addColPtr,
+    int addColNum, int pg ) : QComboBox ( parent ),
     defaultValue( dflt ), disableColorChooser( true )
 {
   ext = new KonfiguratorExtension( this, cls, name, rst, pg );
@@ -595,14 +611,14 @@ QPixmap KonfiguratorColorChooser::createPixmap( QColor color )
 
 void KonfiguratorColorChooser::addColor( QString text, QColor color )
 {
-  insertItem( createPixmap(color), text );
+  addItem( createPixmap(color), text );
   palette.push_back( color );
 }
 
 void KonfiguratorColorChooser::loadInitialValue()
 {
-  krConfig->setGroup( ext->getCfgClass() );
-  QString selected = krConfig->readEntry( ext->getCfgName(), "" );
+  KConfigGroup group( krConfig, ext->getCfgClass() );
+  QString selected = group.readEntry( ext->getCfgName(), QString( "" ) );
   setValue( selected );
   ext->setChanged( false );
 }
@@ -611,34 +627,34 @@ void KonfiguratorColorChooser::setDefaultColor( QColor dflt )
 {
   defaultValue = dflt;
   palette[1] = defaultValue;
-  changeItem( createPixmap( defaultValue ), text( 1 ), 1 );
+  setItemIcon( 1, createPixmap( defaultValue ) );
 
-  if( currentItem() == 1 )
+  if( currentIndex() == 1 )
     emit colorChanged();
 }
 
-void KonfiguratorColorChooser::changeAdditionalColor( unsigned int num, QColor color )
+void KonfiguratorColorChooser::changeAdditionalColor( int num, QColor color )
 {
   if( num < additionalColors.size() )
   {
     palette[2+num] = color;
     additionalColors[num].color = color;
-    changeItem( createPixmap( color ), text( 2+num ), 2+num );
+    setItemIcon( 2+num, createPixmap( color ) );
 
-    if( (unsigned int)currentItem() == 2+num )
+    if( currentIndex() == 2+num )
       emit colorChanged();
   }
 }
 
 void KonfiguratorColorChooser::setDefaultText( QString text )
 {
-  changeItem( createPixmap( defaultValue ), text, 1 );
+  setItemIcon( 1, createPixmap( defaultValue ) );
+  setItemText( 1, text );
 }
 
 void KonfiguratorColorChooser::slotApply(QObject *,QString cls, QString name)
 {
-  krConfig->setGroup( cls );
-  krConfig->writeEntry( name, getValue() );
+  KConfigGroup( krConfig, cls ).writeEntry( name, getValue() );
 }
 
 void KonfiguratorColorChooser::setValue( QString value )
@@ -647,41 +663,41 @@ void KonfiguratorColorChooser::setValue( QString value )
 
   if( value.isEmpty() )
   {
-    setCurrentItem( 1 );
+    setCurrentIndex( 1 );
     customValue = defaultValue;
   }
   else
   {
     bool found = false;
 
-    for( unsigned j=0; j != additionalColors.size(); j++ )
+    for( int j=0; j != additionalColors.size(); j++ )
       if( additionalColors[j].value == value )
       {
-        setCurrentItem( 2 + j );
+        setCurrentIndex( 2 + j );
         found = true;
         break;
       }
 
     if( ! found )
     {
-      krConfig->setGroup( ext->getCfgClass() );
-      krConfig->writeEntry( "TmpColor", value );
-      QColor color = krConfig->readColorEntry( "TmpColor", &defaultValue );
+      KConfigGroup colGroup( krConfig, ext->getCfgClass() );
+      colGroup.writeEntry( "TmpColor", value );
+      QColor color = colGroup.readEntry( "TmpColor", defaultValue );
       customValue = color;
-      krConfig->deleteEntry( "TmpColor" );
+      colGroup.deleteEntry( "TmpColor" );
 
-      setCurrentItem( 0 );
-      for( unsigned i= 2+additionalColors.size(); i != palette.size(); i++ )
+      setCurrentIndex( 0 );
+      for( int i= 2+additionalColors.size(); i != palette.size(); i++ )
         if( palette[i] == color )
         {
-          setCurrentItem( i );
+          setCurrentIndex( i );
           break;
         }
     }
   }
 
   palette[0] = customValue;
-  changeItem( createPixmap( customValue ), text( 0 ), 0 );
+  setItemIcon( 0, createPixmap( customValue ) );
 
   ext->setChanged();
   emit colorChanged();
@@ -690,24 +706,24 @@ void KonfiguratorColorChooser::setValue( QString value )
 
 QString KonfiguratorColorChooser::getValue()
 {
-  QColor color = palette[ currentItem() ];
-  if( currentItem() == 1 )    /* it's the default value? */
+  QColor color = palette[ currentIndex() ];
+  if( currentIndex() == 1 )    /* it's the default value? */
     return "";
-  else if( currentItem() >= 2 && (unsigned)currentItem() < 2 + additionalColors.size() )
-    return additionalColors[ currentItem() - 2 ].value;
+  else if( currentIndex() >= 2 && currentIndex() < 2 + additionalColors.size() )
+    return additionalColors[ currentIndex() - 2 ].value;
   else
     return QString( "%1,%2,%3" ).arg( color.red() ).arg( color.green() ).arg( color.blue() );
 }
 
 bool KonfiguratorColorChooser::isValueRGB()
 {
-  return !( currentItem() >= 1 && (unsigned)currentItem() < 2 + additionalColors.size() );
+  return !( currentIndex() >= 1 && currentIndex() < 2 + additionalColors.size() );
 }
 
 void KonfiguratorColorChooser::slotSetDefaults(QObject *)
 {
   ext->setChanged();
-  setCurrentItem( 1 );
+  setCurrentIndex( 1 );
   emit colorChanged();
 }
 
@@ -716,13 +732,13 @@ void KonfiguratorColorChooser::slotCurrentChanged( int number )
   ext->setChanged();
   if( number == 0 && !disableColorChooser )
   {
-    QColor color = QColorDialog::getColor ( customValue, this, "ColorDialog" );
+    QColor color = QColorDialog::getColor ( customValue, this );
     if( color.isValid() )
     {
       disableColorChooser = true;
       customValue = color;
       palette[0] = customValue;
-      changeItem( createPixmap( customValue ), text( 0 ), 0 );
+      setItemIcon( 0, createPixmap( customValue ) );
       disableColorChooser = false;
     }
   }
@@ -732,14 +748,14 @@ void KonfiguratorColorChooser::slotCurrentChanged( int number )
 
 QColor KonfiguratorColorChooser::getColor()
 {
-  return palette[ currentItem() ];
+  return palette[ currentIndex() ];
 }
 
 // KonfiguratorListBox class
 ///////////////////////////////
 
 KonfiguratorListBox::KonfiguratorListBox( QString cls, QString name, QStringList dflt,
-    QWidget *parent, const char *widgetName, bool rst, int pg ) : QListBox( parent, widgetName ),
+    QWidget *parent, bool rst, int pg ) : KrListWidget( parent ),
     defaultValue( dflt )
 {
   ext = new KonfiguratorExtension( this, cls, name, rst, pg );
@@ -757,15 +773,14 @@ KonfiguratorListBox::~KonfiguratorListBox()
 
 void KonfiguratorListBox::loadInitialValue()
 {
-  krConfig->setGroup( ext->getCfgClass() );
-  setList( krConfig->readListEntry( ext->getCfgName().ascii(), defaultValue ) );
+  KConfigGroup group( krConfig, ext->getCfgClass() );
+  setList( group.readEntry( ext->getCfgName(), defaultValue ) );
   ext->setChanged( false );
 }
 
 void KonfiguratorListBox::slotApply(QObject *,QString cls, QString name)
 {
-  krConfig->setGroup( cls );
-  krConfig->writeEntry( name, list() );
+  KConfigGroup( krConfig, cls ).writeEntry( name, list() );
 }
 
 void KonfiguratorListBox::slotSetDefaults(QObject *)
@@ -780,15 +795,15 @@ void KonfiguratorListBox::slotSetDefaults(QObject *)
 void KonfiguratorListBox::setList( QStringList list )
 {
   clear();
-  insertStringList( list );
+  addItems( list );
 }
 
 QStringList KonfiguratorListBox::list()
 {
   QStringList lst;
   
-  for( unsigned i=0; i != count(); i++ )
-    lst += text( i );
+  for( int i=0; i != count(); i++ )
+    lst += item( i )->text();
 
   return lst;
 }
@@ -797,19 +812,19 @@ void KonfiguratorListBox::addItem( const QString & item )
 {
   if( !list().contains( item ) )
   {
-    insertItem( item );
+    KrListWidget::addItem( item );
     ext->setChanged();
   }
 }
 
 void KonfiguratorListBox::removeItem( const QString & item )
 {
-  QListBoxItem * listItem = findItem( item );
-  if( listItem != 0 )
-  {
-    takeItem( listItem );
+  QList<QListWidgetItem *> list = findItems ( item, Qt::MatchExactly );
+  for( int i=0; i != list.count(); i++ )
+    delete list[ i ];
+
+  if( list.count() )
     ext->setChanged();
-  }
 }
 
 #include "konfiguratoritems.moc"
