@@ -37,13 +37,12 @@
 #include <qspinbox.h>
 #include <qpushbutton.h>
 #include <qradiobutton.h>
-#include <qptrlist.h>
-#include <qvaluelist.h>
-#include <qvaluevector.h>
-#include <qbuttongroup.h>
+#include "../GUI/krlistwidget.h"
+#include <qlist.h>
 #include <qlineedit.h>
+#include <QPixmap>
 #include <kurlrequester.h>
-#include <qhbox.h>
+#include <qboxlayout.h>
 #include <kfontdialog.h>
 #include <qlabel.h>
 #include <qfont.h>
@@ -108,7 +107,7 @@ class KonfiguratorCheckBox : public QCheckBox
 
 public:
   KonfiguratorCheckBox( QString cls, QString name, bool dflt, QString text,
-                        QWidget *parent=0, const char *widgetName=0, bool rst=false, int pg=FIRST_PAGE );
+                        QWidget *parent=0, bool rst=false, int pg=FIRST_PAGE );
   ~KonfiguratorCheckBox();
 
   inline KonfiguratorExtension *extension()   {return ext;}
@@ -132,7 +131,7 @@ class KonfiguratorSpinBox : public QSpinBox
 
 public:
   KonfiguratorSpinBox( QString cls, QString name, int dflt, int min, int max,
-                       QWidget *parent=0, const char *widgetName=0, bool rst=false, int pg=FIRST_PAGE );
+                       QWidget *parent=0, bool rst=false, int pg=FIRST_PAGE );
   ~KonfiguratorSpinBox();
 
   inline KonfiguratorExtension *extension()   {return ext;}
@@ -153,27 +152,28 @@ protected:
 class KonfiguratorCheckBoxGroup : public QWidget
 {
 public:
-  KonfiguratorCheckBoxGroup( QWidget * parent = 0, const char * name = 0 ) :
-    QWidget( parent, name ) {};
+  KonfiguratorCheckBoxGroup( QWidget * parent = 0 ) :
+    QWidget( parent ) {};
 
   void                    add( KonfiguratorCheckBox * );
+  int                     count() { return checkBoxList.count(); };
   KonfiguratorCheckBox *  find( int index );
   KonfiguratorCheckBox *  find( QString name );
 
 private:
-  QPtrList<KonfiguratorCheckBox>  checkBoxList;
+  QList<KonfiguratorCheckBox *>  checkBoxList;
 };
 
 // KonfiguratorRadioButtons class
 ///////////////////////////////
 
-class KonfiguratorRadioButtons : public QButtonGroup
+class KonfiguratorRadioButtons : public QWidget
 {
   Q_OBJECT
 
 public:
   KonfiguratorRadioButtons( QString cls, QString name, QString dflt, QWidget *parent=0,
-                            const char *widgetName=0, bool rst=false, int pg=FIRST_PAGE );
+                            bool rst=false, int pg=FIRST_PAGE );
   ~KonfiguratorRadioButtons();
 
   inline KonfiguratorExtension *extension()   {return ext;}
@@ -182,6 +182,8 @@ public:
 
   void            selectButton( QString value );
 
+  int             count() { return radioButtons.count(); }
+  QString         selectedValue();
   QRadioButton*   find( int index );
   QRadioButton*   find( QString name );
 
@@ -191,12 +193,11 @@ public slots:
   void slotSetDefaults(QObject *);
 
 protected:
-  QPtrList<QRadioButton>  radioButtons;
-  QValueList<QString>   radioValues;
-  QValueList<QString>   radioNames;
+  QList<QRadioButton *>  radioButtons;
+  QList<QString>   radioValues;
+  QList<QString>   radioNames;
 
   QString         defaultValue;
-  QButtonGroup    *buttonGroup;
 
   KonfiguratorExtension *ext;
 };
@@ -210,7 +211,7 @@ class KonfiguratorEditBox : public QLineEdit
 
 public:
   KonfiguratorEditBox( QString cls, QString name, QString dflt, QWidget *parent=0,
-                       const char *widgetName=0, bool rst=false, int pg=FIRST_PAGE );
+                       bool rst=false, int pg=FIRST_PAGE );
   ~KonfiguratorEditBox();
 
   inline KonfiguratorExtension *extension()   {return ext;}
@@ -229,13 +230,13 @@ protected:
 // KonfiguratorURLRequester class
 ///////////////////////////////
 
-class KonfiguratorURLRequester : public KURLRequester
+class KonfiguratorURLRequester : public KUrlRequester
 {
   Q_OBJECT
 
 public:
   KonfiguratorURLRequester( QString cls, QString name, QString dflt, QWidget *parent=0,
-                       const char *widgetName=0, bool rst=false, int pg=FIRST_PAGE );
+                       bool rst=false, int pg=FIRST_PAGE );
   ~KonfiguratorURLRequester();
 
   inline KonfiguratorExtension *extension()   {return ext;}
@@ -253,13 +254,13 @@ protected:
 // KonfiguratorFontChooser class
 ///////////////////////////////
 
-class KonfiguratorFontChooser : public QHBox
+class KonfiguratorFontChooser : public QWidget
 {
   Q_OBJECT
 
 public:
   KonfiguratorFontChooser( QString cls, QString name, QFont *dflt, QWidget *parent=0,
-                            const char *widgetName=0, bool rst=false, int pg=FIRST_PAGE );
+                            bool rst=false, int pg=FIRST_PAGE );
   ~KonfiguratorFontChooser();
 
   inline KonfiguratorExtension *extension()   {return ext;}
@@ -310,7 +311,7 @@ class KonfiguratorComboBox : public QComboBox
 public:
   KonfiguratorComboBox( QString cls, QString name, QString dflt,
                         KONFIGURATOR_NAME_VALUE_PAIR *listIn, int listInLen,
-                        QWidget *parent=0, const char *widgetName=0,
+                        QWidget *parent=0,
                         bool rst=false,  bool editable=false, int pg=FIRST_PAGE );
   ~KonfiguratorComboBox();
 
@@ -347,7 +348,7 @@ class KonfiguratorColorChooser : public QComboBox
 
 public:
   KonfiguratorColorChooser( QString cls, QString name, QColor dflt,
-                            QWidget *parent=0, const char *widgetName=0, bool rst=false,
+                            QWidget *parent=0, bool rst=false,
                             ADDITIONAL_COLOR *addColPtr = 0, int addColNum = 0, int pg=FIRST_PAGE );
   ~KonfiguratorColorChooser();
 
@@ -356,7 +357,7 @@ public:
   void          setDefaultColor( QColor dflt );
   void          setDefaultText( QString text );
   QColor        getColor();
-  void          changeAdditionalColor( unsigned int num, QColor color );
+  void          changeAdditionalColor( int num, QColor color );
   QString       getValue();
   bool          isValueRGB();
   void          setValue( QString value );
@@ -377,8 +378,8 @@ private:
 protected:
   QColor                          defaultValue;
   QColor                          customValue;
-  QValueVector<QColor>            palette;
-  QValueVector<ADDITIONAL_COLOR>  additionalColors;
+  QList<QColor>                   palette;
+  QList<ADDITIONAL_COLOR>         additionalColors;
   KonfiguratorExtension          *ext;
   bool                            disableColorChooser;
 };
@@ -386,13 +387,13 @@ protected:
 // KonfiguratorListBox class
 ///////////////////////////////
 
-class KonfiguratorListBox : public QListBox
+class KonfiguratorListBox : public KrListWidget
 {
   Q_OBJECT
 
 public:
   KonfiguratorListBox( QString cls, QString name, QStringList dflt,
-                        QWidget *parent=0, const char *widgetName=0,
+                        QWidget *parent=0,
                         bool rst=false,  int pg=FIRST_PAGE );
   ~KonfiguratorListBox();
 
