@@ -30,68 +30,53 @@
 
 #include "konfiguratorpage.h"
 #include <qlayout.h>
+#include <QHBoxLayout>
+#include <QGridLayout>
+#include <QScrollArea>
+#include <QLabel>
 #include "../krusader.h"
-#include <qwhatsthis.h>
 
-KonfiguratorPage::KonfiguratorPage( bool firstTime, QWidget* parent,  const char* name ) :
-  QFrame( parent, name ), firstCall( firstTime )
+KonfiguratorPage::KonfiguratorPage( bool firstTime, QWidget* parent ) :
+  QScrollArea( parent ), firstCall( firstTime )
 {
+  setFrameStyle( QFrame::NoFrame );
 }
 
 bool KonfiguratorPage::apply()
 {
   bool restartNeeded = false;
 
-  KonfiguratorExtension *item = itemList.first();
+  for( QList<KonfiguratorExtension *>::iterator item = itemList.begin(); item != itemList.end(); item ++ )
+    restartNeeded = (*item)->apply() || restartNeeded;
 
-  while( item )
-  {
-    restartNeeded = item->apply() || restartNeeded;
-    item = itemList.next();
-  }
-
-  krConfig->sync();  
+  krConfig->sync();
   return restartNeeded;
 }
 
 void KonfiguratorPage::setDefaults()
 {
-  KonfiguratorExtension *item = itemList.first();
   int activePage = activeSubPage();
 
-  while( item )
+  for( QList<KonfiguratorExtension *>::iterator item = itemList.begin(); item != itemList.end(); item ++ )
   {
-    if( item->subPage() == activePage )
-      item->setDefaults();
-    item = itemList.next();
+    if( (*item)->subPage() == activePage )
+      (*item)->setDefaults();
   }
 }
 
 void KonfiguratorPage::loadInitialValues()
 {
-  KonfiguratorExtension *item = itemList.first();
-
-  while( item )
-  {
-    item->loadInitialValue();
-    item = itemList.next();
-  }
+  for( QList<KonfiguratorExtension *>::iterator item = itemList.begin(); item != itemList.end(); item ++ )
+    (*item)->loadInitialValue();
 }
 
 bool KonfiguratorPage::isChanged()
 {
-  KonfiguratorExtension *currentItem = itemList.current();  /* save the current pointer */
   bool isChanged = false;
 
-  KonfiguratorExtension *item = itemList.first();
+  for( QList<KonfiguratorExtension *>::iterator item = itemList.begin(); item != itemList.end(); item ++ )
+    isChanged = isChanged || (*item)->isChanged();
 
-  while( item )
-  {
-    isChanged = isChanged || item->isChanged();
-    item = itemList.next();
-  }
-
-  itemList.find( currentItem );  /* restore the current pointer */
   return isChanged;
 }
 
@@ -99,9 +84,9 @@ KonfiguratorCheckBox* KonfiguratorPage::createCheckBox( QString cls, QString nam
     bool dflt, QString text, QWidget *parent, bool rst, QString toolTip, int pg )
 {
   KonfiguratorCheckBox *checkBox = new KonfiguratorCheckBox( cls, name, dflt, text,
-                                 parent, QString(cls + "/" + name).ascii(), rst, pg );
+                                 parent, rst, pg );
   if( !toolTip.isEmpty() )
-    QWhatsThis::add( checkBox, toolTip );
+    checkBox->setWhatsThis( toolTip );
   
   registerObject( checkBox->extension() );
   return checkBox;
@@ -111,7 +96,7 @@ KonfiguratorSpinBox* KonfiguratorPage::createSpinBox(  QString cls, QString name
     int dflt, int min, int max, QWidget *parent, bool rst, int pg )
 {
   KonfiguratorSpinBox *spinBox = new KonfiguratorSpinBox( cls, name, dflt, min, max,
-                                 parent, QString(cls + "/" + name).ascii(), rst, pg );
+                                 parent, rst, pg );
 
   registerObject( spinBox->extension() );
   return spinBox;
@@ -121,7 +106,7 @@ KonfiguratorEditBox* KonfiguratorPage::createEditBox(  QString cls, QString name
     QString dflt, QWidget *parent, bool rst, int pg )
 {
   KonfiguratorEditBox *editBox = new KonfiguratorEditBox( cls, name, dflt, parent,
-                                        QString(cls + "/" + name).ascii(), rst, pg );
+                                        rst, pg );
 
   registerObject( editBox->extension() );
   return editBox;
@@ -131,7 +116,7 @@ KonfiguratorListBox* KonfiguratorPage::createListBox(  QString cls, QString name
     QStringList dflt, QWidget *parent, bool rst, int pg )
 {
   KonfiguratorListBox *listBox = new KonfiguratorListBox( cls, name, dflt, parent,
-                                        QString(cls + "/" + name).ascii(), rst, pg );
+                                        rst, pg );
 
   registerObject( listBox->extension() );
   return listBox;
@@ -141,46 +126,40 @@ KonfiguratorURLRequester* KonfiguratorPage::createURLRequester(  QString cls, QS
     QString dflt, QWidget *parent, bool rst, int pg )
 {
   KonfiguratorURLRequester *urlRequester = new KonfiguratorURLRequester( cls, name, dflt,
-                                        parent, QString(cls + "/" + name).ascii(), rst, pg );
+                                        parent, rst, pg );
 
   registerObject( urlRequester->extension() );
   return urlRequester;
 }
 
-QGroupBox* KonfiguratorPage::createFrame( QString text, QWidget *parent,
-                                          const char *widgetName )
+QGroupBox* KonfiguratorPage::createFrame( QString text, QWidget *parent )
 {
-  QGroupBox *groupBox = new QGroupBox( parent, widgetName );
-  groupBox->setFrameShape( QGroupBox::Box );
-  groupBox->setFrameShadow( QGroupBox::Sunken );
+  QGroupBox *groupBox = new QGroupBox( parent );
   if( !text.isNull() )
     groupBox->setTitle( text );
-  groupBox->setColumnLayout(0, Qt::Vertical );
-  groupBox->layout()->setSpacing( 0 );
-  groupBox->layout()->setMargin( 0 );
   return groupBox;
-}                                          
+}
 
-QGridLayout* KonfiguratorPage::createGridLayout( QLayout *parent )
+QGridLayout* KonfiguratorPage::createGridLayout( QWidget *parent )
 {
   QGridLayout *gridLayout = new QGridLayout( parent );
   gridLayout->setAlignment( Qt::AlignTop );
   gridLayout->setSpacing( 6 );
-  gridLayout->setMargin( 11 );
+  gridLayout->setContentsMargins( 11, 11, 11, 11 );
   return gridLayout;
 }
 
 QLabel* KonfiguratorPage::addLabel( QGridLayout *layout, int x, int y, QString label,
-                                    QWidget *parent, const char *widgetName )
+                                    QWidget *parent )
 {
-  QLabel *lbl = new QLabel( label, parent, widgetName );
+  QLabel *lbl = new QLabel( label, parent );
   layout->addWidget( lbl, x, y );
   return lbl;
 }
 
-QWidget* KonfiguratorPage::createSpacer( QWidget *parent, const char *widgetName )
+QWidget* KonfiguratorPage::createSpacer( QWidget *parent )
 {
-  QWidget *widget = new QWidget( parent, widgetName );
+  QWidget *widget = new QWidget( parent );
   QHBoxLayout *hboxlayout = new QHBoxLayout( widget );
   QSpacerItem* spacer = new QSpacerItem( 40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
   hboxlayout->addItem( spacer );
@@ -189,12 +168,12 @@ QWidget* KonfiguratorPage::createSpacer( QWidget *parent, const char *widgetName
 
 KonfiguratorCheckBoxGroup* KonfiguratorPage::createCheckBoxGroup( int sizex, int sizey,
     KONFIGURATOR_CHECKBOX_PARAM *params, int paramNum, QWidget *parent,
-    const char *widgetName, int pg )
+    int pg )
 {
-  KonfiguratorCheckBoxGroup *groupWidget = new KonfiguratorCheckBoxGroup( parent, widgetName );
+  KonfiguratorCheckBoxGroup *groupWidget = new KonfiguratorCheckBoxGroup( parent );
   QGridLayout *layout = new QGridLayout( groupWidget );
   layout->setSpacing( 6 );
-  layout->setMargin( 0 );
+  layout->setContentsMargins( 0, 0, 0, 0 );
   
   int x = 0, y = 0;
   
@@ -224,30 +203,23 @@ KonfiguratorCheckBoxGroup* KonfiguratorPage::createCheckBoxGroup( int sizex, int
 
 KonfiguratorRadioButtons* KonfiguratorPage::createRadioButtonGroup( QString cls,
     QString name, QString dflt, int sizex, int sizey, KONFIGURATOR_NAME_VALUE_TIP *params,
-    int paramNum, QWidget *parent, const char *widgetName, bool rst, int pg )
+    int paramNum, QWidget *parent, bool rst, int pg )
 {
-  KonfiguratorRadioButtons *radioWidget = new KonfiguratorRadioButtons( cls, name, dflt, parent, widgetName, rst, pg );
-  radioWidget->setFrameShape( QButtonGroup::NoFrame );
-  radioWidget->setFrameShadow( QButtonGroup::Sunken );
-  radioWidget->setTitle( "" );
-  radioWidget->setExclusive( true );
-  radioWidget->setRadioButtonExclusive( true );
-  radioWidget->setColumnLayout(0, Qt::Vertical );
+  KonfiguratorRadioButtons *radioWidget = new KonfiguratorRadioButtons( cls, name, dflt, parent, rst, pg );
 
-  QGridLayout *layout = new QGridLayout( radioWidget->layout() );
+  QGridLayout *layout = new QGridLayout( radioWidget );
   layout->setAlignment( Qt::AlignTop );
   layout->setSpacing( 6 );
-  layout->setMargin( 0 );
+  layout->setContentsMargins( 0, 0, 0, 0 );
 
   int x = 0, y = 0;
 
   for( int i=0; i != paramNum; i++ )
   {
-    QRadioButton *radBtn = new QRadioButton( params[i].text, radioWidget,
-                        QString( cls + "/" + name + "/" + params[i].value ).ascii() );
+    QRadioButton *radBtn = new QRadioButton( params[i].text, radioWidget );
 
     if( !params[i].tooltip.isEmpty() )
-      QWhatsThis::add( radBtn, params[i].tooltip );
+      radBtn->setWhatsThis( params[i].tooltip );
 
     layout->addWidget( radBtn, y, x );
 
@@ -274,7 +246,7 @@ KonfiguratorFontChooser *KonfiguratorPage::createFontChooser( QString cls, QStri
   QFont *dflt, QWidget *parent, bool rst, int pg )
 {
   KonfiguratorFontChooser *fontChooser = new KonfiguratorFontChooser( cls, name, dflt, parent,
-                                        QString(cls + "/" + name).ascii(), rst, pg );
+                                        rst, pg );
 
   registerObject( fontChooser->extension() );
   return fontChooser;
@@ -284,40 +256,34 @@ KonfiguratorComboBox *KonfiguratorPage::createComboBox(  QString cls, QString na
     KONFIGURATOR_NAME_VALUE_PAIR *params, int paramNum, QWidget *parent, bool rst, bool editable, int pg )
 {
   KonfiguratorComboBox *comboBox = new KonfiguratorComboBox( cls, name, dflt, params,
-                                        paramNum, parent, QString(cls + "/" + name).ascii(),
-                                        rst, editable, pg );
+                                        paramNum, parent, rst, editable, pg );
 
   registerObject( comboBox->extension() );
   return comboBox;
 }
 
-QFrame* KonfiguratorPage::createLine( QWidget *parent, const char *widgetName, bool vertical )
+QFrame* KonfiguratorPage::createLine( QWidget *parent, bool vertical )
 {
-  QFrame *line = new QFrame( parent, widgetName );
+  QFrame *line = new QFrame( parent );
   line->setFrameStyle( ( vertical ? QFrame::VLine : QFrame::HLine ) | QFrame::Sunken );
   return line;
 }
 
 void KonfiguratorPage::registerObject( KonfiguratorExtension *item )
 {
-  KonfiguratorExtension *currentItem = itemList.current();
-  
-  itemList.append( item );
+  itemList.push_back( item );
   connect( item, SIGNAL( sigChanged( bool ) ), this, SIGNAL ( sigChanged( ) ) );
-
-  itemList.find( currentItem );
 }
 
 void KonfiguratorPage::removeObject( KonfiguratorExtension *item )
 {
-  if( item == itemList.current() )
-  {
-    itemList.remove();
-    if( itemList.current() != itemList.getFirst() )
-      itemList.prev();
-  }
-  else
-    itemList.removeRef( item );
+    int ndx = itemList.indexOf( item );
+    if( ndx != -1 )
+    {
+      QList<KonfiguratorExtension *>::iterator it = itemList.begin() + ndx;
+      delete *it;
+      itemList.erase( it );
+    }
 }
 
 KonfiguratorColorChooser *KonfiguratorPage::createColorChooser( QString cls, QString name, QColor dflt,
@@ -325,7 +291,7 @@ KonfiguratorColorChooser *KonfiguratorPage::createColorChooser( QString cls, QSt
                                                                 ADDITIONAL_COLOR *addColPtr, int addColNum, int pg )
 {
   KonfiguratorColorChooser *colorChooser = new KonfiguratorColorChooser( cls, name, dflt,  parent,
-                                        QString(cls + "/" + name).ascii(), rst, addColPtr, addColNum, pg );
+                                        rst, addColPtr, addColNum, pg );
 
   registerObject( colorChooser->extension() );
   return colorChooser;
