@@ -32,11 +32,11 @@
 #define __KONFIGURATOR_PAGE_H__
  
 #include "konfiguratoritems.h"
-#include <qframe.h>
-#include <qptrlist.h>
 #include <qgroupbox.h>
 #include <qlabel.h>
 #include <qlayout.h>
+#include <QGridLayout>
+#include <QScrollArea>
 
 struct KONFIGURATOR_CHECKBOX_PARAM;
 struct KONFIGURATOR_NAME_VALUE_TIP;
@@ -48,7 +48,7 @@ struct KONFIGURATOR_NAME_VALUE_PAIR;
   *
   * @short The base class of a page in Konfigurator
   */  
-class KonfiguratorPage : public QFrame
+class KonfiguratorPage : public QScrollArea
 {
   Q_OBJECT
    
@@ -58,9 +58,8 @@ public:
   *
   * @param firstTime    this parameter is true if it is the first call of Konfigurator
   * @param parent       reference to the parent widget
-  * @param name         name of the newly generated Konfigurator page widget
   */
-  KonfiguratorPage( bool firstTime, QWidget* parent,  const char* name );
+  KonfiguratorPage( bool firstTime, QWidget* parent );
 
   /**
     * Applies the changes in the Konfigurator page.
@@ -135,7 +134,7 @@ public:
     */
   KonfiguratorCheckBox    *createCheckBox( QString cls, QString name, bool dflt,
                                            QString text, QWidget *parent=0, bool rst=false,
-                                           QString toolTip = QString::null, int pg=FIRST_PAGE );
+                                           QString toolTip = QString(), int pg=FIRST_PAGE );
 
   /**
     * Adds a new spinbox item to the page.
@@ -280,26 +279,24 @@ public:
     *
     * @param  text        The text written out onto the frame
     * @param  parent      Reference to the parent widget
-    * @param  widgetName  The name of the widget
     *
     * @return             reference to the newly created frame
     */
-  QGroupBox               *createFrame( QString text = QString::null, QWidget *parent=0,
-                                           const char *widgetName=0 );
+  QGroupBox               *createFrame( QString text = QString(), QWidget *parent=0 );
 
   /**
     * Creates a new QGridLayout element and sets its margins.
     *
     * Sample:<br><br>
     * QGroupBox *myGroup = createFrame( i18n( "MyFrameName" ), parentWidget, "frameName" );<br>
-    * QGridLayout *myLayout = createGridLayout( myGroup->layout() );<br>
+    * QGridLayout *myLayout = createGridLayout( myGroup ) );<br>
     * myLayout->addWidget( myGroup, 0, 0 );
     *
     * @param  parent      Reference to the parent layout
     *
     * @return             reference to the newly created QGridLayout
     */
-  QGridLayout             *createGridLayout( QLayout *parent );
+  QGridLayout             *createGridLayout( QWidget *parent );
 
   /**
     * Adds a new label to a grid layout.
@@ -315,12 +312,11 @@ public:
     * @param  y           the row to which the label will be placed
     * @param  label       the text of the label
     * @param  parent      Reference to the parent widget
-    * @param  widgetName  The name of the newly generated label widget
     *
     * @return             reference to the newly created label
     */
   QLabel                  *addLabel( QGridLayout *layout, int x, int y, QString label,
-                                           QWidget *parent=0, const char *widgetName=0 );
+                                           QWidget *parent=0 );
 
   /**
     * Creates a spacer object (for justifying in QHBox).
@@ -328,15 +324,14 @@ public:
     * Sample:<br><br>
     * QHBox *hbox = new QHBox( myParent, "hbox" );<br>
     * createSpinBox( "class", "spin", 5, 1, 10, hbox );<br>
-    * createSpacer( hbox, "mySpacer" );<br>
+    * createSpacer( hbox );<br>
     * myLayout->addWidget( hbox, 0, 0 );
     *
     * @param  parent      Reference to the parent widget
-    * @param  widgetName  The name of the newly generated label widget
     *
     * @return             reference to the newly created spacer widget
     */
-  QWidget                 *createSpacer( QWidget *parent=0, const char *widgetName=0 );
+  QWidget                 *createSpacer( QWidget *parent=0 );
 
   /**
     * Creates a separator line.
@@ -346,12 +341,11 @@ public:
     * myLayout->addWidget( myLine, 1, 0 );<br>
     *
     * @param  parent      Reference to the parent widget
-    * @param  widgetName  The name of the newly generated label widget
     * @param  vertical    Means vertical line
     *
     * @return             reference to the newly created spacer widget
     */
-  QFrame                  *createLine( QWidget *parent=0, const char *widgetName=0, bool vertical = false );
+  QFrame                   *createLine( QWidget *parent=0, bool vertical = false );
 
   /**
     * Creates a checkbox group. A checkbox group contains a lot of checkboxes.
@@ -378,14 +372,13 @@ public:
     * @param  params      pointer to the checkbox array
     * @param  paramNum    number of the checkbox elements
     * @param  parent      Reference to the parent widget
-    * @param  widgetName  The name of the newly created checkbox group widget
     * @param  pg          The subpage of a Konfigurator page (because of setDefaults)
     *
     * @return             reference to the newly created checkbox group widget
     */
   KonfiguratorCheckBoxGroup *createCheckBoxGroup( int sizex, int sizey,
                                            KONFIGURATOR_CHECKBOX_PARAM *params, int paramNum,
-                                           QWidget *parent=0, const char *widgetName=0, int pg=FIRST_PAGE );
+                                           QWidget *parent=0, int pg=FIRST_PAGE );
   /**
     * Creates a radio button group. A radio button group contains a lot of radio buttons.
     * The grouped buttons are embedded into one widget, which can be placed anywhere
@@ -414,7 +407,6 @@ public:
     * @param  params      pointer to the checkbox array
     * @param  paramNum    number of the checkbox elements
     * @param  parent      Reference to the parent widget
-    * @param  widgetName  The name of the newly created button group widget
     * @param  rst         The change of this parameter requires Krusader restart
     * @param  pg          The subpage of a Konfigurator page (because of setDefaults)
     *
@@ -423,7 +415,7 @@ public:
   KonfiguratorRadioButtons *createRadioButtonGroup( QString cls, QString name, 
                                            QString dflt, int sizex, int sizey,
                                            KONFIGURATOR_NAME_VALUE_TIP *params, int paramNum,
-                                           QWidget *parent=0, const char *widgetName=0, bool rst=false, int pg=FIRST_PAGE );
+                                           QWidget *parent=0, bool rst=false, int pg=FIRST_PAGE );
 
   /**
     * This function is used to insert new, unknown items into KonfiguratorPage. The
@@ -481,7 +473,7 @@ signals:
   void  sigChanged();
   
 protected:
-  QPtrList<KonfiguratorExtension> itemList;
+  QList<KonfiguratorExtension *> itemList;
 
 private:
   bool  firstCall;
