@@ -30,6 +30,10 @@
 
 #include "krresulttable.h"
 #include <iostream>
+#include <QGridLayout>
+#include <QLabel>
+#include <qlist.h>
+#include <kcolorscheme.h>
 using namespace std;
 
 #define PS(x) _supported.contains(x)>0
@@ -47,15 +51,17 @@ KrResultTable::~KrResultTable()
 
 QGridLayout* KrResultTable::initTable()
 {
-  _grid = new QGridLayout(this, _numRows, _numColumns);
-  _grid->setColStretch(_numColumns-1, 1); // stretch last column
+  _grid = new QGridLayout(this);
+  _grid->setColumnStretch(_numColumns-1, 1); // stretch last column
+  _grid->setContentsMargins( 0, 0, 0, 0 );
+  _grid->setSpacing( 0 );
 
   // +++ Build and add table header +++
   int column = 0;
   for( QStringList::Iterator it=_tableHeaders.begin(); it!=_tableHeaders.end(); ++it )
   {
     _label = new QLabel(*it, this);
-    _label->setMargin(5);
+    _label->setContentsMargins(5,5,5,5);
     _grid->addWidget(_label, 0, column);
 
     // Set font
@@ -73,20 +79,24 @@ QGridLayout* KrResultTable::initTable()
 
 void KrResultTable::adjustRow(QGridLayout* grid)
 {
-  QLayoutIterator it = grid->iterator();
+  int i = 0;
   QLayoutItem *child;
   int col = 0;
 
-  while( (child = it.current()) != 0 )
+  while( (child = grid->itemAt(i)) != 0 )
   {
     // Add some space between columns
     child->widget()->setMinimumWidth( child->widget()->sizeHint().width() + 15 );
 
     // Paint uneven rows in alternate color
-    if( ((col/_numColumns)%2) )
-      child->widget()->setPaletteBackgroundColor( KGlobalSettings::baseColor() );
+    if( ((col/_numColumns)%2) ) {
+      child->widget()->setAutoFillBackground( true );
+      QPalette pal = child->widget()->palette();
+      pal.setColor( child->widget()->backgroundRole(), KColorScheme(QPalette::Active, KColorScheme::View).background( KColorScheme::AlternateBackground ).color() );
+      child->widget()->setPalette( pal );
+    }
 
-    ++it;
+    ++i;
     ++col;
   }
 }
@@ -102,6 +112,7 @@ KrArchiverResultTable::KrArchiverResultTable(QWidget* parent)
   Archiver* tar   = new Archiver("tar",   "http://www.gnu.org",      PS("tar"),   true,  true);
   Archiver* gzip  = new Archiver("gzip",  "http://www.gnu.org",      PS("gzip"),  true,  true);
   Archiver* bzip2 = new Archiver("bzip2", "http://www.gnu.org",      PS("bzip2"), true,  true);
+  Archiver* lzma  = new Archiver("lzma",  "http://tukaani.org/lzma", PS("lzma"),  true,  true);
   Archiver* lha   = new Archiver("lha",   "http://www.gnu.org",      PS("lha"),   true,  true);
   Archiver* zip   = new Archiver("zip",   "http://www.info-zip.org", PS("zip"),   true,  false);
   Archiver* unzip = new Archiver("unzip", "http://www.info-zip.org", PS("unzip"), false, true);
@@ -138,6 +149,7 @@ KrArchiverResultTable::KrArchiverResultTable(QWidget* parent)
   addRow(tar, _grid);
   addRow(gzip, _grid);
   addRow(bzip2, _grid);
+  addRow(lzma, _grid);
   addRow(lha, _grid);
   addRow(zip, _grid);
   addRow(unzip, _grid);
@@ -153,6 +165,7 @@ KrArchiverResultTable::KrArchiverResultTable(QWidget* parent)
   delete tar;
   delete gzip;
   delete bzip2;
+  delete lzma;
   delete lha;
   delete zip;
   delete unzip;
@@ -176,50 +189,59 @@ bool KrArchiverResultTable::addRow(SearchObject* search, QGridLayout* grid)
   Archiver* arch = dynamic_cast<Archiver*>(search);
 
   // Name column
-  _label = new KURLLabel(arch->getWebsite(), arch->getSearchName(), this);
-  _label->setMargin(5);
+  _label = new KUrlLabel(arch->getWebsite(), arch->getSearchName(), this);
+  _label->setContentsMargins(5,5,5,5);
   _label->setAlignment(Qt::AlignTop);
   grid->addWidget(_label, _numRows, 0);
-  connect(_label, SIGNAL(leftClickedURL(const QString&)),
+  connect(_label, SIGNAL(leftClickedUrl(const QString&)),
                       SLOT(website(const QString&)));
 
   // Found column
   _label = new QLabel( arch->getPath(), this );
-  _label->setMargin(5);
+  _label->setContentsMargins(5,5,5,5);
   grid->addWidget(_label, _numRows, 1);
 
   // Packing column
   _label = new QLabel(this);
-  _label->setMargin(5);
+  _label->setContentsMargins(5,5,5,5);
   _label->setAlignment( Qt::AlignTop );
   if( arch->getIsPacker() && arch->getFound() ) {
     _label->setText( i18n("enabled") );
-    _label->setPaletteForegroundColor("darkgreen");
+    QPalette pal = _label->palette();
+    pal.setColor( _label->foregroundRole(), "darkgreen" );
+    _label->setPalette( pal );
   } else if( arch->getIsPacker() && !arch->getFound() ) {
     _label->setText( i18n("disabled") );
-    _label->setPaletteForegroundColor("red");
+    QPalette pal = _label->palette();
+    pal.setColor( _label->foregroundRole(), "red" );
+    _label->setPalette( pal );
   } else
     _label->setText( "" );
   grid->addWidget(_label, _numRows, 2);
 
   // Unpacking column
   _label = new QLabel(this);
-  _label->setMargin(5);
+  _label->setContentsMargins(5,5,5,5);
   _label->setAlignment( Qt::AlignTop );
   if( arch->getIsUnpacker() && arch->getFound() ) {
     _label->setText( i18n("enabled") );
-    _label->setPaletteForegroundColor("darkgreen");
+    QPalette pal = _label->palette();
+    pal.setColor( _label->foregroundRole(), "darkgreen" );
+    _label->setPalette( pal );
   } else if( arch->getIsUnpacker() && !arch->getFound() ) {
     _label->setText( i18n("disabled") );
-    _label->setPaletteForegroundColor("red");
+    QPalette pal = _label->palette();
+    pal.setColor( _label->foregroundRole(), "red" );
+    _label->setPalette( pal );
   } else
     _label->setText( "" );
   grid->addWidget(_label, _numRows, 3);
 
   // Note column
   _label = new QLabel(arch->getNote(), this);
-  _label->setMargin(5);
-  _label->setAlignment( Qt::AlignTop | Qt::WordBreak ); // wrap words
+  _label->setContentsMargins(5,5,5,5);
+  _label->setAlignment( Qt::AlignTop );
+  _label->setWordWrap( true ); // wrap words
   grid->addWidget(_label, _numRows, 4);
 
   // Apply shared design elements
@@ -235,7 +257,7 @@ bool KrArchiverResultTable::addRow(SearchObject* search, QGridLayout* grid)
 
 void KrArchiverResultTable::website(const QString& url)
 {
-  (void) new KRun(url);
+  (void) new KRun( KUrl( url ), this );
 }
 
 // -----------------------------------------------------------------------------
@@ -246,10 +268,11 @@ KrToolResultTable::KrToolResultTable(QWidget* parent)
 {
   _supported = Krusader::supportedTools(); // get list of available tools
 
-  QValueVector<Application*> vecDiff, vecMail, vecRename, vecChecksum;
+  QList<Application*> vecDiff, vecMail, vecRename, vecChecksum;
   Application* kdiff3         = new Application("kdiff3",        "http://kdiff3.sourceforge.net/", KrServices::cmdExist("kdiff3"));
   Application* kompare        = new Application("kompare",       "http://www.caffeinated.me.uk/kompare/", KrServices::cmdExist("kompare"));
   Application* xxdiff         = new Application("xxdiff",        "http://xxdiff.sourceforge.net/", KrServices::cmdExist("xxdiff"));
+  Application* thunderbird    = new Application("thunderbird",   "http://www.mozilla.org/", KrServices::cmdExist("thunderbird"));
   Application* kmail          = new Application("kmail",         "http://kmail.kde.org/", KrServices::cmdExist("kmail"));
   Application* krename        = new Application("krename",       "http://www.krename.net/", KrServices::cmdExist("krename"));
   Application* md5sum         = new Application("md5sum",        "http://www.gnu.org/software/textutils/textutils.html", KrServices::cmdExist("md5sum"));
@@ -263,6 +286,7 @@ KrToolResultTable::KrToolResultTable(QWidget* parent)
   vecDiff.push_back(kdiff3);
   vecDiff.push_back(kompare);
   vecDiff.push_back(xxdiff);
+  vecMail.push_back(thunderbird);
   vecMail.push_back(kmail);
   vecRename.push_back(krename);
   vecChecksum.push_back(md5sum);
@@ -291,6 +315,7 @@ KrToolResultTable::KrToolResultTable(QWidget* parent)
   addRow(rename, _grid);
   addRow(checksum, _grid);
 
+  delete thunderbird;
   delete kmail;
   delete kompare;
   delete kdiff3;
@@ -318,46 +343,57 @@ KrToolResultTable::~KrToolResultTable()
 bool KrToolResultTable::addRow(SearchObject* search, QGridLayout* grid)
 {
   ApplicationGroup* appGroup = dynamic_cast<ApplicationGroup*>(search);
-  QValueVector<Application*> _apps = appGroup->getAppVec();
+  QList<Application*> _apps = appGroup->getAppVec();
 
   // Name column
   _label = new QLabel(appGroup->getSearchName(), this);
-  _label->setMargin(5);
+  _label->setContentsMargins(5,5,5,5);
   _label->setAlignment( Qt::AlignTop );
   grid->addWidget(_label, _numRows, 0);
 
   // Tool column
-  QVBox* toolBox = new QVBox(this);
-  for( QValueVector<Application*>::Iterator it=_apps.begin(); it!=_apps.end(); it++ )
+  QWidget* toolBoxWidget = new QWidget(this);
+  QVBoxLayout * toolBox = new QVBoxLayout( toolBoxWidget );
+
+  for( QList<Application*>::Iterator it=_apps.begin(); it!=_apps.end(); it++ )
   {
-    KURLLabel* l = new KURLLabel( (*it)->getWebsite(), (*it)->getAppName(), toolBox);
+    KUrlLabel* l = new KUrlLabel( (*it)->getWebsite(), (*it)->getAppName(), toolBoxWidget);
+    toolBox->addWidget( l );
+
     l->setAlignment(Qt::AlignLeft | Qt::AlignTop);
-    l->setMargin(5);
-    connect(l, SIGNAL(leftClickedURL(const QString&)),
+    l->setContentsMargins(5,5,5,5);
+    connect(l, SIGNAL(leftClickedUrl(const QString&)),
                SLOT(website(const QString&)));
   }
-  grid->addWidget(toolBox, _numRows, 1);
+  grid->addWidget(toolBoxWidget, _numRows, 1);
 
   // Found column
-  QVBox* vbox = new QVBox(this);
-  for( QValueVector<Application*>::Iterator it=_apps.begin(); it!=_apps.end(); it++ )
+  QWidget* vboxWidget = new QWidget(this);
+  QVBoxLayout * vbox = new QVBoxLayout( vboxWidget );
+
+  for( QList<Application*>::Iterator it=_apps.begin(); it!=_apps.end(); it++ )
   {
-    _label = new QLabel( (*it)->getPath(), vbox);
-    _label->setMargin(5);
+    _label = new QLabel( (*it)->getPath(), vboxWidget);
+    _label->setContentsMargins(5,5,5,5);
     _label->setAlignment( Qt::AlignTop );
+    vbox->addWidget( _label );
   }
-  grid->addWidget(vbox, _numRows, 2);
+  grid->addWidget(vboxWidget, _numRows, 2);
 
   // Status column
   _label = new QLabel(this);
-  _label->setMargin(5);
+  _label->setContentsMargins(5,5,5,5);
   _label->setAlignment( Qt::AlignTop );
   if( appGroup->getFoundGroup() ) {
     _label->setText( i18n("enabled") );
-    _label->setPaletteForegroundColor("darkgreen");
+    QPalette pal = _label->palette();
+    pal.setColor( _label->foregroundRole(), "darkgreen" );
+    _label->setPalette( pal );
   } else {
     _label->setText( i18n("disabled") );
-    _label->setPaletteForegroundColor("red");
+    QPalette pal = _label->palette();
+    pal.setColor( _label->foregroundRole(), "red" );
+    _label->setPalette( pal );
   }
   grid->addWidget(_label, _numRows, 3);
 
@@ -373,5 +409,5 @@ bool KrToolResultTable::addRow(SearchObject* search, QGridLayout* grid)
 
 void KrToolResultTable::website(const QString& url)
 {
-  (void) new KRun(url);
+  (void) new KRun( KUrl(url), this );
 }
