@@ -34,8 +34,11 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 #include <kmessagebox.h>
 #include <kprocess.h>
 #include <klocale.h>
-#include <kpopupmenu.h>
+#include <kmenu.h>
 #include <kdebug.h>
+#include <kio/jobuidelegate.h>
+#include <kuiserverjobtracker.h>
+#include <ktoolbarpopupaction.h>
 
 // Krusader includes
 #include "../krusader.h"
@@ -44,7 +47,6 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 #include "../krservices.h"
 #include "kmountmangui.h"
 #include <unistd.h>
-#include "../Dialogs/krprogress.h"
 #include "../VFS/krpermhandler.h"
 
 #ifdef _OS_SOLARIS_
@@ -53,13 +55,21 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 #define FSTAB "/etc/fstab"
 #endif
 
+#include <qdir.h>
+#include <solid/block.h>
+#include <solid/opticaldisc.h>
+#include <solid/opticaldrive.h>
+#include <solid/storageaccess.h>
+#include <solid/storagevolume.h>
+
+
 static int __delayedIdx; // ugly: pass the processEvents deadlock
 
 KMountMan::KMountMan() : QObject(), Operational( false ), waiting(false), mountManGui( 0 ) {
    _actions = 0L;
 
 	// added as a precaution, although we use kde services now
-	if( !KrServices::cmdExist( "df" ) || !KrServices::cmdExist( "mount" ) ) {
+	if( !KrServices::cmdExist( "mount" ) ) {
     	Operational = false;
 	} else { 
 		Operational = true;
@@ -76,12 +86,12 @@ KMountMan::KMountMan() : QObject(), Operational( false ), waiting(false), mountM
 	// list of FS that we don't allow to mount/unmount
 	nonmount_fs << "supermount";
 	{
-		KConfigGroupSaver saver(krConfig, "Advanced");
-		QStringList nonmount = QStringList::split(",", krConfig->readEntry("Nonmount Points", _NonMountPoints));
+		KConfigGroup group( krConfig, "Advanced");
+		QStringList nonmount = group.readEntry("Nonmount Points", _NonMountPoints).split(",");
 		nonmount_fs_mntpoint += nonmount;
 		// simplify the white space
 		for ( QStringList::Iterator it = nonmount_fs_mntpoint.begin(); it != nonmount_fs_mntpoint.end(); ++it ) {
-			*it = (*it).simplifyWhiteSpace();
+			*it = (*it).simplified();
 		}
 	}
 	
@@ -104,32 +114,68 @@ void KMountMan::mainWindow() {
    mountManGui = 0; /* for sanity */
 }
 
-KMountPoint *KMountMan::findInListByMntPoint(KMountPoint::List &lst, QString value) {
-	KMountPoint *m;
+KSharedPtr<KMountPoint> KMountMan::findInListByMntPoint(KMountPoint::List &lst, QString value) {
+	if( value.length() > 1 && value.endsWith( "/" ) )
+		value = value.left( value.length() - 1 );
+	
+	KSharedPtr<KMountPoint> m;
 	for (KMountPoint::List::iterator it = lst.begin(); it != lst.end(); ++it) {
 		m = *it;
-		if (m->mountPoint() == value)
+		QString mntPnt = m->mountPoint();
+		if( mntPnt.length() > 1 && mntPnt.endsWith( "/" ) )
+			mntPnt = mntPnt.left( mntPnt.length() - 1 );
+		if (mntPnt == value)
 			return m;
 	}
 	
-	return 0;
+	return KSharedPtr<KMountPoint>();
 }
 
-void KMountMan::jobResult(KIO::Job *job) {
+void KMountMan::jobResult(KJob *job) {
 	waiting = false;
 	if ( job->error() )
-		job->showErrorDialog( 0 );
+		job->uiDelegate()->showErrorMessage();
 }
 
 void KMountMan::mount( QString mntPoint, bool blocking ) {
-	KMountPoint::List possible = KMountPoint::possibleMountPoints(KMountPoint::NeedMountOptions);
-	KMountPoint *m = findInListByMntPoint(possible, mntPoint);
-	if (!m) return;
-	if (blocking)
-	   waiting = true; // prepare to block
-	KIO::SimpleJob *job = KIO::mount(false, m->mountType().local8Bit(), m->mountedFrom(), m->mountPoint(), false);
-	new KrProgress(job);
-	connect(job, SIGNAL(result(KIO::Job* )), this, SLOT(jobResult(KIO::Job* )));
+	QString udi = findUdiForPath( mntPoint, Solid::DeviceInterface::StorageAccess );
+	if( !udi.isNull() )
+	{
+		Solid::Device device( udi );
+		Solid::StorageAccess *access = device.as<Solid::StorageAccess>();
+		if( access && !access->isAccessible() ) {
+			connect( access, SIGNAL( setupDone(Solid::ErrorType, QVariant, const QString &) ),
+			         this, SLOT( slotSetupDone(Solid::ErrorType, QVariant, const QString &) ) );
+			if (blocking)
+				waiting = true; // prepare to block
+			access->setup();
+		}
+	} else {
+		KMountPoint::List possible = KMountPoint::possibleMountPoints(KMountPoint::NeedMountOptions);
+		KSharedPtr<KMountPoint> m = findInListByMntPoint(possible, mntPoint);
+		if (!((bool)m)) return;
+		if (blocking)
+		   waiting = true; // prepare to block
+		
+		// KDE4 doesn't allow mounting devices as user, because they think it's the right behaviour.
+		// I add this patch, as I don't think so.
+		if( geteuid() ) // tries to mount as an user?
+		{
+			KProcess proc;
+			proc << KrServices::fullPathName( "mount" ) << mntPoint;
+			proc.start();
+			if( !blocking )
+				return;
+			proc.waitForFinished(-1); // -1 msec blocks without timeout
+			if ( proc.exitStatus() == QProcess::NormalExit && proc.exitCode() == 0 )
+				return;
+		}
+	
+		KIO::SimpleJob *job = KIO::mount(false, m->mountType().toLocal8Bit(), m->mountedFrom(), m->mountPoint(), false);
+		job->setUiDelegate(new KIO::JobUiDelegate() );
+		KIO::getJobTracker()->registerJob(job);
+		connect(job, SIGNAL(result(KJob* )), this, SLOT(jobResult(KJob* )));
+	}
 	while (blocking && waiting) {
 		qApp->processEvents();
 		usleep( 1000 );
@@ -137,11 +183,39 @@ void KMountMan::mount( QString mntPoint, bool blocking ) {
 }
 
 void KMountMan::unmount( QString mntPoint, bool blocking ) {
-	if (blocking)
-	   waiting = true; // prepare to block
-	KIO::SimpleJob *job = KIO::unmount(mntPoint, false);
-	new KrProgress(job);
-	connect(job, SIGNAL(result(KIO::Job* )), this, SLOT(jobResult(KIO::Job* )));
+	QString udi = findUdiForPath( mntPoint, Solid::DeviceInterface::StorageAccess );
+	if( !udi.isNull() )
+	{
+		Solid::Device device( udi );
+		Solid::StorageAccess *access = device.as<Solid::StorageAccess>();
+		if( access && access->isAccessible() ) {
+			connect( access, SIGNAL( teardownDone(Solid::ErrorType, QVariant, const QString &) ),
+			         this, SLOT( slotTeardownDone(Solid::ErrorType, QVariant, const QString &) ) );
+			access->teardown();
+		}
+	} else {
+		if (blocking)
+		   waiting = true; // prepare to block
+		
+		// KDE4 doesn't allow unmounting devices as user, because they think it's the right behaviour.
+		// I add this patch, as I don't think so.
+		if( geteuid() ) // tries to mount as an user?
+		{
+			KProcess proc;
+			proc << KrServices::fullPathName( "umount" ) << mntPoint;
+			proc.start();
+			if( !blocking )
+				return;
+			proc.waitForFinished(-1); // -1 msec blocks without timeout
+			if ( proc.exitStatus() == QProcess::NormalExit && proc.exitCode() == 0 )
+				return;
+		}
+		
+		KIO::SimpleJob *job = KIO::unmount(mntPoint, false);
+		job->setUiDelegate(new KIO::JobUiDelegate() );
+		KIO::getJobTracker()->registerJob(job);
+		connect(job, SIGNAL(result(KJob* )), this, SLOT(jobResult(KJob* )));
+	}
 	while (blocking && waiting) {
 		qApp->processEvents();
 		usleep( 1000 );
@@ -150,18 +224,18 @@ void KMountMan::unmount( QString mntPoint, bool blocking ) {
 
 KMountMan::mntStatus KMountMan::getStatus( QString mntPoint ) {	
 	KMountPoint::List::iterator it;
-   KMountPoint *m;
+   KSharedPtr<KMountPoint> m;
 	
 	// 1: is it already mounted
 	KMountPoint::List current = KMountPoint::currentMountPoints();
 	m = findInListByMntPoint(current, mntPoint);
-	if (m) 
+	if ((bool)m) 
 		return MOUNTED;
 	
 	// 2: is it a mount point but not mounted?
 	KMountPoint::List possible = KMountPoint::possibleMountPoints();
 	m = findInListByMntPoint(possible, mntPoint);
-	if (m) 
+	if ((bool)m) 
 		return NOT_MOUNTED;
 	
 	// 3: unknown
@@ -190,23 +264,29 @@ void KMountMan::autoMount( QString path ) {
 }
 
 void KMountMan::eject( QString mntPoint ) {
-   KShellProcess proc;
-   proc << KrServices::fullPathName( "eject" ) << "'" + mntPoint + "'";
-   proc.start( KProcess::Block );
-   if ( !proc.normalExit() || proc.exitStatus() != 0 )         // if we failed with eject
-      KMessageBox::information( 0, i18n( "Error ejecting device! You need to have 'eject' in your path." ), i18n( "Error" ), "CantExecuteEjectWarning" );
+   QString udi = findUdiForPath( mntPoint, Solid::DeviceInterface::OpticalDrive );
+   if( udi.isNull() )
+      return;
+
+   Solid::Device dev( udi );
+   Solid::OpticalDrive *drive = dev.as<Solid::OpticalDrive>();
+   if( drive == 0 )
+      return;
+
+   connect(drive, SIGNAL(ejectDone(Solid::ErrorType, QVariant, const QString &)),
+            this, SLOT(slotTeardownDone(Solid::ErrorType, QVariant, const QString &)));
+
+   drive->eject();
 }
 
 // returns true if the path is an ejectable mount point (at the moment CDROM and DVD)
 bool KMountMan::ejectable( QString path ) {
-#if !defined(BSD) && !defined(_OS_SOLARIS_)
-	KMountPoint::List possible = KMountPoint::possibleMountPoints();
-	KMountPoint *m = findInListByMntPoint(possible, path);
-	if (m && (m->mountType()=="iso9660" || m->mountedFrom().left(7)=="/dev/cd" || m->mountedFrom().left(8)=="/dev/dvd"))
-			return KrServices::cmdExist( "eject" );
-#endif
+   QString udi = findUdiForPath( path, Solid::DeviceInterface::OpticalDisc );
+   if( udi.isNull() )
+      return false;
 
-   return false;
+   Solid::Device dev( udi );
+   return dev.as<Solid::OpticalDisc>() != 0;
 }
 
 
@@ -221,24 +301,24 @@ QString KMountMan::convertSize( KIO::filesize_t size ) {
       fsize = ( float ) size / ( float ) 1073741824;
       if ( fsize > 1024 )         // no name for something bigger than tera byte
          // let's call it Zega-Byte, who'll ever find out? :-)
-         s = i18n( "%1 ZB" ).arg( KGlobal::locale() ->formatNumber( fsize / ( float ) 1024, 1 ) );
+         s = i18n( "%1 ZB", KGlobal::locale() ->formatNumber( fsize / ( float ) 1024, 1 ) );
       else
-         s = i18n( "%1 TB" ).arg( KGlobal::locale() ->formatNumber( fsize, 1 ) );
+         s = i18n( "%1 TB", KGlobal::locale() ->formatNumber( fsize, 1 ) );
    }
    // Giga-byte
    else if ( size >= 1048576 ) {
       fsize = ( float ) size / ( float ) 1048576;
-      s = i18n( "%1 GB" ).arg( KGlobal::locale() ->formatNumber( fsize, 1 ) );
+      s = i18n( "%1 GB", KGlobal::locale() ->formatNumber( fsize, 1 ) );
    }
    // Mega-byte
    else if ( size > 1024 ) {
       fsize = ( float ) size / ( float ) 1024;
-      s = i18n( "%1 MB" ).arg( KGlobal::locale() ->formatNumber( fsize, 1 ) );
+      s = i18n( "%1 MB", KGlobal::locale() ->formatNumber( fsize, 1 ) );
    }
    // Kilo-byte
    else {
       fsize = ( float ) size;
-      s = i18n( "%1 KB" ).arg( KGlobal::locale() ->formatNumber( fsize, 0 ) );
+      s = i18n( "%1 KB", KGlobal::locale() ->formatNumber( fsize, 0 ) );
    }
    return s;
 }
@@ -252,20 +332,20 @@ void KMountMan::quickList() {
    }
 
    // clear the popup menu
-   ( ( KToolBarPopupAction* ) krMountMan ) ->popupMenu() ->clear();
+   ( ( KToolBarPopupAction* ) krMountMan ) ->menu() ->clear();
 
    // create lists of current and possible mount points
    KMountPoint::List current = KMountPoint::currentMountPoints();
    KMountPoint::List possible = KMountPoint::possibleMountPoints();
 
-   // create a popupmenu, displaying mountpoints with possible actions
+   // create a menu, displaying mountpoints with possible actions
    // also, populate a small array with the actions
    if ( _actions )
       delete[] _actions;
    _actions = new QString[ possible.size() ];
 
    KMountPoint::List::iterator it;
-   KMountPoint *m;
+   KSharedPtr<KMountPoint> m;
    int idx;
    for ( it = possible.begin(), idx = 0; it != possible.end(); ++it, ++idx ) {
       m = *it;
@@ -288,28 +368,34 @@ void KMountMan::quickList() {
                      " (" + m->mountedFrom() + ")";
 
 
-      ( ( KToolBarPopupAction* ) krMountMan ) ->popupMenu() ->insertItem( text, idx );
+      QAction * act = ( ( KToolBarPopupAction* ) krMountMan ) ->menu() ->addAction( text );
+      act->setData( QVariant( idx ) );
    }
-   connect( ( ( KToolBarPopupAction* ) krMountMan ) ->popupMenu(), SIGNAL( activated( int ) ),
-            this, SLOT( delayedPerformAction( int ) ) );
+   connect( ( ( KToolBarPopupAction* ) krMountMan ) ->menu(), SIGNAL( triggered( QAction * ) ),
+            this, SLOT( delayedPerformAction( QAction * ) ) );
 
 }
 
-void KMountMan::delayedPerformAction( int idx ) {
+void KMountMan::delayedPerformAction( QAction * act ) {
+   int idx = -1;
+   if( act && act->data().canConvert<int>() )
+     idx = act->data().toInt();
    __delayedIdx = idx;
-   QTimer::singleShot(0, this, SLOT(performAction(int)));   
+
+   if ( idx < 0 )
+      return ;
+
+   QTimer::singleShot(0, this, SLOT(performAction()));   
 }
 
-void KMountMan::performAction( int idx ) {
-   while ( qApp->hasPendingEvents() )
-      qApp->processEvents();
+void KMountMan::performAction() {
+   if( _actions == 0 || __delayedIdx < 0 ) // for sanity
+     return;
 
    // ugly !!! take idx from the value put there by delayedPerformAction so 
    // as to NOT DIE because of a processEvents deadlock!!! @#$@!@
-   idx = __delayedIdx;
-   
-   if ( idx < 0 )
-      return ;
+   int idx = __delayedIdx;
+
    bool domount = _actions[ idx ].left( 3 ) == "_M_";
    QString mountPoint = _actions[ idx ].mid( 3 );
    if ( !domount ) { // umount
@@ -321,7 +407,53 @@ void KMountMan::performAction( int idx ) {
    // free memory
    delete[] _actions;
    _actions = 0L;
-   disconnect( ( ( KToolBarPopupAction* ) krMountMan ) ->popupMenu(), SIGNAL( activated( int ) ), 0, 0 );
+   disconnect( ( ( KToolBarPopupAction* ) krMountMan ) ->menu(), SIGNAL( triggered( QAction * ) ), 0, 0 );
+}
+
+QString KMountMan::findUdiForPath( QString path, const Solid::DeviceInterface::Type &expType )
+{
+   KMountPoint::List current = KMountPoint::currentMountPoints();
+   KMountPoint::List possible = KMountPoint::possibleMountPoints();
+   KSharedPtr<KMountPoint> mp = findInListByMntPoint(current, path);
+   if( !(bool)mp )
+   {
+      mp = findInListByMntPoint(possible, path);
+      if( !(bool)mp )
+         return QString::null;
+   }
+   QString dev = QDir( mp->mountedFrom() ).canonicalPath();
+   QList<Solid::Device> storageDevices = Solid::Device::listFromType( Solid::DeviceInterface::Block );
+
+   for( int p = storageDevices.count()-1 ; p >= 0; p-- ) {
+      Solid::Device device = storageDevices[ p ];
+      QString udi     = device.udi();
+
+      Solid::Block * sb = device.as<Solid::Block>();
+      if( sb )
+      {
+         QString devb = QDir( sb->device() ).canonicalPath();
+         if( expType != Solid::DeviceInterface::Unknown && !device.isDeviceInterface( expType ) )
+            continue;
+         if( devb == dev )
+            return udi;
+      }
+   }
+
+   return QString::null;
+}
+
+void KMountMan::slotTeardownDone(Solid::ErrorType error, QVariant errorData, const QString &udi) {
+    waiting = false;
+    if (error != Solid::NoError && errorData.isValid()) {
+        KMessageBox::sorry( krApp, errorData.toString());
+    }
+}
+
+void KMountMan::slotSetupDone(Solid::ErrorType error, QVariant errorData, const QString &udi) {
+    waiting = false;
+    if (error != Solid::NoError && errorData.isValid()) {
+        KMessageBox::sorry( krApp, errorData.toString());
+    }
 }
 
 #include "kmountman.moc"
