@@ -33,6 +33,7 @@ A
 // QT includes
 #include <qobject.h>
 #include <qstring.h>
+#include <qaction.h>
 
 // KDE includes
 #include <kdeversion.h>
@@ -45,6 +46,9 @@ A
 #include <stdlib.h>
 #include <math.h>
 
+#include <solid/device.h>
+#include <solid/solidnamespace.h>
+
 class KMountManGUI;
 
 class KMountMan : public QObject {
@@ -63,7 +67,7 @@ public:
    void unmount( QString mntPoint, bool blocking=true ); // this is probably what you need for unmount
    mntStatus getStatus( QString mntPoint );  // return the status of a mntPoint (if any)
    void autoMount( QString path );           // just call it before refreshing into a dir
-   static void eject( QString mntPoint );
+   void eject( QString mntPoint );
    bool ejectable( QString path );
    QString convertSize( KIO::filesize_t size );
 	bool invalidFilesystem(QString type);
@@ -72,17 +76,21 @@ public:
    KMountMan();
    ~KMountMan();
 
+   QString findUdiForPath( QString path, const Solid::DeviceInterface::Type &expType = Solid::DeviceInterface::Unknown );
+
 public slots:
-   void delayedPerformAction( int idx );
-   void performAction( int idx );
+   void delayedPerformAction( QAction * );
+   void performAction();
    void quickList();
 
 protected slots:
-	void jobResult(KIO::Job *job);
+	void jobResult(KJob *job);
+	void slotTeardownDone(Solid::ErrorType error, QVariant errorData, const QString &udi);
+	void slotSetupDone(Solid::ErrorType error, QVariant errorData, const QString &udi);
 	
 protected:
 	// used internally
-	static KMountPoint *findInListByMntPoint(KMountPoint::List &lst, QString value); 
+	static KSharedPtr<KMountPoint> findInListByMntPoint(KMountPoint::List &lst, QString value); 
    void toggleMount( QString mntPoint ); 
 		
 private:
