@@ -30,66 +30,74 @@ A
 #ifndef KRBRIEFVIEW_H
 #define KRBRIEFVIEW_H
 
+#ifndef QT3_SUPPORT
+#define QT3_SUPPORT 1
+#define KDE3_SUPPORT 1
+#endif
+
 #include "krview.h"
 #include "krviewitem.h"
-#include <kiconview.h>
+#include <k3iconview.h>
+#include <q3header.h>
 #include <qtimer.h>
-
-// extends KrViewProperties to add detailedview-only properties
-class KrBriefViewProperties: public KrViewProperties {
-public:
-	int numberOfColumns; // the number of columns in the view
-};
+#include <QDragMoveEvent>
+#include <QDropEvent>
+#include <QDragLeaveEvent>
+#include <QWheelEvent>
+#include <QResizeEvent>
+#include <QPixmap>
+#include <QMouseEvent>
+#include <QKeyEvent>
+#include <QEvent>
 
 class KrBriefViewItem;
 class QDragMoveEvent;
-class QToolTip;
-class QHeader;
+class Q3Header;
 
 /**
  * KrBriefView implements everthing and anything regarding a brief view in a filemananger.
- * IT MUST USE KrViewItem as the children to it's *KIconView. KrBriefView and KrViewItem are
+ * IT MUST USE KrViewItem as the children to it's *K3IconView. KrBriefView and KrViewItem are
  * tightly coupled and the view will not work with other kinds of items.
  * Apart from this, the view is self-reliant and you can use the vast interface to get whatever
  * information is necessery from it.
  */
-class KrBriefView: public KIconView, public KrView {
+class KrBriefView: public K3IconView, public KrView {
 	friend class KrBriefViewItem;
 	Q_OBJECT
 public:
-	KrBriefView( QHeader *header, QWidget *parent, bool &left, KConfig *cfg = krConfig, const char *name = 0 );
+	KrBriefView( Q3Header *header, QWidget *parent, bool &left, KConfig *cfg = krConfig );
 	virtual ~KrBriefView();
 	virtual inline KrViewItem *getFirst() { return dynamic_cast<KrViewItem*>( firstItem() ); }
 	virtual inline KrViewItem *getLast() { return dynamic_cast<KrViewItem*>( lastItem() ); }
-	virtual inline KrViewItem *getNext( KrViewItem *current ) { return dynamic_cast<KrViewItem*>( dynamic_cast<QIconViewItem*>( current ) ->nextItem() ); }
-	virtual inline KrViewItem *getPrev( KrViewItem *current ) { return dynamic_cast<KrViewItem*>( dynamic_cast<QIconViewItem*>( current ) ->prevItem() ); }
+	virtual inline KrViewItem *getNext( KrViewItem *current ) { return dynamic_cast<KrViewItem*>( dynamic_cast<Q3IconViewItem*>( current ) ->nextItem() ); }
+	virtual inline KrViewItem *getPrev( KrViewItem *current ) { return dynamic_cast<KrViewItem*>( dynamic_cast<Q3IconViewItem*>( current ) ->prevItem() ); }
 	virtual inline KrViewItem *getCurrentKrViewItem() { return dynamic_cast<KrViewItem*>( currentItem() ); }
 	virtual KrViewItem *getKrViewItemAt(const QPoint &vp);
-	virtual inline KrViewItem *findItemByName(const QString &name) { return dynamic_cast<KrViewItem*>( findItem( name, Qt::ExactMatch ) ); }
+	virtual inline KrViewItem *findItemByName(const QString &name) { return dynamic_cast<KrViewItem*>( findItem( name, K3IconView::ExactMatch ) ); }
 	virtual void addItems(vfs* v, bool addUpDir = true);
 	virtual void delItem(const QString &);
 	virtual QString getCurrentItem() const;
 	virtual void makeItemVisible(const KrViewItem * item );
 	virtual void setCurrentItem(const QString& name );
+	virtual void setCurrentKrViewItem( KrViewItem * item );
 	virtual void updateView();
 	virtual void updateItem(KrViewItem* item );
 	virtual void clear();
-	virtual void sort()                        { if( sortDirection() ) sortOrderChanged();KIconView::sort( true ); }
-	virtual void sort( bool ascending )        { if( sortDirection() != ascending ) sortOrderChanged();KIconView::sort( ascending ); }
+	virtual void sort()                        { if( sortDirection() ) sortOrderChanged();K3IconView::sort( true ); }
+	virtual void sort( bool ascending )        { if( sortDirection() != ascending ) sortOrderChanged();K3IconView::sort( ascending ); }
 	virtual void prepareForActive();
 	virtual void prepareForPassive();
 	virtual void saveSettings() {}
 	virtual void restoreSettings() {}
 	virtual QString nameInKConfig() {return _nameInKConfig;}
-	virtual void resizeEvent ( QResizeEvent * );
-
-signals:
-	void middleButtonClicked( KrViewItem *item );
-	void currentChanged( KrViewItem *item );
+	virtual void redraw() { ((QWidget *)parent())->show(); header->show(); viewport()->show(); show(); }
+	virtual int  itemsPerPage();
+	virtual void selectRegion( KrViewItem *, KrViewItem *, bool ) {} // not used
+	
+	static KrView* create( QWidget *parent, bool &left, KConfig *cfg );
 
 protected:
 	virtual void setup();
-	virtual void initProperties();
 	virtual void initOperator();
 	virtual KrViewItem *preAddItem(vfile * vf);
 	virtual bool preDelItem(KrViewItem * item );
@@ -97,10 +105,9 @@ protected:
 	void setColumnNr();
 	void redrawColumns();
 
+	virtual void resizeEvent ( QResizeEvent * );
 	virtual void keyPressEvent( QKeyEvent *e );
-	virtual void imStartEvent( QIMEvent* e );
-	virtual void imEndEvent( QIMEvent *e );
-	virtual void imComposeEvent( QIMEvent *e );
+	virtual void inputMethodEvent(QInputMethodEvent *e);
 	virtual void contentsMousePressEvent( QMouseEvent *e );
 	virtual void contentsMouseReleaseEvent (QMouseEvent *e);
 	virtual void contentsMouseMoveEvent ( QMouseEvent * e );
@@ -112,37 +119,35 @@ protected:
 	virtual void startDrag() { op()->startDrag(); }
 	virtual bool event( QEvent *e );
 	virtual bool eventFilter( QObject * watched, QEvent * e );
+	virtual void wheelEvent( QWheelEvent *e );
 	QMouseEvent * transformMouseEvent( QMouseEvent * );
 
 protected slots:
-	void rename( QIconViewItem *item );
-	void slotClicked( QIconViewItem *item );
-	void slotDoubleClicked( QIconViewItem *item );
-	void slotItemDescription( QIconViewItem * );
-	void slotCurrentChanged( QIconViewItem *item );
-	void handleContextMenu( QIconViewItem*, const QPoint& );
+	void rename( Q3IconViewItem *item );
+	void slotClicked( Q3IconViewItem *item );
+	void slotDoubleClicked( Q3IconViewItem *item );
+	void slotItemDescription( Q3IconViewItem * );
+	void slotCurrentChanged( Q3IconViewItem *item );
+	void handleContextMenu( Q3IconViewItem*, const QPoint& );
 	virtual void renameCurrentItem();
 	virtual void showContextMenu( );
-	void inplaceRenameFinished( QIconViewItem *it );
-	void setNameToMakeCurrent( QIconViewItem *it );
+	void inplaceRenameFinished( Q3IconViewItem *it );
+	void setNameToMakeCurrent( Q3IconViewItem *it );
 	void sortOrderChanged();
-	void slotRightButtonPressed(QIconViewItem*, const QPoint& point);
-	void transformCurrentChanged( QIconViewItem * item ) { emit currentChanged( dynamic_cast<KrViewItem *>(item ) ); }
+	void slotRightButtonPressed(Q3IconViewItem*, const QPoint& point);
+	void transformCurrentChanged( Q3IconViewItem * item ) { op()->emitCurrentChanged( dynamic_cast<KrViewItem *>(item ) ); }
 
 	/**
 	  * used internally to produce the signal middleButtonClicked()
 	 */
-	void slotMouseClicked( int button, QIconViewItem * item, const QPoint & pos );
-	inline void slotExecuted( QIconViewItem* i ) {
+	void slotMouseClicked( int button, Q3IconViewItem * item, const QPoint & pos );
+	inline void slotExecuted( Q3IconViewItem* i ) {
 		QString tmp = dynamic_cast<KrViewItem*>( i ) ->name();
 		op()->emitExecuted( tmp );
 	}
 
 public slots:
 	void refreshColors();
-	void quickSearch( const QString &, int = 0 );
-	void stopQuickSearch( QKeyEvent* );
-	void handleQuickSearchEvent( QKeyEvent* );
 	void changeSortOrder();
 
   
@@ -151,22 +156,22 @@ signals:
 	void gotDrop(QDropEvent *);
 
 private:
-	QHeader * header;
+	Q3Header * header;
 	bool swushSelects;
 	QPoint dragStartPos;
-	QIconViewItem *lastSwushPosition;
+	Q3IconViewItem *lastSwushPosition;
 	KrViewItem *_currDragItem;
 	bool singleClicked;
 	bool modifierPressed;
 	QTime clickTime;
-	QIconViewItem *clickedItem;
+	Q3IconViewItem *clickedItem;
 	QTimer renameTimer;
 	QTimer contextMenuTimer;
 	QPoint contextMenuPoint;
 	KrBriefViewItem *currentlyRenamedItem;
-	QIconViewItem *pressedItem;
+	Q3IconViewItem *pressedItem;
 	QMouseEvent *mouseEvent;
-	QToolTip *toolTip;
+	bool inWheelEvent; // fix recursion crash
 };
 
 #endif
