@@ -31,26 +31,32 @@
 #ifndef KRBRIEFVIEWITEM_H
 #define KRBRIEFVIEWITEM_H
 
+#ifndef QT3_SUPPORT
+#define QT3_SUPPORT 1
+#define KDE3_SUPPORT 1
+#endif
+
 #include "krviewitem.h"
 #include <sys/types.h>
 #include "../VFS/vfile.h"
-#include <kiconview.h>
-#include <qguardedptr.h>
+#include <k3iconview.h>
+#include <qpointer.h>
+#include <QPixmap>
 
 #define FASTER
 
 class QPixmap;
 class KrBriefView;
 
-class KrBriefViewItem : public KIconViewItem, public KrViewItem {
+class KrBriefViewItem : public K3IconViewItem, public KrViewItem {
 friend class KrBriefView;
 friend class KrCalcSpaceDialog;
 public:
-	KrBriefViewItem(KrBriefView *parent, QIconViewItem *after, vfile *vf);
-	inline bool isSelected() const { return KIconViewItem::isSelected(); }
-	inline void setSelected(bool s) { KIconViewItem::setSelected(s); }
+	KrBriefViewItem(KrBriefView *parent, Q3IconViewItem *after, vfile *vf);
+	inline bool isSelected() const { return K3IconViewItem::isSelected(); }
+	inline void setSelected(bool s) { K3IconViewItem::setSelected(s, true); }
 	inline void cancelRename() { removeRenameBox(); }
-	int compare(QIconViewItem *i) const;
+	int compare(Q3IconViewItem *i) const;
 	virtual void repaintItem();
 	static void itemHeightChanged(); // force the items to resize when icon/font size change
 	// TODO: virtual void setup(); // called when iconview needs to know the height of the item
@@ -59,10 +65,14 @@ public:
 	virtual void setPixmap ( const QPixmap &icon ) { itemIcon = icon;}
 #endif
 
+	virtual QRect itemRect() const { return rect(); }
+        virtual void redraw() { repaint(); }
+
+
 protected:
 	virtual void paintItem(QPainter *p, const QColorGroup &cg);
 	virtual void paintFocus(QPainter *p, const QColorGroup &cg);
-	virtual void calcRect ( const QString & text_ = QString::null );
+	virtual void calcRect ( const QString & text_ = QString() );
 
 private:
 #ifdef FASTER
