@@ -30,8 +30,9 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 #include "krcolorcache.h"
 #include "../krusader.h"
 #include "../defaults.h"
-#include <kglobalsettings.h> 
+#include <kcolorscheme.h> 
 #include <qfile.h> 
+#include <QList>
 
 
 // Macro: set target = col, if col is valid
@@ -47,11 +48,11 @@ class KrColorSettingNames
 	static QMap<QString, bool> s_boolNames;
 	static void initialize();
 public:
-	static QValueList<QString> getColorNames();
+	static QStringList getColorNames();
 	static bool isColorNameValid(const QString & settingName);
-	static QValueList<QString> getNumNames();
+	static QStringList getNumNames();
 	static bool isNumNameValid(const QString & settingName);
-	static QValueList<QString> getBoolNames();
+	static QStringList getBoolNames();
 	static bool isBoolNameValid(const QString & settingName);
 } krColorSettingNames;
 
@@ -99,7 +100,7 @@ void KrColorSettingNames::initialize()
 	s_boolNames["Dim Inactive Colors"] = true;
 }
 
-QValueList<QString> KrColorSettingNames::getColorNames()
+QStringList KrColorSettingNames::getColorNames()
 {
 	initialize();
 	return s_colorNames.keys();
@@ -111,7 +112,7 @@ bool KrColorSettingNames::isColorNameValid(const QString & settingName)
 	return s_colorNames.contains(settingName);
 }
 
-QValueList<QString> KrColorSettingNames::getNumNames()
+QStringList KrColorSettingNames::getNumNames()
 {
 	initialize();
 	return s_numNames.keys();
@@ -123,7 +124,7 @@ bool KrColorSettingNames::isNumNameValid(const QString & settingName)
 	return s_numNames.contains(settingName);
 }
 
-QValueList<QString> KrColorSettingNames::getBoolNames()
+QStringList KrColorSettingNames::getBoolNames()
 {
 	initialize();
 	return s_boolNames.keys();
@@ -152,24 +153,27 @@ class KrColorSettingsImpl
 
 void KrColorSettingsImpl::loadFromConfig()
 {
-	krConfig->setGroup("Colors");
-	QValueList<QString> names = KrColorSettingNames::getColorNames();
+	KConfigGroup group( krConfig, "Colors" );
+	QStringList names = KrColorSettingNames::getColorNames();
 	for ( QStringList::Iterator it = names.begin(); it != names.end(); ++it )
 	{
-		m_colorTextValues[*it] = krConfig->readEntry(*it, "");
-		m_colorValues[*it] = krConfig->readColorEntry(*it);
+		m_colorTextValues[*it] = group.readEntry(*it, QString());
+		if (m_colorTextValues[*it].contains(',') == 3)
+			m_colorValues[*it] = group.readEntry(*it, QColor());
+		else
+			m_colorValues[*it] = QColor();
 	}
 	names = KrColorSettingNames::getNumNames();
 	for ( QStringList::Iterator it = names.begin(); it != names.end(); ++it )
 	{
-		if (krConfig->readEntry(*it) != QString::null)
-			m_numValues[*it] = krConfig->readNumEntry(*it);
+		if (group.readEntry(*it, QString()) != QString())
+			m_numValues[*it] = group.readEntry(*it, (long long)0 );
 	}
 	names = KrColorSettingNames::getBoolNames();
 	for ( QStringList::Iterator it = names.begin(); it != names.end(); ++it )
 	{
-		if (krConfig->readEntry(*it) != QString::null)
-			m_boolValues[*it] = krConfig->readBoolEntry(*it);
+		if (group.readEntry(*it, QString()) != QString())
+			m_boolValues[*it] = group.readEntry(*it, false);
 	}
 }
 
@@ -196,7 +200,7 @@ const KrColorSettings & KrColorSettings::operator= (const KrColorSettings & src)
 {
 	if (this == & src)
 		return * this;
-	QValueList<QString> names = KrColorSettingNames::getColorNames();
+	QStringList names = KrColorSettingNames::getColorNames();
 	for ( QStringList::Iterator it = names.begin(); it != names.end(); ++it )
 	{
 		m_impl->m_colorTextValues[*it] = src.m_impl->m_colorTextValues[*it];
@@ -204,16 +208,16 @@ const KrColorSettings & KrColorSettings::operator= (const KrColorSettings & src)
 	}
 	for ( QMap<QString, int>::Iterator it = src.m_impl->m_numValues.begin(); it != src.m_impl->m_numValues.end(); ++it )
 	{
-		m_impl->m_numValues[it.key()] = it.data();
+		m_impl->m_numValues[it.key()] = it.value();
 	}
 	for ( QMap<QString, bool>::Iterator it = src.m_impl->m_boolValues.begin(); it != src.m_impl->m_boolValues.end(); ++it )
 	{
-		m_impl->m_boolValues[it.key()] = it.data();
+		m_impl->m_boolValues[it.key()] = it.value();
 	}
 	return * this;
 }
 
-QValueList<QString> KrColorSettings::getColorNames()
+QList<QString> KrColorSettings::getColorNames()
 {
 	return KrColorSettingNames::getColorNames();
 }
@@ -265,7 +269,7 @@ QString KrColorSettings::getColorTextValue(const QString & settingName) const
 	return m_impl->m_colorTextValues[settingName];
 }
 
-QValueList<QString> KrColorSettings::getNumNames()
+QList<QString> KrColorSettings::getNumNames()
 {
 	return KrColorSettingNames::getNumNames();
 }
@@ -298,7 +302,7 @@ int KrColorSettings::getNumValue(const QString & settingName, int defaultValue)
 	return m_impl->m_numValues[settingName];
 }
 
-QValueList<QString> KrColorSettings::getBoolNames()
+QList<QString> KrColorSettings::getBoolNames()
 {
 	return KrColorSettingNames::getBoolNames();
 }
@@ -378,9 +382,9 @@ getColors is the only method to call. All other are taken from the previous vers
 class KrColorCacheImpl
 {
 	friend class KrColorCache;
-	QMap<QString, QColorGroup> m_cachedColors;
+	QMap<QString, KrColorGroup> m_cachedColors;
 	KrColorSettings m_colorSettings;
-	QColorGroup getColors(const KrColorItemType & type) const;
+	KrColorGroup getColors(const KrColorItemType & type) const;
 	static const QColor & setColorIfContrastIsSufficient(const QColor & background, const QColor & color1, const QColor & color2);
 	QColor getForegroundColor(bool isActive) const;
 	QColor getSpecialForegroundColor(const QString & type, bool isActive) const;
@@ -395,21 +399,29 @@ class KrColorCacheImpl
 	QColor dimColor(QColor color, bool isBackgroundColor) const;
 };
 
-QColorGroup KrColorCacheImpl::getColors(const KrColorItemType & type) const
+KrColorGroup KrColorCacheImpl::getColors(const KrColorItemType & type) const
 {
-	QColorGroup result;
+	KrColorGroup result;
 	if (m_colorSettings.getBoolValue("KDE Default", _KDEDefaultColors))
 	{
 		// KDE default? Getcolors from KGlobalSettings.
 		bool enableAlternateBackground = m_colorSettings.getBoolValue("Enable Alternate Background", _AlternateBackground);
 		QColor background = enableAlternateBackground && type.m_alternateBackgroundColor ? 
-			KGlobalSettings::alternateBackgroundColor()
-			: KGlobalSettings::baseColor();
-		result.setColor(QColorGroup::Base, background);
-		result.setColor(QColorGroup::Background, background);
-		result.setColor(QColorGroup::Text, KGlobalSettings::textColor());
-		result.setColor(QColorGroup::HighlightedText, KGlobalSettings::highlightedTextColor());
-		result.setColor(QColorGroup::Highlight, KGlobalSettings::highlightColor());
+			KColorScheme(QPalette::Active, KColorScheme::View).background(KColorScheme::AlternateBackground).color()
+			: KColorScheme(QPalette::Active, KColorScheme::View).background().color();
+		result.setBackground(background);
+		result.setText( KColorScheme(QPalette::Active, KColorScheme::View).foreground().color() );
+		result.setHighlightedText( KColorScheme(QPalette::Active, KColorScheme::Selection).foreground().color());
+		result.setHighlight( KColorScheme(QPalette::Active, KColorScheme::Selection).background().color());
+
+/*		if (type.m_currentItem && type.m_activePanel)
+		{
+			QColor currentBackground = KColorScheme(QPalette::Active).background(KColorScheme::ActiveBackground).color();
+			// set the background
+			result.setColor(QColorGroup::Highlight, currentBackground);
+			result.setColor(QColorGroup::Base, currentBackground);
+			result.setColor(QColorGroup::Background, currentBackground);
+		}*/
 		return result;
 	}
 	bool markCurrentAlways = m_colorSettings.getBoolValue("Show Current Item Always", _ShowCurrentItemAlways);
@@ -445,11 +457,10 @@ QColorGroup KrColorCacheImpl::getColors(const KrColorItemType & type) const
 	}
 
 	// set the background color
-	result.setColor(QColorGroup::Base, background);
-	result.setColor(QColorGroup::Background, background);
+	result.setBackground(background);
 	
 	// set the foreground color
-	result.setColor(QColorGroup::Text, foreground);
+	result.setText(foreground);
 
 	// now the color of a marked item
 	QColor markedBackground = type.m_alternateBackgroundColor ?
@@ -461,8 +472,8 @@ QColorGroup KrColorCacheImpl::getColors(const KrColorItemType & type) const
 		markedForeground = setColorIfContrastIsSufficient(markedBackground, foreground, background);
 
 	// set it in the color group (different group color than normal foreground!)
-	result.setColor(QColorGroup::HighlightedText, markedForeground);
-	result.setColor(QColorGroup::Highlight, markedBackground);
+	result.setHighlightedText(markedForeground);
+	result.setHighlight(markedBackground);
 
 	// In case the current item is a selected one, set the fore- and background colors for the contrast calculation below
 	if (type.m_selectedItem)
@@ -481,9 +492,8 @@ QColorGroup KrColorCacheImpl::getColors(const KrColorItemType & type) const
 			currentBackground = background;
 		
 		// set the background
-		result.setColor(QColorGroup::Highlight, currentBackground);
-		result.setColor(QColorGroup::Base, currentBackground);
-		result.setColor(QColorGroup::Background, currentBackground);
+		result.setHighlight(currentBackground);
+		result.setBackground(currentBackground);
 		
 		QColor color;
 		if (type.m_selectedItem)
@@ -497,18 +507,17 @@ QColorGroup KrColorCacheImpl::getColors(const KrColorItemType & type) const
 		}
 		
 		// set the foreground
-		result.setColor(QColorGroup::Text, color);
-		result.setColor(QColorGroup::HighlightedText, color);
+		result.setText(color);
+		result.setHighlightedText(color);
 	}
 
 	if (dimBackground && !type.m_activePanel)
 	{
 		// if color dimming is choosen, dim the colors for the inactive panel 
-		result.setColor(QColorGroup::Base, dimColor(result.base(), true));
-		result.setColor(QColorGroup::Background, dimColor(result.base(), true));
-		result.setColor(QColorGroup::Text, dimColor(result.text(), false));
-		result.setColor(QColorGroup::HighlightedText, dimColor(result.highlightedText(), false));
-		result.setColor(QColorGroup::Highlight, dimColor(result.highlight(), true));
+		result.setBackground( dimColor(result.background(), true));
+		result.setText( dimColor(result.text(), false));
+		result.setHighlightedText( dimColor(result.highlightedText(), false));
+		result.setHighlight( dimColor(result.highlight(), true));
 	}
 	return result;
 }
@@ -526,7 +535,7 @@ const QColor & KrColorCacheImpl::setColorIfContrastIsSufficient(const QColor & b
 
 QColor KrColorCacheImpl::getForegroundColor(bool isActive) const
 {
-	QColor color = KGlobalSettings::textColor();
+	QColor color = KColorScheme(QPalette::Active, KColorScheme::View).foreground().color();
 	SETCOLOR(color, m_colorSettings.getColorValue("Foreground"));
 	if (!isActive) SETCOLOR(color, m_colorSettings.getColorValue("Inactive Foreground"));
 	return color;
@@ -546,7 +555,7 @@ QColor KrColorCacheImpl::getSpecialForegroundColor(const QString & type, bool is
 
 QColor KrColorCacheImpl::getBackgroundColor(bool isActive) const
 {
-	QColor color = KGlobalSettings::baseColor();
+	QColor color = KColorScheme(QPalette::Active, KColorScheme::View).background().color();
 	SETCOLOR(color, m_colorSettings.getColorValue("Background"));
 	if (!isActive) SETCOLOR(color, m_colorSettings.getColorValue("Inactive Background"));
 	return color;
@@ -564,9 +573,9 @@ QColor KrColorCacheImpl::getAlternateBackgroundColor(bool isActive) const
 		m_colorSettings.getColorValue("Alternate Background") 
 		: m_colorSettings.getColorValue("Inactive Alternate Background");
 	if (!color.isValid())
-		color = KGlobalSettings::alternateBackgroundColor();
+		color = KColorScheme(QPalette::Active, KColorScheme::View).background(KColorScheme::AlternateBackground).color();
 	if (!color.isValid())
-		color = KGlobalSettings::baseColor();
+		color = KColorScheme(QPalette::Active, KColorScheme::View).background().color();
 	return color;
 }
 
@@ -576,7 +585,7 @@ QColor KrColorCacheImpl::getMarkedForegroundColor(bool isActive) const
 	if (m_colorSettings.getColorTextValue(colorName) == "transparent")
 		return QColor();
 	if (isActive && m_colorSettings.getColorTextValue(colorName) == "")
-		return KGlobalSettings::highlightedTextColor();
+		return KColorScheme(QPalette::Active, KColorScheme::Selection).foreground().color();
 	if (!isActive && m_colorSettings.getColorTextValue(colorName) == "")
 		return getMarkedForegroundColor(true);
 	return m_colorSettings.getColorValue(colorName);
@@ -585,7 +594,7 @@ QColor KrColorCacheImpl::getMarkedForegroundColor(bool isActive) const
 QColor KrColorCacheImpl::getMarkedBackgroundColor(bool isActive) const
 {
 	if (isActive && m_colorSettings.getColorTextValue("Marked Background") == "")
-		return KGlobalSettings::highlightColor();
+		return KColorScheme(QPalette::Active, KColorScheme::Selection).background().color();
 	if (isActive && m_colorSettings.getColorTextValue("Marked Background") == "Background")
 		return getBackgroundColor(true);
 	if (!isActive && m_colorSettings.getColorTextValue("Inactive Marked Background") == "")
@@ -652,7 +661,6 @@ QColor KrColorCacheImpl::getCurrentMarkedForegroundColor(bool isActive) const
 
 QColor KrColorCacheImpl::dimColor(QColor color, bool /* isBackgroundColor */) const
 {
-	krConfig->setGroup("Colors");
 	int dimFactor = m_colorSettings.getNumValue("Dim Factor", 100);
 	QColor targetColor = m_colorSettings.getColorValue("Dim Target Color");
 	if (!targetColor.isValid())
@@ -691,7 +699,7 @@ KrColorCache & KrColorCache::getColorCache()
 	return * m_instance;
 }
 
-void KrColorCache::getColors(QColorGroup  & result, const KrColorItemType & type) const
+void KrColorCache::getColors(KrColorGroup  & result, const KrColorItemType & type) const
 {
 	// for the cache lookup: calculate a unique key from the type
 	char hashKey[128];
@@ -727,14 +735,13 @@ void KrColorCache::getColors(QColorGroup  & result, const KrColorItemType & type
 		m_impl->m_cachedColors[hashKey] = m_impl->getColors(type);
 
 	// get color group from cache
-	const QColorGroup & col = m_impl->m_cachedColors[hashKey];
+	const KrColorGroup & col = m_impl->m_cachedColors[hashKey];
 
 	// copy colors in question to result color group
-	result.setColor(QColorGroup::Base, col.base());
-	result.setColor(QColorGroup::Background, col.base());
-	result.setColor(QColorGroup::Text, col.text());
-	result.setColor(QColorGroup::HighlightedText, col.highlightedText());
-	result.setColor(QColorGroup::Highlight, col.highlight());
+	result.setBackground(col.background());
+	result.setText(col.text());
+	result.setHighlightedText(col.highlightedText());
+	result.setHighlight(col.highlight());
 }
 
 QColor KrColorCache::dimColor(const QColor & color, int dim, const QColor & targetColor)
