@@ -28,18 +28,19 @@
  *                                                                         *
  ***************************************************************************/
 
+#include "krdetailedviewitem.h"
+#include "krdetailedview.h"
 #include "../krusader.h"
 #include "../defaults.h"
 #include "../kicons.h"
 #include "../krusaderview.h"
-#include "krdetailedviewitem.h"
-#include "krdetailedview.h"
 #include "krcolorcache.h"
 #include "listpanel.h"
 #include "../VFS/krpermhandler.h"
 #include <sys/types.h>
 #include <time.h>
 #include <qpainter.h>
+#include <QPixmap>
 #include <pwd.h>
 #include <grp.h>
 #include <stdlib.h>
@@ -57,14 +58,14 @@
 int KrDetailedViewItem::expHeight = 0;
 #endif // FASTER
 
-KrDetailedViewItem::KrDetailedViewItem(KrDetailedView *parent, QListViewItem *after, vfile *vf):
-	KListViewItem(parent, after), KrViewItem(vf, parent->properties()) {
+KrDetailedViewItem::KrDetailedViewItem(KrDetailedView *parent, Q3ListViewItem *after, vfile *vf):
+	K3ListViewItem(parent, after), KrViewItem(vf, parent->properties()) {
 #ifdef FASTER
 	initiated = false;
 	// get the expected height of an item - should be done only once
 	if (expHeight == 0) {
-		KConfigGroupSaver svr(krConfig, "Look&Feel");
-  		expHeight = 2 + (krConfig->readEntry("Filelist Icon Size",_FilelistIconSize)).toInt();
+		KConfigGroup svr( krConfig, "Look&Feel" );
+  		expHeight = 2 + (svr.readEntry("Filelist Icon Size",_FilelistIconSize)).toInt();
 	}
 
 #endif	
@@ -72,12 +73,12 @@ KrDetailedViewItem::KrDetailedViewItem(KrDetailedView *parent, QListViewItem *af
 	// in that case, create a special vfile for that item, and delete it, if needed
 	if (!_vf) {
 		dummyVfile = true;
-		_vf = new vfile("..", 0, "drw-r--r--", 0, false, 0, 0, QString::null, QString::null, 0);
+		_vf = new vfile("..", 0, "drw-r--r--", 0, false, 0, 0, QString(), QString(), 0);
 		
 		setText(COLUMN(Name), "..");
 		setText(COLUMN(Size), i18n("<DIR>") );
       if ( PROPS->displayIcons )
-         setPixmap( COLUMN(Name), FL_LOADICON( "up" ) );
+         setPixmap( COLUMN(Name), FL_LOADICON( "go-up" ) );
       setSelectable( false );
 #ifdef FASTER
 		initiated = true;
@@ -92,7 +93,7 @@ void KrDetailedViewItem::setup() {
 	// idea: when not having pixmaps in the first place, the height of the item is smaller then with
 	// the pixmap. when the pixmap is inserted, the item resizes, thereby making ensureItemVisible()
 	// become 'confused' and stop working. therefore, we set the correct height here and avoid the issue
-	KListViewItem::setup();
+	K3ListViewItem::setup();
 	setHeight(expHeight);
 }
 #endif
@@ -103,7 +104,9 @@ void KrDetailedViewItem::repaintItem() {
     // set text in columns, according to what columns are available
     int id = KrDetailedViewProperties::Unused;
     if ((id = COLUMN(Mime)) != -1) {
-      tmp = KMimeType::mimeType(_vf->vfile_getMime())->comment();
+      KMimeType::Ptr mt = KMimeType::mimeType(_vf->vfile_getMime());
+      if( mt )
+         tmp = mt->comment();
       setText( id, tmp );
     }
     if ((id = COLUMN(Size)) != -1) {
@@ -116,7 +119,7 @@ void KrDetailedViewItem::repaintItem() {
       setText(id, dateTime());
     if ((id = COLUMN(KrPermissions)) != -1) {
       // first, build the krusader permissions
-      tmp=QString::null;
+      tmp=QString();
       switch (_vf->vfile_isReadable()){
         case ALLOWED_PERM: tmp+='r'; break;
         case UNKNOWN_PERM: tmp+='?'; break;
@@ -147,7 +150,7 @@ void KrDetailedViewItem::repaintItem() {
     }
     // if we've got an extention column, clip the name accordingly
     QString name = this->name(), ext = "";
-    if ((id = COLUMN(Extention)) != -1 && !_vf->vfile_isDir()) {
+    if ((id = COLUMN(Extension)) != -1 && !_vf->vfile_isDir()) { 
     	ext = this->extension();
 	name = this->name(false); // request name without extension
       	setText(id, ext);
@@ -179,24 +182,24 @@ void KrDetailedViewItem::paintCell(QPainter *p, const QColorGroup &cg, int colum
   
   QColorGroup _cg(cg);
 
-   // This is ugly! I had to dublicate KListViewItem::paintCell() code, as the
-   // KListViewItem::paintCell() overwrites my color settings. So KrDetailedViewItem::paintCell
-   // must dublicate the KListViewItem::paintCell() code, do the required color settings
-   // and call QListViewItem::paintCell() afterwards (the base class of KListViewItem).
+   // This is ugly! I had to dublicate K3ListViewItem::paintCell() code, as the
+   // K3ListViewItem::paintCell() overwrites my color settings. So KrDetailedViewItem::paintCell
+   // must dublicate the K3ListViewItem::paintCell() code, do the required color settings
+   // and call QListViewItem::paintCell() afterwards (the base class of K3ListViewItem).
    // This tabooed in the object oriented heaven, but necessary here. Blame the KDE team for
    // this really poor paintCell implementation!
    
    const QPixmap *pm = listView()->viewport()->backgroundPixmap();
    if (pm && !pm->isNull())
    {
-         _cg.setBrush(QColorGroup::Base, QBrush(backgroundColor(), *pm));
+         _cg.setBrush(QColorGroup::Base, QBrush(backgroundColor( column ), *pm));
          p->setBrushOrigin( -listView()->contentsX(), -listView()->contentsY() );
    }
    else if (isAlternate())
         if (listView()->viewport()->backgroundMode()==Qt::FixedColor)
-             _cg.setColor(QColorGroup::Background, static_cast< KListView* >(listView())->alternateBackground());
+             _cg.setColor(QColorGroup::Background, static_cast< K3ListView* >(listView())->alternateBackground());
        else
-             _cg.setColor(QColorGroup::Base, static_cast< KListView* >(listView())->alternateBackground());
+             _cg.setColor(QColorGroup::Base, static_cast< K3ListView* >(listView())->alternateBackground());
 
   // end of uglyness
 
@@ -218,21 +221,54 @@ void KrDetailedViewItem::paintCell(QPainter *p, const QColorGroup &cg, int colum
      colorItemType.m_fileType = KrColorItemType::Executable;
   else
      colorItemType.m_fileType = KrColorItemType::File;
-  KrColorCache::getColorCache().getColors(_cg, colorItemType);
+
+  KrColorGroup cols;
+  KrColorCache::getColorCache().getColors(cols, colorItemType);
+  _cg.setColor(QColorGroup::Base, cols.background());
+  _cg.setColor(QColorGroup::Background, cols.background());
+  _cg.setColor(QColorGroup::Text, cols.text());
+  _cg.setColor(QColorGroup::HighlightedText, cols.highlightedText());
+  _cg.setColor(QColorGroup::Highlight, cols.highlight());
+
 	// center the <DIR> thing if needed
 	if(column != COLUMN(Size))
-		QListViewItem::paintCell(p, _cg, column, width, align);
+		Q3ListViewItem::paintCell(p, _cg, column, width, align);
 	else {
   		if (dummyVfile) {
-			QListViewItem::paintCell(p, _cg, column, width, Qt::AlignHCenter); // updir
+			Q3ListViewItem::paintCell(p, _cg, column, width, Qt::AlignHCenter); // updir
   		} else {
     		if (_vf->vfile_isDir() && _vf->vfile_getSize()<=0)
-      		QListViewItem::paintCell(p, _cg, column, width, Qt::AlignHCenter);
-    		else QListViewItem::paintCell(p, _cg, column, width, align); // size
+      		Q3ListViewItem::paintCell(p, _cg, column, width, Qt::AlignHCenter);
+    		else Q3ListViewItem::paintCell(p, _cg, column, width, align); // size
   		}
 	}
 }
 
+void KrDetailedViewItem::paintFocus(QPainter *p, const QColorGroup &cg, const QRect &r)
+{
+   QRect rn = r;
+   if( rn.width() )
+     rn.setWidth( rn.width() - 1 );
+   if( rn.height() )
+     rn.setHeight( rn.height() - 1 );
+
+   KrColorItemType colorItemType;
+   colorItemType.m_activePanel = (dynamic_cast<KrView *>(listView()) == ACTIVE_PANEL->view);
+   colorItemType.m_alternateBackgroundColor = isAlternate();
+   colorItemType.m_currentItem = (listView()->currentItem() == this);
+   colorItemType.m_selectedItem = isSelected();
+   colorItemType.m_fileType = KrColorItemType::File;
+
+   KrColorGroup cols;
+   KrColorCache::getColorCache().getColors(cols, colorItemType);
+   QColor col = cols.text();
+
+   QPen pen( col );
+   pen.setStyle( Qt::DotLine );
+   p->setPen( pen );
+   p->drawRect( rn );
+}
+
 const QColor & KrDetailedViewItem::setColorIfContrastIsSufficient(const QColor & background, const QColor & color1, const QColor & color2)
 {
    #define sqr(x) ((x)*(x))
@@ -244,8 +280,7 @@ const QColor & KrDetailedViewItem::setColorIfContrastIsSufficient(const QColor &
    return color1;
 }
 
-int KrDetailedViewItem::compare(QListViewItem *i,int col,bool ascending ) const {
-  bool ignoreCase = (PROPS->sortMode & KrViewProperties::IgnoreCase);
+int KrDetailedViewItem::compare(Q3ListViewItem *i,int col,bool ascending ) const {
 	bool alwaysSortDirsByName = (PROPS->sortMode & KrViewProperties::AlwaysSortDirsByName);
   int asc = ( ascending ? -1 : 1 );
   KrDetailedViewItem *other = (KrDetailedViewItem *)(i);
@@ -263,24 +298,7 @@ int KrDetailedViewItem::compare(QListViewItem *i,int col,bool ascending ) const
 		
   if (col == COLUMN(Name) ||
 			(alwaysSortDirsByName && thisDir && otherDir )) {
-      // localeAwareCompare doesn't handle names that start with a dot
-		QString text0 = name();
-		QString itext0 = other->name();
-
-		if( ignoreCase )
-		{
-			text0  = text0.lower();
-			itext0 = itext0.lower();
-		}
-
-		if ( isHidden() ) {
-			if ( !other->isHidden() ) return 1*asc;
-		} else if ( other->isHidden() ) return -1*asc;
-		if (!ignoreCase && !PROPS->localeAwareCompareIsCaseSensitive) {
-			// sometimes, localeAwareCompare is not case sensative. in that case,
-			// we need to fallback to a simple string compare (KDE bug #40131)
-			return QString::compare(text0, itext0);
-		} else return QString::localeAwareCompare(text0,itext0);
+    return compareTexts(name(), other->name(), asc, true);
   } else if (col == COLUMN(Size) ) {
       if( VF->vfile_getSize() == other->VF->vfile_getSize() )
         return 0;
@@ -296,13 +314,7 @@ int KrDetailedViewItem::compare(QListViewItem *i,int col,bool ascending ) const
 			return 0;
 		return ((thisPerm > otherPerm) ? 1 : -1);
   } else {
-      QString e1 = (!ignoreCase ? text(col) : text(col).lower());
-      QString e2 = (!ignoreCase ? i->text(col) : i->text(col).lower());
-		if (!ignoreCase && !PROPS->localeAwareCompareIsCaseSensitive) {
-			// sometimes, localeAwareCompare is not case sensative. in that case,
-			// we need to fallback to a simple string compare (KDE bug #40131)
-			return QString::compare(e1, e2);
-		} else return QString::localeAwareCompare(e1, e2);
+     return compareTexts( text(col), i->text(col), asc, false );
   }
 }
 
