@@ -31,36 +31,43 @@
 #ifndef KRDETAILEDVIEWITEM_H
 #define KRDETAILEDVIEWITEM_H
 
+#ifndef QT3_SUPPORT
+#define QT3_SUPPORT 1
+#define KDE3_SUPPORT 1
+#endif
+
 #include "krviewitem.h"
 #include <sys/types.h>
 #include "../VFS/vfile.h"
-#include <klistview.h>
-#include <qguardedptr.h>
+#include <k3listview.h>
+#include <qpointer.h>
+#include <QPixmap>
 
 #define FASTER
 
 class QPixmap;
 class KrDetailedView;
 
-class KrDetailedViewItem : public KListViewItem, public KrViewItem {
+class KrDetailedViewItem : public K3ListViewItem, public KrViewItem {
 friend class KrDetailedView;
-friend class KrCalcSpaceDialog;
 public:
-	KrDetailedViewItem(KrDetailedView *parent, QListViewItem *after, vfile *vf);
-	inline bool isSelected() const { return KListViewItem::isSelected(); }
-	inline void setSelected(bool s) { KListViewItem::setSelected(s); }
-	int compare(QListViewItem *i,int col,bool ascending ) const;
+	KrDetailedViewItem(KrDetailedView *parent, Q3ListViewItem *after, vfile *vf);
+	inline bool isSelected() const { return K3ListViewItem::isSelected(); }
+	inline void setSelected(bool s) { K3ListViewItem::setSelected(s); repaint(); }
+	int compare(Q3ListViewItem *i,int col,bool ascending ) const;
 	void paintCell(QPainter *p, const QColorGroup &cg, int column, int width, int align);
+	void paintFocus(QPainter *p, const QColorGroup &cg, const QRect &r);
 	void repaintItem();
 	static void itemHeightChanged(); // force the items to resize when icon/font size change
 #ifdef FASTER		
 	virtual void setup(); // called when listview needs to know the height of the item
 #endif
-
+        virtual QRect itemRect() const { return listView()->itemRect( this ); }
+        virtual void redraw() { repaintItem(); repaint(); }
 protected:
 	// text() was made protected in order to catch every place where text(x) is used
 	// to gain unlawful information on the object
-	virtual inline QString text(int column) const { return KListViewItem::text(column); }
+	virtual inline QString text(int column) const { return K3ListViewItem::text(column); }
 
 private:
 	static const QColor & setColorIfContrastIsSufficient(const QColor & background, const QColor & color1, const QColor & color2);
