@@ -17,10 +17,10 @@
 
 #include <klocale.h>
 #include <kprocess.h>
-#include <kshred.h>
 #include <krun.h>
 #include <kiconloader.h>
 #include <kmessagebox.h>
+#include <kmimetypetrader.h>
 #include "../krservices.h"
 #include "../defaults.h"
 #include "../MountMan/kmountman.h"
@@ -31,14 +31,20 @@
 #include "panelfunc.h"
 #include "../krusaderview.h"
 #include "../panelmanager.h"
+#include <QPixmap>
+#include <ktoolinvocation.h>
+#include <kactioncollection.h>
 
 void KrPopupMenu::run(const QPoint &pos, ListPanel *panel) {
 	KrPopupMenu menu(panel);
-	int result = menu.exec(pos);
+	QAction * res = menu.exec(pos);
+	int result = -1;
+	if( res && res->data().canConvert<int>() )
+		result = res->data().toInt();
 	menu.performAction(result);
 }
 
-KrPopupMenu::KrPopupMenu(ListPanel *thePanel, QWidget *parent) : KPopupMenu(parent), panel(thePanel), empty(false), 
+KrPopupMenu::KrPopupMenu(ListPanel *thePanel, QWidget *parent) : KMenu(parent), panel(thePanel), empty(false), 
 	multipleSelections(false),actions(0) {
 #ifdef __LIBKONQ__
 	konqMenu = 0;
@@ -47,7 +53,7 @@ KrPopupMenu::KrPopupMenu(ListPanel *thePanel, QWidget *parent) : KPopupMenu(pare
    panel->view->getSelectedKrViewItems( &items );
    if ( items.empty() ) {
    	addCreateNewMenu();
-   	insertSeparator();
+   	addSeparator();
    	addEmptyMenuEntries();
       return;
 	} else if ( items.size() > 1 ) multipleSelections = true;
@@ -56,24 +62,30 @@ KrPopupMenu::KrPopupMenu(ListPanel *thePanel, QWidget *parent) : KPopupMenu(pare
    vfile *vf = panel->func->getVFile(item);
    
    // ------------ the OPEN option - open prefered service
-   insertItem( i18n("Open/Run"), OPEN_ID );
+   QAction * openAct = addAction( i18n("Open/Run") );
+   openAct->setData( QVariant( OPEN_ID ) );
    if ( !multipleSelections ) { // meaningful only if one file is selected
-		changeItem( OPEN_ID, item->icon(), vf->vfile_isExecutable() && !vf->vfile_isDir() ? i18n("Run") : i18n("Open") );
+      openAct->setIcon( item->icon() );
+      openAct->setText( vf->vfile_isExecutable() && !vf->vfile_isDir() ? i18n("Run") : i18n("Open") );
       // open in a new tab (if folder)
       if ( vf->vfile_isDir() ) {
-         insertItem( i18n( "Open in New Tab" ), OPEN_TAB_ID );
-         changeItem( OPEN_TAB_ID, krLoader->loadIcon( "tab_new", KIcon::Panel ), i18n( "Open in New Tab" ) );
+         QAction * openTab = addAction( i18n( "Open in New Tab" ) );
+         openTab->setData( QVariant( OPEN_TAB_ID ) );
+         openTab->setIcon( krLoader->loadIcon( "tab-new", KIconLoader::Panel ) );
+         openTab->setText( i18n( "Open in New Tab" ) );
       }
-      insertSeparator();
+      addSeparator();
    }
 
    // ------------- Preview - normal vfs only ?
-   if ( panel->func->files()->vfs_getType() == vfs::NORMAL ) {
+   if ( panel->func->files()->vfs_getType() == vfs::VFS_NORMAL ) {
       // create the preview popup
       QStringList names;
       panel->getSelectedNames( &names );
       preview.setUrls( panel->func->files() ->vfs_getFiles( &names ) );
-      insertItem( i18n("Preview"), &preview, PREVIEW_ID );
+      QAction *pAct = addMenu( &preview );
+      pAct->setData( QVariant( PREVIEW_ID ) );
+      pAct->setText( i18n("Preview") );
    }
 
    // -------------- Open with: try to find-out which apps can open the file
@@ -81,37 +93,38 @@ KrPopupMenu::KrPopupMenu(ListPanel *thePanel, QWidget *parent) : KPopupMenu(pare
    // have the same mimetype !
    QString mime = panel->func->getVFile(item)->vfile_getMime();
    // check if all the list have the same mimetype
-   for ( unsigned int i = 1; i < items.size(); ++i ) {
-      if ( panel->func->getVFile(( *items.at( i ) )) ->vfile_getMime() != mime ) {
-         mime = QString::null;
+   for ( int i = 1; i < items.size(); ++i ) {
+      if ( panel->func->getVFile( items[ i ] ) ->vfile_getMime() != mime ) {
+         mime = QString();
          break;
       }
    }
    if ( !mime.isEmpty() ) {
-      offers = KServiceTypeProfile::offers( mime );
-      for ( unsigned int i = 0; i < offers.count(); ++i ) {
-         KService::Ptr service = offers[ i ].service();
-         if ( service->isValid() && service->type() == "Application" ) {
-            openWith.insertItem( service->name(), SERVICE_LIST_ID + i );
-            openWith.changeItem( SERVICE_LIST_ID + i, service->pixmap( KIcon::Small ), service->name() );
+      offers = KMimeTypeTrader::self()->query( mime );
+      for ( int i = 0; i < offers.count(); ++i ) {
+         KSharedPtr<KService> service = offers[ i ];
+         if ( service->isValid() && service->isApplication() ) {
+            openWith.addAction( krLoader->loadIcon( service->icon(), KIconLoader::Small ), service->name() )->setData( QVariant( SERVICE_LIST_ID + i ) );
          }
       }
-      openWith.insertSeparator();
+      openWith.addSeparator();
       if ( vf->vfile_isDir() )
-         openWith.insertItem( krLoader->loadIcon( "konsole", KIcon::Small ), i18n( "Terminal" ), OPEN_TERM_ID );
-      openWith.insertItem( i18n( "Other..." ), CHOOSE_ID );
-      insertItem( QPixmap(), &openWith, OPEN_WITH_ID );
-      changeItem( OPEN_WITH_ID, i18n( "Open With" ) );
-      insertSeparator();
+         openWith.addAction( krLoader->loadIcon( "konsole", KIconLoader::Small ), i18n( "Terminal" ))->setData( QVariant( OPEN_TERM_ID ) );
+      openWith.addAction( i18n( "Other..." ) )->setData( QVariant( CHOOSE_ID ) );
+      QAction *owAct = addMenu( &openWith );
+      owAct->setData( QVariant( OPEN_WITH_ID ) );
+      owAct->setText( i18n( "Open With" ) );
+      addSeparator();
    }
 	
 	// --------------- user actions
-   insertItem( i18n("User Actions"), new UserActionPopupMenu( panel->func->files()->vfs_getFile( item->name() ).url() ) );
-   _items.setAutoDelete( true );
+   QAction *uAct = new UserActionPopupMenu( panel->func->files()->vfs_getFile( item->name() ).url() );
+   addAction( uAct );
+   uAct->setText( i18n("User Actions") );
    for ( KrViewItemList::Iterator it = items.begin(); it != items.end(); ++it ) {
 		vfile *file = panel->func->files()->vfs_search(((*it)->name()));
-		KURL url = file->vfile_getUrl();
-		_items.append( new KFileItem( url,  file->vfile_getMime(), file->vfile_getMode() ) );
+		KUrl url = file->vfile_getUrl();
+		_items.append( KFileItem( url,  file->vfile_getMime(), file->vfile_getMode() ) );
    }
    
 #ifdef __LIBKONQ__
@@ -119,88 +132,91 @@ KrPopupMenu::KrPopupMenu(ListPanel *thePanel, QWidget *parent) : KPopupMenu(pare
    actions = new KActionCollection(this);
 	konqMenu = new KonqPopupMenu( KonqBookmarkManager::self(), _items, panel->func->files()->vfs_getOrigin(), *actions, 0, this, 
                            KonqPopupMenu::NoFlags, KParts::BrowserExtension::DefaultPopupItems );
-   insertItem( QPixmap(), konqMenu, KONQ_MENU_ID );
-   changeItem( KONQ_MENU_ID, i18n( "Konqueror Menu" ) );
+   QAction * konqAct = addMenu( konqMenu );
+   konqAct->setData( QVariant( KONQ_MENU_ID ) );
+   konqAct->setText( i18n( "Konqueror Menu" ) );
 #endif
    
 	// ------------- 'create new' submenu
    addCreateNewMenu();
-	insertSeparator();
+	addSeparator();
    
    // ---------- COPY
-   insertItem( i18n( "Copy..." ), COPY_ID );
+   addAction( i18n( "Copy..." ) )->setData( QVariant( COPY_ID ) );
    if ( panel->func->files() ->vfs_isWritable() ) {
       // ------- MOVE
-      insertItem( i18n( "Move..." ), MOVE_ID );
+      addAction( i18n( "Move..." ) )->setData( QVariant( MOVE_ID ) );
       // ------- RENAME - only one file
       if ( !multipleSelections )
-         insertItem( i18n( "Rename" ), RENAME_ID );
+         addAction( i18n( "Rename" ) )->setData( QVariant( RENAME_ID ) );
   
       // -------- MOVE TO TRASH
-      KConfigGroupSaver saver(krConfig, "General");
-      bool trash = krConfig->readBoolEntry( "Move To Trash", _MoveToTrash );
+      KConfigGroup saver( krConfig, "General");
+      bool trash = saver.readEntry( "Move To Trash", _MoveToTrash );
       if( trash )
-        insertItem( i18n( "Move to Trash" ), TRASH_ID );
+        addAction( i18n( "Move to Trash" ) )->setData( QVariant( TRASH_ID ) );
       // -------- DELETE
-      insertItem( i18n( "Delete" ), DELETE_ID );
+      addAction( i18n( "Delete" ) )->setData( QVariant( DELETE_ID ) );
       // -------- SHRED - only one file
-      if ( panel->func->files() ->vfs_getType() == vfs::NORMAL &&
+/*      if ( panel->func->files() ->vfs_getType() == vfs::VFS_NORMAL &&
             !vf->vfile_isDir() && !multipleSelections )
-         insertItem( i18n( "Shred" ), SHRED_ID );
+         addAction( i18n( "Shred" ) )->setData( QVariant( SHRED_ID ) );*/
    }
    
    // ---------- link handling
    // create new shortcut or redirect links - only on local directories:
-   if ( panel->func->files() ->vfs_getType() == vfs::NORMAL ) {
-      insertSeparator();
-      linkPopup.insertItem( i18n( "New Symlink..." ), NEW_SYMLINK_ID );
-      linkPopup.insertItem( i18n( "New Hardlink..." ), NEW_LINK_ID );
+   if ( panel->func->files() ->vfs_getType() == vfs::VFS_NORMAL ) {
+      addSeparator();
+      linkPopup.addAction( i18n( "New Symlink..." ) )->setData( QVariant( NEW_SYMLINK_ID ) );
+      linkPopup.addAction( i18n( "New Hardlink..." ) )->setData( QVariant( NEW_LINK_ID ) );
       if ( panel->func->getVFile(item)->vfile_isSymLink() )
-         linkPopup.insertItem( i18n( "Redirect Link..." ), REDIRECT_LINK_ID);
-      insertItem( QPixmap(), &linkPopup, LINK_HANDLING_ID );
-      changeItem( LINK_HANDLING_ID, i18n( "Link Handling" ) );
+         linkPopup.addAction( i18n( "Redirect Link..." ) )->setData( QVariant( REDIRECT_LINK_ID) );
+      QAction *linkAct = addMenu( &linkPopup );
+      linkAct->setData( QVariant( LINK_HANDLING_ID ) );
+      linkAct->setText( i18n( "Link Handling" ) );
    }
-   insertSeparator();
+   addSeparator();
 
    // ---------- calculate space
-   if ( panel->func->files() ->vfs_getType() == vfs::NORMAL && ( vf->vfile_isDir() || multipleSelections ) )
-      krCalculate->plug( this );
+   if ( panel->func->files() ->vfs_getType() == vfs::VFS_NORMAL && ( vf->vfile_isDir() || multipleSelections ) )
+      addAction( krCalculate  );
 	
 	// ---------- mount/umount/eject
-   if ( panel->func->files() ->vfs_getType() == vfs::NORMAL && vf->vfile_isDir() && !multipleSelections ) {
-      if ( krMtMan.getStatus( panel->func->files() ->vfs_getFile( item->name() ).path( -1 ) ) == KMountMan::MOUNTED )
-         insertItem( i18n( "Unmount" ), UNMOUNT_ID );
-      else if ( krMtMan.getStatus( panel->func->files() ->vfs_getFile( item->name() ).path( -1 ) ) == KMountMan::NOT_MOUNTED )
-         insertItem( i18n( "Mount" ), MOUNT_ID );
-      if ( krMtMan.ejectable( panel->func->files() ->vfs_getFile( item->name() ).path( -1 ) ) )
-         insertItem( i18n( "Eject" ), EJECT_ID );
+   if ( panel->func->files() ->vfs_getType() == vfs::VFS_NORMAL && vf->vfile_isDir() && !multipleSelections ) {
+      if ( krMtMan.getStatus( panel->func->files() ->vfs_getFile( item->name() ).path( KUrl::RemoveTrailingSlash ) ) == KMountMan::MOUNTED )
+         addAction( i18n( "Unmount" ) )->setData( QVariant( UNMOUNT_ID ) );
+      else if ( krMtMan.getStatus( panel->func->files() ->vfs_getFile( item->name() ).path( KUrl::RemoveTrailingSlash ) ) == KMountMan::NOT_MOUNTED )
+         addAction( i18n( "Mount" ) )->setData( QVariant( MOUNT_ID ) );
+      if ( krMtMan.ejectable( panel->func->files() ->vfs_getFile( item->name() ).path( KUrl::RemoveTrailingSlash ) ) )
+         addAction( i18n( "Eject" ) )->setData( QVariant( EJECT_ID ) );
    }
    
    // --------- send by mail
    if ( Krusader::supportedTools().contains( "MAIL" ) && !vf->vfile_isDir() ) {
-      insertItem( i18n( "Send by Email" ), SEND_BY_EMAIL_ID );
+      addAction( i18n( "Send by Email" ) )->setData( QVariant( SEND_BY_EMAIL_ID ) );
    }
    
    // --------- synchronize
    if ( panel->view->numSelected() ) {
-      insertItem( i18n( "Synchronize Selected Files..." ), SYNC_SELECTED_ID );
+      addAction( i18n( "Synchronize Selected Files..." ) )->setData( QVariant( SYNC_SELECTED_ID ) );
    }
    
    // --------- copy/paste
-   insertSeparator();
-   insertItem( i18n( "Copy to Clipboard" ), COPY_CLIP_ID );
+   addSeparator();
+   addAction( i18n( "Copy to Clipboard" ) )->setData( QVariant( COPY_CLIP_ID ) );
    if ( panel->func->files() ->vfs_isWritable() )
    {
-     insertItem( i18n( "Cut to Clipboard" ), MOVE_CLIP_ID );
-     insertItem( i18n( "Paste from Clipboard" ), PASTE_CLIP_ID );
+     addAction( i18n( "Cut to Clipboard" ) )->setData( QVariant( MOVE_CLIP_ID ) );
+     addAction( i18n( "Paste from Clipboard" ) )->setData( QVariant( PASTE_CLIP_ID ) );
    }
-   insertSeparator();
+   addSeparator();
    
    // --------- properties
-   krProperties->plug( this );
+   addAction( krProperties );
 }
 
 KrPopupMenu::~KrPopupMenu() {
+	_items.clear();
 	if (actions) delete actions;
 #ifdef __LIBKONQ__
 	if (konqMenu) delete konqMenu;
@@ -208,21 +224,22 @@ KrPopupMenu::~KrPopupMenu() {
 }
 
 void KrPopupMenu::addEmptyMenuEntries() {
-	insertItem( i18n( "Paste from Clipboard" ), PASTE_CLIP_ID );
+	addAction( i18n( "Paste from Clipboard" ) )->setData( QVariant( PASTE_CLIP_ID ) );
 }
 
 void KrPopupMenu::addCreateNewMenu() {
-	createNewPopup.insertItem( krLoader->loadIcon( "folder", KIcon::Small ), i18n("Folder..."), MKDIR_ID);
-	createNewPopup.insertItem( krLoader->loadIcon( "txt", KIcon::Small ), i18n("Text File..."), NEW_TEXT_FILE_ID);
+	createNewPopup.addAction( krLoader->loadIcon( "folder", KIconLoader::Small ), i18n("Folder...") )->setData( QVariant( MKDIR_ID) );
+	createNewPopup.addAction( krLoader->loadIcon( "txt", KIconLoader::Small ), i18n("Text File...") )->setData( QVariant( NEW_TEXT_FILE_ID) );
 	
-	insertItem( QPixmap(), &createNewPopup, CREATE_NEW_ID);
-	changeItem( CREATE_NEW_ID, i18n( "Create New" ) );
+	QAction *newAct = addMenu( &createNewPopup );
+	newAct->setData( QVariant( CREATE_NEW_ID) );
+	newAct->setText( i18n( "Create New" ) );
 	
 }
 
 void KrPopupMenu::performAction(int id) {
-   KURL u;
-   KURL::List lst;
+   KUrl u;
+   KUrl::List lst;
 
    switch ( id ) {
          case - 1 : // the user clicked outside of the menu
@@ -235,7 +252,7 @@ void KrPopupMenu::performAction(int id) {
          case OPEN_ID :
          	for ( KrViewItemList::Iterator it = items.begin(); it != items.end(); ++it ) {
             	u = panel->func->files()->vfs_getFile( ( *it ) ->name() );
-            	KRun::runURL( u, panel->func->getVFile(item)->vfile_getMime() );
+            	KRun::runUrl( u, panel->func->getVFile(item)->vfile_getMime(), parentWidget() );
          	}
          	break;
          case COPY_ID :
@@ -254,24 +271,24 @@ void KrPopupMenu::performAction(int id) {
          	panel->func->deleteFiles( true );
          	break;
          case EJECT_ID :
-         	KMountMan::eject( panel->func->files() ->vfs_getFile( item->name() ).path( -1 ) );
+         	krMtMan.eject( panel->func->files() ->vfs_getFile( item->name() ).path( KUrl::RemoveTrailingSlash ) );
          	break;
-         case SHRED_ID :
+/*         case SHRED_ID :
             if ( KMessageBox::warningContinueCancel( krApp,
-                 i18n("<qt>Do you really want to shred <b>%1</b>? Once shred, the file is gone forever!</qt>").arg(item->name()),
-                 QString::null, KStdGuiItem::cont(), "Shred" ) == KMessageBox::Continue )
-               KShred::shred( panel->func->files() ->vfs_getFile( item->name() ).path( -1 ) );
-         	break;
+                 i18n("<qt>Do you really want to shred <b>%1</b>? Once shred, the file is gone forever!</qt>", item->name()),
+                 QString(), KStandardGuiItem::cont(), KStandardGuiItem::cancel(), "Shred" ) == KMessageBox::Continue )
+               KShred::shred( panel->func->files() ->vfs_getFile( item->name() ).path( KUrl::RemoveTrailingSlash ) );
+         	break;*/
          case OPEN_KONQ_ID :
-         	kapp->startServiceByDesktopName( "konqueror", panel->func->files() ->vfs_getFile( item->name() ).url() );
+         	KToolInvocation::startServiceByDesktopName( "konqueror", panel->func->files() ->vfs_getFile( item->name() ).url() );
          	break;
          case CHOOSE_ID : // open-with dialog
          	u = panel->func->files() ->vfs_getFile( item->name() );
          	lst.append( u );
-         	KRun::displayOpenWithDialog( lst );
+         	KRun::displayOpenWithDialog( lst, parentWidget() );
          	break;
          case MOUNT_ID :
-         	krMtMan.mount( panel->func->files() ->vfs_getFile( item->name() ).path( -1 ) );
+         	krMtMan.mount( panel->func->files() ->vfs_getFile( item->name() ).path( KUrl::RemoveTrailingSlash ) );
          	break;
          case NEW_LINK_ID :
          	panel->func->krlink( false );
@@ -283,7 +300,7 @@ void KrPopupMenu::performAction(int id) {
          	panel->func->redirectLink();
          	break;
          case UNMOUNT_ID :
-         	krMtMan.unmount( panel->func->files() ->vfs_getFile( item->name() ).path( -1 ) );
+         	krMtMan.unmount( panel->func->files() ->vfs_getFile( item->name() ).path( KUrl::RemoveTrailingSlash ) );
          	break;
          case COPY_CLIP_ID :
          	panel->func->copyToClipboard();
@@ -292,17 +309,21 @@ void KrPopupMenu::performAction(int id) {
          	panel->func->copyToClipboard( true );
          	break;
          case PASTE_CLIP_ID :
-				panel->func->pasteFromClipboard();
+		panel->func->pasteFromClipboard();
          	break;
          case SEND_BY_EMAIL_ID :
-         	SLOTS->sendFileByEmail( panel->func->files() ->vfs_getFile( item->name() ).url() );
-         	break;
-			case MKDIR_ID :
-				SLOTS->mkdir();
-				break;
-			case NEW_TEXT_FILE_ID:
-				SLOTS->editDlg();
-				break;
+		{
+			QStringList fileNames;
+			panel->getSelectedNames( &fileNames );
+	         	SLOTS->sendFileByEmail( *panel->func->files() ->vfs_getFiles( &fileNames ) );
+        	 	break;
+		}
+	case MKDIR_ID :
+		SLOTS->mkdir();
+		break;
+	case NEW_TEXT_FILE_ID:
+		SLOTS->editDlg();
+		break;
          case SYNC_SELECTED_ID :
          	{
 				QStringList selectedNames;
@@ -322,32 +343,22 @@ void KrPopupMenu::performAction(int id) {
          	}
          	break;
          case OPEN_TERM_ID :
-         	QString save = getcwd( 0, 0 );
-         	chdir( panel->func->files() ->vfs_getFile( item->name() ).path( -1 ).local8Bit() );
-				KProcess proc;
-				{
-				KConfigGroupSaver saver(krConfig, "General");
-         	QString term = krConfig->readEntry( "Terminal", _Terminal );
-         	proc << KrServices::separateArgs( term );
-         	if ( !panel->func->getVFile(item)->vfile_isDir() ) proc << "-e" << item->name();
-         	if ( term.contains( "konsole" ) ) {   /* KDE 3.2 bug (konsole is killed by pressing Ctrl+C) */
-         	                                      /* Please remove the patch if the bug is corrected */
-					proc << "&";
-            	proc.setUseShell( true );
-         	}
-         	if ( !proc.start( KProcess::DontCare ) )
-               KMessageBox::sorry( krApp, i18n( "Can't open \"%1\"" ).arg(term) );
-				} // group-saver is blown out of scope here
-         	chdir( save.local8Bit() );
-         	break;
+             {
+                 QStringList args;
+                 if ( !panel->func->getVFile(item)->vfile_isDir() )
+                     args << item->name();
+                 SLOTS->runTerminal( panel->func->files() ->vfs_getFile(item->name()).path(),
+                                     args );
+             }
+             break;
 	}
    
    // check if something from the open-with-offered-services was selected
    if ( id >= SERVICE_LIST_ID ) {
       QStringList names;
       panel->getSelectedNames( &names );
-      KRun::run( *( offers[ id - SERVICE_LIST_ID ].service() ),
-                 *( panel->func->files() ->vfs_getFiles( &names ) ) );
+      KRun::run( *( offers[ id - SERVICE_LIST_ID ] ),
+                 *( panel->func->files() ->vfs_getFiles( &names ) ), parentWidget() );
    }
 }
 
