@@ -1,9 +1,8 @@
 #ifndef KRPOPUPMENU_H
 #define KRPOPUPMENU_H
 
-#include <kpopupmenu.h>
+#include <kmenu.h>
 #include <kurl.h>
-#include <kuserprofile.h>
 #include "listpanel.h"
 #include "krpreviewpopup.h"
 #include "../UserAction/useractionpopupmenu.h"
@@ -13,7 +12,7 @@
 #endif
 
 // should be renamed to KrContextMenu or similar
-class KrPopupMenu : public KPopupMenu {
+class KrPopupMenu : public KMenu {
 	Q_OBJECT
 public:
 	static void run(const QPoint &pos, ListPanel *panel);
@@ -62,13 +61,13 @@ protected:
 private:
 	ListPanel *panel;
 	bool empty, multipleSelections;
-	KPopupMenu openWith, linkPopup, createNewPopup;
+	KMenu openWith, linkPopup, createNewPopup;
    KrPreviewPopup preview;
    KActionCollection *actions;
    KrViewItemList items; // list of selected items
    KrViewItem *item; // the (first) selected item
    KFileItemList _items;
-   QValueList<KServiceOffer> offers;
+   KService::List offers;
 #ifdef __LIBKONQ__
    KonqPopupMenu *konqMenu;
 #endif
