@@ -32,7 +32,10 @@
 
 #include <qpixmap.h>
 #include <qvariant.h>
-#include <qdict.h>
+#include <qhash.h>
+#include <QDropEvent>
+#include <QList>
+#include <QModelIndex>
 #include "../krusader.h"
 #include "../VFS/vfile.h"
 #include "../VFS/vfs.h"
@@ -40,9 +43,14 @@
 
 #include <kdebug.h>
 
+#define MAX_BRIEF_COLS 5
+
+
 class KrView;
 class KrViewItem;
-typedef QValueList<KrViewItem*> KrViewItemList;
+class KrQuickSearch;
+class QModelIndex;
+typedef QList<KrViewItem*> KrViewItemList;
 
 // KrViewProperties
 // This class is an interface class between KrView and KrViewItem
@@ -54,18 +62,29 @@ typedef QValueList<KrViewItem*> KrViewItemList;
 // Every property that the item needs to know about the view must be here!
 class KrViewProperties {
 public:
+	KrViewProperties() {
+		filter = KrViewProperties::All;
+		filterMask = KRQuery( "*" );
+	}
+	
 	enum SortSpec { Name=0x1, Ext=0x2, Size=0x4, Type=0x8, Modified=0x10, Permissions=0x20,
-						KrPermissions=0x40, Owner=0x80, Group=0x100, Descending=0x200,
-						DirsFirst=0x400, IgnoreCase=0x800, AlwaysSortDirsByName=0x1000 };
+                        KrPermissions=0x40, Owner=0x80, Group=0x100, Descending=0x200,
+                        DirsFirst=0x400, IgnoreCase=0x800, AlwaysSortDirsByName=0x1000 };
+	enum SortMethod { Alphabetical=0x1, AlphabeticalNumbers=0x2,
+	                  CharacterCode=0x4, CharacterCodeNumbers=0x8, Krusader=0x10 };
 	enum FilterSpec { Dirs=0x1, Files=0x2, All=0x3, Custom=0x4, ApplyToDirs=0x8 };
 	
+	bool numericPermissions;        // show full permission column as octal numbers
+
 	bool displayIcons;	// true if icons should be displayed in this view
 	SortSpec sortMode;	// sort specifications
+	SortMethod sortMethod;  // sort method for names and extensions
 	FilterSpec filter;	// what items to show (all, custom, exec)
 	KRQuery filterMask;	// what items to show (*.cpp, *.h etc)
 	bool localeAwareCompareIsCaseSensitive; // mostly, it is not! depends on LC_COLLATE
 	bool humanReadableSize;		// display size as KB, MB or just as a long number
 	QStringList atomicExtensions;	// list of strings, which will be treated as one extension. Must start with a dot.
+	int numberOfColumns;    // the number of columns in the brief view
 };
 
 // operator can handle two ways of doing things:
@@ -82,16 +101,30 @@ public:
 	QWidget *widget() const { return _widget; }
 	void startDrag();
 	
-	void emitSelectionChanged() { emit selectionChanged(); }
 	void emitGotDrop(QDropEvent *e) { emit gotDrop(e); }
 	void emitLetsDrag(QStringList items, QPixmap icon ) { emit letsDrag(items, icon); }
 	void emitItemDescription(QString &desc) { emit itemDescription(desc); }
 	void emitContextMenu(const QPoint &point) { emit contextMenu(point); }
 	void emitEmptyContextMenu(const QPoint &point) { emit emptyContextMenu(point); }
    void emitRenameItem(const QString &oldName, const QString &newName) { emit renameItem(oldName, newName); }
-   void emitExecuted( QString &name ) { emit executed(name); }
+   void emitExecuted( const QString &name ) { emit executed(name); }
+   void emitGoInside( const QString &name ) { emit goInside(name); }
    void emitNeedFocus() { emit needFocus(); }
-	
+   void emitMiddleButtonClicked( KrViewItem *item ) { emit middleButtonClicked( item ); }
+   void emitCurrentChanged( KrViewItem *item ) { emit currentChanged( item ); }
+   void prepareForPassive();
+   void setQuickSearch( KrQuickSearch *quickSearch );
+   bool handleKeyEvent (QKeyEvent *e);
+   KrQuickSearch * quickSearch() { return _quickSearch; }
+   void setMassSelectionUpdate( bool upd );
+   bool isMassSelectionUpdate() { return _massSelectionUpdate; }
+
+public slots:
+   void emitSelectionChanged() { if( !_massSelectionUpdate ) emit selectionChanged(); }
+   void quickSearch( const QString &, int = 0 );
+   void stopQuickSearch( QKeyEvent* );
+   void handleQuickSearchEvent( QKeyEvent* );
+
 signals:
 	void selectionChanged();
 	void gotDrop( QDropEvent *e );
@@ -100,14 +133,21 @@ signals:
    void contextMenu( const QPoint &point );
    void emptyContextMenu( const QPoint& point );
    void renameItem( const QString &oldName, const QString &newName );
-   void executed( QString &name );
+   void executed( const QString &name );
+   void goInside( const QString &name );
    void needFocus();
+   void middleButtonClicked( KrViewItem *item );
+   void currentChanged( KrViewItem *item );
 
 	
 protected:
 	// never delete those
 	KrView *_view;
 	QWidget *_widget;
+
+private:
+	KrQuickSearch *_quickSearch;
+	bool _massSelectionUpdate;
 };
 
 /****************************************************************************
@@ -115,8 +155,7 @@ protected:
  *
  * You always hold a pointer to KrView, thus you can only use functions declared
  * in this class. If you need something else, either this class is missing something
- * or you are ;-) Using a true name (like dynamic_cast<KrDetailedViewItem*>) should be
- * needed only when doing new(), or connect() - see example in listpanel.cpp
+ * or you are ;-)
  *
  * The functions you'd usually want:
  * 1) getSelectedItems - returns all selected items, or (if none) the current item.
@@ -133,6 +172,7 @@ protected:
  */ 
 class KrView {
 friend class KrViewItem;
+friend class KrViewOperator;
 public:
   // instantiating a new view
   // 1. new KrView
@@ -142,7 +182,8 @@ public:
   virtual void init();
 
 protected:
-  virtual void initProperties() { qFatal("Please implement your own initProperties() method"); }
+  virtual void initProperties();
+  virtual KrViewProperties * createViewProperties() { return new KrViewProperties(); }
   virtual void initOperator() { qFatal("Please implement your own initOperator() method"); }
   virtual void setup() { qFatal("Please implement your own setup() method"); }
   
@@ -150,6 +191,12 @@ protected:
   // Every view must implement the following functions //
   ///////////////////////////////////////////////////////
 public:
+  // interview related functions
+  virtual QModelIndex getCurrentIndex()                 { return QModelIndex(); }
+  virtual bool        isSelected( const QModelIndex & ) { return false; }
+  virtual bool        ensureVisibilityAfterSelect()     { return true; }
+  virtual void        selectRegion( KrViewItem *, KrViewItem *, bool ) = 0;
+
   virtual KrViewItem *getFirst() = 0;
   virtual KrViewItem *getLast() = 0;
   virtual KrViewItem *getNext(KrViewItem *current) = 0;
@@ -160,6 +207,7 @@ public:
   virtual void addItems(vfs* v, bool addUpDir = true) = 0; // kill me, kill me now
   virtual QString getCurrentItem() const = 0;
   virtual void setCurrentItem(const QString& name) = 0;
+  virtual void setCurrentKrViewItem(KrViewItem *item) = 0;
   virtual void makeItemVisible(const KrViewItem *item) = 0;
   virtual void clear();
   virtual void updateView() = 0;
@@ -167,10 +215,14 @@ public:
   virtual void sort() = 0;
   virtual void saveSettings() = 0;
   virtual void restoreSettings() = 0;
+  virtual void refreshColors() = 0;
+  virtual void redraw() = 0;
+  virtual bool handleKeyEvent (QKeyEvent *e);
   virtual void prepareForActive() { _focused = true; }
-  virtual void prepareForPassive() { _focused = false; }
+  virtual void prepareForPassive() { _focused = false; _operator->prepareForPassive(); }
   virtual void renameCurrentItem(); // Rename current item. returns immediatly
   virtual QString nameInKConfig() const { return _nameInKConfig; }
+  virtual int  itemsPerPage() { return 0; }
 
 protected:
 	virtual KrViewItem *preAddItem(vfile *vf) = 0;
@@ -205,12 +257,15 @@ public:
   virtual QString statistics();
   virtual const KrViewProperties* properties() const { return _properties; }
   virtual KrViewOperator* op() const { return _operator; }
+  virtual bool isFocused() const { return _focused; }
+  void changeSelection(const KRQuery& filter, bool select, bool includeDirs = false);
 
   /////////////////////////////////////////////////////////////
   // the following functions have a default and minimalistic //
   // implementation, and may be re-implemented if needed     //
   /////////////////////////////////////////////////////////////
   virtual void setSortMode(KrViewProperties::SortSpec mode) { _properties->sortMode = mode; }
+  virtual void sortModeUpdated(KrViewProperties::SortSpec mode) { _properties->sortMode = mode; }
   virtual KrViewProperties::SortSpec sortMode() const { return _properties->sortMode; }
   virtual void setFilter(KrViewProperties::FilterSpec filter) { _properties->filter = filter; }
   virtual KrViewProperties::FilterSpec filter() const { return _properties->filter; }
@@ -221,10 +276,11 @@ public:
 
   // todo: what about selection modes ???
   virtual ~KrView();
+  static QPixmap getIcon(vfile *vf);
+
 protected:
   KrView(KConfig *cfg = krConfig);
-  static QPixmap getIcon(vfile *vf);
-  void changeSelection(const KRQuery& filter, bool select, bool includeDirs = false);
+  bool handleKeyEventInt (QKeyEvent *e);
 
 
 protected:
@@ -237,7 +293,7 @@ protected:
   bool _left;
   KrViewProperties *_properties;
   KrViewOperator *_operator;
-  QDict<KrViewItem> _dict;
+  QHash<QString, KrViewItem*> _dict;
   bool _focused;
   QString _nameInKConfig;
 };
