@@ -34,12 +34,14 @@
 #include <kio/global.h>
 #include "../VFS/vfile.h"
 #include "krview.h"
+#include <QPixmap>
 
 class QString;
 class QPixmap;
 
 class KrViewItem {
 	friend class KrView;
+	friend class KrCalcSpaceDialog;
 
 public:
 	virtual const QString& name(bool withExtension=true) const;
@@ -50,20 +52,23 @@ public:
 	virtual bool isSelected() const = 0;
 	virtual void setSelected( bool s ) = 0;
 	virtual QPixmap icon();
+	virtual QRect itemRect() const = 0;
+	virtual void redraw() = 0;
 	
 	KrViewItem(vfile *vf, const KrViewProperties* properties);
 	virtual ~KrViewItem() { if (dummyVfile) delete _vf; }
 		
 	// DON'T USE THOSE OUTSIDE THE VIEWS!!!
 	inline const vfile* getVfile() const { return _vf; }
+	inline void setVfile(vfile *vf) { _vf = vf; }
 	inline vfile* getMutableVfile() { return _vf; }
 	inline bool isDummy() const { return dummyVfile; }
 	inline bool isHidden() const { return _hidden; }
 
-protected:
 	// used INTERNALLY when calculation of dir size changes the displayed size of the item
 	inline void setSize(KIO::filesize_t size) { _vf->vfile_setSize(size); }
 	
+protected:
 	vfile* _vf;			// each view item holds a pointer to a corrosponding vfile for fast access	
 	bool dummyVfile;	// used in case our item represents the ".." (updir) item
 	const KrViewProperties* _viewProperties;
@@ -71,6 +76,13 @@ protected:
 	bool _hidden;
 	QString _name;
 	QString _extension;
+
+	// return -1, 0, 1 if aS1 is less, equal or greater than aS2
+	int compareTexts(QString aS1, QString aS2, int asc, bool isName) const;
+	int compareTextsAlphabetical(QString& aS1, QString& aS2, bool aNumbers) const;
+	int compareTextsCharacterCode(QString& aS1, QString& aS2, bool aNumbers) const;
+	int compareTextsKrusader(QString& aS1, QString& aS2, int asc, bool isName) const;
+
 };
 
 #endif
