@@ -35,7 +35,6 @@
 #include "listpanel.h"
 #include "krviewitem.h"
 #include <qobject.h>
-#include <qvaluestack.h>
 #include <qtimer.h>
 
 class ListPanelFunc : public QObject{
@@ -44,11 +43,13 @@ friend class ListPanel;
 public slots:
 	inline vfile* getVFile(KrViewItem *item) { return files()->vfs_search(item->name()); }
 	inline vfile* getVFile(const QString& name) { return files()->vfs_search(name); }
-	void execute(QString&);
-	void openUrl(const KURL& path, const QString& nameToMakeCurrent = QString::null);
-	void openUrl(const QString& path, const QString& nameToMakeCurrent = QString::null);
-   void immediateOpenUrl( const KURL& path);
-   void doOpenUrl();
+	void execute(const QString&);
+	void goInside(const QString&);
+	void openUrl(const KUrl& path, const QString& nameToMakeCurrent = QString());
+	void openUrl(const QString& path, const QString& nameToMakeCurrent = QString());
+	void popErronousUrl();
+	void immediateOpenUrl( const KUrl& path);
+	void doOpenUrl();
 	void refresh();
 	void rename(const QString &oldname, const QString &newname);
 
@@ -69,11 +70,11 @@ public:
 	void view();
 	void rename();
 	void mkdir();
-	void moveFiles();
+	void moveFiles( bool enqueue=false );
 	void pack();
 	void unpack();
 	void testArchive();
-	void copyFiles();
+	void copyFiles( bool enqueue=false );
 	void deleteFiles(bool reallyDelete=false);
 	void calcSpace(); // calculate the occupied space and show it in a dialog
 	void createChecksum();
@@ -90,16 +91,17 @@ public:
 	inline ListPanelFunc* otherFunc(){ return panel->otherPanel->func; }
 
 private:
-	KURL getVirtualBaseURL();
+	KUrl getVirtualBaseURL();
 
 protected:
 	ListPanel*           panel;     // our ListPanel
-	QValueStack<KURL>    urlStack;  // Path stack for the "back" button
+	QList<KUrl>          urlStack;  // Path stack for the "go-previous" button
 	bool                 inRefresh; // true when we are in refresh()
 	vfs*                 vfsP;      // pointer to vfs.
 	QTimer               delayTimer;
-	KURL                 delayURL;
+	KUrl                 delayURL;
 	QString              nameToMakeCurrent;
+	bool                 canGoBack();
 };
 
 #endif
