@@ -29,6 +29,7 @@
  ***************************************************************************/
 
 #include "../krusader.h"
+#include "../krslots.h"
 #include "../defaults.h"
 #include "../panelmanager.h"
 #include "../VFS/vfs.h"
@@ -38,53 +39,150 @@
 #include "../Dialogs/krdialogs.h"
 #include "../VFS/virt_vfs.h"
 #include "../KViewer/krviewer.h"
+#include "../kicons.h"
+#include "../GUI/krtreewidget.h"
 #include "krsearchmod.h"
 #include "krsearchdialog.h"
 
 #include <kinputdialog.h>
 #include <qregexp.h>
 #include <qfontmetrics.h>
+#include <QHBoxLayout>
+#include <QKeyEvent>
+#include <QLabel>
+#include <QGridLayout>
+#include <QResizeEvent>
+#include <QCloseEvent>
 #include <kmessagebox.h>
-#include <kpopupmenu.h>
+#include <kmenu.h>
 #include <qcursor.h>
 #include <qclipboard.h>
-#include <qheader.h>
-#include <kurldrag.h>
-#include <../kicons.h>
+#include <qheaderview.h>
+#include <QDrag>
+#include <QMimeData>
 
-class SearchListView : public QListView
+class SearchListView : public KrTreeWidget
 {
 public:
-  SearchListView( QWidget * parent, const char * name ) : QListView( parent, name )
+  SearchListView( QWidget * parent ) : KrTreeWidget( parent )
   {
+    setColumnCount( 5 );
+    
+    QStringList labels;
+    labels << i18n( "Name" );
+    labels << i18n( "Location" );
+    labels << i18n( "Size" );
+    labels << i18n( "Date" );
+    labels << i18n( "Permissions" );
+
+    setHeaderLabels( labels );
+
+    sortItems( 1, Qt::AscendingOrder );
+    setSelectionMode( QAbstractItemView::ExtendedSelection );
+
+    // fix the results list
+    // => make the results font smaller
+    QFont resultsFont( font() );
+    resultsFont.setPointSize(resultsFont.pointSize()-1);
+    setFont(resultsFont);
+
+    int i=QFontMetrics(font()).width("W");
+    int j=QFontMetrics(font()).width("0");
+    j=(i>j ? i : j);
+
+    KConfigGroup group( krConfig, "Search" );
+    if( group.hasKey( "Last State" ) )
+       header()->restoreState( group.readEntry( "Last State", QByteArray() ) );
+    else
+    {
+      setColumnWidth(0, j*14);
+      setColumnWidth(1, j*25);
+      setColumnWidth(2, j*6);
+      setColumnWidth(3, j*7);
+      setColumnWidth(4, j*7);
+    }
+
+    header()->setResizeMode( 0, QHeaderView::Interactive );
+    header()->setResizeMode( 1, QHeaderView::Interactive );
+    header()->setResizeMode( 2, QHeaderView::Interactive );
+    header()->setResizeMode( 3, QHeaderView::Interactive );
+    header()->setResizeMode( 4, QHeaderView::Interactive );
+
+    setStretchingColumn( 1 );
+
+    setDragEnabled( true );
   }
 
-  void startDrag() 
+  virtual void startDrag( Qt::DropActions supportedActs ) 
   {
-    KURL::List urls;
+    KUrl::List urls;
+    QList<QTreeWidgetItem *> list = selectedItems () ;
 
-    QListViewItem * item = firstChild();
-    while( item )
+    QListIterator<QTreeWidgetItem *> it( list );
+    
+    while( it.hasNext() )
     {
-      if( item->isSelected() )
-      {
-         QString name = item->text(1);
-         name += (name.endsWith( "/" ) ? item->text(0) : "/" + item->text(0) );
-         urls.push_back( vfs::fromPathOrURL( name ) );
-      }
-      item = item->nextSibling();
+      QTreeWidgetItem * item = it.next();
+
+      QString name = item->text(1);
+      name += (name.endsWith( "/" ) ? item->text(0) : "/" + item->text(0) );
+      urls.push_back( KUrl( name ) );
     }
 
     if( urls.count() == 0 )
       return;
 
-    KURLDrag *d = new KURLDrag(urls, this);
-    d->setPixmap( FL_LOADICON( "file" ), QPoint( -7, 0 ) );
-    d->dragCopy();
+    QDrag *drag = new QDrag(this);
+    QMimeData *mimeData = new QMimeData;
+    mimeData->setImageData( FL_LOADICON( "file" ) );
+    urls.populateMimeData(mimeData);
+    drag->setMimeData(mimeData);
+    drag->start();
   }
 };
 
 
+class SearchListViewItem : public QTreeWidgetItem
+{
+public:
+  SearchListViewItem( QTreeWidget *resultsList, QString name, QString where, KIO::filesize_t size, 
+                      QDateTime date, QString perm ) : QTreeWidgetItem( resultsList )
+  {
+    setText( 0, name  );
+    setText( 1, where );
+    setText( 2, KRpermHandler::parseSize(size) );
+    setText( 3, KGlobal::locale()->formatDateTime( date ) );
+    setText( 4, perm );
+
+    setTextAlignment( 2, Qt::AlignRight );
+    fileSize = size;
+    fileDate = date;
+  }
+
+  void setFoundText(QString text) { _foundText=text; }
+  const QString& foundText() const { return _foundText; }
+  
+  virtual bool operator<(const QTreeWidgetItem &other) const
+  {
+      int column = treeWidget() ? treeWidget()->sortColumn() : 0;
+
+      switch( column )
+      {
+      case 2:
+        return fileSize < ((SearchListViewItem &)other).fileSize;
+      case 3:
+        return fileDate < ((SearchListViewItem &)other).fileDate;
+      default:
+        return text(column) < other.text(column);
+      }
+  }
+  
+private:
+  KIO::filesize_t fileSize;
+  QDateTime       fileDate;
+  QString         _foundText;
+};
+
 
 KrSearchDialog *KrSearchDialog::SearchDialog = 0;
 
@@ -97,45 +195,46 @@ bool KrSearchDialog::lastContainsWithCase = true;
 bool KrSearchDialog::lastSearchInSubDirs = true;
 bool KrSearchDialog::lastSearchInArchives = false;
 bool KrSearchDialog::lastFollowSymLinks = false;
+bool KrSearchDialog::lastContainsRegExp = false;
 
 // class starts here /////////////////////////////////////////
-KrSearchDialog::KrSearchDialog( QString profile, QWidget* parent,  const char* name, bool modal, WFlags fl )
-                : QDialog( parent, name, modal, fl ), query(0), searcher(0)
+KrSearchDialog::KrSearchDialog( QString profile, QWidget* parent )
+                : QDialog( parent ), query(0), searcher(0)
 {
-  setCaption( i18n( "Krusader::Search" ) );
+  setWindowTitle( i18n( "Krusader::Search" ) );
 
   QGridLayout* searchBaseLayout = new QGridLayout( this );
   searchBaseLayout->setSpacing( 6 );
-  searchBaseLayout->setMargin( 11 );
+  searchBaseLayout->setContentsMargins( 11, 11, 11, 11 );
 
   // creating the dialog buttons ( Search, Stop, Close )
 
   QHBoxLayout* buttonsLayout = new QHBoxLayout();
   buttonsLayout->setSpacing( 6 );
-  buttonsLayout->setMargin( 0 );
+  buttonsLayout->setContentsMargins( 0, 0, 0, 0 );
 
-  profileManager = new ProfileManager( "SearcherProfile", this, "profileManager" );
+  profileManager = new ProfileManager( "SearcherProfile", this );
   buttonsLayout->addWidget( profileManager );
 
   QSpacerItem* spacer = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
   buttonsLayout->addItem( spacer );
 
-  mainFeedToListBoxBtn = new QPushButton( this, "mainFeedToListBoxBtn" );
+  mainFeedToListBoxBtn = new QPushButton( this );
   mainFeedToListBoxBtn->setText( i18n( "Feed to listbox" ) );
   mainFeedToListBoxBtn->setEnabled(false);
   buttonsLayout->addWidget( mainFeedToListBoxBtn );
 
-  mainSearchBtn = new QPushButton( this, "mainSearchBtn" );
+  mainSearchBtn = new QPushButton( this );
   mainSearchBtn->setText( i18n( "Search" ) );
   mainSearchBtn->setDefault(true);
   buttonsLayout->addWidget( mainSearchBtn );
 
-  mainStopBtn = new QPushButton( this, "mainStopBtn" );
+  mainStopBtn = new QPushButton( this );
   mainStopBtn->setEnabled( false );
   mainStopBtn->setText( i18n( "Stop" ) );
   buttonsLayout->addWidget( mainStopBtn );
 
-  mainCloseBtn = new QPushButton( this, "mainCloseBtn" );
+  mainCloseBtn = new QPushButton( this );
   mainCloseBtn->setText( i18n( "Close" ) );
   buttonsLayout->addWidget( mainCloseBtn );
 
@@ -143,30 +242,32 @@ KrSearchDialog::KrSearchDialog( QString profile, QWidget* parent,  const char* n
 
   // creating the searcher tabs
 
-  searcherTabs = new QTabWidget( this, "searcherTabs" );
+  searcherTabs = new QTabWidget( this );
 
   filterTabs = FilterTabs::addTo( searcherTabs, FilterTabs::Default | FilterTabs::HasRemoteContentSearch );
   generalFilter = (GeneralFilter *)filterTabs->get( "GeneralFilter" );
 
-  resultTab = new QWidget( searcherTabs, "resultTab" );
+  resultTab = new QWidget( searcherTabs );
   resultLayout = new QGridLayout( resultTab );
   resultLayout->setSpacing( 6 );
-  resultLayout->setMargin( 11 );
+  resultLayout->setContentsMargins( 11, 11, 11, 11 );
 
   // creating the result tab
 
   QHBoxLayout* resultLabelLayout = new QHBoxLayout();
   resultLabelLayout->setSpacing( 6 );
-  resultLabelLayout->setMargin( 0 );
+  resultLabelLayout->setContentsMargins( 0, 0, 0, 0 );
 
-  foundLabel = new QLabel( resultTab, "foundLabel" );
-  foundLabel->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)1, (QSizePolicy::SizeType)1, foundLabel->sizePolicy().hasHeightForWidth() ) );
+  foundLabel = new QLabel( resultTab );
+  QSizePolicy foundpolicy( QSizePolicy::Minimum, QSizePolicy::Minimum);
+  foundpolicy.setHeightForWidth( foundLabel->sizePolicy().hasHeightForWidth() );
+  foundLabel->setSizePolicy( foundpolicy );
   foundLabel->setFrameShape( QLabel::StyledPanel );
   foundLabel->setFrameShadow( QLabel::Sunken );
   foundLabel->setText( i18n( "Found 0 matches." ) );
   resultLabelLayout->addWidget( foundLabel );
 
-  searchingLabel = new KSqueezedTextLabel( resultTab, "searchingLabel" );
+  searchingLabel = new KSqueezedTextLabel( resultTab );
   searchingLabel->setFrameShape( QLabel::StyledPanel );
   searchingLabel->setFrameShadow( QLabel::Sunken );
   searchingLabel->setText( "" );
@@ -176,47 +277,18 @@ KrSearchDialog::KrSearchDialog( QString profile, QWidget* parent,  const char* n
 
   // creating the result list view
 
-  resultsList = new SearchListView( resultTab, "resultsList" );
-  resultsList->addColumn( i18n( "Name" ) );
-  resultsList->addColumn( i18n( "Location" ) );
-  resultsList->addColumn( i18n( "Size" ) );
-  resultsList->addColumn( i18n( "Date" ) );
-  resultsList->addColumn( i18n( "Permissions" ) );
-
-  resultsList->setSorting(1); // sort by location
-  resultsList->setSelectionMode( QListView::Extended );
-
-  // fix the results list
-  // => make the results font smaller
-  QFont resultsFont(  resultsList->font() );
-  resultsFont.setPointSize(resultsFont.pointSize()-1);
-  resultsList->setFont(resultsFont);
-
-  resultsList->setAllColumnsShowFocus(true);
-  for (int i=0; i<5; ++i) // don't let it resize automatically
-    resultsList->setColumnWidthMode(i, QListView::Manual);
-
-  int i=QFontMetrics(resultsList->font()).width("W");
-  int j=QFontMetrics(resultsList->font()).width("0");
-  j=(i>j ? i : j);
-
-  resultsList->setColumnWidth(0, krConfig->readNumEntry("Name Width", j*14) );
-  resultsList->setColumnWidth(1, krConfig->readNumEntry("Path Width", j*25) );
-  resultsList->setColumnWidth(2, krConfig->readNumEntry("Size Width", j*6) );
-  resultsList->setColumnWidth(3, krConfig->readNumEntry("Date Width", j*7) );
-  resultsList->setColumnWidth(4, krConfig->readNumEntry("Perm Width", j*7) );
-  resultsList->setColumnAlignment( 2, AlignRight );
-
-  resultsList->header()->setStretchEnabled( true, 1 );
+  resultsList = new SearchListView( resultTab );
 
   resultLayout->addWidget( resultsList, 0, 0 );
 
   QHBoxLayout* foundTextLayout = new QHBoxLayout();
   foundTextLayout->setSpacing( 6 );
-  foundTextLayout->setMargin( 0 );
+  foundTextLayout->setContentsMargins( 0, 0, 0, 0 );
   
   QLabel *l1 = new QLabel(resultTab);
-  l1->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)1, (QSizePolicy::SizeType)1, l1->sizePolicy().hasHeightForWidth() ) );
+  QSizePolicy l1policy( QSizePolicy::Minimum, QSizePolicy::Minimum);
+  l1policy.setHeightForWidth( l1->sizePolicy().hasHeightForWidth() );
+  l1->setSizePolicy( l1policy );
   l1->setFrameShape( QLabel::StyledPanel );
   l1->setFrameShadow( QLabel::Sunken );
   l1->setText(i18n("Text found:"));
@@ -229,7 +301,7 @@ KrSearchDialog::KrSearchDialog( QString profile, QWidget* parent,  const char* n
   foundTextLayout->addWidget( foundTextLabel );
   resultLayout->addLayout(foundTextLayout, 1, 0);
   
-  searcherTabs->insertTab( resultTab, i18n( "&Results" ) );
+  searcherTabs->addTab( resultTab, i18n( "&Results" ) );
 
   searchBaseLayout->addWidget( searcherTabs, 0, 0 );
 
@@ -237,15 +309,15 @@ KrSearchDialog::KrSearchDialog( QString profile, QWidget* parent,  const char* n
 
   connect( mainSearchBtn, SIGNAL( clicked() ), this, SLOT( startSearch() ) );
   connect( mainStopBtn, SIGNAL( clicked() ), this, SLOT( stopSearch() ) );
-  connect( resultsList, SIGNAL( returnPressed(QListViewItem*) ), this,
-  	SLOT( resultDoubleClicked(QListViewItem*) ) );
-  connect( resultsList, SIGNAL( doubleClicked(QListViewItem*) ), this,
-  	SLOT( resultDoubleClicked(QListViewItem*) ) );
-  connect( resultsList, SIGNAL( currentChanged(QListViewItem*) ), this,
-  		SLOT( resultClicked(QListViewItem*) ) );
-  connect( resultsList, SIGNAL( clicked(QListViewItem*) ), this,
-  		SLOT( resultClicked(QListViewItem*) ) );
-  connect( resultsList, SIGNAL( rightButtonClicked(QListViewItem*,const QPoint&,int) ), this, SLOT( rightClickMenu(QListViewItem*, const QPoint&, int) ) );
+  connect( resultsList, SIGNAL( itemActivated(QTreeWidgetItem*, int) ), this,
+  	SLOT( resultDoubleClicked(QTreeWidgetItem*) ) );
+  connect( resultsList, SIGNAL( itemDoubleClicked(QTreeWidgetItem*, int) ), this,
+  	SLOT( resultDoubleClicked(QTreeWidgetItem*) ) );
+  connect( resultsList, SIGNAL( currentItemChanged(QTreeWidgetItem*,QTreeWidgetItem*) ), this,
+  		SLOT( resultClicked(QTreeWidgetItem*) ) );
+  connect( resultsList, SIGNAL( itemClicked(QTreeWidgetItem*, int) ), this,
+  		SLOT( resultClicked(QTreeWidgetItem*) ) );
+  connect( resultsList, SIGNAL( itemRightClicked ( QTreeWidgetItem*, const QPoint &, int ) ), this, SLOT( rightClickMenu( QTreeWidgetItem*, const QPoint & ) ) );
   connect( mainCloseBtn, SIGNAL( clicked() ), this, SLOT( closeDialog() ) );
   connect( mainFeedToListBoxBtn, SIGNAL( clicked() ), this, SLOT( feedToListBox() ) );
 
@@ -259,14 +331,14 @@ KrSearchDialog::KrSearchDialog( QString profile, QWidget* parent,  const char* n
   setTabOrder( mainStopBtn, searcherTabs );
   setTabOrder( searcherTabs, resultsList );
 
-  krConfig->setGroup( "Search" );
-  int sx = krConfig->readNumEntry( "Window Width",  -1 );
-  int sy = krConfig->readNumEntry( "Window Height",  -1 );
+  KConfigGroup group( krConfig, "Search" );
+  sizeX = group.readEntry( "Window Width",  -1 );
+  sizeY = group.readEntry( "Window Height",  -1 );
 
-  if( sx != -1 && sy != -1 )
-    resize( sx, sy );
+  if( sizeX != -1 && sizeY != -1 )
+    resize( sizeX, sizeY );
 
-  if( krConfig->readBoolEntry( "Window Maximized",  false ) )
+  if( group.readEntry( "Window Maximized",  false ) )
       showMaximized();
   else
       show();
@@ -281,16 +353,17 @@ KrSearchDialog::KrSearchDialog( QString profile, QWidget* parent,  const char* n
     // load the last used values
     generalFilter->searchFor->setEditText( lastSearchText );
     generalFilter->searchFor->lineEdit()->selectAll();
-    generalFilter->ofType->setCurrentItem( lastSearchType );
+    generalFilter->ofType->setCurrentIndex( lastSearchType );
     generalFilter->searchForCase->setChecked( lastSearchForCase );
     generalFilter->remoteContentSearch->setChecked( lastRemoteContentSearch );
     generalFilter->containsWholeWord->setChecked( lastContainsWholeWord );
     generalFilter->containsTextCase->setChecked( lastContainsWithCase );
+    generalFilter->containsRegExp->setChecked( lastContainsRegExp );
     generalFilter->searchInDirs->setChecked( lastSearchInSubDirs );
     generalFilter->searchInArchives->setChecked( lastSearchInArchives );
     generalFilter->followLinks->setChecked( lastFollowSymLinks );
     // the path in the active panel should be the default search location
-    generalFilter->searchIn->lineEdit()->setText( ACTIVE_PANEL->virtualPath().prettyURL() );
+    generalFilter->searchIn->lineEdit()->setText( ACTIVE_PANEL->virtualPath().prettyUrl() );
   }
   else
     profileManager->loadProfile( profile ); // important: call this _after_ you've connected profileManager ot the loadFromProfile!!
@@ -306,24 +379,21 @@ void KrSearchDialog::closeDialog( bool isAccept )
 
   // saving the searcher state
 
-  krConfig->setGroup( "Search" );
+  KConfigGroup group( krConfig, "Search" );
 
-  krConfig->writeEntry("Window Width", sizeX );
-  krConfig->writeEntry("Window Height", sizeY );
-  krConfig->writeEntry("Window Maximized", isMaximized() );
+  group.writeEntry("Window Width", sizeX );
+  group.writeEntry("Window Height", sizeY );
+  group.writeEntry("Window Maximized", isMaximized() );
 
-  krConfig->writeEntry("Name Width",  resultsList->columnWidth( 0 ) );
-  krConfig->writeEntry("Path Width",  resultsList->columnWidth( 1 ) );
-  krConfig->writeEntry("Size Width",  resultsList->columnWidth( 2 ) );
-  krConfig->writeEntry("Date Width",  resultsList->columnWidth( 3 ) );
-  krConfig->writeEntry("Perm Width",  resultsList->columnWidth( 4 ) );
+  group.writeEntry( "Last State", resultsList->header()->saveState() );
 
   lastSearchText = generalFilter->searchFor->currentText();
-  lastSearchType = generalFilter->ofType->currentItem();
+  lastSearchType = generalFilter->ofType->currentIndex();
   lastSearchForCase = generalFilter->searchForCase->isChecked();
   lastRemoteContentSearch = generalFilter->remoteContentSearch->isChecked();
   lastContainsWholeWord = generalFilter->containsWholeWord->isChecked();
   lastContainsWithCase = generalFilter->containsTextCase->isChecked();
+  lastContainsRegExp = generalFilter->containsRegExp->isChecked();
   lastSearchInSubDirs = generalFilter->searchInDirs->isChecked();
   lastSearchInArchives = generalFilter->searchInArchives->isChecked();
   lastFollowSymLinks = generalFilter->followLinks->isChecked();
@@ -355,9 +425,9 @@ void KrSearchDialog::found(QString what, QString where, KIO::filesize_t size, ti
   // convert the time_t to struct tm
   struct tm* t=localtime((time_t *)&mtime);
   QDateTime tmp(QDate(t->tm_year+1900, t->tm_mon+1, t->tm_mday), QTime(t->tm_hour, t->tm_min));
-  ResultListViewItem *it =new ResultListViewItem(resultsList, what,
+  SearchListViewItem *it =new SearchListViewItem(resultsList, what,
   	 where.replace(QRegExp("\\\\"),"#"), size, tmp, perm);
-  QString totals = QString(i18n("Found %1 matches.")).arg(resultsList->childCount());
+  QString totals = QString(i18n("Found %1 matches.", resultsList->topLevelItemCount()));
   foundLabel->setText(totals);
 
   if (!foundText.isEmpty()) it->setFoundText(foundText);
@@ -393,7 +463,7 @@ void KrSearchDialog::startSearch() {
   resultsList->clear();
   searchingLabel->setText("");
   foundLabel->setText(i18n("Found 0 matches."));
-  searcherTabs->setCurrentPage(2); // show the results page
+  searcherTabs->setCurrentIndex(2); // show the results page
   foundTextLabel->setText("");
   qApp->processEvents();
 
@@ -428,25 +498,25 @@ void KrSearchDialog::stopSearch() {
   mainSearchBtn->setEnabled(true);
   mainCloseBtn->setEnabled(true);
   mainStopBtn->setEnabled(false);
-  if( resultsList->childCount() )
+  if( resultsList->topLevelItemCount() )
     mainFeedToListBoxBtn->setEnabled( true );
   searchingLabel->setText(i18n("Finished searching."));
 }
 
-void KrSearchDialog::resultDoubleClicked(QListViewItem* i) {
-  ACTIVE_FUNC->openUrl(vfs::fromPathOrURL(i->text(1)),i->text(0));
+void KrSearchDialog::resultDoubleClicked(QTreeWidgetItem* i) {
+  ACTIVE_FUNC->openUrl(KUrl(i->text(1)),i->text(0));
   showMinimized();
 }
 
-void KrSearchDialog::resultClicked(QListViewItem* i) {
-	ResultListViewItem *it = dynamic_cast<ResultListViewItem*>(i);
+void KrSearchDialog::resultClicked(QTreeWidgetItem* i) {
+	SearchListViewItem *it = dynamic_cast<SearchListViewItem*>(i);
 	if( it == 0 )
 		return;                
 	if (!it->foundText().isEmpty()) {
 		// ugly hack: find the <b> and </b> in the text, then
 		// use it to set the are which we don't want squeezed
-		int idx = it->foundText().find("<b>")-4; // take "<qt>" into account
-		int length = it->foundText().find("</b>")-idx+4;
+		int idx = it->foundText().indexOf("<b>")-4; // take "<qt>" into account
+		int length = it->foundText().indexOf("</b>")-idx+4;
 		foundTextLabel->setText(it->foundText(), idx, length);
 	}
 }
@@ -465,30 +535,33 @@ void KrSearchDialog::closeEvent(QCloseEvent *e)
 
 void KrSearchDialog::keyPressEvent(QKeyEvent *e)
 {
-  KKey pressedKey( e );
-
-  if( isSearching && e->key() == Key_Escape ) /* at searching we must not close the window */
+  if( isSearching && e->key() == Qt::Key_Escape ) /* at searching we must not close the window */
   {
     stopSearch();         /* so we simply stop searching */
     return;
   }
   if( resultsList->hasFocus() )
   {
-    if( e->key() == Key_F4 )
+    if( e->key() == Qt::Key_F4 )
     {
       if (!generalFilter->containsText->currentText().isEmpty() && QApplication::clipboard()->text() != generalFilter->containsText->currentText())
         QApplication::clipboard()->setText(generalFilter->containsText->currentText());
       editCurrent();
       return;
     }
-    else if( e->key() == Key_F3 )
+    else if( e->key() == Qt::Key_F3 )
     {
       if (!generalFilter->containsText->currentText().isEmpty() && QApplication::clipboard()->text() != generalFilter->containsText->currentText())
         QApplication::clipboard()->setText(generalFilter->containsText->currentText());
       viewCurrent();
       return;
     }
-    else if( Krusader::actCopy->shortcut().contains( pressedKey ) )
+    else if( e->key() == Qt::Key_F10 )
+    {
+      compareByContent();
+      return;
+    }
+    else if( Krusader::actCopy->shortcut().contains( QKeySequence( e->key() | e->modifiers() ) ) )
     {
       copyToClipBoard();
       return;
@@ -500,129 +573,147 @@ void KrSearchDialog::keyPressEvent(QKeyEvent *e)
 
 void KrSearchDialog::editCurrent()
 {
-  QListViewItem *current = resultsList->currentItem();
+  QTreeWidgetItem *current = resultsList->currentItem();
   if( current )
   {
     QString name = current->text(1);
     name += (name.endsWith( "/" ) ? current->text(0) : "/" + current->text(0) );
-    KURL url = vfs::fromPathOrURL( name );
+    KUrl url = KUrl( name );
     KrViewer::edit( url, this );
   }
 }
 
 void KrSearchDialog::viewCurrent()
 {
-  QListViewItem *current = resultsList->currentItem();
+  QTreeWidgetItem *current = resultsList->currentItem();
   if( current )
   {
     QString name = current->text(1);
     name += (name.endsWith( "/" ) ? current->text(0) : "/" + current->text(0) );
-    KURL url = vfs::fromPathOrURL( name );
+    KUrl url = KUrl( name );
     KrViewer::view( url, this );
   }
 }
 
-void KrSearchDialog::rightClickMenu(QListViewItem *item, const QPoint&, int)
+void KrSearchDialog::compareByContent()
+{
+  QList<QTreeWidgetItem *> list = resultsList->selectedItems();
+  if( list.count() != 2 )
+    return;
+
+  QString name1 = list[ 0 ]->text(1);
+  name1 += (name1.endsWith( "/" ) ? list[ 0 ]->text(0) : "/" + list[ 0 ]->text(0) );
+  KUrl url1 = KUrl( name1 );
+
+  QString name2 = list[ 1 ]->text(1);
+  name2 += (name2.endsWith( "/" ) ? list[ 1 ]->text(0) : "/" + list[ 1 ]->text(0) );
+  KUrl url2 = KUrl( name2 );
+
+  SLOTS->compareContent( url1, url2 );
+}
+
+void KrSearchDialog::rightClickMenu( QTreeWidgetItem * item, const QPoint &pos )
 {
-  // these are the values that will exist in the menu
-  #define EDIT_FILE_ID                110
-  #define VIEW_FILE_ID                111
-  #define COPY_SELECTED_TO_CLIPBOARD  112
-  //////////////////////////////////////////////////////////
   if (!item)
     return;
 
   // create the menu
-  KPopupMenu popup;
-  popup.insertTitle(i18n("Krusader Search"));
+  KMenu popup;
+  popup.setTitle(i18n("Krusader Search"));
 
-  popup.insertItem(i18n("View File (F3)"),            VIEW_FILE_ID);
-  popup.insertItem(i18n("Edit File (F4)"),            EDIT_FILE_ID);
-  popup.insertItem(i18n("Copy selected to clipboard"),COPY_SELECTED_TO_CLIPBOARD);
+  QAction *actView = popup.addAction(i18n("View File (F3)"));
+  QAction *actEdit = popup.addAction(i18n("Edit File (F4)"));
+  QAction *actComp = popup.addAction(i18n("Compare by content (F10)"));
+  if( resultsList->selectedItems().count() != 2 )
+    actComp->setEnabled( false );
+  QAction *actClip = popup.addAction(i18n("Copy selected to clipboard"));
 
-  int result=popup.exec(QCursor::pos());
+  QAction *result=popup.exec( pos );
 
   // check out the user's option
-  switch (result)
-  {
-    case VIEW_FILE_ID:
-      viewCurrent();
-      break;
-    case EDIT_FILE_ID:
-      editCurrent();
-      break;
-    case COPY_SELECTED_TO_CLIPBOARD:
-      copyToClipBoard();
-      break;
-    default:    // the user clicked outside of the menu
-      break;
-  }
+  if( result == actView )
+    viewCurrent();
+  else if( result == actEdit )
+    editCurrent();
+  else if( result == actClip )
+    copyToClipBoard();
+  else if( result == actComp )
+    compareByContent();
 }
 
 void KrSearchDialog::feedToListBox()
 {
   virt_vfs v(0,true);
-  v.vfs_refresh( KURL( "/" ) );
+  v.vfs_refresh( KUrl( "/" ) );
 
-  krConfig->setGroup( "Search" );
-  int listBoxNum = krConfig->readNumEntry( "Feed To Listbox Counter", 1 );
+  KConfigGroup group( krConfig, "Search" );
+  int listBoxNum = group.readEntry( "Feed To Listbox Counter", 1 );
   QString queryName;
   do {
     queryName = i18n("Search results")+QString( " %1" ).arg( listBoxNum++ );
   }while( v.vfs_search( queryName ) != 0 );
-  krConfig->writeEntry( "Feed To Listbox Counter", listBoxNum );
+  group.writeEntry( "Feed To Listbox Counter", listBoxNum );
 
-  krConfig->setGroup( "Advanced" );
-  if ( krConfig->readBoolEntry( "Confirm Feed to Listbox",  _ConfirmFeedToListbox ) ) {
+  KConfigGroup ga( krConfig, "Advanced" );
+  if ( ga.readEntry( "Confirm Feed to Listbox",  _ConfirmFeedToListbox ) ) {
     bool ok;
     queryName = KInputDialog::getText(
                 i18n("Query name"),		// Caption
                 i18n("Here you can name the file collection"),	// Questiontext
                 queryName,	// Default
-                &ok );
+                &ok, this );
      if ( ! ok)
        return;
   }
 
-  KURL::List urlList;
-  QListViewItem * item = resultsList->firstChild();
-  while( item )
-  {
+  KUrl::List urlList;
+
+  QTreeWidgetItemIterator it(resultsList);
+  while (*it) {
+    QTreeWidgetItem * item = *it;
+
     QString name = item->text(1);
     name += (name.endsWith( "/" ) ? item->text(0) : "/" + item->text(0) );
-    urlList.push_back( vfs::fromPathOrURL( name ) );
-    item = item->nextSibling();
+    urlList.push_back( KUrl( name ) );
+
+    ++it;
   }
-  KURL url = KURL::fromPathOrURL( QString("virt:/") + queryName );
+
+  KUrl url = KUrl( QString("virt:/") + queryName );
   v.vfs_refresh( url );
   v.vfs_addFiles( &urlList, KIO::CopyJob::Copy, 0 );
   //ACTIVE_FUNC->openUrl(url);
-  ACTIVE_MNG->slotNewTab(url.prettyURL());
+  ACTIVE_MNG->slotNewTab(url.prettyUrl());
   closeDialog();
 }
 
 void KrSearchDialog::copyToClipBoard()
 {
-  KURL::List urls;
+  KUrl::List urls;
+
+
+  QTreeWidgetItemIterator it(resultsList);
+  while (*it) {
+    QTreeWidgetItem * item = *it;
 
-  QListViewItem * item = resultsList->firstChild();
-  while( item )
-  {
     if( item->isSelected() )
     {
        QString name = item->text(1);
        name += (name.endsWith( "/" ) ? item->text(0) : "/" + item->text(0) );
-       urls.push_back( vfs::fromPathOrURL( name ) );
+       urls.push_back( KUrl( name ) );
     }
-    item = item->nextSibling();
+
+    ++it;
   }
 
   if( urls.count() == 0 )
     return;
 
-  KURLDrag *d = new KURLDrag(urls, this);
-  d->setPixmap( FL_LOADICON( "file" ), QPoint( -7, 0 ) );
-  QApplication::clipboard()->setData( d );
+  QMimeData *mimeData = new QMimeData;
+  mimeData->setImageData( FL_LOADICON( "file" ) );
+  urls.populateMimeData(mimeData);
+
+  QApplication::clipboard()->setMimeData( mimeData, QClipboard::Clipboard );
 }
 
 #include "krsearchdialog.moc"
