@@ -41,21 +41,28 @@
 #include "../GUI/profilemanager.h"
 
 #include <qwidget.h>
+#include <QResizeEvent>
+#include <QGridLayout>
+#include <QLabel>
+#include <QKeyEvent>
+#include <QCloseEvent>
 #include <ksqueezedtextlabel.h>
 #include <qstringlist.h>
 #include <sys/types.h>
 #include <time.h>
 #include <qstring.h>
 #include <qtabwidget.h>
-#include <qlistview.h>
 #include <qstringlist.h>
 #include <kglobal.h>
 #include <klocale.h>
 
+class QTreeWidget;
+class QTreeWidgetItem;
+
 class KrSearchDialog : public QDialog  {
    Q_OBJECT
 public: 
-  KrSearchDialog(QString profile = 0, QWidget* parent = 0, const char* name = 0, bool modal = false, WFlags fl = 0 );
+  KrSearchDialog(QString profile = 0, QWidget* parent = 0 );
 
   void prepareGUI();
     
@@ -68,12 +75,12 @@ public slots:
   void copyToClipBoard();
   void found(QString what, QString where, KIO::filesize_t size, time_t mtime, QString perm, QString foundText);
   void closeDialog( bool isAccept = true );
-  void resultDoubleClicked(QListViewItem*);
-  void resultClicked(QListViewItem*);
+  void resultDoubleClicked(QTreeWidgetItem*);
+  void resultClicked(QTreeWidgetItem*);
 
   virtual void keyPressEvent(QKeyEvent *e);
   virtual void closeEvent(QCloseEvent *e);
-  virtual void rightClickMenu(QListViewItem*, const QPoint&, int);
+  virtual void rightClickMenu( QTreeWidgetItem*, const QPoint & );
   virtual void resizeEvent( QResizeEvent *e );
 
 protected slots:
@@ -83,6 +90,7 @@ private:
   bool gui2query();
   void editCurrent();
   void viewCurrent();
+  void compareByContent();
 
 private:
   ProfileManager *profileManager;
@@ -103,7 +111,7 @@ private:
   KrSqueezedTextLabel *foundTextLabel;
   KSqueezedTextLabel *searchingLabel;
   
-  QListView* resultsList;
+  QTreeWidget* resultsList;
 
   KRQuery *query;
   KRSearchMod *searcher;
@@ -120,64 +128,10 @@ private:
   static bool    lastSearchInSubDirs;
   static bool    lastSearchInArchives;
   static bool    lastFollowSymLinks;
+  static bool    lastContainsRegExp;
   
   int            sizeX;
   int            sizeY;
 };
 
-class ResultListViewItem : public QListViewItem
-{
-public:
-  ResultListViewItem( QListView *resultsList, QString name, QString where, KIO::filesize_t size, 
-                      QDateTime date, QString perm ) : QListViewItem( resultsList, name, where, 
-                      KRpermHandler::parseSize(size), 
-                      KGlobal::locale()->formatDateTime( date ), perm )
-  {
-    fileSize = size;
-    fileDate = date;
-    setDragEnabled( true );
-  }  
-
-  void setFoundText(QString text) { _foundText=text; }
-  const QString& foundText() const { return _foundText; }
-  
-  virtual int compare(QListViewItem *i,int col,bool ascending ) const
-  {
-    if( col == 2 ) {
-      ResultListViewItem *other = (ResultListViewItem *)i;
-      KIO::filesize_t otherSize = other->getSize();
-      
-      if( fileSize == otherSize )
-        return 0;
-      if( fileSize > otherSize )
-        return 1;
-      return -1;
-    }
-    if( col == 3 ) {
-      ResultListViewItem *other = (ResultListViewItem *)i;
-      QDateTime otherDate = other->getDate();
-      
-      if( fileDate == otherDate )
-        return 0;
-      if( fileDate > otherDate )
-        return 1;
-      return -1;
-    }
-    return QListViewItem::compare( i, col, ascending );
-  }
-
-  KIO::filesize_t getSize() {
-    return fileSize;
-  }
-
-  QDateTime getDate() {
-    return fileDate;
-  }
-  
-private:
-  KIO::filesize_t fileSize;
-  QDateTime       fileDate;
-  QString _foundText;
-};
-
 #endif
