@@ -34,7 +34,7 @@
 #define KRSEARCHMOD_H
 
 #include <qobject.h>
-#include <qvaluestack.h>
+#include <qstack.h>
 #include <qstringlist.h>
 #include <qdatetime.h>
 #include <time.h>
@@ -53,13 +53,13 @@ public:
   KRSearchMod(const KRQuery *q);
   ~KRSearchMod();
 
-  void scanURL( KURL url );
+  void scanURL( KUrl url );
   void start();
   void stop();
   
 private:
-  void scanLocalDir( KURL url );
-  void scanRemoteDir( KURL url );
+  void scanLocalDir( KUrl url );
+  void scanRemoteDir( KUrl url );
 
 signals:
   void finished();
@@ -71,8 +71,8 @@ private slots:
 
 private:
   bool stopSearch;
-  QValueStack<KURL> scannedUrls;
-  QValueStack<KURL> unScannedUrls;
+  QStack<KUrl> scannedUrls;
+  QStack<KUrl> unScannedUrls;
   KRQuery *query;
   QStringList results;
   
