@@ -33,90 +33,100 @@
 #include "../krusader.h"
 #include "../defaults.h"
 #include <qlayout.h>
-#include <qhbox.h>
+#include <QVBoxLayout>
+#include <QLabel>
 #include <klocale.h>
 
-SynchronizeDialog::SynchronizeDialog( QWidget* parent,  const char* name, bool modal, WFlags fl,
+SynchronizeDialog::SynchronizeDialog( QWidget* parent,
                                       Synchronizer *sync, int pleftCopyNr, KIO::filesize_t pleftCopySize,
                                       int prightCopyNr, KIO::filesize_t prightCopySize, int pdeleteNr,
-                                      KIO::filesize_t pdeleteSize, int parThreads ) : QDialog( parent, name, modal, fl ),
+                                      KIO::filesize_t pdeleteSize, int parThreads ) : QDialog( parent ),
                                       synchronizer( sync ), leftCopyNr ( pleftCopyNr ),
                                       leftCopySize( pleftCopySize ), rightCopyNr ( prightCopyNr ),
                                       rightCopySize( prightCopySize ), deleteNr( pdeleteNr ),
                                       deleteSize( pdeleteSize ), parallelThreads( parThreads ),
                                       isPause( true ), syncStarted( false )
 {
-  setCaption( i18n("Krusader::Synchronize") );
+  setWindowTitle( i18n("Krusader::Synchronize") );
+  setModal( true );
 
-  QVBoxLayout *layout = new QVBoxLayout( this, 11, 6, "SynchronizeDialogLayout" );
+  QVBoxLayout *layout = new QVBoxLayout( this );
+  layout->setContentsMargins( 11, 11, 11, 11 );
+  layout->setSpacing( 6 );
 
-  cbRightToLeft = new QCheckBox( i18n( "Right to left: Copy 1 file", "Right to left: Copy %n files", leftCopyNr) + " " +
-                                 i18n( "(1 byte)", "(%n bytes)", KRpermHandler::parseSize( leftCopySize ).stripWhiteSpace().toInt() ),
-                                 this, "labelRightToLeft" );
+  cbRightToLeft = new QCheckBox( i18np( "Right to left: Copy 1 file", "Right to left: Copy %1 files", leftCopyNr) + " " +
+                                 i18np( "(1 byte)", "(%1 bytes)", KRpermHandler::parseSize( leftCopySize ).trimmed().toInt() ),
+                                 this );
   cbRightToLeft->setChecked( leftCopyNr != 0 );
   cbRightToLeft->setEnabled( leftCopyNr != 0 );
   layout->addWidget( cbRightToLeft );
 
-  lbRightToLeft = new QLabel( "\t" + i18n( "Ready: %1/1 file, %3/%4", "Ready: %1/%n files, %3/%4", leftCopyNr).arg( 0 )
-                             .arg( 0 ).arg( KRpermHandler::parseSize( leftCopySize ).stripWhiteSpace() ),
-                             this, "lbRightToLeft" );
+  lbRightToLeft = new QLabel( "\t" + i18np( "Ready: %2/1 file, %3/%4", "Ready: %2/%1 files, %3/%4", leftCopyNr, 0,
+                             0, KRpermHandler::parseSize( leftCopySize ).trimmed() ),
+                             this );
   lbRightToLeft->setEnabled( leftCopyNr != 0 );
   layout->addWidget( lbRightToLeft );
 
-  cbLeftToRight = new QCheckBox( i18n( "Left to right: Copy 1 file", "Left to right: Copy %n files", rightCopyNr) + " " +
-                                 i18n( "(1 byte)", "(%n bytes)", KRpermHandler::parseSize( rightCopySize ).stripWhiteSpace().toInt() ),
-                                 this, "cbLeftToRight" );
+  cbLeftToRight = new QCheckBox( i18np( "Left to right: Copy 1 file", "Left to right: Copy %1 files", rightCopyNr) + " " +
+                                 i18np( "(1 byte)", "(%1 bytes)", KRpermHandler::parseSize( rightCopySize ).trimmed().toInt() ),
+                                 this );
   cbLeftToRight->setChecked( rightCopyNr != 0 );
   cbLeftToRight->setEnabled( rightCopyNr != 0 );
   layout->addWidget( cbLeftToRight );
 
-  lbLeftToRight = new QLabel( "\t" + i18n( "Ready: %1/1 file, %3/%4", "Ready: %1/%n files, %3/%4", rightCopyNr ).arg( 0 )
-                             .arg( 0 ).arg( KRpermHandler::parseSize( rightCopySize ).stripWhiteSpace() ),
-                             this, "lbLeftToRight" );
+  lbLeftToRight = new QLabel( "\t" + i18np( "Ready: %2/1 file, %3/%4", "Ready: %2/%1 files, %3/%4", rightCopyNr, 0,
+                             0, KRpermHandler::parseSize( rightCopySize ).trimmed() ),
+                             this );
   lbLeftToRight->setEnabled( rightCopyNr != 0 );
   layout->addWidget( lbLeftToRight );
 
-  cbDeletable = new QCheckBox( i18n( "Left: Delete 1 file", "Left: Delete %n files", deleteNr) + " " +
-                               i18n( "(1 byte)", "(%n bytes)", KRpermHandler::parseSize( deleteSize ).stripWhiteSpace().toInt() ),
-                               this, "cbDeletable" );
+  cbDeletable = new QCheckBox( i18np( "Left: Delete 1 file", "Left: Delete %1 files", deleteNr) + " " +
+                               i18np( "(1 byte)", "(%1 bytes)", KRpermHandler::parseSize( deleteSize ).trimmed().toInt() ),
+                               this );
   cbDeletable->setChecked( deleteNr != 0 );
   cbDeletable->setEnabled( deleteNr != 0 );
   layout->addWidget( cbDeletable );
 
-  lbDeletable   = new QLabel( "\t" + i18n( "Ready: %1/1 file, %3/%4", "Ready: %1/%n files, %3/%4", deleteNr ).arg( 0 )
-                             .arg( 0 ).arg( KRpermHandler::parseSize( deleteSize ).stripWhiteSpace() ),
-                             this, "lbDeletable" );
+  lbDeletable   = new QLabel( "\t" + i18np( "Ready: %2/1 file, %3/%4", "Ready: %2/%1 files, %3/%4", deleteNr, 0,
+                             0, KRpermHandler::parseSize( deleteSize ).trimmed() ),
+                             this );
   lbDeletable->setEnabled( deleteNr != 0 );
   layout->addWidget( lbDeletable );
 
-  progress = new QProgressBar(1000, this);
-  progress->setCenterIndicator(true);
-  progress->setProgress( 0 );
+  progress = new QProgressBar(this);
+  progress->setMaximum( 1000 );
+  progress->setMinimum( 0 );
+  progress->setValue( 0 );
   progress->setMinimumWidth( 400 );
   layout->addWidget( progress );
 
-  QHBox *hbox = new QHBox( this, "SynchronizeDialogHBox" );
+  QWidget *hboxWidget = new QWidget( this );
+  QHBoxLayout * hbox = new QHBoxLayout( hboxWidget );
+
   hbox->setSpacing( 6 );
 
-  cbOverwrite = new QCheckBox( i18n( "Confirm overwrites" ), this, "cbOverWrite" );
-  krConfig->setGroup("Synchronize");
-  cbOverwrite->setChecked( krConfig->readBoolEntry( "Confirm overwrites", _ConfirmOverWrites  ) );
+  cbOverwrite = new QCheckBox( i18n( "Confirm overwrites" ), this );
+  KConfigGroup group( krConfig, "Synchronize");
+  cbOverwrite->setChecked( group.readEntry( "Confirm overwrites", _ConfirmOverWrites  ) );
   layout->addWidget( cbOverwrite );
   
   QSpacerItem* spacer = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
-  hbox->layout()->addItem( spacer );
+  hbox->addItem( spacer );
   
-  btnStart = new QPushButton( hbox, "btnStart" );
+  btnStart = new QPushButton( hboxWidget );
   btnStart->setText( i18n( "&Start" ) );
+  hbox->addWidget( btnStart );
 
-  btnPause = new QPushButton( hbox, "btnPause" );
+  btnPause = new QPushButton( hboxWidget );
   btnPause->setEnabled( false );
   btnPause->setText( i18n( "&Pause" ) );
+  hbox->addWidget( btnPause );
   
-  QPushButton *btnClose = new QPushButton( hbox, "btnClose" );
+  QPushButton *btnClose = new QPushButton( hboxWidget );
   btnClose->setText( i18n( "&Close" ) );
+  hbox->addWidget( btnClose );
 
-  layout->addWidget( hbox );
+  layout->addWidget( hboxWidget );
 
   connect( btnStart,  SIGNAL( clicked() ), this, SLOT( startSynchronization() ) );
   connect( btnPause,  SIGNAL( clicked() ), this, SLOT( pauseOrResume() ) );
@@ -127,7 +137,8 @@ SynchronizeDialog::SynchronizeDialog( QWidget* parent,  const char* name, bool m
 
 SynchronizeDialog::~SynchronizeDialog()
 {
-  krConfig->writeEntry("Confirm overwrites", cbOverwrite->isChecked() );  
+  KConfigGroup group( krConfig, "Synchronize");
+  group.writeEntry("Confirm overwrites", cbOverwrite->isChecked() );  
 }
 
 void SynchronizeDialog::startSynchronization()
@@ -155,15 +166,15 @@ void SynchronizeDialog::synchronizationFinished()
 void SynchronizeDialog::processedSizes( int leftNr, KIO::filesize_t leftSize, int rightNr,
                                         KIO::filesize_t rightSize, int delNr, KIO::filesize_t delSize )
 {
-  lbRightToLeft->setText( i18n( "\tReady: %1/%2 files, %3/%4" ).arg( leftNr ).arg( leftCopyNr )
-                          .arg( KRpermHandler::parseSize( leftSize ).stripWhiteSpace() )
-                          .arg( KRpermHandler::parseSize( leftCopySize ).stripWhiteSpace() ) );
-  lbLeftToRight->setText( i18n( "\tReady: %1/%2 files, %3/%4" ).arg( rightNr ).arg( rightCopyNr )
-                          .arg( KRpermHandler::parseSize( rightSize ).stripWhiteSpace() )
-                          .arg( KRpermHandler::parseSize( rightCopySize ).stripWhiteSpace() ) );
-  lbDeletable->setText  ( i18n( "\tReady: %1/%2 files, %3/%4" ).arg( delNr ).arg( deleteNr )
-                          .arg( KRpermHandler::parseSize( delSize ).stripWhiteSpace() )
-                          .arg( KRpermHandler::parseSize( deleteSize ).stripWhiteSpace() ) );
+  lbRightToLeft->setText( i18n( "\tReady: %1/%2 files, %3/%4", leftNr, leftCopyNr,
+                          KRpermHandler::parseSize( leftSize ).trimmed(),
+                          KRpermHandler::parseSize( leftCopySize ).trimmed() ) );
+  lbLeftToRight->setText( i18n( "\tReady: %1/%2 files, %3/%4", rightNr, rightCopyNr,
+                          KRpermHandler::parseSize( rightSize ).trimmed(),
+                          KRpermHandler::parseSize( rightCopySize ).trimmed() ) );
+  lbDeletable->setText  ( i18n( "\tReady: %1/%2 files, %3/%4", delNr, deleteNr,
+                          KRpermHandler::parseSize( delSize ).trimmed(),
+                          KRpermHandler::parseSize( deleteSize ).trimmed() ) );
 
   KIO::filesize_t totalSum      = leftCopySize + rightCopySize + deleteSize;
   KIO::filesize_t processedSum  = leftSize + rightSize + delSize;
@@ -171,7 +182,7 @@ void SynchronizeDialog::processedSizes( int leftNr, KIO::filesize_t leftSize, in
   if( totalSum == 0 )
     totalSum++;
 
-  progress->setProgress( (int)(((double)processedSum / (double)totalSum )*1000) );
+  progress->setValue( (int)(((double)processedSum / (double)totalSum )*1000) );
 }
 
 void SynchronizeDialog::pauseOrResume()
