@@ -34,7 +34,6 @@
 #include "../krservices.h"
 #include "../VFS/vfs.h"
 #include "../VFS/krquery.h"
-#include "config.h"
 #include <kurl.h>
 #include <kmessagebox.h>
 #include <klocale.h>
@@ -42,19 +41,22 @@
 #include <qregexp.h>
 #include <qdir.h>
 #include <qtimer.h>
+#include <QTime>
+#include <QFrame>
+#include <QVBoxLayout>
 #include <kio/job.h>
-#include <kdialogbase.h>
-#include <kio/observer.h>
+#include <kio/deletejob.h>
+#include <kio/jobuidelegate.h>
 #include <kio/renamedlg.h>
-#include <kio/skipdlg.h>
+#include <kio/skipdialog.h>
 #include <unistd.h>
 #include <qeventloop.h>
 #include <qpushbutton.h>
 #include <qdatetime.h>
 #include <kprocess.h>
-#include <kdialogbase.h>
-#include <kprogress.h>
+#include <kdialog.h>
 #include <qlayout.h>
+#include <qprogressbar.h>
 #include <kurlcompletion.h>
 
 #include <sys/types.h>
@@ -66,7 +68,7 @@
 
 
 
-#if KDE_IS_VERSION(3,5,0) && defined( HAVE_POSIX_ACL )
+#if defined( HAVE_POSIX_ACL )
 #include <sys/acl.h>
 #ifdef HAVE_NON_POSIX_ACL_EXTENSIONS
 #include <acl/libacl.h>
@@ -78,10 +80,28 @@
 
 Synchronizer::Synchronizer() : displayUpdateCount( 0 ), markEquals( true ), 
         markDiffers ( true ), markCopyToLeft( true ), markCopyToRight( true ), markDeletable( true ),
-        stack(), jobMap(), receivedMap(), parentWidget( 0 )
+        stack(), jobMap(), receivedMap(), parentWidget( 0 ), resultListIt( resultList )
 {
-  resultList.setAutoDelete( true );
-  stack.setAutoDelete( true );
+}
+
+Synchronizer::~Synchronizer()
+{
+  clearLists();
+}
+
+void Synchronizer::clearLists()
+{
+  QListIterator<SynchronizerFileItem *> i1(resultList);
+  while (i1.hasNext())
+    delete i1.next();
+  resultList.clear();
+
+  QListIterator<SynchronizerTask *> i2(stack);
+  while (i2.hasNext())
+    delete i2.next();
+  stack.clear();
+
+  temporaryList.clear();
 }
 
 void Synchronizer::reset()
@@ -95,18 +115,15 @@ void Synchronizer::reset()
   leftCopyNr = rightCopyNr = deleteNr = 0;
   leftCopySize = rightCopySize = deleteSize = 0;
   comparedDirs = fileCount = 0;
-  leftBaseDir = rightBaseDir = QString::null;
-  resultList.clear();
-  temporaryList.clear();
-  stack.clear();
+  leftBaseDir = rightBaseDir = QString();
+  clearLists();
 }
 
 int Synchronizer::compare( QString leftURL, QString rightURL, KRQuery *query, bool subDirs,
                             bool symLinks, bool igDate, bool asymm, bool cmpByCnt, bool igCase, 
                             bool autoSc, QStringList &selFiles, int equThres, int timeOffs, int parThreads, bool hiddenFiles )
 {
-  resultList.clear();
-  temporaryList.clear();
+  clearLists();
 
   recurseSubDirs = subDirs;
   followSymLinks = symLinks;
@@ -125,14 +142,14 @@ int Synchronizer::compare( QString leftURL, QString rightURL, KRQuery *query, bo
 
   this->query = query;
 
-  leftURL = KURLCompletion::replacedPath( leftURL, true, true );
-  rightURL = KURLCompletion::replacedPath( rightURL, true, true );
+  leftURL = KUrlCompletion::replacedPath( leftURL, true, true );
+  rightURL = KUrlCompletion::replacedPath( rightURL, true, true );
 
   if( !leftURL.endsWith("/" ))  leftURL+="/";
   if( !rightURL.endsWith("/" )) rightURL+="/";
 
   excludedPaths = query->dontSearchInDirs().toStringList();
-  for( unsigned i = 0; i != excludedPaths.count(); i++ )
+  for( int i = 0; i != excludedPaths.count(); i++ )
     if( excludedPaths[ i ].endsWith( "/" ) )
       excludedPaths[ i ].truncate( excludedPaths[ i ].length() - 1 );
 
@@ -141,12 +158,13 @@ int Synchronizer::compare( QString leftURL, QString rightURL, KRQuery *query, bo
   stack.append( new CompareTask( 0, leftBaseDir = leftURL, rightBaseDir = rightURL, "", "", ignoreHidden ) );
   compareLoop();
 
-  SynchronizerFileItem *item = temporaryList.first();
-  while( item )
+  QListIterator<SynchronizerFileItem *> it(temporaryList);
+  while (it.hasNext())
   {
+    SynchronizerFileItem * item = it.next();
+
     if( item->isTemporary() )
       delete item;
-    item = temporaryList.next();
   }
   temporaryList.clear();
 
@@ -154,7 +172,7 @@ int Synchronizer::compare( QString leftURL, QString rightURL, KRQuery *query, bo
   if( !autoScroll )
     refresh( true );
 
-  emit statusInfo( i18n( "Number of files: %1" ).arg( fileCount ) );
+  emit statusInfo( i18n( "Number of files: %1", fileCount ) );
   return fileCount;
 }
 
@@ -185,8 +203,9 @@ void Synchronizer::compareLoop() {
         break;
       case ST_STATE_READY:
       case ST_STATE_ERROR:
-        emit statusInfo( i18n( "Number of compared directories: %1" ).arg( comparedDirs ) );
-        stack.removeRef( entry );
+        emit statusInfo( i18n( "Number of compared directories: %1", comparedDirs ) );
+        stack.removeAll( entry );
+        delete entry;
         continue;
       default:
         break;
@@ -195,6 +214,10 @@ void Synchronizer::compareLoop() {
     if( !stack.isEmpty() )
       qApp->processEvents();
   }
+
+  QListIterator<SynchronizerTask *> it(stack);
+  while (it.hasNext())
+    delete it.next();
   stack.clear();
 }
 
@@ -425,8 +448,8 @@ SynchronizerFileItem * Synchronizer::addLeftOnlyItem( SynchronizerFileItem *pare
                                     const QString &group, mode_t mode, const QString &acl, bool isDir, 
                                     bool isTemp )
 {
-  return addItem( parent, file_name, file_name, dir, dir, true, false, size, 0, date, 0, link, QString::null,
-                  owner, QString::null, group, QString::null, mode, (mode_t)-1, acl, QString::null,
+  return addItem( parent, file_name, file_name, dir, dir, true, false, size, 0, date, 0, link, QString(),
+                  owner, QString(), group, QString(), mode, (mode_t)-1, acl, QString(),
                   asymmetric ? TT_DELETE : TT_COPY_TO_RIGHT, isDir, isTemp );
 }
 
@@ -436,8 +459,8 @@ SynchronizerFileItem * Synchronizer::addRightOnlyItem( SynchronizerFileItem *par
                                     const QString &group, mode_t mode, const QString &acl, bool isDir,
                                     bool isTemp )
 {
-  return addItem( parent, file_name, file_name, dir, dir, false, true, 0, size, 0, date, QString::null, link,
-                  QString::null, owner, QString::null, group, (mode_t)-1, mode, QString::null, acl,
+  return addItem( parent, file_name, file_name, dir, dir, false, true, 0, size, 0, date, QString(), link,
+                  QString(), owner, QString(), group, (mode_t)-1, mode, QString(), acl,
                   TT_COPY_TO_LEFT, isDir, isTemp );
 }
 
@@ -506,8 +529,8 @@ SynchronizerFileItem * Synchronizer::addDuplicateItem( SynchronizerFileItem *par
                                          (TaskType)(task + uncertain), isDir, isTemp );
 
   if( uncertain == TT_UNKNOWN ) {
-    KURL leftURL  = vfs::fromPathOrURL( leftDir.isEmpty() ? leftBaseDir + leftName : leftBaseDir + leftDir + "/" + leftName );
-    KURL rightURL = vfs::fromPathOrURL( rightDir.isEmpty() ? rightBaseDir + rightName : rightBaseDir + rightDir + "/" + rightName );
+    KUrl leftURL  = KUrl( leftDir.isEmpty() ? leftBaseDir + leftName : leftBaseDir + leftDir + "/" + leftName );
+    KUrl rightURL = KUrl( rightDir.isEmpty() ? rightBaseDir + rightName : rightBaseDir + rightDir + "/" + rightName );
     stack.append( new CompareContentTask( this, item, leftURL, rightURL, leftSize ) );
   }
 
@@ -621,10 +644,11 @@ int Synchronizer::refresh(bool nostatus)
 {
   fileCount = 0;
 
-  SynchronizerFileItem *item = resultList.first();
-
-  while( item )
+  QListIterator<SynchronizerFileItem *> it(resultList);
+  while (it.hasNext())
   {
+    SynchronizerFileItem * item = it.next();
+
     bool marked = isMarked( item->task(), item->existsInLeft() && item->existsInRight() );
     item->setMarked( marked );
 
@@ -633,19 +657,17 @@ int Synchronizer::refresh(bool nostatus)
       markParentDirectories( item );
       fileCount++;
     }
-
-    item = resultList.next();
   }
 
-  item = resultList.first();
-  while( item )
+  it.toFront();
+  while( it.hasNext() )
   {
+    SynchronizerFileItem * item = it.next();
     emit markChanged( item, false );
-    item = resultList.next();
   }
 
   if( !nostatus )
-    emit statusInfo( i18n( "Number of files: %1" ).arg( fileCount ) );
+    emit statusInfo( i18n( "Number of files: %1", fileCount ) );
 
   return fileCount;
 }
@@ -662,14 +684,14 @@ void Synchronizer::operate( SynchronizerFileItem *item,
     QString rightDirName = ( item->rightDirectory() == "" ) ?
                         item->rightName() : item->rightDirectory() + "/" + item->rightName() ;
 
-    item = resultList.first();
-    while( item )
+    QListIterator<SynchronizerFileItem *> it(resultList);
+    while (it.hasNext())
     {
+      SynchronizerFileItem * item = it.next();
+
       if( item->leftDirectory() == leftDirName || item->leftDirectory().startsWith( leftDirName + "/" ) ||
           item->rightDirectory() == rightDirName || item->rightDirectory().startsWith( rightDirName + "/" ) )
         executeOperation( item );
-
-      item = resultList.next();
     }
   }
 }
@@ -805,10 +827,11 @@ bool Synchronizer::totalSizes( int * leftCopyNr, KIO::filesize_t *leftCopySize,
   *leftCopySize = *rightCopySize = *deletableSize = 0;
   *leftCopyNr = *rightCopyNr = *deleteNr = 0;
 
-  SynchronizerFileItem *item = resultList.first();
-
-  while( item )
+  QListIterator<SynchronizerFileItem *> it(resultList);
+  while (it.hasNext())
   {
+    SynchronizerFileItem * item = it.next();
+
     if( item->isMarked() )
     {
       switch( item->task() )
@@ -832,7 +855,6 @@ bool Synchronizer::totalSizes( int * leftCopyNr, KIO::filesize_t *leftCopySize,
         break;
       }
     }
-    item = resultList.next();
   }
 
   return hasAnythingToDo;
@@ -844,12 +866,12 @@ void Synchronizer::swapSides()
   leftBaseDir = rightBaseDir;
   rightBaseDir = leftTmp;
 
-  SynchronizerFileItem *item = resultList.first();
-
-  while( item )
+  QListIterator<SynchronizerFileItem *> it(resultList);
+  while (it.hasNext())
   {
+    SynchronizerFileItem * item = it.next();
+
     item->swap( asymmetric );
-    item = resultList.next();
   }
 }
 
@@ -884,13 +906,13 @@ void Synchronizer::synchronize( QWidget *syncWdg, bool leftCopyEnabled, bool rig
     jobMap.clear();
     receivedMap.clear();
 
-    resultList.first();
+    resultListIt = resultList;
     synchronizeLoop();
 }
 
 void Synchronizer::synchronizeLoop() {
   if( disableNewTasks ) {
-    if( resultList.current() == 0 && jobMap.count() == 0 )
+    if( !resultListIt.hasNext() && jobMap.count() == 0 )
       emit synchronizationFinished();
     return;
   }
@@ -910,12 +932,14 @@ void Synchronizer::synchronizeLoop() {
 
 SynchronizerFileItem * Synchronizer::getNextTask() {
   TaskType task;
-  SynchronizerFileItem * currentTask = resultList.current();
+  SynchronizerFileItem * currentTask;
 
   do {
-    if( currentTask == 0 )
+    if( !resultListIt.hasNext() )
       return 0;
 
+    currentTask = resultListIt.next();
+
     if( currentTask->isMarked() )
     {
       task = currentTask->task();
@@ -927,11 +951,8 @@ SynchronizerFileItem * Synchronizer::getNextTask() {
       else if( deleteEnabled && task == TT_DELETE )
         break;
     }
-
-    currentTask = resultList.next();
   }while( true );
 
-  resultList.next();
   return lastTask = currentTask;
 }
 
@@ -945,8 +966,8 @@ void Synchronizer::executeTask( SynchronizerFileItem * task )
   if( !rightDirName.isEmpty() )
     rightDirName += "/";
 
-  KURL leftURL  = vfs::fromPathOrURL( leftBaseDir + leftDirName + task->leftName() );
-  KURL rightURL = vfs::fromPathOrURL( rightBaseDir + rightDirName + task->rightName() );
+  KUrl leftURL  = KUrl( leftBaseDir + leftDirName + task->leftName() );
+  KUrl rightURL = KUrl( rightBaseDir + rightDirName + task->rightName() );
 
   switch( task->task() )
   {
@@ -954,27 +975,27 @@ void Synchronizer::executeTask( SynchronizerFileItem * task )
     if( task->isDir() )
     {
       KIO::SimpleJob *job = KIO::mkdir( leftURL );
-      connect(job,SIGNAL(result(KIO::Job*)),this,SLOT(slotTaskFinished(KIO::Job*)));
+      connect(job,SIGNAL(result(KJob*)),this,SLOT(slotTaskFinished(KJob*)));
       jobMap[ job ] = task;
       disableNewTasks = true;
     }
     else
     {
-      KURL destURL( leftURL );
+      KUrl destURL( leftURL );
       if( !task->destination().isNull() )
-        destURL = vfs::fromPathOrURL( task->destination() );
+        destURL = KUrl( task->destination() );
 
       if( task->rightLink().isNull() ) {
-        KIO::FileCopyJob *job = KIO::file_copy(rightURL, destURL, -1,
-                                  overWrite || task->overWrite(), false, false );
-        connect(job,SIGNAL(processedSize (KIO::Job *, KIO::filesize_t )), this,
-                    SLOT  (slotProcessedSize (KIO::Job *, KIO::filesize_t )));
-        connect(job,SIGNAL(result(KIO::Job*)),this,SLOT(slotTaskFinished(KIO::Job*)));
+        KIO::FileCopyJob *job = KIO::file_copy(rightURL, destURL, -1, 
+		((overWrite || task->overWrite())?KIO::Overwrite:KIO::DefaultFlags) | KIO::HideProgressInfo );
+        connect(job,SIGNAL(processedSize (KJob *, qulonglong )), this,
+                    SLOT  (slotProcessedSize (KJob *, qulonglong )));
+        connect(job,SIGNAL(result(KJob*)),this,SLOT(slotTaskFinished(KJob*)));
         jobMap[ job ] = task;
       } else {
         KIO::SimpleJob *job = KIO::symlink( task->rightLink(), destURL,
-                                            overWrite || task->overWrite(), false );
-        connect(job,SIGNAL(result(KIO::Job*)),this,SLOT(slotTaskFinished(KIO::Job*)));
+		((overWrite || task->overWrite())?KIO::Overwrite:KIO::DefaultFlags) | KIO::HideProgressInfo );
+        connect(job,SIGNAL(result(KJob*)),this,SLOT(slotTaskFinished(KJob*)));
         jobMap[ job ] = task;
       }
     }
@@ -983,27 +1004,27 @@ void Synchronizer::executeTask( SynchronizerFileItem * task )
     if( task->isDir() )
     {
       KIO::SimpleJob *job = KIO::mkdir( rightURL );
-      connect(job,SIGNAL(result(KIO::Job*)),this,SLOT(slotTaskFinished(KIO::Job*)));
+      connect(job,SIGNAL(result(KJob*)),this,SLOT(slotTaskFinished(KJob*)));
       jobMap[ job ] = task;
       disableNewTasks = true;
     }
     else
     {
-      KURL destURL( rightURL );
+      KUrl destURL( rightURL );
       if( !task->destination().isNull() )
-        destURL = vfs::fromPathOrURL( task->destination() );
+        destURL = KUrl( task->destination() );
 
       if( task->leftLink().isNull() ) {
         KIO::FileCopyJob *job = KIO::file_copy(leftURL, destURL, -1,
-                                  overWrite || task->overWrite(), false, false );
-        connect(job,SIGNAL(processedSize (KIO::Job *, KIO::filesize_t )), this,
-                    SLOT  (slotProcessedSize (KIO::Job *, KIO::filesize_t )));
-        connect(job,SIGNAL(result(KIO::Job*)),this,SLOT(slotTaskFinished(KIO::Job*)));
+		((overWrite || task->overWrite())?KIO::Overwrite:KIO::DefaultFlags) | KIO::HideProgressInfo );
+        connect(job,SIGNAL(processedSize (KJob *, qulonglong )), this,
+                    SLOT  (slotProcessedSize (KJob *, qulonglong )));
+        connect(job,SIGNAL(result(KJob*)),this,SLOT(slotTaskFinished(KJob*)));
         jobMap[ job ] = task;
       } else {
         KIO::SimpleJob *job = KIO::symlink( task->leftLink(), destURL,
-                                            overWrite || task->overWrite(), false );
-        connect(job,SIGNAL(result(KIO::Job*)),this,SLOT(slotTaskFinished(KIO::Job*)));
+		((overWrite || task->overWrite())?KIO::Overwrite:KIO::DefaultFlags) | KIO::HideProgressInfo );
+        connect(job,SIGNAL(result(KJob*)),this,SLOT(slotTaskFinished(KJob*)));
         jobMap[ job ] = task;
       }
     }
@@ -1011,7 +1032,7 @@ void Synchronizer::executeTask( SynchronizerFileItem * task )
   case TT_DELETE:
     {
       KIO::DeleteJob *job = KIO::del( leftURL, false );
-      connect(job,SIGNAL(result(KIO::Job*)),this,SLOT(slotTaskFinished(KIO::Job*)));
+      connect(job,SIGNAL(result(KJob*)),this,SLOT(slotTaskFinished(KJob*)));
       jobMap[ job ] = task;
     }
     break;
@@ -1020,7 +1041,7 @@ void Synchronizer::executeTask( SynchronizerFileItem * task )
   }
 }
 
-void Synchronizer::slotTaskFinished(KIO::Job *job )
+void Synchronizer::slotTaskFinished(KJob *job )
 {
   inTaskFinished++;
 
@@ -1039,8 +1060,8 @@ void Synchronizer::slotTaskFinished(KIO::Job *job )
 
   QString leftDirName     = item->leftDirectory().isEmpty() ? "" : item->leftDirectory() + "/";
   QString rightDirName     = item->rightDirectory().isEmpty() ? "" : item->rightDirectory() + "/";
-  KURL leftURL  = vfs::fromPathOrURL( leftBaseDir + leftDirName + item->leftName() );
-  KURL rightURL = vfs::fromPathOrURL( rightBaseDir + rightDirName + item->rightName() );
+  KUrl leftURL  = KUrl( leftBaseDir + leftDirName + item->leftName() );
+  KUrl rightURL = KUrl( rightBaseDir + rightDirName + item->rightName() );
 
   do {
     if( !job->error() )
@@ -1055,7 +1076,7 @@ void Synchronizer::slotTaskFinished(KIO::Job *job )
           timestamp.actime = time( 0 );
           timestamp.modtime = item->rightDate() - timeOffset;
 
-          utime( (const char *)( leftURL.path( -1 ).local8Bit() ), &timestamp );
+          utime( (const char *)( leftURL.path( KUrl::RemoveTrailingSlash ).toLocal8Bit() ), &timestamp );
 
           uid_t newOwnerID = (uid_t)-1; // chown(2) : -1 means no change
           if ( !item->rightOwner().isEmpty() )
@@ -1071,17 +1092,17 @@ void Synchronizer::slotTaskFinished(KIO::Job *job )
             if ( g != 0L )
               newGroupID = g->gr_gid;
           }
-          chown( (const char *)( leftURL.path( -1 ).local8Bit() ), newOwnerID, (gid_t)-1 );
-          chown( (const char *)( leftURL.path( -1 ).local8Bit() ), (uid_t)-1, newGroupID );
+          chown( (const char *)( leftURL.path( KUrl::RemoveTrailingSlash ).toLocal8Bit() ), newOwnerID, (gid_t)-1 );
+          chown( (const char *)( leftURL.path( KUrl::RemoveTrailingSlash ).toLocal8Bit() ), (uid_t)-1, newGroupID );
 
-          chmod( (const char *)( leftURL.path( -1 ).local8Bit() ), item->rightMode() & 07777 );
+          chmod( (const char *)( leftURL.path( KUrl::RemoveTrailingSlash ).toLocal8Bit() ), item->rightMode() & 07777 );
 
-#if KDE_IS_VERSION(3,5,0) && defined( HAVE_POSIX_ACL )
+#if defined( HAVE_POSIX_ACL )
           if( !item->rightACL().isNull() )
           {
-            acl_t acl = acl_from_text( item->rightACL().latin1() );
+            acl_t acl = acl_from_text( item->rightACL().toLatin1() );
             if( acl && !acl_valid( acl ) )
-              acl_set_file( leftURL.path( -1 ).local8Bit(), ACL_TYPE_ACCESS, acl );
+              acl_set_file( leftURL.path( KUrl::RemoveTrailingSlash ).toLocal8Bit(), ACL_TYPE_ACCESS, acl );
             if( acl )
               acl_free( acl );
           }
@@ -1096,7 +1117,7 @@ void Synchronizer::slotTaskFinished(KIO::Job *job )
           timestamp.actime = time( 0 );
           timestamp.modtime = item->leftDate() + timeOffset;
 
-          utime( (const char *)( rightURL.path( -1 ).local8Bit() ), &timestamp );
+          utime( (const char *)( rightURL.path( KUrl::RemoveTrailingSlash ).toLocal8Bit() ), &timestamp );
 
           uid_t newOwnerID = (uid_t)-1; // chown(2) : -1 means no change
           if ( !item->leftOwner().isEmpty() )
@@ -1112,17 +1133,17 @@ void Synchronizer::slotTaskFinished(KIO::Job *job )
             if ( g != 0L )
               newGroupID = g->gr_gid;
           }
-          chown( (const char *)( rightURL.path( -1 ).local8Bit() ), newOwnerID, (uid_t)-1 );
-          chown( (const char *)( rightURL.path( -1 ).local8Bit() ), (uid_t)-1, newGroupID );
+          chown( (const char *)( rightURL.path( KUrl::RemoveTrailingSlash ).toLocal8Bit() ), newOwnerID, (uid_t)-1 );
+          chown( (const char *)( rightURL.path( KUrl::RemoveTrailingSlash ).toLocal8Bit() ), (uid_t)-1, newGroupID );
 
-          chmod( (const char *)( rightURL.path( -1 ).local8Bit() ), item->leftMode() & 07777 );
+          chmod( (const char *)( rightURL.path( KUrl::RemoveTrailingSlash ).toLocal8Bit() ), item->leftMode() & 07777 );
 
-#if KDE_IS_VERSION(3,5,0) && defined( HAVE_POSIX_ACL )
+#if defined( HAVE_POSIX_ACL )
           if( !item->leftACL().isNull() )
           {
-            acl_t acl = acl_from_text( item->leftACL().latin1() );
+            acl_t acl = acl_from_text( item->leftACL().toLatin1() );
             if( acl && !acl_valid( acl ) )
-              acl_set_file( rightURL.path( -1 ).local8Bit(), ACL_TYPE_ACCESS, acl );
+              acl_set_file( rightURL.path( KUrl::RemoveTrailingSlash ).toLocal8Bit(), ACL_TYPE_ACCESS, acl );
             if( acl )
               acl_free( acl );
           }
@@ -1137,7 +1158,7 @@ void Synchronizer::slotTaskFinished(KIO::Job *job )
     {
       if( job->error() == KIO::ERR_FILE_ALREADY_EXIST && item->task() != TT_DELETE )
       {
-        KIO::RenameDlg_Result result;
+        KIO::RenameDialog_Result result;
         QString newDest;
 
         if( autoSkip )
@@ -1145,29 +1166,23 @@ void Synchronizer::slotTaskFinished(KIO::Job *job )
 
         if ( item->task() == TT_COPY_TO_LEFT )
         {
-          QWidget *mainWidget = qApp->mainWidget(); // WORKAROUND, don't give focus to the main widget
-          qApp->setMainWidget( syncDlgWidget );
+          ((KIO::Job *)job)->ui()->setWindow( syncDlgWidget );
 
-          result = Observer::self()->open_RenameDlg ( job, i18n("File Already Exists"),
-            vfs::pathOrURL( rightURL ), vfs::pathOrURL( leftURL ),
-            (KIO::RenameDlg_Mode)( KIO::M_OVERWRITE | KIO::M_SKIP | KIO::M_MULTI ), newDest,
+          result = ((KIO::Job *)job)->ui()->askFileRename( job, i18n("File Already Exists"),
+            rightURL.pathOrUrl(), leftURL.pathOrUrl(),
+            (KIO::RenameDialog_Mode)( KIO::M_OVERWRITE | KIO::M_SKIP | KIO::M_MULTI ), newDest,
             item->rightSize(), item->leftSize(), (time_t)-1, (time_t)-1,
             item->rightDate(), item->leftDate());
-
-          qApp->setMainWidget( mainWidget );
         }
         else
         {
-          QWidget *mainWidget = qApp->mainWidget(); // WORKAROUND, don't give focus to the main widget
-          qApp->setMainWidget( syncDlgWidget );
+          ((KIO::Job *)job)->ui()->setWindow( syncDlgWidget );
 
-          result = Observer::self()->open_RenameDlg ( job, i18n("File Already Exists"),
-            vfs::pathOrURL( leftURL ), vfs::pathOrURL( rightURL ),
-            (KIO::RenameDlg_Mode)( KIO::M_OVERWRITE | KIO::M_SKIP | KIO::M_MULTI ), newDest,
+          result = ((KIO::Job *)job)->ui()->askFileRename( job, i18n("File Already Exists"),
+            leftURL.pathOrUrl(), rightURL.pathOrUrl(),
+            (KIO::RenameDialog_Mode)( KIO::M_OVERWRITE | KIO::M_SKIP | KIO::M_MULTI ), newDest,
             item->leftSize(), item->rightSize(), (time_t)-1, (time_t)-1,
             item->leftDate(), item->rightDate());
-
-          qApp->setMainWidget( mainWidget );
         }
 
         switch ( result )
@@ -1206,28 +1221,23 @@ void Synchronizer::slotTaskFinished(KIO::Job *job )
         switch( item->task() )
         {
         case TT_COPY_TO_LEFT:
-          error = i18n("Error at copying file %1 to %2!")
-                       .arg( vfs::pathOrURL( rightURL ) )
-                       .arg( vfs::pathOrURL( leftURL ) );
+          error = i18n("Error at copying file %1 to %2!",
+                       rightURL.pathOrUrl(), leftURL.pathOrUrl() );
           break;
         case TT_COPY_TO_RIGHT:
-          error = i18n("Error at copying file %1 to %2!")
-                       .arg( vfs::pathOrURL( leftURL ) )
-                       .arg( vfs::pathOrURL( rightURL ) );
+          error = i18n("Error at copying file %1 to %2!",
+                       leftURL.pathOrUrl(), rightURL.pathOrUrl() );
           break;
         case TT_DELETE:
-          error = i18n("Error at deleting file %1!").arg( vfs::pathOrURL( leftURL ) );
+          error = i18n("Error at deleting file %1!", leftURL.pathOrUrl() );
           break;
         default:
           break;
         }
 
-        QWidget *mainWidget = qApp->mainWidget(); // WORKAROUND, don't give focus to the main widget
-        qApp->setMainWidget( syncDlgWidget );
+        ((KIO::Job *)job)->ui()->setWindow( syncDlgWidget );
 
-        KIO::SkipDlg_Result result = Observer::self()->open_SkipDlg( job, true, error );
-
-        qApp->setMainWidget( mainWidget );
+        KIO::SkipDialog_Result result = ((KIO::Job *)job)->ui()->askSkip( job, true, error );
 
         switch( result )
         {
@@ -1272,7 +1282,7 @@ void Synchronizer::slotTaskFinished(KIO::Job *job )
   }
 }
 
-void Synchronizer::slotProcessedSize( KIO::Job * job , KIO::filesize_t size)
+void Synchronizer::slotProcessedSize( KJob * job , qulonglong size)
 {
   KIO::filesize_t dl = 0, dr = 0, dd = 0;
   SynchronizerFileItem * item = jobMap[ job ];
@@ -1322,107 +1332,106 @@ QString Synchronizer::rightBaseDirectory()
   return rightBaseDir;
 }
 
-class KgetProgressDialog : public KDialogBase
+KgetProgressDialog::KgetProgressDialog( QWidget *parent, const QString &caption,
+                    const QString &text, bool modal) : KDialog( parent )
 {
-public:
-  KgetProgressDialog( QWidget *parent=0, const char *name=0, const QString &caption=QString::null,
-                    const QString &text=QString::null, bool modal=false) : KDialogBase( KDialogBase::Plain,
-                    caption, KDialogBase::User1 | KDialogBase::Cancel, KDialogBase::Cancel, parent, name, modal )
-  {
-    showButton(KDialogBase::Close, false);
+  if( caption.isEmpty() )
+    setWindowTitle( caption );
+  setButtons( KDialog::User1 | KDialog::Cancel );
+  setDefaultButton( KDialog::Cancel );
+  setModal( modal );
 
-    QFrame* mainWidget = plainPage();
-    QVBoxLayout* layout = new QVBoxLayout(mainWidget, 10);
+  showButton(KDialog::Close, false);
 
-    QLabel *mLabel = new QLabel(text, mainWidget);
-    layout->addWidget(mLabel);
+  QWidget* mainWidget = new QWidget( this );
+  QVBoxLayout* layout = new QVBoxLayout(mainWidget);
+  layout->setContentsMargins( 10, 10, 10, 10 );
 
-    mProgressBar = new KProgress(mainWidget);
-    layout->addWidget(mProgressBar);
+  QLabel *mLabel = new QLabel(text, mainWidget);
+  layout->addWidget(mLabel);
 
-    setButtonText( KDialogBase::User1, i18n( "Pause" ) );
+  mProgressBar = new QProgressBar(mainWidget);
+  layout->addWidget(mProgressBar);
 
-    mCancelled = mPaused = false;
-  }
+  setButtonText( KDialog::User1, i18n( "Pause" ) );
 
-  KProgress *progressBar() { return mProgressBar; }
+  mCancelled = mPaused = false;
 
-  void slotUser1()
-  {
-    if( ( mPaused = !mPaused ) == false )
-      setButtonText( KDialogBase::User1, i18n( "Pause" ) );
-    else
-      setButtonText( KDialogBase::User1, i18n( "Resume" ) );
-  }
+  connect( this, SIGNAL( user1Clicked() ), this, SLOT( slotUser1() ) );
+  connect( this, SIGNAL( cancelClicked() ), this, SLOT( reject() ) );
 
-  void slotCancel()
-  {
-    mCancelled = true;
+  setMainWidget( mainWidget );
+}
 
-    KDialogBase::slotCancel();
-  }
+void KgetProgressDialog::slotUser1()
+{
+  if( ( mPaused = !mPaused ) == false )
+    setButtonText( KDialog::User1, i18n( "Pause" ) );
+  else
+    setButtonText( KDialog::User1, i18n( "Resume" ) );
+}
 
-  bool wasCancelled()      { return mCancelled; }
-  bool isPaused()          { return mPaused; }
+void KgetProgressDialog::slotCancel()
+{
+  mCancelled = true;
 
-private:
-  KProgress *mProgressBar;
-  bool       mCancelled;
-  bool       mPaused;
-};
+  KDialog::reject();
+}
 
 
 void Synchronizer::synchronizeWithKGet()
 {
-  bool isLeftLocal = vfs::fromPathOrURL( leftBaseDirectory() ).isLocalFile();
+  bool isLeftLocal = KUrl( leftBaseDirectory() ).isLocalFile();
   KgetProgressDialog *progDlg = 0;
   int  processedCount = 0, totalCount = 0;
 
-  SynchronizerFileItem *item = resultList.first();
-  for(; item; item = resultList.next() )
-    if( item->isMarked() )
+  QListIterator<SynchronizerFileItem *> it(resultList);
+  while (it.hasNext())
+    if( it.next()->isMarked() )
       totalCount++;
 
-  item = resultList.first();
-  while( item )
+  it.toFront();
+  while( it.hasNext() )
   {
+    SynchronizerFileItem * item = it.next();
+
     if( item->isMarked() )
     {
-      KURL downloadURL, destURL;
+      KUrl downloadURL, destURL;
       QString leftDirName     = item->leftDirectory().isEmpty() ? "" : item->leftDirectory() + "/";
       QString rightDirName    = item->rightDirectory().isEmpty() ? "" : item->rightDirectory() + "/";
       QString destDir;
 
       if( progDlg == 0 )
       {
-        progDlg = new KgetProgressDialog( krApp, "Synchronizer Progress Dlg", i18n("Krusader::Synchronizer"),
+        progDlg = new KgetProgressDialog( krApp, i18n("Krusader::Synchronizer"),
                                           i18n( "Feeding the URLs to Kget" ), true );
-        progDlg->progressBar()->setTotalSteps( totalCount );
+        progDlg->progressBar()->setMaximum( totalCount );
         progDlg->show();
         qApp->processEvents();
       }
 
       if( item->task() == TT_COPY_TO_RIGHT && !isLeftLocal )
       {
-        downloadURL = vfs::fromPathOrURL( leftBaseDirectory() + leftDirName + item->leftName() );
+        downloadURL = KUrl( leftBaseDirectory() + leftDirName + item->leftName() );
         destDir     = rightBaseDirectory() + rightDirName;
-        destURL     = vfs::fromPathOrURL( destDir + item->rightName() );
+        destURL     = KUrl( destDir + item->rightName() );
 
         if( item->isDir() )
           destDir += item->leftName();
       }
       if( item->task() == TT_COPY_TO_LEFT && isLeftLocal )
       {
-        downloadURL = vfs::fromPathOrURL( rightBaseDirectory() + rightDirName + item->rightName() );
+        downloadURL = KUrl( rightBaseDirectory() + rightDirName + item->rightName() );
         destDir     = leftBaseDirectory() + leftDirName;
-        destURL     = vfs::fromPathOrURL( destDir + item->leftName() );
+        destURL     = KUrl( destDir + item->leftName() );
 
         if( item->isDir() )
           destDir += item->rightName();
       }
 
       // creating the directory system
-      for( int i=0; i >= 0 ; i= destDir.find('/',i+1) )
+      for( int i=0; i >= 0 ; i= destDir.indexOf('/',i+1) )
         if( !QDir( destDir.left(i) ).exists() )
           QDir().mkdir( destDir.left(i) );
 
@@ -1431,10 +1440,10 @@ void Synchronizer::synchronizeWithKGet()
         if( QFile( destURL.path() ).exists() )
           QFile( destURL.path() ).remove();
 
-        QString source = downloadURL.prettyURL();
-        if( source.contains( '@' ) >= 2 ) /* is this an ftp proxy URL? */
+        QString source = downloadURL.prettyUrl();
+        if( source.indexOf( '@' ) >= 2 ) /* is this an ftp proxy URL? */
         {
-          int lastAt = source.findRev( '@' );
+          int lastAt = source.lastIndexOf( '@' );
           QString startString = source.left( lastAt );
           QString endString = source.mid( lastAt );
           startString.replace( "@", "%40" );
@@ -1444,13 +1453,15 @@ void Synchronizer::synchronizeWithKGet()
         KProcess p;
 
         p << KrServices::fullPathName( "kget" ) << source << destURL.path();
-        if (!p.start(KProcess::Block))
-          KMessageBox::error(parentWidget,i18n("Error executing ")+KrServices::fullPathName( "kget" )+" !");
-        else
-          p.detach();
+        if (!p.startDetached())
+          KMessageBox::error(parentWidget, i18n("Error executing %1!").arg(KrServices::fullPathName( "kget" )));
       }
 
-      progDlg->progressBar()->setProgress( ++processedCount );
+      progDlg->progressBar()->setValue( ++processedCount );
+
+      QTime t;
+      t.start();
+      bool canExit = false;
 
       do
       {
@@ -1459,15 +1470,16 @@ void Synchronizer::synchronizeWithKGet()
         if( progDlg->wasCancelled() )
           break;
 
-        if( progDlg->isPaused() )
-          usleep( 100000 );
+        canExit = ( t.elapsed() > 100 );
 
-      }while( progDlg->isPaused() );
+        if( progDlg->isPaused() || !canExit )
+          usleep( 10000 );
+
+      }while( progDlg->isPaused() || !canExit );
 
       if( progDlg->wasCancelled() )
         break;
     }
-    item = resultList.next();
   }
 
   if( progDlg )
@@ -1487,7 +1499,15 @@ QString Synchronizer::readLink( const vfile * file ) {
   if( file->vfile_isSymLink() )
     return file->vfile_getSymDest();
   else
-    return QString::null;
+    return QString();
+}
+
+SynchronizerFileItem *Synchronizer::getItemAt( unsigned ndx )
+{
+  if( ndx < (unsigned)resultList.count() )
+    return resultList.at(ndx);
+  else
+    return 0;
 }
 
 #include "synchronizer.moc"
