@@ -34,10 +34,11 @@
 #include "synchronizertask.h"
 #include "synchronizerfileitem.h"
 #include <qobject.h>
-#include <qptrvector.h>
 #include <qmap.h>
 #include <qcolor.h>
+#include <QList>
 #include <kio/job.h>
+#include <kdialog.h>
 
 class KRQuery;
 class vfile;
@@ -58,6 +59,7 @@ class Synchronizer : public QObject
   
   public:
     Synchronizer();
+    ~Synchronizer();
     int     compare( QString leftURL, QString rightURL, KRQuery *query, bool subDirs, bool symLinks,
                      bool igDate, bool asymm, bool cmpByCnt, bool igCase, bool autoSc, QStringList &selFiles,
                      int equThres, int timeOffs, int parThreads, bool hiddenFiles );
@@ -73,6 +75,7 @@ class Synchronizer : public QObject
     void    resume();
     void    swapSides();
     void    reset();
+    void    clearLists();
 
     void    exclude( SynchronizerFileItem * );
     void    restore( SynchronizerFileItem * );
@@ -85,7 +88,7 @@ class Synchronizer : public QObject
     QString rightBaseDirectory();
     static QString getTaskTypeName( TaskType taskType );
 
-    SynchronizerFileItem *getItemAt( unsigned ndx ) {return resultList.at(ndx);}
+    SynchronizerFileItem *getItemAt( unsigned ndx );
 
     void     setParentWidget( QWidget * widget )    {parentWidget = widget;}
     void     compareContentResult( SynchronizerFileItem * item, bool result );
@@ -99,8 +102,8 @@ class Synchronizer : public QObject
     void    statusInfo( QString );
 
   public slots:
-    void    slotTaskFinished(KIO::Job*);
-    void    slotProcessedSize( KIO::Job * , KIO::filesize_t );
+    void    slotTaskFinished(KJob*);
+    void    slotProcessedSize( KJob * , qulonglong );
     
   private:
     bool                  isDir( const vfile * file );
@@ -150,8 +153,8 @@ class Synchronizer : public QObject
     bool                              cmpByContent;   // compare the files by content
     bool                              ignoreCase;     // case insensitive synchronization for Windows fs
     bool                              autoScroll;     // automatic update of the directory
-    QPtrList<SynchronizerFileItem>    resultList;     // the found files
-    QPtrList<SynchronizerFileItem>    temporaryList;  // temporary files
+    QList<SynchronizerFileItem *>     resultList;     // the found files
+    QList<SynchronizerFileItem *>     temporaryList;  // temporary files
     QString                           leftBaseDir;    // the left-side base directory
     QString                           rightBaseDir;   // the right-side base directory
     QStringList                       excludedPaths;  // list of the excluded paths
@@ -190,15 +193,41 @@ class Synchronizer : public QObject
     int                               fileCount;      // the number of counted files
 
   private:
-    QPtrList<SynchronizerTask>        stack;          // stack for comparing
-    QMap<KIO::Job *,SynchronizerFileItem *> jobMap;   // job maps
-    QMap<KIO::Job *,KIO::filesize_t>  receivedMap;    // the received file size
+    QList<SynchronizerTask *>         stack;          // stack for comparing
+    QMap<KJob *,SynchronizerFileItem *> jobMap;   // job maps
+    QMap<KJob *,KIO::filesize_t>      receivedMap;    // the received file size
     SynchronizerFileItem             *lastTask;       // reference to the last stack
     int                               inTaskFinished; // counter of quasy 'threads' in slotTaskFinished
 
     QStringList                       selectedFiles;  // the selected files to compare
     QWidget                          *parentWidget;   // the parent widget
     QWidget                          *syncDlgWidget;  // the synchronizer dialog widget
+    QListIterator<SynchronizerFileItem *> resultListIt; // iterator for result list
+};
+
+class QProgressBar;
+
+class KgetProgressDialog : public KDialog
+{
+  Q_OBJECT
+
+public:
+  KgetProgressDialog( QWidget *parent=0, const QString &caption=QString(),
+                    const QString &text=QString(), bool modal=false);
+
+  QProgressBar *progressBar() { return mProgressBar; }
+
+public slots:
+  void slotUser1();
+  void slotCancel();
+
+  bool wasCancelled()      { return mCancelled; }
+  bool isPaused()          { return mPaused; }
+
+private:
+  QProgressBar *mProgressBar;
+  bool          mCancelled;
+  bool          mPaused;
 };
 
 #endif /* __SYNCHRONIZER_H__ */
