@@ -10,25 +10,33 @@
 //
 //
 
-#include <kdialogbase.h>
+#include <kdialog.h>
 #include <kdebug.h>
 #include <klocale.h>
 #include <kinputdialog.h>
+#include <kactioncollection.h>
+#include <kshell.h>
 #include <qtextedit.h>
-#include <qvbox.h>
+#include <qtextstream.h>
+#include <qboxlayout.h>
 #include <qlayout.h>
 #include <qsplitter.h>
 #include <qpushbutton.h>
 #include <qcheckbox.h>
 #include <qfile.h>
 #include <qlabel.h>
+#include <QKeyEvent>
+#include <QEvent>
 #include <kaction.h>
 #include <kurl.h>
 #include <kmessagebox.h>
 #include <kfiledialog.h>
+#include <kvbox.h>
+#include <kpushbutton.h>
 #include "kraction.h"
 #include "expander.h"
 #include "useraction.h"
+#include "../GUI/terminaldock.h"
 #include "../krusader.h"
 #include "../krusaderview.h"
 #include "../defaults.h"
@@ -43,34 +51,44 @@
 //////////////////////////////////////////////////////////////////////////////////////////////////////
 #include <qlayout.h>
 KrActionProcDlg::KrActionProcDlg( QString caption, bool enableStderr, QWidget *parent ) :
-KDialogBase( parent, 0, false, caption, KDialogBase::User1 | KDialogBase::Ok | KDialogBase::Cancel, KDialogBase::Cancel ),
-_stdout(0), _stderr(0), _currentTextEdit(0) {
+        KDialog( parent ), _stdout(0), _stderr(0), _currentTextEdit(0) {
+   setWindowTitle( caption );
+   setButtons( KDialog::User1 | KDialog::Ok | KDialog::Cancel );
+   setDefaultButton( KDialog::Cancel );
+   setWindowModality( Qt::NonModal );
 
-   setButtonOK( i18n( "Close" ) );
-   enableButtonOK( false ); // disable the close button, until the process finishes
+   setButtonGuiItem( KDialog::Ok, KGuiItem( i18n( "Close" ) ) );
+   enableButtonOk( false ); // disable the close button, until the process finishes
 
-   setButtonCancel( KGuiItem(i18n("Kill"), i18n( "Kill the running process" )) );
+   setButtonGuiItem( KDialog::Cancel, KGuiItem(i18n("Kill"), i18n( "Kill the running process" )) );
 
-   setButtonText(KDialogBase::User1, i18n("Save as") );
+   setButtonText(KDialog::User1, i18n("Save as") );
 
-   QVBox *page = makeVBoxMainWidget();
+   KVBox *page = new KVBox( this );
+   setMainWidget( page );
    // do we need to separate stderr and stdout?
    if ( enableStderr ) {
-      QSplitter *splitt = new QSplitter( QSplitter::Vertical, page );
+      QSplitter *splitt = new QSplitter( Qt::Vertical, page );
       // create stdout
-      QVBox *stdoutBox = new QVBox( splitt, "stdout VBox" );
+      QWidget *stdoutWidget = new QWidget( splitt );
+      QVBoxLayout *stdoutBox = new QVBoxLayout( stdoutWidget );
+
       stdoutBox->setSpacing( 6 );
-      new QLabel( i18n( "Standard Output (stdout)" ), stdoutBox );
-      _stdout = new QTextEdit( stdoutBox );
+      stdoutBox->addWidget( new QLabel( i18n( "Standard Output (stdout)" ), stdoutWidget ) );
+      _stdout = new QTextEdit( stdoutWidget );
       _stdout->setReadOnly( true );
       _stdout->setMinimumWidth( fontMetrics().maxWidth() * 40 );
+      stdoutBox->addWidget( _stdout );
       // create stderr
-      QVBox *stderrBox = new QVBox( splitt, "stderr VBox" );
+      QWidget *stderrWidget = new QWidget( splitt );
+      QVBoxLayout *stderrBox = new QVBoxLayout( stderrWidget );
+
       stderrBox->setSpacing( 6 );
-      new QLabel( i18n( "Standard Error (stderr)" ), stderrBox );
-      _stderr = new QTextEdit( stderrBox );
+      stderrBox->addWidget( new QLabel( i18n( "Standard Error (stderr)" ), stderrWidget ) );
+      _stderr = new QTextEdit( stderrWidget );
       _stderr->setReadOnly( true );
       _stderr->setMinimumWidth( fontMetrics().maxWidth() * 40 );
+      stderrBox->addWidget( _stderr );
    } else {
       // create stdout
       new QLabel( i18n( "Output" ), page );
@@ -80,39 +98,41 @@ _stdout(0), _stderr(0), _currentTextEdit(0) {
    }
 
    _currentTextEdit = _stdout;
-   connect( _stdout, SIGNAL( clicked(int, int) ), SLOT( currentTextEditChanged() ) );
+   connect( _stdout, SIGNAL( textChanged() ), SLOT( currentTextEditChanged() ) );
    if (_stderr)
-      connect( _stderr, SIGNAL( clicked(int, int) ), SLOT( currentTextEditChanged() ) );
+      connect( _stderr, SIGNAL( textChanged() ), SLOT( currentTextEditChanged() ) );
 
-   krConfig->setGroup( "UserActions" );
-   normalFont = krConfig->readFontEntry( "Normal Font", _UserActions_NormalFont );
-   fixedFont = krConfig->readFontEntry( "Fixed Font", _UserActions_FixedFont );
-   bool startupState = krConfig->readBoolEntry( "Use Fixed Font", _UserActions_UseFixedFont );
+   KConfigGroup group( krConfig, "UserActions" );
+   normalFont = group.readEntry( "Normal Font", *_UserActions_NormalFont );
+   fixedFont = group.readEntry( "Fixed Font", *_UserActions_FixedFont );
+   bool startupState = group.readEntry( "Use Fixed Font", _UserActions_UseFixedFont );
    toggleFixedFont( startupState );
 
-   // HACK This fetches the layout of the buttonbox from KDialogBase, although it is not accessable with KDialogBase's API
+   // HACK This fetches the layout of the buttonbox from KDialog, although it is not accessable with KDialog's API
    // None the less it's quite save to use since this implementation hasn't changed since KDE-3.3 (I haven't looked at earlier
    // versions since we don't support them) and now all work is done in KDE-4.
-   QWidget* buttonBox = static_cast<QWidget*>( actionButton(KDialogBase::Ok)->parent() );
+   QWidget* buttonBox = static_cast<QWidget*>( button(KDialog::Ok)->parent() );
    QBoxLayout* buttonBoxLayout = static_cast<QBoxLayout*>( buttonBox->layout() );
    QCheckBox* useFixedFont = new QCheckBox( i18n("Use font with fixed width"), buttonBox );
    buttonBoxLayout->insertWidget( 0, useFixedFont );
    useFixedFont->setChecked( startupState );
    connect( useFixedFont, SIGNAL( toggled(bool) ), SLOT( toggleFixedFont(bool) ) );
+
+   connect( this, SIGNAL( user1Clicked() ), this, SLOT( slotUser1() ) );
 }
 
-void KrActionProcDlg::addStderr( KProcess *, char *buffer, int buflen ) {
+void KrActionProcDlg::addStderr(const QString& str) {
    if (_stderr)
-      _stderr->append( QString::fromLatin1( buffer, buflen ) );
+      _stderr->append(str);
    else {
-      _stdout->setItalic(true);
-      _stdout->append( QString::fromLatin1( buffer, buflen ) );
-      _stdout->setItalic(false);
+      _stdout->setFontItalic(true);
+      _stdout->append(str);
+      _stdout->setFontItalic(false);
    }
 }
 
-void KrActionProcDlg::addStdout( KProcess *, char *buffer, int buflen ) {
-   _stdout->append( QString::fromLatin1( buffer, buflen ) );
+void KrActionProcDlg::addStdout(const QString& str) {
+   _stdout->append(str);
 }
 
 void KrActionProcDlg::toggleFixedFont( bool state ) {
@@ -129,7 +149,7 @@ void KrActionProcDlg::toggleFixedFont( bool state ) {
 }
 
 void KrActionProcDlg::slotUser1() {
-   QString filename = KFileDialog::getSaveFileName(QString::null, i18n("*.txt|Text files\n*|all files"), this);
+   QString filename = KFileDialog::getSaveFileName(QString(), i18n("*.txt|Text files\n*|all files"), this);
    if ( filename.isEmpty() )
       return;
    QFile file( filename );
@@ -138,27 +158,27 @@ void KrActionProcDlg::slotUser1() {
       answer = KMessageBox::warningYesNoCancel( this,	//parent
       		i18n("This file already exists.\nDo you want to overwrite it or append the output?"),	//text
       		i18n("Overwrite or append?"),	//caption
-      		i18n("Overwrite"),	//label for Yes-Button
-      		i18n("Append")	//label for No-Button
+      		KGuiItem( i18n("Overwrite") ),	//label for Yes-Button
+      		KGuiItem( i18n("Append") )	//label for No-Button
       	);
    if ( answer == KMessageBox::Cancel )
       return;
    bool open;
    if ( answer == KMessageBox::No ) // this means to append
-      open = file.open( IO_WriteOnly | IO_Append );
+      open = file.open( QIODevice::WriteOnly | QIODevice::Append );
    else
-      open = file.open( IO_WriteOnly );
+      open = file.open( QIODevice::WriteOnly );
 
    if ( ! open ) {
       KMessageBox::error( this,
-      		i18n("Can't open %1 for writing!\nNothing exported.").arg(filename),
+      		i18n("Can't open %1 for writing!\nNothing exported.", filename),
       		i18n("Export failed!")
       	);
       return;
    }
 
    QTextStream stream( &file );
-   stream << _currentTextEdit->text();
+   stream << _currentTextEdit->toPlainText();
    file.close();
 }
 
@@ -174,10 +194,8 @@ void KrActionProcDlg::currentTextEditChanged() {
 //////////////////////////////////////////////////////////////////////////////////////////////////////
 
 KrActionProc::KrActionProc( KrActionBase* action ) : QObject(), _action( action ), _proc( new KProcess(this) ), _output( 0 ) {
-   _proc->setUseShell( true );
-
-   connect( _proc, SIGNAL( processExited( KProcess* ) ),
-            this, SLOT( processExited( KProcess* ) ) ) ;
+   connect( _proc, SIGNAL( finished( int, QProcess::ExitStatus ) ),
+            this, SLOT( processExited( int, QProcess::ExitStatus ) ) ) ;
 }
 
 KrActionProc::~KrActionProc() {
@@ -185,13 +203,15 @@ KrActionProc::~KrActionProc() {
 }
 
 void KrActionProc::start( QString cmdLine ) {
-   QStringList list = cmdLine;
+   QStringList list;
+   list << cmdLine;
    start( list );
 }
 
 void KrActionProc::start( QStringList cmdLineList ) {
-   _proc->clearArguments();
-   QString cmd;
+   _proc->clearProgram(); // this clears the arglist too
+   QString cmd; // This is the command the user wants to execute
+   QStringList shellCmd; // this is the command which is really executed (with  maybe kdesu, maybe konsole, ...)
 
    if ( ! _action->startpath().isEmpty() )
       _proc->setWorkingDirectory( _action->startpath() );
@@ -200,12 +220,12 @@ void KrActionProc::start( QStringList cmdLineList ) {
       KMessageBox::sorry( 0, i18n("Support for more than one command doesn't work in a terminal. Only the first is executed in the terminal.") );
 
    if ( _action->execType() == KrAction::RunInTE
-         && ( MAIN_VIEW->konsole_part == NULL || MAIN_VIEW->konsole_part->widget() == NULL ) ) {
+         && ( ! MAIN_VIEW->terminal_dock->initialise() ) ) {
       KMessageBox::sorry( 0, i18n("Embedded terminal emulator does not work, using output collection instead.") );
    }
 
    if( _action->execType() == KrAction::Normal || _action->execType() == KrAction::Terminal
-       || ( _action->execType() == KrAction::RunInTE && MAIN_VIEW->konsole_part && MAIN_VIEW->konsole_part->widget() )
+       || ( _action->execType() == KrAction::RunInTE && MAIN_VIEW->terminal_dock->isInitialised() )
    ) { // not collect output
       //TODO option to run them in paralell (not available for: collect output)
       for ( QStringList::Iterator it = cmdLineList.begin(); it != cmdLineList.end(); ++it) {
@@ -216,26 +236,25 @@ void KrActionProc::start( QStringList cmdLineList ) {
       //run in TE
       if ( _action->execType() == KrAction::RunInTE ) {
          //send the commandline contents to the terminal emulator
-         QKeyEvent keyEvent( QEvent::KeyPress, 0, -1, 0,  cmd+"\n");
-         QApplication::sendEvent( MAIN_VIEW->konsole_part->widget(), &keyEvent );     
+        MAIN_VIEW->terminal_dock->sendInput( cmd+"\n" );
       } else { // will start a new process
          // run in terminal
          if ( _action->execType() == KrAction::Terminal ) {
-           krConfig->setGroup( "UserActions" );
-           QString term = krConfig->readEntry( "Terminal", _UserActions_Terminal );
+           KConfigGroup group( krConfig, "UserActions" );
+           QString term = group.readEntry( "Terminal", _UserActions_Terminal );
 
             if ( _action->user().isEmpty() )
-               ( *_proc ) << term << cmd;
+               shellCmd << term << cmd;
             else
-//                ( *_proc )  << "kdesu" << "-u" << *_properties->user() << "-c" << KProcess::quote("konsole --noclose -e " + KProcess::quote(cmd) );
-               ( *_proc )  << "kdesu" << "-u" << _action->user() << "-c" << KProcess::quote( term + " " + cmd );
+               shellCmd  << "kdesu" << "-u" << _action->user() << "-c" << KShell::quoteArg( term + " " + cmd );
          } else { // no terminal, no output collection, start&forget
             if ( _action->user().isEmpty() )
-               ( *_proc ) << cmd;
+               shellCmd << cmd;
             else
-               ( *_proc ) << "kdesu" << "-u" << _action->user() << "-c" << KProcess::quote(cmd);
+               shellCmd << "kdesu" << "-u" << _action->user() << "-c" << KShell::quoteArg(cmd);
          }
-         _proc->start( KProcess::NotifyOnExit, ( KProcess::Communication ) ( KProcess::Stdout | KProcess::Stderr ) );
+         _proc->setShellCommand(shellCmd.join(" "));
+         _proc->start();
       }
    }
    else { // collect output
@@ -244,8 +263,9 @@ void KrActionProc::start( QStringList cmdLineList ) {
          separateStderr = true;
       _output = new KrActionProcDlg( _action->text(), separateStderr );
       // connect the output to the dialog
-      connect( _proc, SIGNAL( receivedStderr( KProcess*, char*, int ) ), _output, SLOT( addStderr( KProcess*, char *, int ) ) );
-      connect( _proc, SIGNAL( receivedStdout( KProcess*, char*, int ) ), _output, SLOT( addStdout( KProcess*, char *, int ) ) );
+      _proc->setOutputChannelMode( KProcess::SeparateChannels );
+      connect( _proc, SIGNAL( readyReadStandardError() ), SLOT( addStderr() ) );
+      connect( _proc, SIGNAL( readyReadStandardOutput() ), SLOT( addStdout() ) );
       connect( _output, SIGNAL( cancelClicked() ), this, SLOT( kill() ) );
       _output->show();
       for ( QStringList::Iterator it = cmdLineList.begin(); it != cmdLineList.end(); ++it) {
@@ -257,46 +277,68 @@ void KrActionProc::start( QStringList cmdLineList ) {
          cmd += *it;
       }
       if ( _action->user().isEmpty() )
-         ( *_proc ) << cmd;
+         shellCmd << cmd;
       else
          // "-t" is nessesary that kdesu displays the terminal-output of the command
-         ( *_proc ) << "kdesu" << "-t" << "-u" << _action->user() << "-c" << KProcess::quote(cmd);
-      _proc->start( KProcess::NotifyOnExit, ( KProcess::Communication ) ( KProcess::Stdout | KProcess::Stderr ) );
+         shellCmd << "kdesu" << "-t" << "-u" << _action->user() << "-c" << KShell::quoteArg(cmd);
+      _proc->setShellCommand(shellCmd.join(" "));
+      _proc->start();
    }
 
 }
 
-void KrActionProc::processExited( KProcess * ) {
+void KrActionProc::processExited( int exitCode, QProcess::ExitStatus exitStatus ) {
    // enable the 'close' button on the dialog (if active), disable 'kill' button
    if ( _output ) {
-      _output->enableButtonOK( true );
+      // TODO tell the user the programms exit code
+      _output->enableButtonOk( true );
       _output->enableButtonCancel( false);
    }
    delete this; // banzai!!
 }
 
+void KrActionProc::addStderr() {
+   if (_output) {
+      _output->addStderr(QString::fromLocal8Bit(_proc->readAllStandardError().data()));
+   }
+}
+
+void KrActionProc::addStdout() {
+   if (_output) {
+      _output->addStdout(QString::fromLocal8Bit(_proc->readAllStandardOutput().data()));
+   }
+}
+
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////
 ///////////////////////////////////////  KrAction  ///////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////////////////////////////
 
-KrAction::KrAction( KActionCollection *parent, const char* name ) : KAction( parent, name ) {
-   connect(this, SIGNAL(activated()), this, SLOT(exec()) );
+KrAction::KrAction( KActionCollection *parent, QString name ) : KAction( (QObject *)parent ) {
+   if( !name.isNull() )
+     _name = name;
+   else
+     _name = "";
+
+   parent->addAction( _name, this );
+
+   connect(this, SIGNAL(triggered()), this, SLOT(exec()) );
 }
 
 KrAction::~KrAction() {
-   unplugAll();
+   foreach (QWidget *w, associatedWidgets())
+     w->removeAction(this);
    krUserAction->removeKrAction( this ); // Importent! Else Krusader will crash when writing the actions to file
 }
 
-bool KrAction::isAvailable( const KURL& currentURL ) {
+bool KrAction::isAvailable( const KUrl& currentURL ) {
    bool available = true; //show per default (FIXME: make the default an attribute of <availability>)
    
    //check protocol
    if ( ! _showonlyProtocol.empty() ) {
       available = false;
       for ( QStringList::Iterator it = _showonlyProtocol.begin(); it != _showonlyProtocol.end(); ++it ) {
-         //kdDebug() << "KrAction::isAvailable currendProtocol: " << currentURL.protocol() << " =?= " << *it << endl;
+         //kDebug() << "KrAction::isAvailable currendProtocol: " << currentURL.protocol() << " =?= " << *it << endl;
          if ( currentURL.protocol() == *it ) {  // FIXME remove trailing slashes at the xml-parsing (faster because done only once)
             available = true;
             break;
@@ -305,11 +347,11 @@ bool KrAction::isAvailable( const KURL& currentURL ) {
    } //check protocol: done
       
    //check the Path-list:
-   if ( ! _showonlyPath.empty() ) {
+   if ( available && ! _showonlyPath.empty() ) {
       available = false;
       for ( QStringList::Iterator it = _showonlyPath.begin(); it != _showonlyPath.end(); ++it ) {
          if ( (*it).right(1) == "*" ){
-             if ( currentURL.path().find( (*it).left( (*it).length() - 1 ) ) == 0 ) {
+             if ( currentURL.path().indexOf( (*it).left( (*it).length() - 1 ) ) == 0 ) {
                available = true;
                break;
             }
@@ -322,30 +364,33 @@ bool KrAction::isAvailable( const KURL& currentURL ) {
    } //check the Path-list: done
    
    //check mime-type
-   if ( ! _showonlyMime.empty() ) {
+   if ( available && ! _showonlyMime.empty() ) {
       available = false;
-      KMimeType::Ptr mime = KMimeType::findByURL( currentURL );
-      for ( QStringList::Iterator it = _showonlyMime.begin(); it != _showonlyMime.end(); ++it ) {
-         if ( (*it).contains("/") ) {
-            if ( mime->is( *it ) ) {  // don't use ==; use 'is()' instead, which is aware of inheritence (ie: text/x-makefile is also text/plain)
-               available = true;
-               break;
+      KMimeType::Ptr mime = KMimeType::findByUrl( currentURL );
+      if( mime )
+      {
+         for ( QStringList::Iterator it = _showonlyMime.begin(); it != _showonlyMime.end(); ++it ) {
+            if ( (*it).contains("/") ) {
+               if ( mime->is( *it ) ) {  // don't use ==; use 'is()' instead, which is aware of inheritence (ie: text/x-makefile is also text/plain)
+                  available = true;
+                  break;
+               }
             }
-         }
-         else {
-            if ( mime->name().find( *it ) == 0 ) {  // 0 is the beginning, -1 is not found
-               available = true;
-               break;
+            else {
+               if ( mime->name().indexOf( *it ) == 0 ) {  // 0 is the beginning, -1 is not found
+                  available = true;
+                  break;
+               }
             }
-         }
-      } //for
+         } //for
+      }
    } //check the mime-type: done
    
    //check filename
-   if ( ! _showonlyFile.empty() ) {
+   if ( available && ! _showonlyFile.empty() ) {
       available = false;
       for ( QStringList::Iterator it = _showonlyFile.begin(); it != _showonlyFile.end(); ++it ) {
-         QRegExp regex = QRegExp( *it, false, true ); // case-sensitive = false; wildcards = true
+         QRegExp regex = QRegExp( *it, Qt::CaseInsensitive, QRegExp::Wildcard ); // case-sensitive = false; wildcards = true
          if ( regex.exactMatch( currentURL.fileName() ) ) {
             available = true;
             break;
@@ -366,8 +411,15 @@ bool KrAction::xmlRead( const QDomElement& element ) {
 
    Also the name has to be checked before the action is created!
 
-   setName( element.attribute( "name" ).latin1() );
+   setName( element.attribute( "name" ).toLatin1() );
 */
+   QString attr;
+
+   attr = element.attribute( "enabled", "true" ); // default: "true"
+   if ( attr == "false" ) {
+      setEnabled( false );
+      setVisible( false );
+   }
 
    for ( QDomNode node = element.firstChild(); !node.isNull(); node = node.nextSibling() ) {
       QDomElement e = node.toElement();
@@ -381,7 +433,7 @@ bool KrAction::xmlRead( const QDomElement& element ) {
          setToolTip( e.text() );
       else
       if ( e.tagName() == "icon" )
-         setIcon( e.text() );
+         setIcon( KIcon( _iconName = e.text() ) );
       else
       if ( e.tagName() == "category" )
          setCategory( e.text() );
@@ -404,7 +456,7 @@ bool KrAction::xmlRead( const QDomElement& element ) {
 
       // unknown but not empty
       if ( ! e.tagName().isEmpty() )
-         krOut << "KrAction::xmlRead() - unrecognized tag found: <action name=\"" << name() << "\"><" << e.tagName() << ">" << endl;
+         krOut << "KrAction::xmlRead() - unrecognized tag found: <action name=\"" << _name << "\"><" << e.tagName() << ">" << endl;
 
    } // for ( QDomNode node = action->firstChild(); !node.isNull(); node = node.nextSibling() )
 
@@ -413,7 +465,11 @@ bool KrAction::xmlRead( const QDomElement& element ) {
 
 QDomElement KrAction::xmlDump( QDomDocument& doc ) const {
    QDomElement actionElement = doc.createElement("action");
-   actionElement.setAttribute( "name", name() );
+   actionElement.setAttribute( "name", _name );
+   
+   if ( ! isVisible() ) {
+      actionElement.setAttribute( "enabled", "false" );
+   }
 
 #define TEXT_ELEMENT( TAGNAME, TEXT ) \
    { \
@@ -427,8 +483,8 @@ QDomElement KrAction::xmlDump( QDomDocument& doc ) const {
    if ( ! toolTip().isEmpty() )
       TEXT_ELEMENT( "tooltip", toolTip() )
 
-   if ( ! icon().isEmpty() )
-      TEXT_ELEMENT( "icon", icon() )
+   if ( ! _iconName.isEmpty() )
+      TEXT_ELEMENT( "icon", _iconName )
 
    if ( ! category().isEmpty() )
       TEXT_ELEMENT( "category", category() )
@@ -445,8 +501,8 @@ QDomElement KrAction::xmlDump( QDomDocument& doc ) const {
    if ( availabilityElement.hasChildNodes() )
       actionElement.appendChild( availabilityElement );
 
-   if ( ! shortcut().isNull() )
-      TEXT_ELEMENT( "defaultshortcut", shortcut().toStringInternal() )  //.toString() would return a localised string which can't be read again
+   if ( ! shortcut().isEmpty() )
+      TEXT_ELEMENT( "defaultshortcut", shortcut().toString() )  //.toString() would return a localised string which can't be read again
 
    return actionElement;
 } //KrAction::xmlDump
@@ -465,7 +521,7 @@ void KrAction::readCommand( const QDomElement& element ) {
    else if ( attr == "collect_output_separate_stderr")
       setExecType( CollectOutputSeparateStderr );
    else
-      krOut << "KrAction::readCommand() - unrecognized attribute value found: <action name=\"" << name() << "\"><command executionmode=\"" << attr << "\""<< endl;
+      krOut << "KrAction::readCommand() - unrecognized attribute value found: <action name=\"" << _name << "\"><command executionmode=\"" << attr << "\""<< endl;
 
    attr = element.attribute( "accept", "local" ); // default: "local"
    if ( attr == "local" )
@@ -473,7 +529,7 @@ void KrAction::readCommand( const QDomElement& element ) {
    else if ( attr == "url")
       setAcceptURLs( true );
    else
-        krOut << "KrAction::readCommand() - unrecognized attribute value found: <action name=\"" << name() << "\"><command accept=\"" << attr << "\""<< endl;
+        krOut << "KrAction::readCommand() - unrecognized attribute value found: <action name=\"" << _name << "\"><command accept=\"" << attr << "\""<< endl;
 
    attr = element.attribute( "confirmexecution", "false" ); // default: "false"
    if ( attr == "true" )
@@ -539,7 +595,7 @@ void KrAction::readAvailability( const QDomElement& element ) {
       if ( e.tagName() == "filename" )
          showlist = & _showonlyFile;
       else {
-         krOut << "KrAction::readAvailability() - unrecognized element found: <action name=\"" << name() << "\"><availability><" << e.tagName() << ">"<< endl;
+         krOut << "KrAction::readAvailability() - unrecognized element found: <action name=\"" << _name << "\"><availability><" << e.tagName() << ">"<< endl;
          showlist = 0;
       }
 
@@ -555,7 +611,7 @@ void KrAction::readAvailability( const QDomElement& element ) {
 } //KrAction::readAvailability
 
 QDomElement KrAction::dumpAvailability( QDomDocument& doc ) const {
-   QDomElement availabilityElement = doc.createElement("command");
+   QDomElement availabilityElement = doc.createElement("availability");
 
 # define LIST_ELEMENT( TAGNAME, LIST ) \
    { \
