@@ -15,7 +15,8 @@
 
 #include <kaction.h>
 #include <kprocess.h>
-#include <kdialogbase.h>
+#include <kdialog.h>
+#include <qbytearray.h>
 #include "kractionbase.h"
 
 class UserActionProperties;
@@ -31,7 +32,7 @@ class QDomDocument;
 class KrAction: public KAction, public KrActionBase {
    Q_OBJECT
    public:
-      KrAction( KActionCollection *parent, const char* name );
+      KrAction( KActionCollection *parent, QString name = QString::null );
       ~KrAction();
 
       /**
@@ -39,12 +40,16 @@ class KrAction: public KAction, public KrActionBase {
        * @param currentURL Check for this file
        * @return true if the KrAction if available
        */
-      bool isAvailable( const KURL& currentURL );
+      bool isAvailable( const KUrl& currentURL );
+
+      const QString& iconName() const { return _iconName; } // TODO: added for kde4 porting (functionality is missing)
+      void setIconName( const QString& name ) { _iconName = name; }
 
       bool xmlRead( const QDomElement& element );
       QDomElement xmlDump( QDomDocument& doc ) const;
 
       void setName( const char* ) { /* empty reimplementation to prevent a name-change */ };
+      const QString & getName()   { return _name; }
 
       QString category() const { return _category; };
       void setCategory( const QString& category ) { _category = category; };
@@ -100,6 +105,7 @@ class KrAction: public KAction, public KrActionBase {
       void readAvailability( const QDomElement& element );
       QDomElement dumpAvailability( QDomDocument& doc ) const;
 
+      QString _iconName;
       QString _category;
       QString _command;
       QString _user;
@@ -112,6 +118,7 @@ class KrAction: public KAction, public KrActionBase {
       QStringList _showonlyMime;
       QStringList _showonlyFile;
 
+      QString  _name;
 };
 
 class QFont;
@@ -119,14 +126,16 @@ class QFont;
  * This displays the output of a process
  * @author Shie Erlich, Jonas Bähr
  */
-class KrActionProcDlg: public KDialogBase {
+class KrActionProcDlg: public KDialog {
       Q_OBJECT
    public:
       KrActionProcDlg( QString caption, bool enableStderr = false, QWidget *parent = 0 );
 
+   public slots:
+      void addStderr(const QString& str);
+      void addStdout(const QString& str);
+
    protected slots:
-      void addStderr( KProcess *proc, char *buffer, int buflen );
-      void addStdout( KProcess *proc, char *buffer, int buflen );
       void toggleFixedFont( bool state );
       void slotUser1(); ///< This is used to save the buffer to disc
 
@@ -152,8 +161,10 @@ class KrActionProc: public QObject {
       void start( QStringList cmdLineList );
 
    protected slots:
-      void kill() { _proc->kill( SIGINT ); }
-      void processExited( KProcess *proc );
+      void kill() { _proc->kill(); }
+      void processExited( int exitCode, QProcess::ExitStatus exitStatus );
+      void addStderr();
+      void addStdout();
 
    private:
       KrActionBase* _action;
