@@ -4,7 +4,7 @@
 // Description: 
 //
 //
-// Author: Jonas Bhr, (C) 2004
+// Author: Jonas Bähr, (C) 2004
 //
 // Copyright: See COPYING file that comes with this distribution
 //
@@ -13,13 +13,13 @@
 #ifndef USERACTIONPOPUPMENU_H
 #define USERACTIONPOPUPMENU_H
 
-#include <kpopupmenu.h>
+#include <kactionmenu.h>
 
-class KURL;
+class KUrl;
 
-class UserActionPopupMenu : public KPopupMenu {
+class UserActionPopupMenu : public KActionMenu {
 public:
-   UserActionPopupMenu( KURL currentURL, QWidget *parent = 0 );
+   UserActionPopupMenu( const KUrl &currentURL, QWidget *parent = 0 );
 };
 
 #endif // ifndef USERACTIONPOPUPMENU_H
