@@ -18,12 +18,13 @@ email                :
 #ifndef USERMENU_H
 #define USERMENU_H
 
-#include <kpopupmenu.h>
+#include <kmenu.h>
 
 class QWidget;
 class UserMenu;
+class QAction;
 
-class UserMenuGui: public KPopupMenu {
+class UserMenuGui: public KMenu {
    public:
       UserMenuGui( UserMenu* menu, QWidget *parent = 0 );
       void run();
@@ -31,11 +32,14 @@ class UserMenuGui: public KPopupMenu {
 
    protected:
       void readEntries();
+
+   private:
+      QAction* _manageAction;
 };
 
 class UserMenu : public QWidget {
    public:
-      UserMenu( QWidget *parent = 0, const char *name = 0 );
+      UserMenu( QWidget *parent = 0 );
       void exec();
       void update();
    
