@@ -44,14 +44,15 @@
 #include <kio/jobclasses.h>
 #include <klocale.h>
 #include <kio/job.h>
+#include <kio/jobuidelegate.h>
+#include <kio/deletejob.h>
+#include <kuiserverjobtracker.h>
 #include <kmessagebox.h>
-#include <kprotocolinfo.h>
+#include <kprotocolmanager.h>
 #include <kdebug.h> 
 // Krusader includes
 #include "ftp_vfs.h"
 #include "krpermhandler.h"
-#include "../Dialogs/krdialogs.h"
-#include "../Dialogs/krprogress.h"
 #include "../krusader.h"
 #include "../defaults.h"
 #include "../resources.h"
@@ -59,7 +60,7 @@
 ftp_vfs::ftp_vfs( QObject* panel ) : vfs( panel ), busy( false ) {
 	// set the writable attribute
 	isWritable = true;
-	vfs_type = FTP;
+	vfs_type = VFS_FTP;
 }
 
 ftp_vfs::~ftp_vfs() {
@@ -73,8 +74,8 @@ void ftp_vfs::slotAddFiles( KIO::Job *, const KIO::UDSEntryList& entries ) {
 	if( prot == "krarc" || prot == "tar" || prot == "zip" )
 		rwx = PERM_ALL;
 	
-	KIO::UDSEntryListConstIterator it = entries.begin();
-	KIO::UDSEntryListConstIterator end = entries.end();
+	KIO::UDSEntryList::const_iterator it = entries.begin();
+	KIO::UDSEntryList::const_iterator end = entries.end();
 
 	// as long as u can find files - add them to the vfs
 	for ( ; it != end; ++it ) {
@@ -87,7 +88,7 @@ void ftp_vfs::slotAddFiles( KIO::Job *, const KIO::UDSEntryList& entries ) {
 		if ( name.isEmpty() || name == "." || name == ".." ) continue;
 
 		KIO::filesize_t size = kfi.size();
-		time_t mtime = kfi.time( KIO::UDS_MODIFICATION_TIME );
+		time_t mtime = kfi.time( KFileItem::ModificationTime ).toTime_t();
 		bool symLink = kfi.isLink();
 		mode_t mode = kfi.mode() | kfi.permissions();
 		QString perm = KRpermHandler::mode2QString( mode );
@@ -105,68 +106,60 @@ void ftp_vfs::slotAddFiles( KIO::Job *, const KIO::UDSEntryList& entries ) {
 		else {
 			QString currentUser = vfs_origin.user();
 			if ( currentUser.contains( "@" ) )  /* remove the FTP proxy tags from the username */
-				currentUser.truncate( currentUser.find( '@' ) );
+				currentUser.truncate( currentUser.indexOf( '@' ) );
 			if ( currentUser.isEmpty() ) {
 				if( vfs_origin.host().isEmpty() )
 					currentUser = KRpermHandler::uid2user( getuid() );
 				else {
-					currentUser = ""; // empty, but not QString::null
+					currentUser = ""; // empty, but not QString()
 				}
 			}
-#if KDE_IS_VERSION(3,5,0)
 			temp = new vfile( name, size, perm, mtime, symLink,
 			                  kfi.user(), kfi.group(), currentUser, 
 			                  mime, symDest, mode, rwx, kfi.ACL().asString(),
 			                  kfi.defaultACL().asString() );
-#else
-			temp = new vfile( name, size, perm, mtime, symLink, kfi.user(), kfi.group(), currentUser, mime, symDest, mode, rwx );
-#endif
 		}
 
-#if KDE_IS_VERSION(3,4,0)
 		if( !kfi.localPath().isEmpty() ){
 			temp->vfile_setUrl( kfi.localPath() );
 		} else {
 			temp->vfile_setUrl( kfi.url() );
 		}
-#else
-		temp->vfile_setUrl( kfi.url() );
-#endif
 		temp->vfile_setIcon( kfi.iconName() );
 		foundVfile( temp );
 	}
 }
 
-void ftp_vfs::slotPermanentRedirection( KIO::Job*, const KURL&, const KURL& newUrl ) {
+void ftp_vfs::slotPermanentRedirection( KIO::Job*, const KUrl&, const KUrl& newUrl ) {
 	vfs_origin = newUrl;
-	vfs_origin.adjustPath(-1);
+	vfs_origin.adjustPath(KUrl::RemoveTrailingSlash);
 }
 
-void ftp_vfs::slotRedirection( KIO::Job *, const KURL &url ) {
+void ftp_vfs::slotRedirection( KIO::Job *, const KUrl &url ) {
 	// update the origin
 	vfs_origin = url;
-	vfs_origin.adjustPath(-1);
+	vfs_origin.adjustPath(KUrl::RemoveTrailingSlash);
 }
 
-void ftp_vfs::slotListResult( KIO::Job *job ) {
+void ftp_vfs::slotListResult( KJob *job ) {
 	if ( job && job->error() ) {
 		// we failed to refresh
 		listError = true;
 		// display error message
-		if ( !quietMode ) job->showErrorDialog( krApp );
+		if ( !quietMode ) job->uiDelegate()->showErrorMessage();
 	}
 	busy = false;
 }
 
-bool ftp_vfs::populateVfsList( const KURL& origin, bool showHidden ) {
-	QString errorMsg = QString::null;
+bool ftp_vfs::populateVfsList( const KUrl& origin, bool showHidden ) {
+	QString errorMsg = QString();
 	if ( !origin.isValid() )
-		errorMsg = i18n( "Malformed URL:\n%1" ).arg( origin.url() );
-	if ( !KProtocolInfo::supportsListing( origin ) ) {
-		if( origin.protocol() == "ftp" && KProtocolInfo::supportsReading( origin ) ) 
+		errorMsg = i18n( "Malformed URL:\n%1", origin.url() );
+	if ( !KProtocolManager::supportsListing( origin ) ) {
+		if( origin.protocol() == "ftp" && KProtocolManager::supportsReading( origin ) ) 
 			errorMsg = i18n( "Krusader doesn't support FTP access via HTTP.\nIf it is not the case, please check and change the Proxy settings in kcontrol." );
 		else
-			errorMsg = i18n( "Protocol not supported by Krusader:\n%1" ).arg( origin.url() );
+			errorMsg = i18n( "Protocol not supported by Krusader:\n%1", origin.url() );
 	}
 
 	if ( !errorMsg.isEmpty() ) {
@@ -177,29 +170,27 @@ bool ftp_vfs::populateVfsList( const KURL& origin, bool showHidden ) {
 	busy = true;
 
 	vfs_origin = origin;
-	vfs_origin.adjustPath(-1);
+	vfs_origin.adjustPath(KUrl::RemoveTrailingSlash);
 
 	//QTimer::singleShot( 0,this,SLOT(startLister()) );
 	listError = false;
 	// Open the directory	marked by origin
-	krConfig->setGroup( "Look&Feel" );
-	//vfs_origin.adjustPath(+1);
-	KIO::Job *job = KIO::listDir( vfs_origin, false, showHidden );
+	//vfs_origin.adjustPath(KUrl::AddTrailingSlash);
+	KIO::Job *job = KIO::listDir( vfs_origin, KIO::HideProgressInfo, showHidden );
 	connect( job, SIGNAL( entries( KIO::Job*, const KIO::UDSEntryList& ) ),
 	         this, SLOT( slotAddFiles( KIO::Job*, const KIO::UDSEntryList& ) ) );
-	connect( job, SIGNAL( redirection( KIO::Job*, const KURL& ) ),
-	         this, SLOT( slotRedirection( KIO::Job*, const KURL& ) ) );
-	connect( job, SIGNAL( permanentRedirection( KIO::Job*, const KURL&, const KURL& ) ),
-	         this, SLOT( slotPermanentRedirection( KIO::Job*, const KURL&, const KURL& ) ) );
+	connect( job, SIGNAL( redirection( KIO::Job*, const KUrl& ) ),
+	         this, SLOT( slotRedirection( KIO::Job*, const KUrl& ) ) );
+	connect( job, SIGNAL( permanentRedirection( KIO::Job*, const KUrl&, const KUrl& ) ),
+	         this, SLOT( slotPermanentRedirection( KIO::Job*, const KUrl&, const KUrl& ) ) );
 
-	connect( job, SIGNAL( result( KIO::Job* ) ),
-	         this, SLOT( slotListResult( KIO::Job* ) ) );
+	connect( job, SIGNAL( result( KJob* ) ),
+	         this, SLOT( slotListResult( KJob* ) ) );
 
-	job->setWindow( krApp );
+	job->ui()->setWindow( krApp );
 
 	if ( !quietMode ) {
 		emit startJob( job );
-		//new KrProgress(job); ==> disabled because of in-panel refresh
 	}
 
 	while ( busy && vfs_processEvents());
@@ -211,45 +202,57 @@ bool ftp_vfs::populateVfsList( const KURL& origin, bool showHidden ) {
 
 
 // copy a file to the vfs (physical)
-void ftp_vfs::vfs_addFiles( KURL::List *fileUrls, KIO::CopyJob::CopyMode mode, QObject* toNotify, QString dir,  PreserveMode /*pmode*/ ) {
-	KURL destUrl = vfs_origin;
+void ftp_vfs::vfs_addFiles( KUrl::List *fileUrls, KIO::CopyJob::CopyMode mode, QObject* toNotify, QString dir,  PreserveMode /*pmode*/ ) {
+	KUrl destUrl = vfs_origin;
 
 	if ( dir != "" ) {
 		destUrl.addPath( dir );
 		destUrl.cleanPath();  // removes the '..', '.' and extra slashes from the URL.
 
 		if ( destUrl.protocol() == "tar" || destUrl.protocol() == "zip" || destUrl.protocol() == "krarc" ) {
-			if ( QDir( destUrl.path( -1 ) ).exists() )
+			if ( QDir( destUrl.path( KUrl::RemoveTrailingSlash ) ).exists() )
 				destUrl.setProtocol( "file" );  // if we get out from the archive change the protocol
 		}
 	}
 
-	KIO::Job* job = new KIO::CopyJob( *fileUrls, destUrl, mode, false, true );
-	connect( job, SIGNAL( result( KIO::Job* ) ), this, SLOT( vfs_refresh( KIO::Job* ) ) );
+	KIO::Job* job = 0;
+	switch( mode ) {
+	case KIO::CopyJob::Copy:
+		job = KIO::copy( *fileUrls, destUrl );
+		break;
+	case KIO::CopyJob::Move:
+		job = KIO::move( *fileUrls, destUrl );
+		break;
+	case KIO::CopyJob::Link:
+		job = KIO::link( *fileUrls, destUrl );
+		break;
+	}
+
+	connect( job, SIGNAL( result( KJob* ) ), this, SLOT( vfs_refresh( KJob* ) ) );
 	if ( mode == KIO::CopyJob::Move )  // notify the other panel
-		connect( job, SIGNAL( result( KIO::Job* ) ), toNotify, SLOT( vfs_refresh( KIO::Job* ) ) );
+		connect( job, SIGNAL( result( KJob* ) ), toNotify, SLOT( vfs_refresh( KJob* ) ) );
 }
 
 // remove a file from the vfs (physical)
-void ftp_vfs::vfs_delFiles( QStringList *fileNames ) {
-	KURL::List filesUrls;
-	KURL url;
+void ftp_vfs::vfs_delFiles( QStringList *fileNames, bool /* reallyDelete */ ) {
+	KUrl::List filesUrls;
+	KUrl url;
 
 	// names -> urls
-	for ( uint i = 0 ; i < fileNames->count(); ++i ) {
+	for ( int i = 0 ; i < fileNames->count(); ++i ) {
 		QString filename = ( *fileNames ) [ i ];
 		url = vfs_origin;
 		url.addPath( filename );
 		filesUrls.append( url );
 	}
-	KIO::Job *job = new KIO::DeleteJob( filesUrls, false, true );
-	connect( job, SIGNAL( result( KIO::Job* ) ), this, SLOT( vfs_refresh( KIO::Job* ) ) );
+	KIO::Job *job = KIO::del( filesUrls );
+	connect( job, SIGNAL( result( KJob* ) ), this, SLOT( vfs_refresh( KJob* ) ) );
 }
 
 
-KURL::List* ftp_vfs::vfs_getFiles( QStringList* names ) {
-	KURL url;
-	KURL::List* urls = new KURL::List();
+KUrl::List* ftp_vfs::vfs_getFiles( QStringList* names ) {
+	KUrl url;
+	KUrl::List* urls = new KUrl::List();
 	for ( QStringList::Iterator name = names->begin(); name != names->end(); ++name ) {
 		url = vfs_getFile( *name );
 		urls->append( url );
@@ -259,39 +262,36 @@ KURL::List* ftp_vfs::vfs_getFiles( QStringList* names ) {
 
 
 // return a path to the file
-KURL ftp_vfs::vfs_getFile( const QString& name ) {
+KUrl ftp_vfs::vfs_getFile( const QString& name ) {
 	vfile * vf = vfs_search( name );
-	if ( !vf ) return KURL(); // empty
+	if ( !vf ) return KUrl(); // empty
 
-	KURL url = vf->vfile_getUrl();
-	if ( vf->vfile_isDir() ) url.adjustPath( + 1 );
+	KUrl url = vf->vfile_getUrl();
+	if ( vf->vfile_isDir() ) url.adjustPath( KUrl::AddTrailingSlash );
 	return url;
 }
 
 void ftp_vfs::vfs_mkdir( const QString& name ) {
-	KURL url = vfs_origin;
+	KUrl url = vfs_origin;
 	url.addPath( name );
 
 	KIO::SimpleJob* job = KIO::mkdir( url );
-	connect( job, SIGNAL( result( KIO::Job* ) ), this, SLOT( vfs_refresh( KIO::Job* ) ) );
+	connect( job, SIGNAL( result( KJob* ) ), this, SLOT( vfs_refresh( KJob* ) ) );
 }
 
 void ftp_vfs::vfs_rename( const QString& fileName, const QString& newName ) {
-	KURL::List fileUrls;
-	KURL oldUrl = vfs_origin;
+	KUrl oldUrl = vfs_origin;
 	oldUrl.addPath( fileName ) ;
 
-	fileUrls.append( oldUrl );
-
-	KURL newUrl = vfs_origin;
+	KUrl newUrl = vfs_origin;
 	newUrl.addPath( newName );
 
-	KIO::Job *job = new KIO::CopyJob( fileUrls, newUrl, KIO::CopyJob::Move, true, true );
-	connect( job, SIGNAL( result( KIO::Job* ) ), this, SLOT( vfs_refresh( KIO::Job* ) ) );
+	KIO::Job *job = KIO::moveAs( oldUrl, newUrl, false );
+	connect( job, SIGNAL( result( KJob* ) ), this, SLOT( vfs_refresh( KJob* ) ) );
 }
 
 QString ftp_vfs::vfs_workingDir() {
-	return vfs_origin.url( -1 );
+	return vfs_origin.url( KUrl::RemoveTrailingSlash );
 }
 
 #include "ftp_vfs.moc"
