@@ -35,8 +35,7 @@
 #include <qstring.h>
 #include <qfileinfo.h>
 #include <sys/types.h>
-#include <qdict.h>
-#include <qintdict.h>
+#include <qhash.h>
 #include <kio/global.h>
 
 #define NO_PERM      0
@@ -56,9 +55,9 @@ public:
 	static QString gid2group(gid_t groupId);
 	static QString uid2user (uid_t userId);
 
-	static char writeable (QString perm, gid_t gid, uid_t uid);
-	static char readable  (QString perm, gid_t gid, uid_t uid);
-	static char executable(QString perm, gid_t gid, uid_t uid);
+	static char writeable (QString perm, gid_t gid, uid_t uid, int rwx=-1);
+	static char readable  (QString perm, gid_t gid, uid_t uid, int rwx=-1);
+	static char executable(QString perm, gid_t gid, uid_t uid, int rwx=-1);
 	
   static bool fileWriteable (QString localFile);
 	static bool fileReadable  (QString localFile);
@@ -79,11 +78,11 @@ public:
 
 private:
 	// cache for passwd and group entries
-	static QDict<uid_t> 	    *passwdCache;
-  static QDict<gid_t> 	    *groupCache;
-	static QIntDict<char>     *currentGroups;
-  static QIntDict<QString>  *uidCache;
-  static QIntDict<QString>  *gidCache;
+  static QHash<QString, uid_t> *passwdCache;
+  static QHash<QString, gid_t> *groupCache;
+  static QHash<int, char>      *currentGroups;
+  static QHash<int, QString>   *uidCache;
+  static QHash<int, QString>   *gidCache;
 };
 
 #endif
