@@ -37,41 +37,55 @@
 #include "krarchandler.h"
 #include "krpermhandler.h"
 
-#include <qtextstream.h>
 #include <qtextcodec.h>
 #include <qregexp.h>
-#include <klargefile.h>
+#include <kde_file.h>
 #include <klocale.h>
 #include <kmimetype.h>
 #include <qfile.h>
 #include <kurlcompletion.h>
 #include <kio/job.h>
 #include <kfileitem.h>
+#include <qtextcodec.h>
 
 #define  STATUS_SEND_DELAY     250
-#define  MAX_LINE_LEN          500
+#define  MAX_LINE_LEN          1000
 
 // set the defaults
 KRQuery::KRQuery(): QObject(), matchesCaseSensitive(true), bNull( true ),
-                    contain(QString::null),containCaseSensetive(true),
-                    containWholeWord(false),containOnRemote(false),
+                    contain(QString()),containCaseSensetive(true),
+                    containWholeWord(false),containRegExp(false),containOnRemote(false),
                     minSize(0),maxSize(0),newerThen(0),olderThen(0),
-                    owner(QString::null),group(QString::null),perm(QString::null),
-                    type(QString::null),inArchive(false),recurse(true),
-                    followLinksP(true), receivedBuffer( 0 ), processEventsConnected(0)  {}
+                    owner(QString()),group(QString()),perm(QString()),
+                    type(QString()),inArchive(false),recurse(true),
+                    followLinksP(true), receivedBuffer( 0 ), receivedBufferLen( 0 ), processEventsConnected(0),
+                    codec( QTextCodec::codecForLocale() )  {
+  QChar ch = '\n';
+  QTextCodec::ConverterState state( QTextCodec::IgnoreHeader );
+  encodedEnterArray = codec->fromUnicode( &ch, 1, &state );
+  encodedEnter = encodedEnterArray.data();
+  encodedEnterLen = encodedEnterArray.size();
+}
 
 // set the defaults
 KRQuery::KRQuery( const QString &name, bool matchCase ) : QObject(),
-                    bNull( true ),contain(QString::null),containCaseSensetive(true),
-                    containWholeWord(false), containOnRemote(false),
+                    bNull( true ),contain(QString()),containCaseSensetive(true),
+                    containWholeWord(false),containRegExp(false), containOnRemote(false),
                     minSize(0),maxSize(0),newerThen(0),olderThen(0),
-                    owner(QString::null),group(QString::null),perm(QString::null),
-                    type(QString::null),inArchive(false),recurse(true),
-                    followLinksP(true), receivedBuffer( 0 ), processEventsConnected(0) {
+                    owner(QString()),group(QString()),perm(QString()),
+                    type(QString()),inArchive(false),recurse(true),
+                    followLinksP(true), receivedBuffer( 0 ), receivedBufferLen( 0 ), processEventsConnected(0),
+                    codec( QTextCodec::codecForLocale() )  {
+  QChar ch = '\n';
+  QTextCodec::ConverterState state( QTextCodec::IgnoreHeader );
+  encodedEnterArray = codec->fromUnicode( &ch, 1, &state );
+  encodedEnter = encodedEnterArray.data();
+  encodedEnterLen = encodedEnterArray.size();
+
   setNameFilter( name, matchCase );
 }
 
-KRQuery::KRQuery( const KRQuery & that ) : QObject(), receivedBuffer( 0 ), processEventsConnected(0) {
+KRQuery::KRQuery( const KRQuery & that ) : QObject(), receivedBuffer( 0 ), receivedBufferLen( 0 ), processEventsConnected(0) {
   *this = that;
 }
 
@@ -91,6 +105,7 @@ KRQuery& KRQuery::operator=(const KRQuery &old) {
   contain = old.contain;
   containCaseSensetive = old.containCaseSensetive;
   containWholeWord = old.containWholeWord;
+  containRegExp = old.containRegExp;
   containOnRemote = old.containOnRemote;
   minSize = old.minSize;
   maxSize = old.maxSize;
@@ -108,6 +123,12 @@ KRQuery& KRQuery::operator=(const KRQuery &old) {
   whereNotToSearch = old.whereNotToSearch;
   origFilter = old.origFilter;
   
+  codec = old.codec;
+
+  encodedEnterArray = old.encodedEnterArray;
+  encodedEnter = encodedEnterArray.data();
+  encodedEnterLen = encodedEnterArray.size();
+
   return *this;
 }
 
@@ -159,24 +180,23 @@ bool KRQuery::matchCommon( const QString &nameIn, const QStringList &matchList,
     return true;
 
   QString name( nameIn );
-  int ndx = nameIn.findRev( '/' ); // virtual filenames may contain '/'
+  int ndx = nameIn.lastIndexOf( '/' ); // virtual filenames may contain '/'
   if( ndx != -1 )                  // but the end of the filename is OK
     name = nameIn.mid( ndx + 1 );
 
-  unsigned int len;
-  for ( unsigned int i = 0; i < excludeList.count(); ++i )
+  for ( int i = 0; i < excludeList.count(); ++i )
   {
-    QRegExp( *excludeList.at( i ), matchesCaseSensitive, true ).match( name, 0, ( int* ) & len );
-    if ( len == name.length() ) return false;
+    if( QRegExp( excludeList[ i ], matchesCaseSensitive ? Qt::CaseSensitive : Qt::CaseInsensitive, QRegExp::Wildcard ).exactMatch( name ) )
+      return false;
   }
 
   if( matchList.count() == 0 )
     return true;
 
-  for ( unsigned int i = 0; i < matchList.count(); ++i )
+  for ( int i = 0; i < matchList.count(); ++i )
   {
-    QRegExp( *matchList.at( i ), matchesCaseSensitive, true ).match( name, 0, ( int* ) & len );
-    if ( len == name.length() ) return true;
+    if( QRegExp( matchList[ i ], matchesCaseSensitive ? Qt::CaseSensitive : Qt::CaseInsensitive, QRegExp::Wildcard ).exactMatch( name ) )
+      return true;
   }
   return false;
 }
@@ -208,10 +228,10 @@ bool KRQuery::match( vfile *vf ) const
     if( (totalBytes = vf->vfile_getSize()) == 0 )
       totalBytes++; // sanity
     receivedBytes = 0;
-    if( receivedBuffer ) {
-      delete []receivedBuffer;
-      receivedBuffer = 0;
-    }
+    if( receivedBuffer )
+      delete receivedBuffer;
+    receivedBuffer = 0;
+    receivedBufferLen = 0;
     fileName = vf->vfile_getName();
     timer.start();
 
@@ -237,7 +257,7 @@ bool KRQuery::match( KFileItem *kfi ) const {
   if ( kfi->isDir() ) 
     perm[ 0 ] = 'd';
 
-  vfile temp( kfi->text(), kfi->size(), perm, kfi->time( KIO::UDS_MODIFICATION_TIME ),
+  vfile temp( kfi->text(), kfi->size(), perm, kfi->time( KFileItem::ModificationTime ).toTime_t(),
               kfi->isLink(), kfi->user(), kfi->group(), kfi->user(), 
               kfi->mimetype(), kfi->linkDest(), mode );
 
@@ -266,125 +286,105 @@ void fixFoundTextForDisplay(QString& haystack, int start, int length) {
   haystack = ("<qt>"+before+"<b>"+text+"</b>"+after+"</qt>" );
 }
 
-bool KRQuery::checkBuffer( const char *buf, int len ) const {
-  if( len == 0 )  { // last block?
-    if( receivedBuffer ) {
-      bool result = checkLines( receivedBuffer, receivedBufferLen );
-      delete []receivedBuffer;
-      receivedBuffer = 0;
-      return result;
-    }
-    return false;
-  }
+bool KRQuery::checkBuffer( const char * data, int len ) const {
+  bool result = false;
 
-  int after = len;
-  while( buf[ after-1 ] != '\n' && buf[ after-1 ] != 0 ) {
-    after--;
-    if( after <= 0 || after <= len - MAX_LINE_LEN ) {
-      after = len;  // if there's no <ENTER> in MAX_LINE_LEN, we break the line
-      break;        // breaking the line causes problems at Unicode characters
+  char * mergedBuffer = new char [ len + receivedBufferLen ];
+  if( receivedBufferLen )
+    memcpy( mergedBuffer, receivedBuffer, receivedBufferLen );
+  if( len )
+    memcpy( mergedBuffer + receivedBufferLen, data, len );
+
+  int maxLen = len + receivedBufferLen;
+  int maxBuffer = maxLen - encodedEnterLen;
+  int lastLinePosition = 0;
+
+  for( int enterIndex = 0; enterIndex < maxBuffer; enterIndex++ ) {
+    if( memcmp( mergedBuffer + enterIndex, encodedEnter, encodedEnterLen ) == 0 ) {
+      QString str = codec->toUnicode( mergedBuffer + lastLinePosition, enterIndex + encodedEnterLen - lastLinePosition );
+      if( str.endsWith( "\n" ) ) {
+        str.chop( 1 );
+        result = result || checkLine( str );
+        lastLinePosition = enterIndex + encodedEnterLen;
+        enterIndex = lastLinePosition;
+        continue;
+      }
     }
   }
 
-  if( receivedBuffer ) {
-    int previous = 0;
-    while( previous < after && previous < MAX_LINE_LEN && buf[previous] != '\n' && buf[previous] != 0 )
-      previous++;
+  if( maxLen - lastLinePosition > MAX_LINE_LEN || len == 0 ) {
+      QString str = codec->toUnicode( mergedBuffer + lastLinePosition, maxLen - lastLinePosition );
+      result = result || checkLine( str );
+      lastLinePosition = maxLen;
+  }
 
-    char * str = new char[ receivedBufferLen + previous ];
-    memcpy( str, receivedBuffer, receivedBufferLen );
-    delete []receivedBuffer;
-    receivedBuffer = 0;
-    memcpy( str + receivedBufferLen, buf, previous );
+  delete []receivedBuffer;
+  receivedBuffer = 0;
+  receivedBufferLen = maxLen - lastLinePosition;
 
-    if( checkLines( str, receivedBufferLen+previous ) ) {
-      delete []str;
-      return true;
-    }
-    delete []str;
-
-    if( after > previous && checkLines( buf+previous, after-previous ) )
-      return true; 
-
-  } else if( checkLines( buf, after ) )
-      return true;
-
-  if( after < len ) {
-    receivedBufferLen = len-after;
+  if( receivedBufferLen ) {
     receivedBuffer = new char [ receivedBufferLen ];
-    memcpy( receivedBuffer, buf+after, receivedBufferLen );
+    memcpy( receivedBuffer, mergedBuffer + lastLinePosition, receivedBufferLen );
   }
-  return false;
+
+  delete []mergedBuffer;
+  return result;
 }
 
-bool KRQuery::checkLines( const char * buf, int len ) const
+bool KRQuery::checkLine( const QString & line ) const
 {
-  QStringList list;
+  int ndx = 0;
 
-  int start = 0;
-  int k = 0;
-  while( k < len )
-  {
-    if( buf[ k ] == 0 || buf[ k ] == '\n' )
-    {
-      if( k != start )
-      {
-        QString line = QTextCodec::codecForLocale()->toUnicode( buf + start, k - start );
-        if( !line.isEmpty() )
-          list << line;
-      }
-      start = k + 1;
-    }
-    k++;
-  }
-  if( start != k )
-  {
-    QString line = QTextCodec::codecForLocale()->toUnicode( buf + start, k - start );
-    if( !line.isEmpty() )
-      list << line;
+  if( containRegExp ) {
+    QRegExp rexp( contain, containCaseSensetive ? Qt::CaseSensitive : Qt::CaseInsensitive, QRegExp::RegExp );
+    int ndx = rexp.indexIn( line );
+    bool result = ndx >= 0;
+    if( result )
+      fixFoundTextForDisplay(lastSuccessfulGrep = line, ndx, rexp.matchedLength());
+    return result;
   }
 
-  for( unsigned int i=0; i != list.count(); i++ ) {
-    QString line = list[ i ];
-
-    int ndx = 0;
-    if ( line.isNull() ) return false;
-    if ( containWholeWord )
+  if ( line.isNull() ) return false;
+  if ( containWholeWord )
+  {
+    while ( ( ndx = line.indexOf( contain, ndx, containCaseSensetive ? Qt::CaseSensitive : Qt::CaseInsensitive ) ) != -1 )
     {
-      while ( ( ndx = line.find( contain, ndx, containCaseSensetive ) ) != -1 )
-      {
-        QChar before = line.at( ndx - 1 );
-        QChar after = line.at( ndx + contain.length() );
+      QChar before = '\n';
+      QChar after = '\n';
 
-        if ( !before.isLetterOrNumber() && !after.isLetterOrNumber() &&
-          after != '_' && before != '_' ) {
-            lastSuccessfulGrep = line;
-            fixFoundTextForDisplay(lastSuccessfulGrep, ndx, contain.length());
-            return true;
-           }
-        ndx++;
-      }
-    }
-    else if ( (ndx = line.find( contain, 0, containCaseSensetive )) != -1 ) {
-      lastSuccessfulGrep = line;
-      fixFoundTextForDisplay(lastSuccessfulGrep, ndx, contain.length());
-      return true;
+      if( ndx > 0 )
+        before = line.at( ndx - 1 );
+      if( ndx + contain.length() < line.length() ) 
+        after = line.at( ndx + contain.length() );
+
+      if ( !before.isLetterOrNumber() && !after.isLetterOrNumber() &&
+        after != '_' && before != '_' ) {
+          lastSuccessfulGrep = line;
+          fixFoundTextForDisplay(lastSuccessfulGrep, ndx, contain.length());
+          return true;
+         }
+      ndx++;
     }
   }
+  else if ( (ndx = line.indexOf( contain, 0, containCaseSensetive ? Qt::CaseSensitive : Qt::CaseInsensitive )) != -1 ) {
+    lastSuccessfulGrep = line;
+    fixFoundTextForDisplay(lastSuccessfulGrep, ndx, contain.length());
+    return true;
+  }
   return false;
 }
 
 bool KRQuery::containsContent( QString file ) const
 {
   QFile qf( file );
-  if( !qf.open( IO_ReadOnly ) )
+  if( !qf.open( QIODevice::ReadOnly ) )
     return false;
 
   char buffer[ 1440 ]; // 2k buffer
 
   while ( !qf.atEnd() )
   {
-    int bytes = qf.readBlock( buffer, sizeof( buffer ) );
+    int bytes = qf.read( buffer, sizeof( buffer ) );
     if( bytes <= 0 )
       break;
 
@@ -403,17 +403,19 @@ bool KRQuery::containsContent( QString file ) const
   if( checkBuffer( buffer, 0 ) )
     return true;
 
-  lastSuccessfulGrep = QString::null; // nothing was found
+  lastSuccessfulGrep = QString(); // nothing was found
   return false;
 }
 
-bool KRQuery::containsContent( KURL url ) const
+
+
+bool KRQuery::containsContent( KUrl url ) const
 {
-  KIO::TransferJob *contentReader = KIO::get( url, false, false );
+  KIO::TransferJob *contentReader = KIO::get( url, KIO::NoReload, KIO::HideProgressInfo );
   connect(contentReader, SIGNAL(data(KIO::Job *, const QByteArray &)),
           this, SLOT(containsContentData(KIO::Job *, const QByteArray &)));
-  connect(contentReader, SIGNAL( result( KIO::Job* ) ),
-          this, SLOT(containsContentFinished( KIO::Job* ) ) );
+  connect(contentReader, SIGNAL( result( KJob* ) ),
+          this, SLOT(containsContentFinished( KJob* ) ) );
 
   busy = true;
   containsContentResult = false;
@@ -425,7 +427,7 @@ bool KRQuery::containsContent( KURL url ) const
   }
 
   if( busy ) {
-    contentReader->kill();
+    contentReader->kill( KJob::EmitResult );
     busy = false;
   }
 
@@ -437,21 +439,20 @@ void KRQuery::containsContentData(KIO::Job *job, const QByteArray &array) {
   if( checkBuffer( array.data(), array.size() ) ) {
     containsContentResult = true;
     containsContentFinished( job );
-    job->kill();
+    job->kill( KJob::EmitResult );
     return;
   }
   checkTimer();
 }
 
-void KRQuery::containsContentFinished( KIO::Job * ) {
+void KRQuery::containsContentFinished( KJob * ) {
   busy = false;
 }
 
 bool KRQuery::checkTimer() const {
   if( timer.elapsed() >= STATUS_SEND_DELAY ) {
     int pcnt = (int)(100.*(double)receivedBytes/(double)totalBytes + .5);
-    QString message = i18n( "Searching content of '%1' (%2%)" )
-                      .arg( fileName ).arg( pcnt );
+    QString message = i18n( "Searching content of '%1' (%2%)", fileName, pcnt );
     timer.start();
     emit ((KRQuery *)this)->status( message );
     return true;
@@ -462,8 +463,8 @@ bool KRQuery::checkTimer() const {
 QStringList KRQuery::split( QString str )
 {
   QStringList list;
-  unsigned splitNdx = 0;
-  unsigned startNdx = 0;
+  int splitNdx = 0;
+  int startNdx = 0;
   bool quotation = false;
 
   while( splitNdx < str.length() )
@@ -504,7 +505,7 @@ void KRQuery::setNameFilter( const QString &text, bool cs )
   QString matchText = text;
   QString excludeText;
   
-  unsigned excludeNdx = 0;
+  int excludeNdx = 0;
   bool quotationMark = 0;
   while( excludeNdx < matchText.length() )
   {
@@ -520,14 +521,14 @@ void KRQuery::setNameFilter( const QString &text, bool cs )
 
   if( excludeNdx < matchText.length() )
   {
-    excludeText = matchText.mid( excludeNdx + 1 ).stripWhiteSpace();
+    excludeText = matchText.mid( excludeNdx + 1 ).trimmed();
     matchText.truncate( excludeNdx );
-    matchText = matchText.stripWhiteSpace();
+    matchText = matchText.trimmed();
     if( matchText.isEmpty() )
       matchText = "*";
   }
 
-  unsigned i;
+  int i;
 
   matches  = split( matchText );
   includedDirs.clear();
@@ -535,7 +536,7 @@ void KRQuery::setNameFilter( const QString &text, bool cs )
   for( i=0; i < matches.count(); ) {
     if( matches[ i ].endsWith( "/" ) ) {
       includedDirs.push_back( matches[ i ].left( matches[ i ].length() - 1 ) );
-      matches.remove( matches.at( i ) );
+      matches.removeAll( matches.at( i ) );
       continue;
     }
 
@@ -551,7 +552,7 @@ void KRQuery::setNameFilter( const QString &text, bool cs )
   for( i=0; i < excludes.count(); ) {
     if( excludes[ i ].endsWith( "/" ) ) {
       excludedDirs.push_back( excludes[ i ].left( excludes[ i ].length() - 1 ) );
-      excludes.remove( excludes.at( i ) );
+      excludes.removeAll( excludes.at( i ) );
       continue;
     }
 
@@ -562,13 +563,28 @@ void KRQuery::setNameFilter( const QString &text, bool cs )
   }
 }
 
-void KRQuery::setContent( const QString &content, bool cs, bool wholeWord, bool remoteSearch )
+void KRQuery::setContent( const QString &content, bool cs, bool wholeWord, bool remoteSearch, QString encoding, bool regExp )
 {
   bNull = false;
   contain = content;
   containCaseSensetive = cs;
   containWholeWord = wholeWord;
+  containRegExp = regExp;
   containOnRemote = remoteSearch;
+
+  if( encoding.isEmpty() )
+    codec = QTextCodec::codecForLocale();
+  else {
+    codec = QTextCodec::codecForName( encoding.toLatin1() );
+    if( codec == 0 )
+      codec = QTextCodec::codecForLocale();
+  }
+
+  QChar ch = '\n';
+  QTextCodec::ConverterState state( QTextCodec::IgnoreHeader );
+  encodedEnterArray = codec->fromUnicode( &ch, 1, &state );
+  encodedEnter = encodedEnterArray.data();
+  encodedEnterLen = encodedEnterArray.size();
 }
 
 void KRQuery::setMinimumFileSize( KIO::filesize_t minimumSize )
@@ -620,10 +636,10 @@ void KRQuery::setMimeType( const QString &typeIn, QStringList customList )
   customType = customList;
 }
 
-bool KRQuery::isExcluded( const KURL &url )
+bool KRQuery::isExcluded( const KUrl &url )
 {
-  for ( unsigned int i = 0; i < whereNotToSearch.count(); ++i )
-    if( whereNotToSearch [ i ].isParentOf( url ) || url.equals( whereNotToSearch [ i ], true ) )
+  for ( int i = 0; i < whereNotToSearch.count(); ++i )
+    if( whereNotToSearch [ i ].isParentOf( url ) || url.equals( whereNotToSearch [ i ], KUrl::CompareWithoutTrailingSlash ) )
       return true;
 
   if( !matchDirName( url.fileName() ) )
@@ -632,20 +648,20 @@ bool KRQuery::isExcluded( const KURL &url )
   return false;
 }
 
-void KRQuery::setSearchInDirs( const KURL::List &urls ) { 
+void KRQuery::setSearchInDirs( const KUrl::List &urls ) { 
   whereToSearch.clear();
-  for( unsigned int i = 0; i < urls.count(); ++i ) {
+  for( int i = 0; i < urls.count(); ++i ) {
     QString url = urls[ i ].url();
-    KURL completed = vfs::fromPathOrURL( KURLCompletion::replacedPath( url, true, true ) );
+    KUrl completed = KUrl( KUrlCompletion::replacedPath( url, true, true ) );
     whereToSearch.append( completed );
   }
 }
 
-void KRQuery::setDontSearchInDirs( const KURL::List &urls ) { 
+void KRQuery::setDontSearchInDirs( const KUrl::List &urls ) { 
   whereNotToSearch.clear();
-  for( unsigned int i = 0; i < urls.count(); ++i ) {
+  for( int i = 0; i < urls.count(); ++i ) {
     QString url = urls[ i ].url();
-    KURL completed = vfs::fromPathOrURL( KURLCompletion::replacedPath( url, true, true ) );
+    KUrl completed = KUrl( KUrlCompletion::replacedPath( url, true, true ) );
     whereNotToSearch.append( completed );
   }
 }
