@@ -17,9 +17,9 @@
 
 #include "krvfshandler.h"
 #include "normal_vfs.h"
-#include "temp_vfs.h"
 #include "ftp_vfs.h"
 #include "virt_vfs.h"
+#include "../krservices.h"
 
 #include <qdir.h>
 
@@ -31,25 +31,25 @@ KrVfsHandler::KrVfsHandler(){
 KrVfsHandler::~KrVfsHandler(){
 }
 
-vfs::VFS_TYPE KrVfsHandler::getVfsType(const KURL& url){
+vfs::VFS_TYPE KrVfsHandler::getVfsType(const KUrl& url){
   QString protocol = url.protocol();
 
   if( ( protocol == "krarc" || protocol == "tar" || protocol == "zip" ) &&
-      QDir(url.path(-1)).exists() )
-    return vfs::NORMAL;
+      QDir(KrServices::getPath(url, KUrl::RemoveTrailingSlash)).exists() )
+    return vfs::VFS_NORMAL;
   
 	if( url.isLocalFile() ){
-		return vfs::NORMAL;
+		return vfs::VFS_NORMAL;
 	}
   else{
-		if(url.protocol() == "virt") return vfs::VIRT;
-		else return vfs::FTP;
+		if(url.protocol() == "virt") return vfs::VFS_VIRT;
+		else return vfs::VFS_FTP;
 	}
-	return vfs::ERROR;
+	return vfs::VFS_ERROR;
 }
 
-vfs* KrVfsHandler::getVfs(const KURL& url,QObject* parent,vfs* oldVfs){
-	vfs::VFS_TYPE newType,oldType = vfs::ERROR;
+vfs* KrVfsHandler::getVfs(const KUrl& url,QObject* parent,vfs* oldVfs){
+	vfs::VFS_TYPE newType,oldType = vfs::VFS_ERROR;
 
 	if(oldVfs) oldType = oldVfs->vfs_getType();
 	newType = getVfsType(url);
@@ -59,11 +59,10 @@ vfs* KrVfsHandler::getVfs(const KURL& url,QObject* parent,vfs* oldVfs){
 
 	if( oldType != newType ){
 		switch( newType ){
-		  case (vfs::NORMAL) : newVfs = new normal_vfs(parent); break;
-		  case (vfs::FTP   ) : newVfs = new ftp_vfs(parent)   ; break;
-		  case (vfs::TEMP  ) : newVfs = 0/*new temp_vfs(parent)*/  ; break;
-		  case (vfs::VIRT  ) : newVfs = new virt_vfs(parent)  ; break;
-      case (vfs::ERROR ) : newVfs = 0                       ; break;
+		  case (vfs::VFS_NORMAL) : newVfs = new normal_vfs(parent); break;
+		  case (vfs::VFS_FTP   ) : newVfs = new ftp_vfs(parent)   ; break;
+		  case (vfs::VFS_VIRT  ) : newVfs = new virt_vfs(parent)  ; break;
+      case (vfs::VFS_ERROR ) : newVfs = 0                     ; break;
 		}
   }
 
