@@ -33,8 +33,8 @@ public:
 	KrVfsHandler();
 	~KrVfsHandler();
 
-  static vfs::VFS_TYPE getVfsType(const KURL& url);
-  static vfs* getVfs(const KURL& url,QObject* parent=0,vfs* oldVfs=0);
+  static vfs::VFS_TYPE getVfsType(const KUrl& url);
+  static vfs* getVfs(const KUrl& url,QObject* parent=0,vfs* oldVfs=0);
 };
 
 #endif
