@@ -27,22 +27,25 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-#include <strings.h>
+#include <string.h>
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <unistd.h>
 #include <dirent.h>
 // QT includes
-#include <qdir.h>
 #include <qtimer.h>
+#include <QByteArray>
+#include <QDir>
 // KDE includes
 #include <kmessagebox.h>
 #include <kmimetype.h>
 #include <kio/jobclasses.h>
+#include <kio/deletejob.h>
+#include <kio/jobuidelegate.h>
 #include <klocale.h>
 #include <kglobalsettings.h>
 #include <kdebug.h>
-#include <klargefile.h>
+#include <kde_file.h>
 #include <kfileitem.h>
 // Krusader includes
 #include "normal_vfs.h"
@@ -53,23 +56,28 @@
 #include "../defaults.h"
 #include "../resources.h"
 #include "../krslots.h"
+#include "../krservices.h"
 
 // header files for ACL
-#if KDE_IS_VERSION(3,5,0)
 #ifdef HAVE_POSIX_ACL
 #include <sys/acl.h>
 #ifdef HAVE_NON_POSIX_ACL_EXTENSIONS
 #include <acl/libacl.h>
 #endif
 #endif
-#endif
 
 normal_vfs::normal_vfs(QObject* panel):vfs(panel), watcher(0) {
-  vfs_type=NORMAL;
+  vfs_type=VFS_NORMAL;
 }
 
-bool normal_vfs::populateVfsList(const KURL& origin, bool showHidden){
-	QString path = origin.path(-1);
+bool normal_vfs::populateVfsList(const KUrl& origin, bool showHidden){
+	QString path = KrServices::getPath( origin, KUrl::RemoveTrailingSlash);
+#ifdef Q_WS_WIN
+	if(! path.contains("/"))
+	{   //change C: to C:/
+		path = path + QString( "/" );
+	}
+#endif
 	
 	// set the writable attribute to true, if that's not the case - the KIO job
 	// will give the warnings and errors
@@ -80,30 +88,31 @@ bool normal_vfs::populateVfsList(const KURL& origin, bool showHidden){
 
 	// set the origin...
 	vfs_origin = origin;
-	vfs_origin.adjustPath(-1);
+	vfs_origin.setPath(path);
+	//vfs_origin.adjustPath(KUrl::RemoveTrailingSlash);
 	vfs_origin.setProtocol("file"); // do not remove !
-	vfs_origin.cleanPath(-1);
+	vfs_origin.cleanPath();
 	
 	// check that the new origin exists
 	if ( !QDir(path).exists() )
 	{
-		if( !quietMode ) KMessageBox::error(krApp, i18n("Directory %1 does not exist!").arg( path ), i18n("Error"));
+		if( !quietMode ) KMessageBox::error(krApp, i18n("Directory %1 does not exist!", path ), i18n("Error"));
 		return false;
 	}
     
-	krConfig->setGroup("Advanced");
-	if (krConfig->readBoolEntry("AutoMount",_AutoMount)) krMtMan.autoMount(path);
+	KConfigGroup group( krConfig, "Advanced");
+	if (group.readEntry("AutoMount",_AutoMount)) krMtMan.autoMount(path);
 	
-	DIR* dir = opendir(path.local8Bit());
+	DIR* dir = opendir(path.toLocal8Bit());
 	if(!dir) 
 	{
-		if( !quietMode ) KMessageBox::error(krApp, i18n("Can't open the %1 directory!").arg( path ), i18n("Error"));
+		if( !quietMode ) KMessageBox::error(krApp, i18n("Can't open the %1 directory!", path ), i18n("Error"));
 		return false;
 	}
 
   // change directory to the new directory
-        QString save = getcwd( 0, 0 );
-	if (chdir(path.local8Bit()) != 0) {
+	QString save = QDir::currentPath();
+	if ( ! QDir::setCurrent( path ) ) {
 		if( !quietMode ) KMessageBox::error(krApp, i18n("Access denied to")+path, i18n("Error"));
 		closedir(dir);
 		return false;
@@ -120,12 +129,12 @@ bool normal_vfs::populateVfsList(const KURL& origin, bool showHidden){
 		// we dont need the ".",".." enteries
 		if (name=="." || name == "..") continue;
 	  
-		vfile* temp = vfileFromName(name);
+		vfile* temp = vfileFromName( name, dirEnt->d_name );
     foundVfile(temp);
   }
 	// clean up
 	closedir(dir);
-        chdir( save.local8Bit() );
+	QDir::setCurrent( save );
 	
 	if( panelConnected )
 	{
@@ -134,7 +143,7 @@ bool normal_vfs::populateVfsList(const KURL& origin, bool showHidden){
 		connect(watcher,SIGNAL(dirty(const QString&)),this,SLOT(vfs_slotDirty(const QString&)));
 		connect(watcher,SIGNAL(created(const QString&)),this, SLOT(vfs_slotCreated(const QString&)));
 		connect(watcher,SIGNAL(deleted(const QString&)),this, SLOT(vfs_slotDeleted(const QString&)));	
-		watcher->addDir(vfs_getOrigin().path(-1),true); //start watching the new dir
+		watcher->addDir(vfs_getOrigin().path(KUrl::RemoveTrailingSlash), KDirWatch::WatchFiles); //start watching the new dir
 		watcher->startScan(true);
 	}
 
@@ -142,28 +151,28 @@ bool normal_vfs::populateVfsList(const KURL& origin, bool showHidden){
 }
 
 // copy a file to the vfs (physical)	
-void normal_vfs::vfs_addFiles(KURL::List *fileUrls,KIO::CopyJob::CopyMode mode,QObject* toNotify,QString dir, PreserveMode pmode ){
+void normal_vfs::vfs_addFiles(KUrl::List *fileUrls,KIO::CopyJob::CopyMode mode,QObject* toNotify,QString dir, PreserveMode pmode ){
   //if( watcher ) watcher->stopScan(); // we will refresh manually this time...	
   if( watcher ) {
     delete watcher;   // stopScan is buggy, leaves reference on the directory, that's why we delete the watcher
     watcher = 0;
   }
 
-  KURL dest;
+  KUrl dest;
   dest.setPath(vfs_workingDir()+"/"+dir);
 
   KIO::Job* job = PreservingCopyJob::createCopyJob( pmode, *fileUrls,dest,mode,false,true );
-  connect(job,SIGNAL(result(KIO::Job*)),this,SLOT(vfs_refresh()) );
+  connect(job,SIGNAL(result(KJob*)),this,SLOT(vfs_refresh(KJob *)) );
   if(mode == KIO::CopyJob::Move) // notify the other panel
-    connect(job,SIGNAL(result(KIO::Job*)),toNotify,SLOT(vfs_refresh(KIO::Job*)) );
+    connect(job,SIGNAL(result(KJob*)),toNotify,SLOT(vfs_refresh(KJob*)) );
   else
-    job->setAutoErrorHandlingEnabled( true );
+    job->ui()->setAutoErrorHandlingEnabled( true );
 }
 
 // remove a file from the vfs (physical)
-void normal_vfs::vfs_delFiles(QStringList *fileNames){
-	KURL::List filesUrls;
-	KURL url;
+void normal_vfs::vfs_delFiles(QStringList *fileNames, bool reallyDelete){
+	KUrl::List filesUrls;
+	KUrl url;
 	QDir local( vfs_workingDir() );
 	vfile* vf;
 
@@ -174,7 +183,7 @@ void normal_vfs::vfs_delFiles(QStringList *fileNames){
 	}
 
 	// names -> urls
-	for(uint i=0 ; i<fileNames->count(); ++i){
+	for(int i=0 ; i<fileNames->count(); ++i){
 		QString filename = (*fileNames)[i];
 		vf = vfs_search(filename);
 		url.setPath( vfs_workingDir()+"/"+filename);
@@ -183,32 +192,28 @@ void normal_vfs::vfs_delFiles(QStringList *fileNames){
 	KIO::Job *job;
 	
 	// delete of move to trash ?
-	krConfig->setGroup("General");
-	if( krConfig->readBoolEntry("Move To Trash",_MoveToTrash) ){
-#if KDE_IS_VERSION(3,4,0)
-	  job = KIO::trash(filesUrls, true );
-#else
-	  job = new KIO::CopyJob(filesUrls,KGlobalSettings::trashPath(),KIO::CopyJob::Move,false,true );
-#endif
-	  connect(job,SIGNAL(result(KIO::Job*)),SLOTS,SLOT(changeTrashIcon()));
+	KConfigGroup group( krConfig, "General");
+	if( !reallyDelete && group.readEntry("Move To Trash",_MoveToTrash) ){
+	  job = KIO::trash(filesUrls);
+	  connect(job,SIGNAL(result(KJob*)),SLOTS,SLOT(changeTrashIcon()));
 	}
 	else
-	  job = new KIO::DeleteJob(filesUrls, false, true);
+	  job = KIO::del(filesUrls);
 	
-	connect(job,SIGNAL(result(KIO::Job*)),this,SLOT(vfs_refresh(KIO::Job*)));
+	connect(job,SIGNAL(result(KJob*)),this,SLOT(vfs_refresh(KJob*)));
 }
 
 // return a path to the file
-KURL normal_vfs::vfs_getFile(const QString& name){	
+KUrl normal_vfs::vfs_getFile(const QString& name){	
   QString url;
 	if ( vfs_workingDir() == "/" ) url = "/"+name;
 	else url = vfs_workingDir()+"/"+name;
 
-	return vfs::fromPathOrURL(url);
+	return KUrl(url);
 }
 
-KURL::List* normal_vfs::vfs_getFiles(QStringList* names){
-  KURL::List* urls = new KURL::List();
+KUrl::List* normal_vfs::vfs_getFiles(QStringList* names){
+  KUrl::List* urls = new KUrl::List();
   for(QStringList::Iterator name = names->begin(); name != names->end(); ++name){
     urls->append( vfs_getFile(*name) );
   }
@@ -222,8 +227,8 @@ void normal_vfs::vfs_mkdir(const QString& name){
 }
 
 void normal_vfs::vfs_rename(const QString& fileName,const QString& newName){
-  KURL::List fileUrls;
-  KURL url , dest;
+  KUrl::List fileUrls;
+  KUrl url , dest;
 
   //if( watcher ) watcher->stopScan(); // we will refresh manually this time...	
   if( watcher ) {
@@ -235,26 +240,28 @@ void normal_vfs::vfs_rename(const QString& fileName,const QString& newName){
   fileUrls.append(url);
   dest.setPath(vfs_workingDir()+"/"+newName);
 
-  KIO::Job *job = new KIO::CopyJob(fileUrls,dest,KIO::CopyJob::Move,true,false );
-  connect(job,SIGNAL(result(KIO::Job*)),this,SLOT(vfs_refresh(KIO::Job*)));
+  KIO::Job *job = KIO::move(fileUrls,dest);
+  connect(job,SIGNAL(result(KJob*)),this,SLOT(vfs_refresh(KJob*)));
 }
 
-vfile* normal_vfs::vfileFromName(const QString& name){
+vfile* normal_vfs::vfileFromName(const QString& name, char * rawName ){
 	QString path = vfs_workingDir()+"/"+name;
-	QCString fileName = path.local8Bit();
+	QByteArray fileName = rawName == 0 ? path.toLocal8Bit() : (vfs_workingDir()+"/").toLocal8Bit().append( rawName );
 	
 	KDE_struct_stat stat_p;
+	stat_p.st_size = 0;
+	stat_p.st_mode = 0;
 	KDE_lstat(fileName.data(),&stat_p);
 	KIO::filesize_t size = stat_p.st_size;
 	QString perm = KRpermHandler::mode2QString(stat_p.st_mode);
 	bool symLink= S_ISLNK(stat_p.st_mode);
 	if( S_ISDIR(stat_p.st_mode) ) perm[0] = 'd';
 	
-	KURL mimeUrl = fromPathOrURL(path);
-	QString mime=QString::null;
+	KUrl mimeUrl = KUrl(path);
+	QString mime=QString();
 
 	char symDest[256];
-	bzero(symDest,256); 
+	memset(symDest,0,256); 
 	if( S_ISLNK(stat_p.st_mode) ){  // who the link is pointing to ?
 		int endOfName=0;
 		endOfName=readlink(fileName.data(),symDest,256);
@@ -282,9 +289,9 @@ vfile* normal_vfs::vfileFromName(const QString& name){
 
 void normal_vfs::getACL( vfile *file, QString &acl, QString &defAcl )
 {
-	acl = defAcl = QString::null;
-#if KDE_IS_VERSION(3,5,0) && defined( HAVE_POSIX_ACL )
-	QCString fileName = file->vfile_getUrl().path( -1 ).local8Bit();
+	acl = defAcl = QString();
+#if defined( HAVE_POSIX_ACL )
+	QByteArray fileName = file->vfile_getUrl().path( KUrl::RemoveTrailingSlash ).toLocal8Bit();
 #if HAVE_NON_POSIX_ACL_EXTENSIONS
 	if ( acl_extended_file( fileName.data() ) )
 	{
@@ -300,7 +307,7 @@ void normal_vfs::getACL( vfile *file, QString &acl, QString &defAcl )
 
 QString normal_vfs::getACL( const QString & path, int type )
 {
-#if KDE_IS_VERSION(3,5,0) && defined( HAVE_POSIX_ACL )
+#if defined( HAVE_POSIX_ACL )
 	acl_t acl = 0;
 	// do we have an acl for the file, and/or a default acl for the dir, if it is one?
 	if ( ( acl = acl_get_file( path.data(), type ) ) != 0 )
@@ -334,7 +341,7 @@ QString normal_vfs::getACL( const QString & path, int type )
 	}
 	
 	if( acl == 0 )
-		return QString::null;
+		return QString();
 	
 	char *aclString = acl_to_text( acl, 0 );
 	QString ret = QString::fromLatin1( aclString );
@@ -343,21 +350,22 @@ QString normal_vfs::getACL( const QString & path, int type )
 	
 	return ret;
 #else
-	return QString::null;
+	return QString();
 #endif
 }
 
 void normal_vfs::vfs_slotRefresh()
 {
-	krConfig->setGroup("Advanced");
-	int maxRefreshFrequency = krConfig->readNumEntry("Max Refresh Frequency", 1000);
+	KConfigGroup group( krConfig, "Advanced");
+	int maxRefreshFrequency = group.readEntry("Max Refresh Frequency", 1000);
 	vfs_refresh();
 	disconnect( &refreshTimer, SIGNAL( timeout() ), this, SLOT( vfs_slotRefresh() ) );
-	refreshTimer.start( maxRefreshFrequency, true );
+	refreshTimer.setSingleShot( true );
+	refreshTimer.start( maxRefreshFrequency );
 }
 
 bool normal_vfs::burstRefresh(const QString& path ){
-	if( path == vfs_getOrigin().path(-1) ) {
+	if( path == vfs_getOrigin().path(KUrl::RemoveTrailingSlash) ) {
 		if( !refreshTimer.isActive() ) {
 			// the directory itself is dirty - full refresh is needed
 			QTimer::singleShot(0, this, SLOT( vfs_slotRefresh() ) ); // safety: dirty signal comes from KDirWatch!
@@ -365,7 +373,7 @@ bool normal_vfs::burstRefresh(const QString& path ){
 		}
 		disconnect( &refreshTimer, SIGNAL( timeout() ), this, SLOT( vfs_slotRefresh() ) );
 		connect( &refreshTimer, SIGNAL( timeout() ), this, SLOT( vfs_slotRefresh() ) );
-		postponedRefreshURL = fromPathOrURL(path);
+		postponedRefreshURL = KUrl(path);
 		return true;
 	}
 	return false;
@@ -373,50 +381,59 @@ bool normal_vfs::burstRefresh(const QString& path ){
 
 void normal_vfs::vfs_slotDirty(const QString& path){ 
 	if( disableRefresh ){
-		postponedRefreshURL = fromPathOrURL(path);
+		if( postponedRefreshURL.isEmpty() )
+			postponedRefreshURL = vfs_getOrigin();
 		return;
 	}
 	
 	if( burstRefresh( path ) )
 		return;        
 	
-	KURL url = fromPathOrURL(path);
+	KUrl url = KUrl(path);
 	QString name = url.fileName();
 	
+	if ( name.left(1) == "." && !vfs_showHidden() )
+		return;
+	
 	// do we have it already ?
 	if( !vfs_search(name ) ) return vfs_slotCreated(path);
 	
 	// we have an updated file..
 	removeFromList(name);
-	vfile* vf = vfileFromName(name);
+	vfile* vf = vfileFromName(name, 0);
 	addToList(vf);
 	emit updatedVfile(vf);
 }
 
 void normal_vfs::vfs_slotCreated(const QString& path){  
 	if( disableRefresh ){
-		postponedRefreshURL = fromPathOrURL(path);
+		if( postponedRefreshURL.isEmpty() )
+			postponedRefreshURL = vfs_getOrigin();
 		return;
 	}	
 	
 	if( burstRefresh( path ) )
 		return;        
 	
-	
-	KURL url = fromPathOrURL(path);
+	KUrl url = KUrl(path);
 	QString name = url.fileName();	
+	
+	if ( name.left(1) == "." && !vfs_showHidden() )
+		return;
+	
 	// if it's in the CVS - it's an update not new file
 	if( vfs_search(name) )
 		return vfs_slotDirty(path);
 	
-	vfile* vf = vfileFromName(name);
+	vfile* vf = vfileFromName(name, 0);
 	addToList(vf);
 	emit addedVfile(vf);	
 }
 
 void normal_vfs::vfs_slotDeleted(const QString& path){ 
 	if( disableRefresh ){
-		postponedRefreshURL = fromPathOrURL(path);
+		if( postponedRefreshURL.isEmpty() )
+			postponedRefreshURL = vfs_getOrigin();
 		return;
 	}
 	
@@ -424,7 +441,7 @@ void normal_vfs::vfs_slotDeleted(const QString& path){
 		return;        
 	
 	
-	KURL url = fromPathOrURL(path);
+	KUrl url = KUrl(path);
 	QString name = url.fileName();
 	
 	// if it's not in the CVS - do nothing
