@@ -36,6 +36,7 @@
 #include <sys/types.h>
 // KDE includes
 #include <kio/global.h>
+#include <kio/udsentry.h>
 #include <kmimetype.h>
 
 #define PERM_ALL          -2
@@ -80,8 +81,8 @@ public:
 	      const QString& symDest,
 	      const mode_t  mode,
 	      const int rwx = -1,
-	      const QString& aclString = QString::null,
-	      const QString& aclDfltString = QString::null );
+	      const QString& aclString = QString(),
+	      const QString& aclDfltString = QString() );
 	
 	bool        operator==(const vfile& vf) const;
 	vfile&      operator= (const vfile& vf); 
@@ -98,7 +99,7 @@ public:
 	inline uid_t            vfile_getUid()     const { return vfile_ownerId;        }
 	inline gid_t            vfile_getGid()     const { return vfile_groupId;        }
 	inline time_t           vfile_getTime_t()  const { return vfile_time_t;         }
-	inline const KURL&      vfile_getUrl()     const { return vfile_url;            }
+	inline const KUrl&      vfile_getUrl()     const { return vfile_url;            }
   
 	const QString&          vfile_getMime(bool fast=false);
 	const QString&          vfile_getOwner();
@@ -115,12 +116,15 @@ public:
 	 * displayed size of the viewitem and thus the vfile. For INTERNAL USE !
 	 */
 	inline void             vfile_setSize(KIO::filesize_t size) {vfile_size = size;}
-	inline void             vfile_setUrl(const KURL& url)       {vfile_url = url;  }
+	inline void             vfile_setUrl(const KUrl& url)       {vfile_url = url;  }
 
 	inline void             vfile_setIcon(const QString& icn)   {vfile_icon = icn; }
 	inline QString          vfile_getIcon();
 
 	virtual ~vfile(){}
+	
+	inline static void      vfile_loadUserDefinedFolderIcons( bool load ) { vfile_userDefinedFolderIcons = load; }
+	inline static void      vfile_enableMimeTypeMagic( bool enable )      { vfile_useMimeTypeMagic = enable; }
 
 private:
 	void                    vfile_loadACL();
@@ -140,7 +144,7 @@ protected:
 	bool             vfile_symLink;  //< true if the file is a symlink
 	QString          vfile_mimeType; //< file mimetype
 	QString          vfile_symDest;  //< if it's a sym link - its detination
-	KURL             vfile_url;      //< file URL - empty by default
+	KUrl             vfile_url;      //< file URL - empty by default
 	QString          vfile_icon;     //< the name of the icon file
 	bool             vfile_isdir;    //< flag, if it's a directory
 	int              vfile_rwx;      //< flag, showing read, write, execute properties
@@ -148,16 +152,20 @@ protected:
 	bool             vfile_has_acl;  //< flag, indicates ACL permissions
 	QString          vfile_acl;      //< ACL permission string
 	QString          vfile_def_acl;  //< ACL default string
+	
+	static bool      vfile_userDefinedFolderIcons;
+	static bool      vfile_useMimeTypeMagic;
 };
 
 	
 QString vfile::vfile_getIcon(){
 	if( vfile_icon.isEmpty() ){
-		QString mime = this->vfile_getMime();
+		QString mime = this->vfile_getMime( !vfile_useMimeTypeMagic );
       if ( mime == "Broken Link !" )
-         vfile_icon = "file_broken";
-      else {
-         vfile_icon = KMimeType::mimeType( mime ) ->icon( QString::null, true );
+         vfile_icon = "file-broken";
+      else if( vfile_icon.isEmpty() ) {
+         KMimeType::Ptr mt = KMimeType::mimeType( mime );
+         vfile_icon = mt ? mt->iconName() : "file-broken";
       }		
 	}
 	return vfile_icon;
