@@ -34,12 +34,16 @@
 #include <unistd.h>
 #include <time.h>
 #include <qeventloop.h>
+#include <QList>
 #include <kapplication.h>
-#include <klargefile.h>
+#include <kio/directorysizejob.h>
+#include <kio/jobuidelegate.h>
+#include <kde_file.h>
 #include <qdir.h>
 #include "vfs.h"
 #include "../krusader.h"
 #include "../defaults.h"
+#include "kiojobwrapper.h"
 
 vfs::vfs(QObject* panel, bool quiet): vfs_busy(false), quietMode(quiet),disableRefresh(false),postponedRefreshURL(),
                                       invalidated(true),panelConnected(false),vfs_tempFilesP(0),vfileIterator(0),deletePossible( true ),
@@ -50,7 +54,7 @@ vfs::vfs(QObject* panel, bool quiet): vfs_busy(false), quietMode(quiet),disableR
 	if ( panel ){
 		panelConnected = true;
 		connect(this,SIGNAL(startUpdate()),panel,SLOT(slotStartUpdate()));
-		connect(this,SIGNAL(incrementalRefreshFinished( const KURL& )),panel,SLOT(slotGetStats( const KURL& )));
+		connect(this,SIGNAL(incrementalRefreshFinished( const KUrl& )),panel,SLOT(slotGetStats( const KUrl& )));
 	}
 	else quietMode = true;
 }
@@ -75,65 +79,25 @@ KIO::filesize_t vfs::vfs_totalSize(){
 	return temp;                                                     
 }
 
-bool vfs::vfs_refresh(KIO::Job* job){
-  if(job && job->error()){
-		job->showErrorDialog(krApp);
+bool vfs::vfs_refresh(KJob* job){
+  if( job && job->error() ){
+		if( job->uiDelegate() )
+			job->uiDelegate()->showErrorMessage();
 	}
 	return vfs_refresh(vfs_origin);
 }
 
-KURL vfs::fromPathOrURL( const QString &originIn )
-{
-  QString password, loginName, origin = originIn;
-  bool bugfix = false;
-  
-  if ( originIn.contains( ":/" ) && !originIn.startsWith( "/" ) )
-  {
-    // breakdown the url;
-    /* FIXME: untill KDE fixes the bug we have to check for
-       passwords and users with @ in them... */
-    bugfix = origin.find("@") != origin.findRev("@");
-    if(bugfix){
-      if(origin.find(":") != origin.findRev(":", origin.findRev("@") )){
-        int passStart = origin.find( ":",origin.find(":")+1 )+1;
-        int passLen = origin.findRev("@")-passStart;
-        password = origin.mid(passStart,passLen);
-        origin = origin.remove(passStart-1,passLen+1);
-      }
-      if(origin.find("@") != origin.findRev("@")){
-        int usrStart = origin.find( "/" )+1;
-        if(origin.at(usrStart) == '/') ++usrStart;
-        int usrLen = origin.findRev("@")-usrStart;
-        loginName = origin.mid(usrStart,usrLen);
-        origin = origin.remove(usrStart,usrLen+1);
-      }
-    }
-  }
-  KURL url = KURL::fromPathOrURL( origin );
-  if(loginName.isEmpty()) loginName = url.user();
-  if(password.isEmpty())  password  = url.pass();
-  if(bugfix){
-    url.setPass(password);
-    url.setUser(loginName);
-  }
-
-  return url;
-}
-
-QString vfs::pathOrURL( const KURL &originIn, int trailingSlash )
+QString vfs::pathOrUrl( const KUrl &originIn, KUrl::AdjustPathOption trailingSlash )
 {
   if( originIn.isLocalFile() )
     return originIn.path( trailingSlash );
-  return originIn.prettyURL( trailingSlash );
+  return originIn.prettyUrl( trailingSlash );
 }  
 
 void vfs::setVfsFilesP(vfileDict* dict){
 	vfs_filesP=dict;
 	vfs_tempFilesP = new vfileDict();
-	vfs_tempFilesP->setAutoDelete( true );
-	dict->setAutoDelete(true);
-	if( vfileIterator ) delete vfileIterator;
-	vfileIterator = new QDictIterator<vfile>(*dict);
+	vfileIterator = vfs_filesP->begin();
 }
 
 bool vfs::vfs_refresh(){ 
@@ -151,10 +115,10 @@ bool vfs::vfs_refresh(){
 	
 	vfs_busy = true;
 	// and populate it
-	krConfig->setGroup("Advanced");
-	int maxIncrementalRefreshFileNr = krConfig->readNumEntry("Max Incremental Refresh File Nr", 50);
-	krConfig->setGroup("Look&Feel");
-	bool showHidden = krConfig->readBoolEntry("Show Hidden",_ShowHidden);
+	KConfigGroup ga( krConfig, "Advanced");
+	int maxIncrementalRefreshFileNr = ga.readEntry("Max Incremental Refresh File Nr", 50);
+	KConfigGroup gl( krConfig, "Look&Feel");
+	bool showHidden = gl.readEntry("Show Hidden",_ShowHidden);
 	bool res = populateVfsList(vfs_getOrigin(),showHidden);
 
 	QString name;
@@ -182,9 +146,13 @@ bool vfs::vfs_refresh(){
 			if( !newVf ){
 				// the file was deleted..
 				emit deletedVfile(name);
-				vfs_filesP->remove(name);
-				// the remove() advance our iterator ! 
-				vf = vfileIterator->current();
+				delete (*vfs_filesP)[ name ]; 
+				vfileIterator  = vfs_filesP->erase( vfs_filesP->find( name ) );
+				// the remove() advance our iterator !
+				if( vfileIterator ==  vfs_filesP->end() )
+					vf = 0;
+				else
+					vf = *vfileIterator;
 			} else {
 				if( *vf != *newVf ){
 					// the file was changed..
@@ -193,11 +161,15 @@ bool vfs::vfs_refresh(){
 				}
 				vf=vfs_getNextFile();
 			}
+			delete (*vfs_tempFilesP)[ name ]; 
 			vfs_tempFilesP->remove(name);
 		} 
 		// everything thats left is a new file
-		QDictIterator<vfile> it(*vfs_tempFilesP);
-		for(vfile* vf=it.toFirst(); vf; vf=(++it)){
+		QHashIterator<QString, vfile *> it(*vfs_tempFilesP);
+		while( it.hasNext() )
+		{
+			vfile *vf = it.next().value();
+			
 			// sanity checking
 			if( !vf || (*vfs_filesP)[vf->vfile_getName()] ) continue;
 			
@@ -217,22 +189,25 @@ bool vfs::vfs_refresh(){
 	return res; 
 }
 
-bool vfs::vfs_refresh(const KURL& origin){
+bool vfs::vfs_refresh(const KUrl& origin){
 	if( vfs_busy )
 		return false;
 	
 	if( disableRefresh )
 	{
 		postponedRefreshURL = origin;
+		if( !origin.equals(vfs_getOrigin(),KUrl::CompareWithoutTrailingSlash) )
+			invalidated = true;
+		vfs_origin = origin;
 		return true;
 	}
 
-	if( !invalidated && origin.equals(vfs_getOrigin(),true) ) return vfs_refresh();
+	if( !invalidated && origin.equals(vfs_getOrigin(),KUrl::CompareWithoutTrailingSlash) ) return vfs_refresh();
 	
 	vfs_busy = true;
 	
-	krConfig->setGroup("Look&Feel");
-	bool showHidden = krConfig->readBoolEntry("Show Hidden",_ShowHidden);
+	KConfigGroup group( krConfig, "Look&Feel");
+	bool showHidden = group.readEntry("Show Hidden",_ShowHidden);
 
 	vfs_tempFilesP->clear();
 	// and re-populate it
@@ -253,17 +228,22 @@ bool vfs::vfs_refresh(const KURL& origin){
 	return true;
 }
 
-void vfs::vfs_enableRefresh(bool enable){
-	if (vfs_type != NORMAL) return;
-	if (disableRefresh == !enable) return; // if gets called twice by mistake
+bool vfs::vfs_enableRefresh(bool enable){
+	if (vfs_type != VFS_NORMAL) return true;
+	if (disableRefresh == !enable) return true; // if gets called twice by mistake
 	disableRefresh = quietMode = !enable;
-	if( enable && !postponedRefreshURL.isEmpty() ) vfs_refresh( postponedRefreshURL );
-	postponedRefreshURL = KURL();
+	bool res = true;
+	if( enable && !postponedRefreshURL.isEmpty() ) res = vfs_refresh( postponedRefreshURL );
+	postponedRefreshURL = KUrl();
+	return res;
 }
 
 void vfs::clear()
 {
 	emit cleared();
+	QHashIterator< QString, vfile *> lit( *vfs_filesP );
+	while( lit.hasNext() )
+		delete lit.next().value();
 	vfs_filesP->clear();
 }
 
@@ -271,7 +251,7 @@ bool vfs::vfs_processEvents() {
 	if( deleteRequested )
 		return false;        
 	deletePossible = false;
-	qApp->eventLoop() ->processEvents( QEventLoop::AllEvents | QEventLoop::WaitForMore );
+	qApp->processEvents( QEventLoop::AllEvents | QEventLoop::WaitForMoreEvents );
 	deletePossible = true;        
 	if( deleteRequested ) {
 		emit deleteAllowed();
@@ -287,11 +267,9 @@ void vfs::vfs_requestDelete() {
 }
 
 /// to be implemented
-#if KDE_IS_VERSION(3,3,0)
-#include <kdirsize.h>
-void vfs::slotKdsResult( KIO::Job* job){
+void vfs::slotKdsResult( KJob* job){
 	if( job && !job->error() ){
-		KDirSize* kds = static_cast<KDirSize*>(job);
+		KIO::DirectorySizeJob* kds = static_cast<KIO::DirectorySizeJob*>(job);
 		*kds_totalSize += kds->totalSize();
 		*kds_totalFiles += kds->totalFiles();
 		*kds_totalDirs += kds->totalSubdirs();
@@ -303,7 +281,7 @@ void vfs::vfs_calcSpace( QString name , KIO::filesize_t* totalSize, unsigned lon
 	calculateURLSize( vfs_getFile( name ), totalSize, totalFiles, totalDirs, stop );
 }        
         
-void vfs::calculateURLSize( KURL url,  KIO::filesize_t* totalSize, unsigned long* totalFiles, unsigned long* totalDirs, bool* stop ) {
+void vfs::calculateURLSize( KUrl url,  KIO::filesize_t* totalSize, unsigned long* totalFiles, unsigned long* totalDirs, bool* stop ) {
 	if ( stop && *stop ) return ;        
 	kds_busy = stop;
 	kds_totalSize  = totalSize ;
@@ -311,14 +289,16 @@ void vfs::calculateURLSize( KURL url,  KIO::filesize_t* totalSize, unsigned long
 	kds_totalDirs  = totalDirs;
 
 	if( url.isLocalFile() ) {
-		vfs_calcSpaceLocal( url.path(-1), totalSize, totalFiles, totalDirs, stop );
+		vfs_calcSpaceLocal( url.path(KUrl::RemoveTrailingSlash), totalSize, totalFiles, totalDirs, stop );
 		return;
 	} else {
 		stat_busy = true;
-		KIO::StatJob* statJob = KIO::stat( url, false );
-		connect( statJob, SIGNAL( result( KIO::Job* ) ), this, SLOT( slotStatResultArrived( KIO::Job* ) ) );
+		KIOJobWrapper * statJob = KIOJobWrapper::stat( url );
+		statJob->connectTo( SIGNAL( result( KJob* ) ), this, SLOT( slotStatResultArrived( KJob* ) ) );
+		statJob->start();
 		while ( !(*stop) && stat_busy ) {usleep(1000);}
-		if( entry.isEmpty()  ) return; // statJob failed
+		
+		if( entry.count() == 0 ) return; // statJob failed
 		KFileItem kfi(entry, url, true );        
 		if( kfi.isFile() || kfi.isLink() ) {
 			*totalFiles++;
@@ -327,8 +307,9 @@ void vfs::calculateURLSize( KURL url,  KIO::filesize_t* totalSize, unsigned long
 		}
 	}
 	
-	KDirSize* kds  = KDirSize::dirSizeJob( url );
-	connect( kds, SIGNAL( result( KIO::Job* ) ), this, SLOT( slotKdsResult( KIO::Job* ) ) );
+	KIOJobWrapper* kds  = KIOJobWrapper::directorySize( url );
+	kds->connectTo( SIGNAL( result( KJob* ) ), this, SLOT( slotKdsResult( KJob* ) ) );
+	kds->start();
 	while ( !(*stop) ){ 
 		// we are in a sepetate thread - so sleeping is OK
 		usleep(1000);
@@ -341,7 +322,10 @@ void vfs::vfs_calcSpaceLocal(QString name ,KIO::filesize_t *totalSize,unsigned l
   if (name == "/proc") return;
 
   KDE_struct_stat stat_p;                // KDE lstat is necessary as QFileInfo and KFileItem 
-  KDE_lstat(name.local8Bit(),&stat_p);   //         reports wrong size for a symbolic link
+  // if the name is wrongly encoded, then we zero the size out
+  stat_p.st_size = 0;
+  stat_p.st_mode = 0;
+  KDE_lstat(name.toLocal8Bit(),&stat_p);   //         reports wrong size for a symbolic link
   
   if( S_ISLNK(stat_p.st_mode) || !S_ISDIR(stat_p.st_mode) ) { // single files are easy : )
     ++(*totalFiles);
@@ -349,7 +333,7 @@ void vfs::vfs_calcSpaceLocal(QString name ,KIO::filesize_t *totalSize,unsigned l
   }
   else{  // handle directories
     // avoid a nasty crash on un-readable dirs
-    bool readable = ::access( name.local8Bit(), R_OK | X_OK ) == 0;
+    bool readable = ::access( name.toLocal8Bit(), R_OK | X_OK ) == 0;
     if( !readable )
       return;
       
@@ -357,37 +341,38 @@ void vfs::vfs_calcSpaceLocal(QString name ,KIO::filesize_t *totalSize,unsigned l
     if ( !dir.exists() ) return;
     
     ++(*totalDirs);
-    dir.setFilter(QDir::All | QDir::System | QDir::Hidden);
+    dir.setFilter(QDir::TypeMask | QDir::System | QDir::Hidden);
     dir.setSorting(QDir::Name | QDir::DirsFirst);
 
     // recurse on all the files in the directory
-    QFileInfoList* fileList = const_cast<QFileInfoList*>(dir.entryInfoList());
-    for (QFileInfo* qfiP = fileList->first(); qfiP != 0; qfiP = fileList->next()){
+    QFileInfoList fileList = dir.entryInfoList();
+    for (int k=0; k != fileList.size(); k++){
       if ( *stop ) return;
-      if (qfiP->fileName() != "." && qfiP->fileName() != "..")
-        vfs_calcSpaceLocal(name+"/"+qfiP->fileName(),totalSize,totalFiles,totalDirs,stop);
+      QFileInfo qfiP = fileList[ k ];
+      if (qfiP.fileName() != "." && qfiP.fileName() != "..")
+        vfs_calcSpaceLocal(name+"/"+qfiP.fileName(),totalSize,totalFiles,totalDirs,stop);
     }
   }
 }
 
         
-void vfs::slotStatResultArrived( KIO::Job* job ) {
+void vfs::slotStatResultArrived( KJob* job ) {
 	if( !job || job->error() ) entry = KIO::UDSEntry();
 	else entry = static_cast<KIO::StatJob*>(job)->statResult();
 	stat_busy = false;
 }
-        
-#else
-void vfs::slotKdsResult(KIO::Job *job){/* empty */}
-void vfs::vfs_calcSpace( QString /*name*/ , KIO::filesize_t* /*totalSize*/, unsigned long* /*totalFiles*/, unsigned long* /*totalDirs*/, bool* /*stop*/ ) {/* empty*/}
-#endif
 
-QValueList<vfile*> vfs::vfs_search(const KRQuery& filter) {
-	QValueList<vfile*> result;
+QList<vfile*> vfs::vfs_search(const KRQuery& filter) {
+	QList<vfile*> result;
 	for ( vfile *vf = vfs_getFirstFile(); vf != 0 ; vf = vfs_getNextFile() )
 		if (filter.match(vf)) 
 			result.append(vf);
 	return result;
 }
 
+bool vfs::vfs_showHidden() {
+	KConfigGroup gl( krConfig, "Look&Feel");
+	return gl.readEntry("Show Hidden",_ShowHidden);
+}
+
 #include "vfs.moc"
