@@ -32,9 +32,9 @@
 
 // QT includes
 #include <qstring.h>
-#include <qvaluelist.h>
+#include <qlist.h>
 #include <qobject.h>
-#include <qdict.h>
+#include <qhash.h>
 // KDE includes
 #include <kurl.h>
 #include <kio/jobclasses.h>
@@ -51,8 +51,8 @@
 class vfs: public QObject{
 	Q_OBJECT
 public:
-	typedef QDict<vfile> vfileDict;	
-	enum VFS_TYPE{ERROR=0,NORMAL,FTP,TEMP,VIRT};
+	typedef QHash<QString, vfile *> vfileDict;	
+	enum VFS_TYPE{VFS_ERROR=0,VFS_NORMAL,VFS_FTP,VFS_VIRT};
 
 	/**
 	 * Creates a vfs.
@@ -63,13 +63,13 @@ public:
 	virtual			~vfs();
 
 	/// Copy a file to the vfs (physical).
-	virtual void vfs_addFiles(KURL::List *fileUrls,KIO::CopyJob::CopyMode mode,QObject* toNotify,QString dir = "", PreserveMode pmode = PM_DEFAULT)=0;	
+	virtual void vfs_addFiles(KUrl::List *fileUrls,KIO::CopyJob::CopyMode mode,QObject* toNotify,QString dir = "", PreserveMode pmode = PM_DEFAULT)=0;	
 	/// Remove a file from the vfs (physical)
-	virtual void vfs_delFiles(QStringList *fileNames)=0;	
+	virtual void vfs_delFiles(QStringList *fileNames, bool reallyDelete=false)=0;	
 	/// Return a list of URLs for multiple files	
-	virtual KURL::List* vfs_getFiles(QStringList* names)=0;
+	virtual KUrl::List* vfs_getFiles(QStringList* names)=0;
 	/// Return a URL to a single file	
-	virtual KURL vfs_getFile(const QString& name)=0;
+	virtual KUrl vfs_getFile(const QString& name)=0;
 	/// Create a new directory
 	virtual void vfs_mkdir(const QString& name)=0;
 	/// Rename file
@@ -86,21 +86,23 @@ public:
 	/// Return vfile* or 0 if not found
 	inline vfile* vfs_search(const QString& name){ return (*vfs_filesP)[name]; } 
 	/// Return an empty vfile* list if not found
-	QValueList<vfile*> vfs_search(const KRQuery& filter);
+	QList<vfile*> vfs_search(const KRQuery& filter);
 	/// The total size of all the files in the VFS,
 	KIO::filesize_t vfs_totalSize();
 	/// The number of files in the VFS
 	inline unsigned long vfs_noOfFiles() { return vfs_filesP->count(); }
 	/// Returns the VFS url.
-	inline KURL vfs_getOrigin()          { return vfs_origin;          }
+	inline KUrl vfs_getOrigin()          { return vfs_origin;          }
 	/// Return the VFS type.
 	inline VFS_TYPE vfs_getType()        { return vfs_type;            }
 	/// Returns true if vfs is busy
 	inline bool vfs_isBusy()             { return vfs_busy;            }
+	/// Returns true if hidden files has to be shown
+	       bool vfs_showHidden();
 	/// Return the first file in the VFS and set the internal iterator to the beginning of the list.
-	inline vfile* vfs_getFirstFile(){ return (vfileIterator ? vfileIterator->toFirst() : 0); }
+	inline vfile* vfs_getFirstFile(){ vfileIterator = vfs_filesP->begin(); return (vfileIterator == vfs_filesP->end() ? 0 : *vfileIterator ); }
 	/// Return the the next file in the list and advance the iterator.
-	inline vfile* vfs_getNextFile() { return (vfileIterator ? ++(*vfileIterator) : 0);  }
+	inline vfile* vfs_getNextFile() { if( vfileIterator == vfs_filesP->end() || ++vfileIterator == vfs_filesP->end() ) return 0; else return *vfileIterator;  }
 	/// returns true if the vfs can be deleted without crash        
 	virtual bool vfs_canDelete() { return deletePossible; } 
 	/// process the application events               
@@ -110,25 +112,24 @@ public:
 	/// process the application events               
 	virtual bool vfs_isDeleting()    { return deleteRequested; }
    // KDE FTP proxy bug correction
-   static KURL fromPathOrURL( const QString &originIn );
-   static QString pathOrURL( const KURL &originIn, int trailingSlash = 0 );
+   static QString pathOrUrl( const KUrl &originIn, KUrl::AdjustPathOption trailingSlash = KUrl::LeaveTrailingSlash );
 
 
 public slots:
 	/// Re-reads files and stats and fills the vfile list
-	bool vfs_refresh(const KURL& origin);
+	bool vfs_refresh(const KUrl& origin);
 	/// Used to refresh the VFS when a job finishs. it calls the refresh() slot
 	/// or display a error message if the job fails
-	bool vfs_refresh(KIO::Job* job);
+	bool vfs_refresh(KJob * job);
 	bool vfs_refresh();
 	void vfs_setQuiet(bool beQuiet){ quietMode=beQuiet; }
-	void vfs_enableRefresh(bool enable);        
+	bool vfs_enableRefresh(bool enable);        
 	void vfs_invalidate() { invalidated = true; }          
 
 signals:
 	void startUpdate(); //< emitted when the VFS starts to refresh its list of vfiles.
 	void startJob(KIO::Job* job);
-	void incrementalRefreshFinished( const KURL& ); //< emitted when the incremental refresh was finished
+	void incrementalRefreshFinished( const KUrl& ); //< emitted when the incremental refresh was finished
 	void addedVfile(vfile* vf);
 	void deletedVfile(const QString& name);
 	void updatedVfile(vfile* vf);
@@ -137,7 +138,7 @@ signals:
 
 protected:
 	/// Feel the vfs dictionary with vfiles, must be implemented for each vfs
-	virtual bool populateVfsList(const KURL& origin, bool showHidden) = 0;
+	virtual bool populateVfsList(const KUrl& origin, bool showHidden) = 0;
 	/// Called by populateVfsList for each file
 	void foundVfile( vfile *vf ) { vfs_tempFilesP->insert(vf->vfile_getName(),vf); }
 	/// Set the vfile list pointer
@@ -150,27 +151,27 @@ protected:
 	inline void removeFromList(QString name){ vfs_filesP->remove(name); }
 
 	/// Deletes a vfile from the list.
-	void calculateURLSize(KURL url,KIO::filesize_t *totalSize,unsigned long *totalFiles,unsigned long *totalDirs, bool * stop);
+	void calculateURLSize(KUrl url,KIO::filesize_t *totalSize,unsigned long *totalFiles,unsigned long *totalDirs, bool * stop);
         
 	VFS_TYPE      vfs_type;     //< the vfs type.
-	KURL          vfs_origin;   //< the path or file the VFS originates from.
+	KUrl          vfs_origin;   //< the path or file the VFS originates from.
 	bool          vfs_busy;     //< true if vfs is busy with refreshing
 	bool quietMode;             //< if true the vfs won't display error messages or emit signals
 	bool disableRefresh;        //< true if refresh is disabled
 	bool isWritable;            //< true if it's writable
-	KURL postponedRefreshURL;   //< true if vfs_refresh() was called when refresh is disabled.
+	KUrl postponedRefreshURL;   //< true if vfs_refresh() was called when refresh is disabled.
 	bool invalidated;           //< the content of the cache is invalidated
 	bool panelConnected;        //< indicates that there's a panel connected. Important for disabling the dir watcher
 	
 protected slots:
-	/// The slot for the KDirSize job
-	void slotKdsResult(KIO::Job *job);
-	void slotStatResultArrived(KIO::Job *job);
+	/// The slot for the KIO::DirectorySizeJob
+	void slotKdsResult(KJob *job);
+	void slotStatResultArrived(KJob *job);
         
 private:
 	vfileDict*  vfs_filesP;    //< Point to a lists of virtual files (vfile).
 	vfileDict*  vfs_tempFilesP;//< Temporary files are stored here
-	QDictIterator<vfile>* vfileIterator; //< Point to a dictionary of virtual files (vfile).
+	QHash<QString, vfile *>::iterator vfileIterator; //< Point to a dictionary of virtual files (vfile).
 	
 	// used in the calcSpace function
 	bool* kds_busy;
