@@ -23,7 +23,9 @@
 #include <kurl.h>
 #include <kmessagebox.h>
 #include <klocale.h>
-#include <kdirsize.h>
+#include <kio/directorysizejob.h>
+#include <kio/deletejob.h>
+#include <kio/copyjob.h>
 #include <kstandarddirs.h>
 
 #include "krpermhandler.h"
@@ -33,63 +35,70 @@
 
 #define VIRT_VFS_DB "virt_vfs.db"
 
-QDict<KURL::List> virt_vfs::virtVfsDict;
+QHash<QString, KUrl::List *> virt_vfs::virtVfsDict;
 KConfig* virt_vfs::virt_vfs_db=0;
 
 virt_vfs::virt_vfs( QObject* panel, bool quiet ) : vfs( panel, quiet ) {
 	// set the writable attribute
 	isWritable = true;
 
-	virtVfsDict.setAutoDelete( true );
 	if ( virtVfsDict.isEmpty() ) {
 		restore();
 	}
 
-	vfs_type = VIRT;
+	vfs_type = VFS_VIRT;
 }
 
 virt_vfs::~virt_vfs() {}
 
-bool virt_vfs::populateVfsList( const KURL& origin, bool /*showHidden*/ ) {
+bool virt_vfs::populateVfsList( const KUrl& origin, bool /*showHidden*/ ) {
 	vfs_origin = origin;
-	vfs_origin.adjustPath(-1);
-	path = origin.path( -1 ).mid( 1 );
+	vfs_origin.adjustPath(KUrl::RemoveTrailingSlash);
+	path = origin.path( KUrl::RemoveTrailingSlash ).mid( 1 );
 	if ( path.isEmpty() ) path = "/";
 
-	KURL::List* urlList = virtVfsDict[ path ];
-	if ( !urlList ) {
-		urlList = new KURL::List();
+	KUrl::List* urlList;
+	if( virtVfsDict.find( path ) == virtVfsDict.end() ) {
+		urlList = new KUrl::List();
 		virtVfsDict.insert( path, urlList );
-		virtVfsDict[ "/" ] ->append( KURL::fromPathOrURL( "virt:/" + path ) );
+		virtVfsDict[ "/" ] ->append( KUrl( "virt:/" + path ) );
 	}
+	else
+		urlList = virtVfsDict[ path ];
 	
+	save();
 	if ( urlList->isEmpty() ) return true;
-	KURL::List::iterator it;
+	KUrl::List::iterator it;
 	for ( it = urlList->begin() ; it != urlList->end() ; /*++it*/ ) {
-		KURL url = *it;
+		KUrl url = *it;
 		// translate url->vfile and remove urls that no longer exist from the list
 		vfile* vf = stat(url);
 		if ( !vf ) {
-			it = urlList->remove( it );
+			it = urlList->erase( it );
 			// the iterator is advanced automaticly
 			continue;
 		}
 		foundVfile( vf );
 		++it;
 	}
-	save();
 	return true;
 }
 
-void virt_vfs::vfs_addFiles( KURL::List *fileUrls, KIO::CopyJob::CopyMode /*mode*/, QObject* /*toNotify*/, QString /*dir*/, PreserveMode /*pmode*/ ) {
+void virt_vfs::vfs_addFiles( KUrl::List *fileUrls, KIO::CopyJob::CopyMode /*mode*/, QObject* /*toNotify*/, QString /*dir*/, PreserveMode /*pmode*/ ) {
 	if ( path == "/" ) {
 		if ( !quietMode )
 			KMessageBox::error( krApp, i18n( "You can't copy files directly to the 'virt:/' directory.\nYou can create a sub directory and copy your files into it." ), i18n( "Error" ) );
 		return ;
 	}
 	
-	KURL::List* urlList = virtVfsDict[ path ];
-	for( unsigned i=0; i != fileUrls->count(); i++ ) {
+	if( virtVfsDict.find( path ) == virtVfsDict.end() ) {
+		KUrl::List *urlList = new KUrl::List();
+		virtVfsDict.insert( path, urlList );
+		virtVfsDict[ "/" ] ->append( KUrl( "virt:/" + path ) );
+	}
+	
+	KUrl::List* urlList = virtVfsDict[ path ];
+	for( int i=0; i != fileUrls->count(); i++ ) {
 		if( !urlList->contains( (*fileUrls)[ i ] ) )
 			urlList->push_back( (*fileUrls)[ i ] );
 	}
@@ -97,41 +106,38 @@ void virt_vfs::vfs_addFiles( KURL::List *fileUrls, KIO::CopyJob::CopyMode /*mode
 	vfs_refresh();
 }
 
-void virt_vfs::vfs_delFiles( QStringList *fileNames ) {
+void virt_vfs::vfs_delFiles( QStringList *fileNames, bool reallyDelete ) {
 	if ( path == "/" ) {
-		for ( uint i = 0 ; i < fileNames->count(); ++i ) {
+		for ( int i = 0 ; i < fileNames->count(); ++i ) {
 			QString filename = ( *fileNames ) [ i ];
-			virtVfsDict[ "/" ] ->remove( QString("virt:/")+filename );
+			virtVfsDict[ "/" ] ->removeAll( QString("virt:/")+filename );
+			delete virtVfsDict[ filename ];
 			virtVfsDict.remove( filename );
 		}
 		vfs_refresh();
 		return ;
 	}
 
-	KURL::List filesUrls;
-	KURL url;
+	KUrl::List filesUrls;
+	KUrl url;
 
 	// names -> urls
-	for ( uint i = 0 ; i < fileNames->count(); ++i ) {
+	for ( int i = 0 ; i < fileNames->count(); ++i ) {
 		QString filename = ( *fileNames ) [ i ];
 		filesUrls.append( vfs_getFile( filename ) );
 	}
 	KIO::Job *job;
 
 	// delete of move to trash ?
-	krConfig->setGroup( "General" );
-	if ( krConfig->readBoolEntry( "Move To Trash", _MoveToTrash ) ) {
-#if KDE_IS_VERSION(3,4,0)
-		job = KIO::trash( filesUrls, true );
-#else
-		job = new KIO::CopyJob( filesUrls, KGlobalSettings::trashPath(), KIO::CopyJob::Move, false, true );
-#endif
-		connect( job, SIGNAL( result( KIO::Job* ) ), krApp, SLOT( changeTrashIcon() ) );
+	KConfigGroup group( krConfig, "General" );
+	if ( !reallyDelete && group.readEntry( "Move To Trash", _MoveToTrash ) ) {
+		job = KIO::trash( filesUrls );
+		connect( job, SIGNAL( result( KJob* ) ), krApp, SLOT( changeTrashIcon() ) );
 	} else
-		job = new KIO::DeleteJob( filesUrls, false, true );
+		job = KIO::del( filesUrls );
 
 	// refresh will remove the deleted files...
-	connect( job, SIGNAL( result( KIO::Job* ) ), this, SLOT( vfs_refresh( KIO::Job* ) ) );
+	connect( job, SIGNAL( result( KJob* ) ), this, SLOT( vfs_refresh( KJob* ) ) );
 }
 
 void virt_vfs::vfs_removeFiles( QStringList *fileNames ) {
@@ -139,18 +145,19 @@ void virt_vfs::vfs_removeFiles( QStringList *fileNames ) {
 		return; 
 	
 	// removing the URLs from the collection
-	for ( uint i = 0 ; i < fileNames->count(); ++i ) {
-		KURL::List* urlList = virtVfsDict[ path ];
-		if( urlList )
-			urlList->remove( vfs_getFile( ( *fileNames ) [ i ] ) );
+	for ( int i = 0 ; i < fileNames->count(); ++i ) {
+		if( virtVfsDict.find( path ) != virtVfsDict.end() ) {
+			KUrl::List* urlList = virtVfsDict[ path ];
+			urlList->removeAll( vfs_getFile( ( *fileNames ) [ i ] ) );
+		}
 	}
 	
 	vfs_refresh();
 }
 
-KURL::List* virt_vfs::vfs_getFiles( QStringList* names ) {
-	KURL url;
-	KURL::List* urls = new KURL::List();
+KUrl::List* virt_vfs::vfs_getFiles( QStringList* names ) {
+	KUrl url;
+	KUrl::List* urls = new KUrl::List();
 	for ( QStringList::Iterator name = names->begin(); name != names->end(); ++name ) {
 		url = vfs_getFile( *name );
 		urls->append( url );
@@ -158,12 +165,12 @@ KURL::List* virt_vfs::vfs_getFiles( QStringList* names ) {
 	return urls;
 }
 
-KURL virt_vfs::vfs_getFile( const QString& name ) {
+KUrl virt_vfs::vfs_getFile( const QString& name ) {
 	vfile * vf = vfs_search( name );
-	if ( !vf ) return KURL(); // empty
+	if ( !vf ) return KUrl(); // empty
 
-	KURL url = vf->vfile_getUrl();
-	if ( vf->vfile_isDir() ) url.adjustPath( + 1 );
+	KUrl url = vf->vfile_getUrl();
+	if ( vf->vfile_isDir() ) url.adjustPath( KUrl::AddTrailingSlash );
 	return url;
 }
 
@@ -173,7 +180,7 @@ void virt_vfs::vfs_mkdir( const QString& name ) {
 			KMessageBox::error( krApp, i18n( "Creating new directories is allowed only in the 'virt:/' directory." ), i18n( "Error" ) );
 		return ;
 	}
-	KURL::List* temp = new KURL::List();
+	KUrl::List* temp = new KUrl::List();
 	virtVfsDict.insert( name, temp );
 	virtVfsDict[ "/" ] ->append( QString( "virt:/" )+name );
 
@@ -181,15 +188,15 @@ void virt_vfs::vfs_mkdir( const QString& name ) {
 }
 
 void virt_vfs::vfs_rename( const QString& fileName, const QString& newName ) {
-	KURL::List fileUrls;
-	KURL url , dest;
+	KUrl::List fileUrls;
+	KUrl url , dest;
 
 	vfile* vf = vfs_search( fileName );
 	if ( !vf ) return ; // not found
 
 	if ( path == "/" ) {
 		virtVfsDict[ "/" ] ->append( QString( "virt:/" ) + newName  );
-		virtVfsDict[ "/" ] ->remove( QString( "virt:/" ) + fileName );
+		virtVfsDict[ "/" ] ->removeAll( QString( "virt:/" ) + fileName );
 		virtVfsDict.insert( newName, virtVfsDict.take( fileName ) );
 		vfs_refresh();
 		return ;
@@ -198,23 +205,23 @@ void virt_vfs::vfs_rename( const QString& fileName, const QString& newName ) {
 	url = vf->vfile_getUrl();
 	fileUrls.append( url );
 
-	dest = fromPathOrURL( newName );
+	dest = KUrl( newName );
 	// add the new url to the list
 	// the the list is refreshed only existing files remain -
 	// so we don't have to worry if the job was successful
 	virtVfsDict[ path ] ->append( dest );
 
-	KIO::Job *job = new KIO::CopyJob( fileUrls, dest, KIO::CopyJob::Move, true, false );
-	connect( job, SIGNAL( result( KIO::Job* ) ), this, SLOT( vfs_refresh( KIO::Job* ) ) );
+	KIO::Job *job = KIO::move( fileUrls, dest );
+	connect( job, SIGNAL( result( KJob* ) ), this, SLOT( vfs_refresh( KJob* ) ) );
 }
 
-void virt_vfs::slotStatResult( KIO::Job* job ) {
+void virt_vfs::slotStatResult( KJob* job ) {
 	if( !job || job->error() ) entry = KIO::UDSEntry();
 	else entry = static_cast<KIO::StatJob*>(job)->statResult();
 	busy = false;
 }
 
-vfile* virt_vfs::stat( const KURL& url ) {
+vfile* virt_vfs::stat( const KUrl& url ) {
 	if( url.protocol() == "virt" ){
 		QString path = url.path().mid(1);
 		if( path.isEmpty() ) path = "/";
@@ -229,14 +236,14 @@ vfile* virt_vfs::stat( const KURL& url ) {
 	else {
 		busy = true;
 		KIO::StatJob* statJob = KIO::stat( url, false );
-		connect( statJob, SIGNAL( result( KIO::Job* ) ), this, SLOT( slotStatResult( KIO::Job* ) ) );
+		connect( statJob, SIGNAL( result( KJob* ) ), this, SLOT( slotStatResult( KJob* ) ) );
 		while ( busy && vfs_processEvents() );
-		if( entry.isEmpty()  ) return 0; // statJob failed
+		if( entry.count() == 0 ) return 0; // statJob failed
 		
 		kfi = new KFileItem(entry, url, true );
 	}
 	
-	if ( !kfi->time( KIO::UDS_MODIFICATION_TIME ) ){
+	if ( kfi->time( KFileItem::ModificationTime ).isNull() ){
 		 delete kfi;
 		 return 0; // file not found		
 	}
@@ -248,15 +255,15 @@ vfile* virt_vfs::stat( const KURL& url ) {
 	if( url.isLocalFile() )
 		name = url.path();
 	else
-		name = url.prettyURL();
+		name = url.prettyUrl();
 
 	KIO::filesize_t size = kfi->size();
-	time_t mtime = kfi->time( KIO::UDS_MODIFICATION_TIME );
+	time_t mtime = kfi->time( KFileItem::ModificationTime ).toTime_t();
 	bool symLink = kfi->isLink();
 	mode_t mode = kfi->mode() | kfi->permissions();
 	QString perm = KRpermHandler::mode2QString( mode );
 // set the mimetype
-	QString mime = QString::null;
+	QString mime = QString();
 	QString symDest = "";
 	if ( symLink ) {
 		symDest = kfi->linkDest();
@@ -269,7 +276,7 @@ vfile* virt_vfs::stat( const KURL& url ) {
 	else {
 		QString currentUser = url.user();
 		if ( currentUser.contains( "@" ) )  /* remove the FTP proxy tags from the username */
-			currentUser.truncate( currentUser.find( '@' ) );
+			currentUser.truncate( currentUser.indexOf( '@' ) );
 		if ( currentUser.isEmpty() )
 			currentUser = KRpermHandler::uid2user( getuid() );
 		temp = new vfile( name, size, perm, mtime, symLink, kfi->user(), kfi->group(), currentUser, mime, symDest, mode );
@@ -282,23 +289,28 @@ vfile* virt_vfs::stat( const KURL& url ) {
 
 KConfig*  virt_vfs::getVirtDB(){
 	if( !virt_vfs_db ){
-		virt_vfs_db = new KConfig(VIRT_VFS_DB,false,"data");
+//		virt_vfs_db = new KConfig("data",VIRT_VFS_DB,KConfig::NoGlobals);
+		virt_vfs_db = new KConfig(VIRT_VFS_DB, KConfig:: CascadeConfig, "data");
 	}
 	return virt_vfs_db; 
 }
 
 bool virt_vfs::save(){
 	KConfig* db = getVirtDB();
+	db->deleteGroup( "virt_db" );
+	KConfigGroup group( db, "virt_db");
 	
-	db->setGroup("virt_db");
-	QDictIterator<KURL::List> it( virtVfsDict ); // See QDictIterator
-	for( ; it.current(); ++it ){
-		KURL::List::iterator url;
+	QHashIterator< QString, KUrl::List *> lit( virtVfsDict );
+	while( lit.hasNext() ) {
+		KUrl::List * curr = lit.next().value();
+		
+		KUrl::List::iterator url;
 		QStringList entry;
-		for ( url = it.current()->begin() ; url != it.current()->end() ; ++url ) {
-			entry.append( (*url).prettyURL() );
+		for ( url = curr->begin() ; url != curr->end() ; ++url ) {
+			entry.append( (*url).prettyUrl() );
 		}
-		db->writeEntry(it.currentKey(),entry);
+		// KDE 4.0 workaround, Item_ is added as KConfig fails on 1 char names (such as /)
+		group.writeEntry( "Item_" + lit.key(),entry);
 	}
 	
 	db->sync();
@@ -308,18 +320,20 @@ bool virt_vfs::save(){
 
 bool virt_vfs::restore(){
 	KConfig* db = getVirtDB();
-	db->setGroup("virt_db");
+	KConfigGroup dbGrp( db, "virt_db");
 	
 	QMap<QString, QString> map = db->entryMap("virt_db");
 	QMap<QString, QString>::Iterator it;
-	KURL::List* urlList;
+	KUrl::List* urlList;
 	for ( it = map.begin(); it != map.end(); ++it ) {
-		urlList = new KURL::List( db->readListEntry(it.key()) );
-		virtVfsDict.insert( it.key(),urlList );
+		urlList = new KUrl::List( dbGrp.readEntry(it.key(), QStringList() ) );
+		// KDE 4.0 workaround, Item_ is removed (KConfig fails on 1 char names (such as /))
+		QString key = it.key().mid( 5 ); // remove Item_
+		virtVfsDict.insert( key,urlList );
 	}
 
 	if( !virtVfsDict["/" ]){
-		urlList = new KURL::List();
+		urlList = new KUrl::List();
 		virtVfsDict.insert( "/", urlList );	
 	}
 		
@@ -329,9 +343,9 @@ bool virt_vfs::restore(){
 void virt_vfs::vfs_calcSpace( QString name , KIO::filesize_t* totalSize, unsigned long* totalFiles, unsigned long* totalDirs, bool* stop ) {
 	if ( stop && *stop ) return ;
 	if( path == "/" ) {
-		KURL::List* urlList = virtVfsDict[ name ];
+		KUrl::List* urlList = virtVfsDict[ name ];
 		if ( urlList )
-			for( unsigned i=0; (i != urlList->size()) && !(*stop); i++ )
+			for( int i=0; (i != urlList->size()) && !(*stop); i++ )
 				calculateURLSize( (*urlList)[ i ], totalSize, totalFiles, totalDirs, stop );
 		return;        
 	}                
