@@ -19,6 +19,7 @@
 #define VIRT_VFS_H
 
 #include <kconfig.h>
+#include <qhash.h>
 
 #include "vfs.h"
 
@@ -33,15 +34,15 @@ public:
 	~virt_vfs();
 	
 	/// Copy a file to the vfs (physical).
-	void vfs_addFiles(KURL::List *fileUrls,KIO::CopyJob::CopyMode mode,QObject* toNotify,QString dir = "",  PreserveMode pmode = PM_DEFAULT );	
+	void vfs_addFiles(KUrl::List *fileUrls,KIO::CopyJob::CopyMode mode,QObject* toNotify,QString dir = "",  PreserveMode pmode = PM_DEFAULT );	
 	/// Remove a file from the vfs (physical)
-	void vfs_delFiles(QStringList *fileNames);	
+	void vfs_delFiles(QStringList *fileNames, bool reallyDelete = true);	
 	/// Remove a file from the collection (only its link, not the file)
 	void vfs_removeFiles(QStringList *fileNames);	
 	/// Return a list of URLs for multiple files	
-	KURL::List* vfs_getFiles(QStringList* names);
+	KUrl::List* vfs_getFiles(QStringList* names);
 	/// Return a URL to a single file	
-	KURL vfs_getFile(const QString& name);
+	KUrl vfs_getFile(const QString& name);
 	/// Create a new directory
 	void vfs_mkdir(const QString& name);
 	/// Rename file
@@ -50,10 +51,10 @@ public:
 	virtual void vfs_calcSpace(QString name ,KIO::filesize_t *totalSize,unsigned long *totalFiles,unsigned long *totalDirs, bool * stop);
 	
 	/// Return the VFS working dir
-	QString vfs_workingDir(){ return QString::null; }
+	QString vfs_workingDir(){ return QString(); }
 	
 protected slots:
-	void slotStatResult(KIO::Job *job);
+	void slotStatResult(KJob *job);
 
 protected:
 	/// Save the dictionary to file
@@ -63,10 +64,10 @@ protected:
 	/// return the URLs DB
 	KConfig*  getVirtDB();
 
-	bool populateVfsList(const KURL& origin, bool showHidden);
-	vfile* stat(const KURL& url);
+	bool populateVfsList(const KUrl& origin, bool showHidden);
+	vfile* stat(const KUrl& url);
 	
-	static QDict<KURL::List> virtVfsDict;
+	static QHash<QString, KUrl::List *> virtVfsDict;
 	static KConfig* virt_vfs_db;
 	bool busy;
 	QString path;
