@@ -67,7 +67,7 @@
 #define _MarkDirs       false 
 // Show Hidden /////////
 #define _ShowHidden     true 
-// Sort By Extention ///
+// Sort By Extension ///
 #define _SortByExt      false 
 // Case Sensative Sort /
 #define _CaseSensativeSort false 
@@ -79,6 +79,8 @@
 #define _MouseSelection 0 // 0 - normal (shift+click, ctrl+click), 1 - left click, 2 - right click
 // Use fullpath tab names /////
 #define _FullPathTabNames false
+// User defined folder icons
+#define _UserDefinedFolderIcons true
 
 // Panel Toolbar Checkboxes
 // Panel Toolbar Visible checkbox turned off
@@ -95,8 +97,6 @@
 #define _Open               false 
 // syncBrowseButton is turned on
 #define _syncBrowseButton   false 
-// Clear Location Bar Visible
-#define _ClearLocation		true
 // Use the default colors of KDE
 #define _KDEDefaultColors     true 
 // Enable Alternate Background colors
@@ -115,8 +115,8 @@
 #define _NumericPermissions false
 // Number of Columns in the Brief View
 #define _NumberOfBriefColumns  3
-// Create brief mode panels
-#define _DefaultPanelType   "Detailed"
+// Default Sort Method
+#define _DefaultSortMethod KrViewProperties::Krusader
 // Show splashscreen
 #define _ShowSplashScreen true
 // Single instance mode
@@ -128,7 +128,7 @@
 // Move To Trash //////
 #define _MoveToTrash   false 
 // Terminal ///////////
-#define _Terminal      "konsole"
+#define _Terminal      "konsole --workdir %d"
 // Send CDs ///////////
 #define _SendCDs		true
 // Editor /////////////
@@ -173,6 +173,8 @@
 #define _DoUnZip       true 
 // Do BZip2 ///////////
 #define _DoBZip2       true 
+// Do LZMA ///////////
+#define _DoLZMA       true 
 // Do Rar /////////////
 #define _DoRar         true 
 // Do UnRar ///////////
@@ -198,6 +200,8 @@
 // Test Before Unpack ////
 #define _TestBeforeUnpack	true 
 // Supported Packers // ====> a QStringList of SYSTEM supported archives ( also new )
+// default compression level
+#define _defaultCompressionLevel 5
 
 /////////////////////// [UserActions]
 // Terminal for UserActions ///////////
@@ -211,9 +215,9 @@
 
 /////////////////////// [Private]
 // Start Position /////
-#define _StartPosition new QPoint(QApplication::desktop()->width()/2 - mainView->sizeHint().width()/2,QApplication::desktop()->height()/2 - 250) 
+#define _StartPosition QPoint(QApplication::desktop()->width()/2 - mainView->sizeHint().width()/2,QApplication::desktop()->height()/2 - 250) 
 // Start Size /////////
-#define _StartSize     new QSize(mainView->sizeHint().width(),500) 
+#define _StartSize     QSize(mainView->sizeHint().width(),500) 
 // Panel Size /////////
 #define _PanelSize     0 
 // Terminal Size //////
@@ -304,3 +308,22 @@
 #define _InsertMovesDown	true
 // Immediate Context Menu
 #define _ImmediateContextMenu	true
+
+// Root directory
+#ifdef Q_WS_WIN
+#define DIR_SEPARATOR       "/"
+#define DIR_SEPARATOR2      "\\"
+#define DIR_SEPARATOR_CHAR  '/'
+#define DIR_SEPARATOR_CHAR2 '\\'
+#define REPLACE_DIR_SEP2(x) x = x.replace( DIR_SEPARATOR2, DIR_SEPARATOR );
+#define ROOT_DIR "C:\\"
+#define EXEC_SUFFIX         ".exe"
+#else
+#define DIR_SEPARATOR       "/"
+#define DIR_SEPARATOR2      "/"
+#define DIR_SEPARATOR_CHAR  '/'
+#define DIR_SEPARATOR_CHAR2 '/'
+#define REPLACE_DIR_SEP2(x)
+#define ROOT_DIR            "/"
+#define EXEC_SUFFIX         ""
+#endif
