@@ -21,7 +21,10 @@
 #include <qstring.h>
 #include <qstringlist.h>
 #include <qmap.h>
-#include <kprocess.h>
+#include <kurl.h>
+
+class QTextStream;
+class QFile;
 
 /**
   *@author Shie Erlich & Rafi Yanai
@@ -33,12 +36,15 @@ public:
 	~KrServices(){}
 
 	static bool         cmdExist(QString cmdName);
+	static QString      chooseFullPathName( QStringList names, QString confName );
 	static QString      detectFullPathName( QString name );
-	static QString      fullPathName( QString name, QString confName = QString::null );
+	static QString      fullPathName( QString name, QString confName = QString() );
 	static QStringList  separateArgs( QString args );
 	static QString      registerdProtocol(QString mimetype);
+	static QString      getPath( const KUrl &url, KUrl::AdjustPathOption trailing=KUrl::LeaveTrailingSlash );
 	static void         clearProtocolCache();
 	static bool         fileToStringList(QTextStream *stream, QStringList& target, bool keepEmptyLines=false);
+	static bool         fileToStringList(QFile *file, QStringList& target, bool keepEmptyLines=false);
 	static QString		  quote( QString name );
 	static QStringList  quote( const QStringList& names );
 
@@ -53,26 +59,4 @@ private:
 
 // TODO: make KrServices a namespace and move it there
 
-// wraps over kprocess, but buffers stdout and stderr and allows easy access to them later
-// note, that you still have to enable stdout,stderr in KEasyProcess::start() for buffering
-// to happen (ie: start(KEasyProcess::Block, KEasyProcess::AllOutput);)
-class KEasyProcess: public KProcess {
-	Q_OBJECT
-public:
-	KEasyProcess(QObject *parent, const char *name=0);
-	KEasyProcess();
-	virtual ~KEasyProcess() {}
-
-	const QString& getStdout() const { return _stdout; }
-	const QString& getStderr() const { return _stderr; }
-
-protected slots:
-	void receivedStdout (KProcess *proc, char *buffer, int buflen);
-	void receivedStderr (KProcess *proc, char *buffer, int buflen);
-	void init();
-
-private:
-	QString _stdout, _stderr;
-};
-
 #endif
