@@ -31,20 +31,20 @@
 #include <qdir.h>
 #include <qpoint.h>
 #include <qstringlist.h>
-#include <qprogressdialog.h>
-#include <qlistview.h>
 #include <qpixmapcache.h>
+#include <QKeyEvent>
+#include <QList>
+#include <QEvent>
 // KDE includes
+#include <ktoggleaction.h>
+#include <ktoolbar.h>
 #include <klocale.h>
-#include <kprocess.h>
 #include <kmessagebox.h>
-#include <klineeditdlg.h>
-#include <kdirnotify_stub.h>
-#include <kio/netaccess.h>
 #include <kedittoolbar.h>
 #include <kdeversion.h>
 #include <kcmdlineargs.h>
-#include <KViewer/krviewer.h>
+#include "KViewer/krviewer.h"
+#include "Panel/krviewfactory.h"
 
 #ifdef __KJSEMBED__
 #include "KrJS/krjs.h"
@@ -57,15 +57,10 @@
 #include "krusaderview.h"
 #include "Panel/listpanel.h"
 #include "Panel/krselectionmode.h"
-#include "Panel/krdetailedview.h"
-#include "Panel/krdetailedviewitem.h"
-#include "Panel/krbriefview.h"
-#include "Panel/krbriefviewitem.h"
 #include "Dialogs/krdialogs.h"
 #include "Dialogs/krspwidgets.h"
 #include "Dialogs/krkeydialog.h"
 #include "GUI/krusaderstatus.h"
-#include "RemoteMan/remoteman.h"
 #include "Panel/panelfunc.h"
 #include "Konfigurator/konfigurator.h"
 #include "MountMan/kmountman.h"
@@ -73,12 +68,14 @@
 #include "resources.h"
 #include "GUI/kfnkeys.h"
 #include "GUI/kcmdline.h"
+#include "GUI/terminaldock.h"
 #include "GUI/syncbrowsebutton.h"
 #include "VFS/krquery.h"
 #include "Search/krsearchmod.h"
 #include "Search/krsearchdialog.h"
 #include "Locate/locate.h"
 #include "VFS/vfs.h"
+#include "VFS/vfile.h"
 #include "panelmanager.h"
 #include "Splitter/splittergui.h"
 #include "Splitter/splitter.h"
@@ -90,6 +87,7 @@
 #include "DiskUsage/diskusagegui.h"
 #include "krservices.h"
 #include "Panel/krviewitem.h"
+#include "Queue/queuedialog.h"
 
 #define REFRESH_BOTH_PANELS { ListPanel *p=ACTIVE_PANEL;        \
                               MAIN_VIEW->left->func->refresh(); \
@@ -98,32 +96,61 @@
 #define ACTIVE_PANEL_MANAGER  (ACTIVE_PANEL == krApp->mainView->left ? krApp->mainView->leftMng : \
                                 krApp->mainView->rightMng)
 
-void KRslots::sendFileByEmail(QString filename) {
+void KRslots::sendFileByEmail(const KUrl::List &urls) {
+  if( urls.count() == 0 ) {
+    KMessageBox::error(0,i18n("No selected files to send!"));
+    return;
+  }
+
   QString mailProg;
   QStringList lst = Krusader::supportedTools();
-  if (lst.contains("MAIL")) mailProg=lst[lst.findIndex("MAIL") + 1];
+  if (lst.contains("MAIL")) mailProg=lst[lst.indexOf("MAIL") + 1];
   else {
     KMessageBox::error(0,i18n("Krusader can't find a supported mail client. Please install one to your path. Hint: Krusader supports Kmail."));
     return;
   }
 
-  KShellProcess proc;
+  QString subject, separator;
+  foreach( KUrl url, urls ) {
+    subject += separator + url.fileName();
+    separator=",";
+  }
+  subject = i18np("Sending file: %2", "Sending files: %2", urls.count(), subject);
 
-  if ( vfs::fromPathOrURL( mailProg ).fileName() == "kmail") {
-    proc << "kmail" << "--subject \""+i18n("Sending file: ")+
-            filename.mid(filename.findRev('/')+1)+"\"" << QString::null +
-            "--attach "+"\"" + filename + "\"";
+  KProcess proc;
+
+  if ( KUrl( mailProg ).fileName() == "kmail") {
+    proc << mailProg << "--subject"
+         << subject;
+    foreach( KUrl url2, urls )
+         proc << "--attach" << url2.prettyUrl();
+  } else   if ( KUrl( mailProg ).fileName() == "thunderbird") {
+    QString param="attachment=\'";
+    separator = "";
+    foreach( KUrl url2, urls ) {
+      param += separator + url2.prettyUrl();
+      separator=",";
+    }
+    param+="\',subject=\'" + subject + "\'";
+    proc << mailProg << "--compose" << param;
+  } else if ( KUrl( mailProg ).fileName() == "evolution") {
+    QString param="mailto:?cc=&subject=" + subject + "&attach=";
+    separator = "";
+    foreach( KUrl url2, urls ){
+      param += separator + url2.prettyUrl();
+      separator = "&attach=";
+    }
+    proc << mailProg << param + "";
   }
 
-	if (!proc.start(KProcess::DontCare))
-    KMessageBox::error(0,i18n("Error executing ")+mailProg+" !");
-  else proc.detach();
+  if (!proc.startDetached())
+    KMessageBox::error(0, i18n("Error executing %1!", mailProg));
 }
 
 void KRslots::compareContent() {
   QStringList lstLeft, lstRight;
   QStringList* lstActive;
-  KURL name1, name2;
+  KUrl name1, name2;
 
   MAIN_VIEW->left->getSelectedNames( &lstLeft );
   MAIN_VIEW->right->getSelectedNames( &lstRight );
@@ -156,85 +183,55 @@ void KRslots::compareContent() {
   compareContent( name1, name2 );
 }
 
-class KrProcess: public KProcess
-{
-  QString tmp1, tmp2;
-  
-public:
-  KrProcess( QString in1, QString in2 )
-  {
-    tmp1 = in1;
-    tmp2 = in2;
-  }
-  
-  virtual void processHasExited (int )
-  {
-    if( !tmp1.isEmpty() )
-      KIO::NetAccess::removeTempFile( tmp1 );
-    if( !tmp2.isEmpty() )
-      KIO::NetAccess::removeTempFile( tmp2 );
-    delete this;
-  }
-};
-
-void KRslots::compareContent( KURL url1, KURL url2 )
+void KRslots::compareContent( KUrl url1, KUrl url2 )
 {
   QString diffProg;
   QStringList lst = Krusader::supportedTools();
-  if (lst.contains("DIFF")) diffProg=lst[lst.findIndex("DIFF") + 1];
+  if (lst.contains("DIFF")) diffProg=lst[lst.indexOf("DIFF") + 1];
   else {
     KMessageBox::error(0,i18n("Krusader can't find any of the supported diff-frontends. Please install one to your path. Hint: Krusader supports Kompare, Kdiff3 and Xxdiff."));
     return;
   }
 
-  QString tmp1 = QString::null, tmp2 = QString::null;
-  
-  if (!url1.isLocalFile()) {
-    if( !KIO::NetAccess::download( url1, tmp1, 0 ) ){
-      KMessageBox::sorry(krApp,i18n("Krusader is unable to download: ")+url1.fileName());
-      return;
-    }
-  } else tmp1 = url1.path();
-  if (!url2.isLocalFile()) {
-    if( !KIO::NetAccess::download( url2, tmp2, 0 ) ){
-      KMessageBox::sorry(krApp,i18n("Krusader is unable to download: ")+url2.fileName());
-      if( tmp1 != url1.path() )
-        KIO::NetAccess::removeTempFile( tmp1 );
-      return;
-    }
-  } else tmp2 = url2.path();
+  QString tmp1 = QString(), tmp2 = QString();
 
-  KrProcess *p = new KrProcess( tmp1 != url1.path() ? tmp1 : QString::null,
-                                tmp2 != url2.path() ? tmp2 : QString::null );
+  // kdiff3 sucks with spaces
+  if( KUrl( diffProg ).fileName() == "kdiff3" && !url1.prettyUrl().contains(" ") && !url2.prettyUrl().contains(" ") ) {
+    tmp1 = url1.prettyUrl();
+    tmp2 = url2.prettyUrl();
+  } else {
+    if (!url1.isLocalFile()) {
+      if( !KIO::NetAccess::download( url1, tmp1, 0 ) ){
+        KMessageBox::sorry(krApp, i18n("Krusader is unable to download %1", url1.fileName()));
+        return;
+      }
+    } else tmp1 = url1.path();
+    if (!url2.isLocalFile()) {
+      if( !KIO::NetAccess::download( url2, tmp2, 0 ) ){
+        KMessageBox::sorry(krApp,i18n("Krusader is unable to download %1", url2.fileName()));
+        if( tmp1 != url1.path() )
+          KIO::NetAccess::removeTempFile( tmp1 );
+        return;
+      }
+    } else tmp2 = url2.path();
+  }
+
+  KrProcess *p = new KrProcess( tmp1 != url1.path() ? tmp1 : QString(),
+                                tmp2 != url2.path() ? tmp2 : QString() );
   *p << diffProg << tmp1 << tmp2;
-  if (!p->start(KProcess::DontCare))
-    KMessageBox::error(0,i18n("Error executing ")+diffProg+" !");
+  p->start();
+  if (!p->waitForStarted())
+    KMessageBox::error(0,i18n("Error executing %1!", diffProg));
 }
 
 void KRslots::rightclickMenu() {
-  if( dynamic_cast<KrDetailedView*>(ACTIVE_PANEL->view) != 0 )
+  if( ACTIVE_PANEL->view->getCurrentKrViewItem() )
   {
-    QListViewItem * currentItem = dynamic_cast<QListViewItem*>(ACTIVE_PANEL->view->getCurrentKrViewItem());
-    if( currentItem )
-    {
-      ACTIVE_PANEL->popRightClickMenu(
-       ACTIVE_PANEL->mapToGlobal(
-         dynamic_cast<KListView*>(ACTIVE_PANEL->view)->itemRect( currentItem ).topLeft()
-       )
-      );
-    }
-  }
-  else if( dynamic_cast<KrBriefView*>(ACTIVE_PANEL->view) != 0 )
-  {
-    QIconViewItem * currentItem = dynamic_cast<QIconViewItem*>(ACTIVE_PANEL->view->getCurrentKrViewItem());
-    if( currentItem )
-    {
-      ACTIVE_PANEL->popRightClickMenu(
-       ACTIVE_PANEL->mapToGlobal(
-         currentItem->rect().topLeft()
-       )
-      );
-    }
+    ACTIVE_PANEL->popRightClickMenu(
+     ACTIVE_PANEL->mapToGlobal(
+       ACTIVE_PANEL->view->getCurrentKrViewItem()->itemRect().topLeft()
+     )
+    );
   }
 }
 
@@ -280,29 +277,27 @@ void KRslots::toggleTerminal() {
 void KRslots::insertFileName(bool full_path)
 {
   QString filename = ACTIVE_PANEL->view->getCurrentItem();
-  if( filename == QString::null )
+  if( filename == QString() )
     return;
   
   if( full_path ){
-    QString path=vfs::pathOrURL( ACTIVE_FUNC->files()->vfs_getOrigin(), 1 );
+    QString path=vfs::pathOrUrl(ACTIVE_FUNC->files()->vfs_getOrigin(), KUrl::AddTrailingSlash );
     filename = path+filename;
   }
 
   filename = KrServices::quote( filename );
 
-  if(MAIN_VIEW->cmdLine->isVisible() || !MAIN_VIEW->konsole_part || !MAIN_VIEW->konsole_part->widget() ||
-    !MAIN_VIEW->konsole_part->widget()->isVisible() ){
+  if(MAIN_VIEW->cmdLine->isVisible() || !MAIN_VIEW->terminal_dock->isTerminalVisible() ){
     QString current = MAIN_VIEW->cmdLine->text();
     if( current.length() != 0 && !current.endsWith( " " ) )
       current += " ";
     MAIN_VIEW->cmdLine->setText( current + filename );
 	MAIN_VIEW->cmdLine->setFocus();
   }
-  else if(MAIN_VIEW->konsole_part){
+  else if(MAIN_VIEW->terminal_dock->isTerminalVisible() ){
     filename = QString( " " ) + filename + QString( " " );
-    QKeyEvent keyEvent( QEvent::KeyPress, 0, -1, 0,  filename);
-    QApplication::sendEvent( MAIN_VIEW->konsole_part->widget(), &keyEvent );
-    MAIN_VIEW->konsole_part->widget()->setFocus();
+    MAIN_VIEW->terminal_dock->sendInput( filename );
+    MAIN_VIEW->terminal_dock->setFocus();
   }
 }
 
@@ -317,9 +312,9 @@ void KRslots::markGroup(const QString& mask, bool select) { ACTIVE_PANEL->select
 void KRslots::unmarkGroup()     { ACTIVE_PANEL->select(false,false);         }
 void KRslots::invert()          { ACTIVE_PANEL->invertSelection();           }
 
-void KRslots::root()            { ACTIVE_FUNC->openUrl(vfs::fromPathOrURL("/"));}
-void KRslots::refresh(const KURL& u){ ACTIVE_FUNC->openUrl(u);        }
-void KRslots::home()            { ACTIVE_FUNC->openUrl(QDir::homeDirPath()); }
+void KRslots::root()            { ACTIVE_FUNC->openUrl(KUrl("/"));}
+void KRslots::refresh(const KUrl& u){ ACTIVE_FUNC->openUrl(u);        }
+void KRslots::home()            { ACTIVE_FUNC->openUrl(QDir::homePath()); }
 void KRslots::refresh()         { ACTIVE_FUNC->refresh();                    }
 void KRslots::properties()      { ACTIVE_FUNC->properties();                 }
 void KRslots::dirUp()           { ACTIVE_FUNC->dirUp();                      }
@@ -339,19 +334,23 @@ void KRslots::matchChecksum()  { ACTIVE_FUNC->matchChecksum(); }
 // run external modules / programs
 void KRslots::runKonfigurator(bool firstTime) {
 
-  krConfig->setGroup( "Look&Feel" );
-  int size = (krConfig->readEntry("Filelist Icon Size",_FilelistIconSize)).toInt();
+  KConfigGroup group( krConfig, "Look&Feel");
+  KConfigGroup groupgen( krConfig, "General");
+  int size = (group.readEntry("Filelist Icon Size",_FilelistIconSize)).toInt();
   
   Konfigurator *konfigurator = new Konfigurator(firstTime);
 
+  vfile::vfile_enableMimeTypeMagic( groupgen.readEntry( "Mimetype Magic", _MimetypeMagic ) );
   if( konfigurator->isGUIRestartNeeded() )
   {
-    krConfig->setGroup( "Look&Feel" );
-    if((krConfig->readEntry("Filelist Icon Size",_FilelistIconSize)).toInt() != size )
+    vfile::vfile_loadUserDefinedFolderIcons( group.readEntry( "Load User Defined Folder Icons", _UserDefinedFolderIcons ) );
+
+    if((group.readEntry("Filelist Icon Size",_FilelistIconSize)).toInt() != size )
       QPixmapCache::clear();
-      
-    KrDetailedViewItem::itemHeightChanged(); // needed when icon size / font size changes
-    KrBriefViewItem::itemHeightChanged();
+
+    QList<KrViewInstance *> views = KrViewFactory::registeredViews();
+    foreach( KrViewInstance * inst, views )
+      KrViewFactory::itemHeightChanged( inst->id() );
 
     MAIN_VIEW->leftMng->slotRecreatePanels();
     MAIN_VIEW->rightMng->slotRecreatePanels();
@@ -363,38 +362,58 @@ void KRslots::runKonfigurator(bool firstTime) {
   delete konfigurator;
 }
 
-void KRslots::setDetailedView() {
-  if( ACTIVE_PANEL && ACTIVE_PANEL->getType() != "Detailed" )
-    ACTIVE_PANEL->changeType( "Detailed" );
+void KRslots::setView0() {
+  if( ACTIVE_PANEL && ACTIVE_PANEL->getType() != Krusader::viewIds[ 0 ] )
+    ACTIVE_PANEL->changeType( Krusader::viewIds[ 0 ] );
 }
 
-void KRslots::setBriefView() {
-  if( ACTIVE_PANEL && ACTIVE_PANEL->getType() != "Brief" )
-    ACTIVE_PANEL->changeType( "Brief" );
+void KRslots::setView1() {
+  if( ACTIVE_PANEL && ACTIVE_PANEL->getType() != Krusader::viewIds[ 1 ] )
+    ACTIVE_PANEL->changeType( Krusader::viewIds[ 1 ] );
+}
+
+void KRslots::setView2() {
+  if( ACTIVE_PANEL && ACTIVE_PANEL->getType() != Krusader::viewIds[ 2 ] )
+    ACTIVE_PANEL->changeType( Krusader::viewIds[ 2 ] );
+}
+
+void KRslots::setView3() {
+  if( ACTIVE_PANEL && ACTIVE_PANEL->getType() != Krusader::viewIds[ 3 ] )
+    ACTIVE_PANEL->changeType( Krusader::viewIds[ 3 ] );
+}
+
+void KRslots::setView4() {
+  if( ACTIVE_PANEL && ACTIVE_PANEL->getType() != Krusader::viewIds[ 4 ] )
+    ACTIVE_PANEL->changeType( Krusader::viewIds[ 4 ] );
+}
+
+void KRslots::setView5() {
+  if( ACTIVE_PANEL && ACTIVE_PANEL->getType() != Krusader::viewIds[ 5 ] )
+    ACTIVE_PANEL->changeType( Krusader::viewIds[ 5 ] );
 }
 
 void KRslots::toggleHidden(){
-  krConfig->setGroup("Look&Feel");
-  bool show = !krConfig->readBoolEntry("Show Hidden",_ShowHidden);
+  KConfigGroup group( krConfig, "Look&Feel");
+  bool show = !group.readEntry("Show Hidden",_ShowHidden);
   krApp->actToggleHidden->setChecked(show);
-  krConfig->writeEntry("Show Hidden",show);
+  group.writeEntry("Show Hidden",show);
 
   MAIN_VIEW->leftMng->refreshAllTabs( true );
   MAIN_VIEW->rightMng->refreshAllTabs( true );
 }
 
 void KRslots::swapPanels(){
-  KURL leftURL = MAIN_VIEW->left->func->files()->vfs_getOrigin();
-  KURL rightURL = MAIN_VIEW->right->func->files()->vfs_getOrigin();
+  KUrl leftURL = MAIN_VIEW->left->func->files()->vfs_getOrigin();
+  KUrl rightURL = MAIN_VIEW->right->func->files()->vfs_getOrigin();
 
   MAIN_VIEW->left->func->openUrl( rightURL );
   MAIN_VIEW->right->func->openUrl( leftURL );
 }
 
 void KRslots::toggleSwapSides(){
-  QValueList<int> lst = MAIN_VIEW->horiz_splitter->sizes();
+  QList<int> lst = MAIN_VIEW->horiz_splitter->sizes();
 
-  MAIN_VIEW->horiz_splitter->moveToLast( MAIN_VIEW->leftMng );
+  MAIN_VIEW->horiz_splitter->addWidget( MAIN_VIEW->leftMng );
 
   int old = lst[ 0 ];
   lst[ 0 ] = lst [ 1 ];
@@ -422,14 +441,14 @@ void KRslots::toggleSwapSides(){
 
 void KRslots::search() {
 	if ( KrSearchDialog::SearchDialog != 0 ) {
-		krConfig->setGroup( "Search" );
-		if( krConfig->readBoolEntry( "Window Maximized",  false ) )
-	KrSearchDialog::SearchDialog->showMaximized();
+		KConfigGroup group( krConfig, "Search" );
+		if( group.readEntry( "Window Maximized",  false ) )
+			KrSearchDialog::SearchDialog->showMaximized();
 		else
 			KrSearchDialog::SearchDialog->showNormal();
 	
 		KrSearchDialog::SearchDialog->raise();
-		KrSearchDialog::SearchDialog->setActiveWindow();
+		KrSearchDialog::SearchDialog->activateWindow();
 	} else
 		KrSearchDialog::SearchDialog = new KrSearchDialog();
 }
@@ -447,31 +466,15 @@ void KRslots::locate()
   if ( LocateDlg::LocateDialog != 0 ) {
     LocateDlg::LocateDialog->showNormal();
     LocateDlg::LocateDialog->raise();
-    LocateDlg::LocateDialog->setActiveWindow();
+    LocateDlg::LocateDialog->activateWindow();
     LocateDlg::LocateDialog->reset();
   } else
     LocateDlg::LocateDialog = new LocateDlg();
 }
 
-void KRslots::runRemoteMan() {
-  // display outage information
-  KMessageBox::information(krApp, i18n( "Important: RemoteMan has been replaced by our new bookmark manager. "
-                                        "The new manager handles local files and remote URLs the same way. "
-                                        "RemoteMan is being left around to allow an easier transition and "
-                                        "give you a chance to move your bookmarks. IT WILL BE REMOVED SOON!"
-                                        "\n"
-                                        "Try the new bookmark-manager: open a new remote connection, once "
-                                        "done, press the bookmark button, select 'Add bookmark' and that's it!"));
-
-  QString host=remoteMan::getHost();
-	if (host==QString::null) return;
-	// otherwise, attempt a connection
-	ACTIVE_FUNC->openUrl(vfs::fromPathOrURL(host));
-}
-
 void KRslots::runMountMan() {
   // left as a precaution, although we use kde's services now
-  if( !KrServices::cmdExist( "df" ) || !KrServices::cmdExist( "mount" ) )
+  if( !KrServices::cmdExist( "mount" ) )
   {
     KMessageBox::error(0,
       i18n("Can't start 'mount'! Check the 'Dependencies' page in konfigurator."));
@@ -481,38 +484,46 @@ void KRslots::runMountMan() {
   krApp->mountMan->mainWindow();
 }
 
-void KRslots::homeTerminal(){
-  QString save = getcwd(0,0);
-  chdir (QDir::homeDirPath().local8Bit());
-
+void KRslots::runTerminal( const QString & dir, const QStringList & args ){
   KProcess proc;
-  krConfig->setGroup("General");
-  QString term = krConfig->readEntry("Terminal",_Terminal);
-  proc << KrServices::separateArgs( term );
-      
+  proc.setWorkingDirectory( dir );
+  KConfigGroup group( krConfig, "General");
+  QString term = group.readEntry("Terminal",_Terminal);
+  QStringList sepdArgs = KrServices::separateArgs( term );
+  for( int i=0; i != sepdArgs.size(); i++ )
+    if( sepdArgs[ i ] == "%d" )
+      sepdArgs[ i ] = dir;
+  proc << sepdArgs;
+  if( !args.isEmpty() )
+  {
+    proc << "-e" << args; // FIXME this depends on term!! But works in konsole, xterm and gnome-terminal
+  }
+#if 0 // I hope this is no longer needed...
   if( term.contains( "konsole" ) )   /* KDE 3.2 bug (konsole is killed by pressing Ctrl+C) */
   {                                  /* Please remove the patch if the bug is corrected */
     proc << "&";
     proc.setUseShell( true );
   }
-  
-  if(!proc.start(KProcess::DontCare))
-    KMessageBox::sorry(krApp,i18n("Can't open ")+"\""+term+"\"");
+#endif
+  if(!proc.startDetached())
+    KMessageBox::sorry(krApp,i18n("Error executing %1!", term));
+}
 
-  chdir(save.local8Bit());
+void KRslots::homeTerminal(){
+  runTerminal( QDir::homePath(), QStringList() );
 }
 
 void KRslots::sysInfo(){
   KProcess proc;
-  proc << "kcmshell" << "System/ksysctrl";
-  if (!proc.start(KProcess::DontCare)){
+  proc << KrServices::fullPathName("kcmshell") << "System/ksysctrl";
+  if (!proc.startDetached()){
     KMessageBox::sorry(krApp,i18n("Can't find \"KsysCtrl\". Please install KDE admin package"));
   }
 }
 
 void KRslots::multiRename(){
 	QStringList lst = Krusader::supportedTools();
-	int i = lst.findIndex("RENAME");
+	int i = lst.indexOf("RENAME");
 	if (i == -1){
   	KMessageBox::sorry(krApp,i18n("Can't find a batch rename tool.\nYou can get Krename at http://www.krename.net"));
   	return;
@@ -521,22 +532,23 @@ void KRslots::multiRename(){
 	
   QStringList names;
   ((ListPanel*)ACTIVE_PANEL)->getSelectedNames(&names);
-	KURL::List* urls = ACTIVE_FUNC->files()->vfs_getFiles(&names);
+	KUrl::List* urls = ACTIVE_FUNC->files()->vfs_getFiles(&names);
 
 	if( urls->isEmpty() ){
 		delete urls;
 		return;
 	}
 
-	KShellProcess proc;
+	KProcess proc;
 	proc << pathToRename;
 
-	for( KURL::List::iterator u=urls->begin(); u != urls->end(); ++u){
+	for( KUrl::List::iterator u=urls->begin(); u != urls->end(); ++u){
     if( QFileInfo((*u).path()).isDir() ) proc << "-r";
-		proc << "\"" + (*u).path() + "\""; // patch thanks to Tobias Vogele
+		proc << (*u).path();
 	}
 
-	proc.start(KProcess::DontCare);
+	if (!proc.startDetached())
+    KMessageBox::error(0,i18n("Error executing %1!", pathToRename));
 	delete urls;
 }
 
@@ -548,35 +560,47 @@ void KRslots::rootKrusader()
     return;
   }
   
-  KShellProcess proc;
-  proc << KrServices::fullPathName( "kdesu" ) << QString("'") + KrServices::fullPathName( "krusader" ) +
-       " --left=\"" +MAIN_VIEW->left->func->files()->vfs_getOrigin().url() +
-       "\" --right=\""+MAIN_VIEW->right->func->files()->vfs_getOrigin().url() + "\"'";
+  KProcess proc;
+  proc << KrServices::fullPathName( "kdesu" ) << KrServices::fullPathName( "krusader" )
+       + " --left=" + MAIN_VIEW->left->func->files()->vfs_getOrigin().url()
+       + " --right=" + MAIN_VIEW->right->func->files()->vfs_getOrigin().url();
 
-  proc.start(KProcess::DontCare);
+  if (!proc.startDetached())
+    KMessageBox::error(0,i18n("Error executing %1!", proc.program()[0]));
 }
 
 // settings slots
 void KRslots::configToolbar(){
-  KEditToolbar dlg(krApp->factory());
+  KConfigGroup cg(KGlobal::config(), QString());
+  krApp->saveMainWindowSettings(cg);
+  KEditToolBar dlg(krApp->factory());
+  connect( &dlg, SIGNAL( newToolBarConfig() ), this, SLOT( saveNewToolbarConfig() ) );
   if (dlg.exec()) krApp->updateGUI();
 }
 
+void KRslots::saveNewToolbarConfig() {
+  KConfigGroup cg(KGlobal::config(), QString());
+  krApp->applyMainWindowSettings(cg);
+  krApp->updateGUI();
+}
+
 void KRslots::configKeys(){
   KrKeyDialog( MAIN_VIEW );
 }
 
 // misc
 void KRslots::changeTrashIcon(){
+#if 0 // TODO: is this needed?
 	// update trash bin icon - this is "stolen" konqi code
 	// Copyright (C) 2000  David Faure <faure@kde.org>
-	KURL trash;
+	KUrl trash;
 	trash.setPath(KGlobalSettings::trashPath());
-	KURL::List lst;
+	KUrl::List lst;
 	lst.append(trash);
 	KDirNotify_stub allDirNotify("*","KDirNotify*");
 	allDirNotify.FilesChanged( lst );
 	// end of konqi code
+#endif
 }
 
 // F2
@@ -589,6 +613,10 @@ void KRslots::edit()           { ACTIVE_FUNC->editFile();   }
 void KRslots::copyFiles()      { ACTIVE_FUNC->copyFiles();  }
 // F6
 void KRslots::moveFiles()      { ACTIVE_FUNC->moveFiles();  }	
+// SHIFT + F5
+void KRslots::copyFilesByQueue() { ACTIVE_FUNC->copyFiles( true );  }
+// SHIFT + F6
+void KRslots::moveFilesByQueue() { ACTIVE_FUNC->moveFiles( true );  }	
 // F7
 void KRslots::mkdir()          { ACTIVE_FUNC->mkdir();      }
 // F8
@@ -599,7 +627,7 @@ void KRslots::rename()         { ACTIVE_FUNC->rename();     }
 // Shift F3
 void KRslots::viewDlg(){
   // ask the user for a url to view
-	KURL dest = KChooseDir::getDir(i18n("Enter a URL to view:"), ACTIVE_PANEL->virtualPath(), ACTIVE_PANEL->virtualPath());
+	KUrl dest = KChooseDir::getDir(i18n("Enter a URL to view:"), ACTIVE_PANEL->virtualPath(), ACTIVE_PANEL->virtualPath());
 	if ( dest.isEmpty() ) return ; // the user canceled
    
     KrViewer::view( dest ); // view the file
@@ -610,12 +638,12 @@ void KRslots::viewDlg(){
 // Shift F4
 void KRslots::editDlg(){
   // ask the user for the filename to edit
-	KURL dest = KChooseDir::getDir(i18n("Enter the filename to edit:"), ACTIVE_PANEL->virtualPath(), ACTIVE_PANEL->virtualPath());
+	KUrl dest = KChooseDir::getDir(i18n("Enter the filename to edit:"), ACTIVE_PANEL->virtualPath(), ACTIVE_PANEL->virtualPath());
 	if ( dest.isEmpty() ) return ; // the user canceled
 
     KrViewer::edit( dest );
     
-    if( dest.upURL().equals( ACTIVE_PANEL->virtualPath(), true ) )
+    if( dest.upUrl().equals( ACTIVE_PANEL->virtualPath(), KUrl::CompareWithoutTrailingSlash ) )
       refresh();
 }
 
@@ -624,7 +652,7 @@ void KRslots::duplicateTab() {
 }
 
 // ugly: do this right before release!
-void KRslots::newTab(const KURL& url) {
+void KRslots::newTab(const KUrl& url) {
   if (url.isValid())
      ACTIVE_PANEL_MANAGER->slotNewTab(url);
   else ACTIVE_PANEL_MANAGER->slotNewTab();
@@ -641,11 +669,11 @@ void KRslots::previousTab() {
 void KRslots::newTab(KrViewItem *it) {
   if (!it) return;
   if( it->name() == ".." ) {
-    KURL url = ACTIVE_PANEL->virtualPath();
-    ACTIVE_PANEL_MANAGER->slotNewTab( url.upURL() );
+    KUrl url = ACTIVE_PANEL->virtualPath();
+    ACTIVE_PANEL_MANAGER->slotNewTab( url.upUrl() );
   }
   else if (ITEM2VFILE(ACTIVE_PANEL, it)->vfile_isDir()) {
-    KURL url = ACTIVE_PANEL->virtualPath();
+    KUrl url = ACTIVE_PANEL->virtualPath();
     url.addPath( it->name() );
     ACTIVE_PANEL_MANAGER->slotNewTab( url );
   }
@@ -671,7 +699,7 @@ void KRslots::slotSplit()
     return;
   }
 
-  KURL fileURL = ACTIVE_FUNC->files()->vfs_getFile(name);
+  KUrl fileURL = ACTIVE_FUNC->files()->vfs_getFile(name);
   if( fileURL.isEmpty() )
     return;
 
@@ -680,13 +708,13 @@ void KRslots::slotSplit()
     return ;
   }
 
-  KURL destDir  = ACTIVE_PANEL->otherPanel->func->files()->vfs_getOrigin();
+  KUrl destDir  = ACTIVE_PANEL->otherPanel->func->files()->vfs_getOrigin();
 
   SplitterGUI splitterGUI( MAIN_VIEW, fileURL, destDir );
 
   if( splitterGUI.result() == QDialog::Accepted )
   {
-    bool splitToOtherPanel = ( splitterGUI.getDestinationDir().equals( ACTIVE_PANEL->otherPanel->virtualPath(), true ) );
+    bool splitToOtherPanel = ( splitterGUI.getDestinationDir().equals( ACTIVE_PANEL->otherPanel->virtualPath(), KUrl::CompareWithoutTrailingSlash ) );
 
     Splitter split( MAIN_VIEW, fileURL, splitterGUI.getDestinationDir() );
     split.split( splitterGUI.getSplitSize() );
@@ -698,11 +726,11 @@ void KRslots::slotSplit()
 
 void KRslots::slotCombine(){
   QStringList   list;
-  KURL          baseURL;
+  KUrl          baseURL;
   bool          unixStyle = false;
   bool          windowsStyle = false;
-  QString       commonName = QString::null;
-  unsigned int  commonLength = 0;
+  QString       commonName = QString();
+  int           commonLength = 0;
 
   ((ListPanel*)ACTIVE_PANEL)->getSelectedNames(&list);
   if ( list.isEmpty() )
@@ -714,7 +742,7 @@ void KRslots::slotCombine(){
   /* checking splitter names */
   for ( QStringList::Iterator it = list.begin(); it != list.end(); ++it )
   {
-    KURL url = ACTIVE_FUNC->files()->vfs_getFile(*it);
+    KUrl url = ACTIVE_FUNC->files()->vfs_getFile(*it);
     if( url.isEmpty() )
       return;
 
@@ -726,7 +754,7 @@ void KRslots::slotCombine(){
     if( !unixStyle )
     {
       QString name = url.fileName();
-      int extPos = name.findRev( '.' );
+      int extPos = name.lastIndexOf( '.' );
       QString ext = name.mid( extPos + 1 );
       name.truncate( extPos );
       url.setFileName( name );
@@ -738,7 +766,7 @@ void KRslots::slotCombine(){
       {
         if( windowsStyle )
         {
-          KMessageBox::error(0,i18n("Not a split file %1!").arg( vfs::pathOrURL( url ) ));
+          KMessageBox::error(0,i18n("Not a split file %1!", url.pathOrUrl() ));
           return;
         }
         unixStyle = true;
@@ -770,7 +798,7 @@ void KRslots::slotCombine(){
 
         if( lastChar.isLetter() )
         {
-          char fillLetter = ( lastChar.upper() == lastChar ) ? 'A' : 'a';
+          char fillLetter = ( lastChar.toUpper() == lastChar ) ? 'A' : 'a';
 
           if( commonName.isNull() )
           {
@@ -780,7 +808,7 @@ void KRslots::slotCombine(){
             while ( commonName.length() )
             {
               QString shorter  = commonName.left( commonName.length() - 1 );
-              QString testFile = shorter.leftJustify( commonLength, fillLetter );
+              QString testFile = shorter.leftJustified( commonLength, fillLetter );
 
               if( ACTIVE_FUNC->files()->vfs_search( testFile ) == 0 )
                 break;
@@ -801,18 +829,18 @@ void KRslots::slotCombine(){
 
       if( error )
       {
-        KMessageBox::error(0,i18n("Not a splitted file %1!").arg( vfs::pathOrURL( url ) ));
+        KMessageBox::error(0,i18n("Not a splitted file %1!", url.pathOrUrl() ));
         return;
       }
     }
   }
 
    // ask the user for the copy dest
-  KURL dest = KChooseDir::getDir(i18n("Combining %1.* to directory:" ).arg( vfs::pathOrURL( baseURL ) ),
+  KUrl dest = KChooseDir::getDir(i18n("Combining %1.* to directory:", baseURL.pathOrUrl() ),
                                  ACTIVE_PANEL->otherPanel->virtualPath(), ACTIVE_PANEL->virtualPath());
   if ( dest.isEmpty() ) return ; // the user canceled
 
-  bool combineToOtherPanel = ( dest.equals( ACTIVE_PANEL->otherPanel->virtualPath(), true ) );
+  bool combineToOtherPanel = ( dest.equals( ACTIVE_PANEL->otherPanel->virtualPath(), KUrl::CompareWithoutTrailingSlash ) );
 
   Combiner combine( MAIN_VIEW, baseURL, dest, unixStyle );
   combine.combine();
@@ -845,12 +873,12 @@ void KRslots::updatePopupPanel(KrViewItem *item) {
 	ListPanel *lp = 0;
 	if (ACTIVE_PANEL->popup->isHidden() &&
 		 ACTIVE_PANEL->otherPanel->popup->isHidden()) return;
-	if (ACTIVE_PANEL->popup->isShown())
+	if (!ACTIVE_PANEL->popup->isHidden())
 		lp = ACTIVE_PANEL;
-	else if (ACTIVE_PANEL->otherPanel->popup->isShown())
+	else if (!ACTIVE_PANEL->otherPanel->popup->isHidden())
 		lp = ACTIVE_PANEL->otherPanel;
 
-	KURL url;
+	KUrl url;
 	if (item->name()!="..") // updir
 		url = ACTIVE_FUNC->files()->vfs_getFile(item->name());
 	lp->popup->update(url);
@@ -867,8 +895,8 @@ void KRslots::compareSetup()
   for( int i=0; Krusader::compareArray[i] != 0; i++ )
     if( (*Krusader::compareArray[i])->isChecked() )
     {
-      krConfig->setGroup( "Private" );
-      krConfig->writeEntry( "Compare Mode", i );
+      KConfigGroup group( krConfig, "Private" );
+      group.writeEntry( "Compare Mode", i );
       break;
     }
 }
@@ -881,7 +909,7 @@ void KRslots::execTypeSetup()
     {
       if( *Krusader::execTypeArray[i] == Krusader::actExecTerminalEmbedded ){
          // if commands are to be executed in the TE, it must be loaded
-         MAIN_VIEW->createTE();
+         MAIN_VIEW->terminal_dock->initialise();
       }
       KConfigGroup grp(krConfig,  "Private" );
       grp.writeEntry( "Command Execution Mode", i );
@@ -895,7 +923,12 @@ void KRslots::togglePopupPanel() {
 
 void KRslots::slotDiskUsage()
 {
-  DiskUsageGUI du( ACTIVE_FUNC->files()->vfs_getOrigin(), MAIN_VIEW, "DiskUsage" );
+  DiskUsageGUI du( ACTIVE_FUNC->files()->vfs_getOrigin(), MAIN_VIEW );
+}
+
+void KRslots::slotQueueManager()
+{
+  QueueDialog::showDialog( false );
 }
 
 // when window becomes focused, enable the refresh in the visible panels
