@@ -34,6 +34,8 @@
 #define KRSLOTS_H
 
 #include <qobject.h>
+#include <kprocess.h>
+#include <kio/netaccess.h>
 // the 2 following #includes should go away with the ugly stubs on the bottom
 #include "krusader.h"
 #include "krusaderview.h"
@@ -45,7 +47,32 @@
 #include "GUI/mediabutton.h"
 
 class ListPanel;
-class KURL;
+class KUrl;
+
+class KrProcess: public KProcess
+{
+  Q_OBJECT
+
+  QString tmp1, tmp2;
+  
+public:
+  KrProcess( QString in1, QString in2 )
+  {
+    tmp1 = in1;
+    tmp2 = in2;
+    connect(this,  SIGNAL(finished(int, QProcess::ExitStatus)), SLOT(processHasExited()));
+  }
+
+public slots:
+  void processHasExited()
+  {
+    if( !tmp1.isEmpty() )
+      KIO::NetAccess::removeTempFile( tmp1 );
+    if( !tmp2.isEmpty() )
+      KIO::NetAccess::removeTempFile( tmp2 );
+    deleteLater();
+  }
+};
 
 class KRslots : public QObject {
     Q_OBJECT
@@ -53,21 +80,25 @@ class KRslots : public QObject {
   public:
     enum compareMode { full } ;
 
-    KRslots(QObject *parent): QObject(parent, "KRslots") {}
+    KRslots(QObject *parent): QObject(parent) {}
     ~KRslots() {}
 
   public slots:
     void createChecksum();
     void matchChecksum();
-    void sendFileByEmail( QString filename );
+    void sendFileByEmail( const KUrl::List &filename );
     void compareContent();
-    void compareContent( KURL, KURL );
+    void compareContent( KUrl, KUrl );
     void rightclickMenu();
     void insertFileName(bool full_path);
     void rootKrusader();
     void swapPanels();
-    void setBriefView();
-    void setDetailedView();
+    void setView0();
+    void setView1();
+    void setView2();
+    void setView3();
+    void setView4();
+    void setView5();
     void toggleHidden();
     void toggleSwapSides();
 	 void togglePopupPanel();
@@ -91,7 +122,7 @@ class KRslots : public QObject {
     /** called by actExec* actions to choose the built-in command line mode */
     void execTypeSetup();
     void refresh();
-    void refresh( const KURL& u );
+    void refresh( const KUrl& u );
     void properties();
     void back();
     void slotPack();
@@ -110,25 +141,25 @@ class KRslots : public QObject {
     void startKonfigurator() { runKonfigurator( false ); }
     void search();						 				// call the search module
     void locate();
+    void runTerminal( const QString & dir, const QStringList & args );
     void homeTerminal();
     void sysInfo();
     void addBookmark();
     void runMountMan();
-    void runRemoteMan();
     void toggleFnkeys();
     void toggleCmdline();
     void changeTrashIcon();
     void multiRename();
-    void openRightBookmarks() { RIGHT_PANEL->slotFocusOnMe(); RIGHT_PANEL->bookmarksButton->openPopup(); }
-    void openLeftBookmarks() { LEFT_PANEL->slotFocusOnMe(); LEFT_PANEL->bookmarksButton->openPopup(); }
-	 void openBookmarks() { ACTIVE_PANEL->bookmarksButton->openPopup(); }
+    void openRightBookmarks() { RIGHT_PANEL->slotFocusOnMe(); RIGHT_PANEL->bookmarksButton->showMenu(); }
+    void openLeftBookmarks() { LEFT_PANEL->slotFocusOnMe(); LEFT_PANEL->bookmarksButton->showMenu(); }
+	 void openBookmarks() { ACTIVE_PANEL->bookmarksButton->showMenu(); }
     void bookmarkCurrent();
-	 void openHistory() { ACTIVE_PANEL->historyButton->openPopup(); }
-    void openLeftHistory() { LEFT_PANEL->historyButton->openPopup(); }
-    void openRightHistory() { RIGHT_PANEL->historyButton->openPopup(); }
-    void openMedia() { ACTIVE_PANEL->mediaButton->openPopup(); }
-    void openLeftMedia() { LEFT_PANEL->mediaButton->openPopup(); }
-    void openRightMedia() { RIGHT_PANEL->mediaButton->openPopup(); }
+	 void openHistory() { ACTIVE_PANEL->historyButton->showMenu(); }
+    void openLeftHistory() { LEFT_PANEL->historyButton->showMenu(); }
+    void openRightHistory() { RIGHT_PANEL->historyButton->showMenu(); }
+    void openMedia() { ACTIVE_PANEL->mediaButton->showMenu(); }
+    void openLeftMedia() { LEFT_PANEL->mediaButton->showMenu(); }
+    void openRightMedia() { RIGHT_PANEL->mediaButton->showMenu(); }
 	 void syncPanels() {
 	 	ListPanel *t = ACTIVE_PANEL;
 		OTHER_FUNC->openUrl(ACTIVE_PANEL->virtualPath());
@@ -136,7 +167,7 @@ class KRslots : public QObject {
 	 }
     void cmdlinePopup() { MAIN_VIEW->cmdLine->popup(); }
     void duplicateTab();
-    void newTab(const KURL& url = KURL());
+    void newTab(const KUrl& url = KUrl());
     void newTab(KrViewItem *item);
     void closeTab();
     void nextTab();
@@ -148,6 +179,7 @@ class KRslots : public QObject {
     void slotSynchronizeDirs( QStringList selected = QStringList() );
     void slotSyncBrowse();
     void slotDiskUsage();
+    void slotQueueManager();
     void slotLocationBar();
     void slotJumpBack();
     void slotSetJumpBack();
@@ -169,6 +201,10 @@ class KRslots : public QObject {
     void copyFiles();
     // F6
     void moveFiles();
+    // SHIFT + F5
+    void copyFilesByQueue();
+    // SHIFT + F6
+    void moveFilesByQueue();
     // F7
     void mkdir();
     // F8
@@ -182,6 +218,7 @@ class KRslots : public QObject {
 
     
     void jsConsole();
+    void saveNewToolbarConfig();
 };
 
 #endif
