@@ -29,10 +29,15 @@
 ***************************************************************************/
 
 // Qt includes
-#include <qwhatsthis.h> 
+#include <QGridLayout>
+#include <QList>
+#include <QKeyEvent>
+#include <QEvent>
 #include <kstatusbar.h>
 #include <kmenubar.h>
 #include <kshortcut.h>
+#include <ktoolbar.h>
+#include <ktoggleaction.h>
 // Krusader includes
 #include "krusaderview.h"
 #include "krusader.h"
@@ -42,6 +47,7 @@
 #include "Panel/panelfunc.h"
 #include "GUI/kcmdline.h"
 #include "GUI/kfnkeys.h"
+#include "GUI/terminaldock.h"
 #include "resources.h"
 #include "panelmanager.h"
 #include <klibloader.h> //<>
@@ -50,21 +56,23 @@
 #include "krservices.h"
 #include <qclipboard.h>
 
-KrusaderView::KrusaderView( QWidget *parent ) : QWidget( parent, "KrusaderView" ), activePanel(0), 
-								konsole_part( 0L ) {}
+KrusaderView::KrusaderView( QWidget *parent ) : QWidget( parent ), activePanel(0) {}
 
-void KrusaderView::start( QStringList leftTabs, QStringList leftTypes, QValueList<int> leftProps, int leftActiveTab,
-                          QStringList rightTabs, QStringList rightTypes, QValueList<int> rightProps, int rightActiveTab, 
+void KrusaderView::start( QStringList leftTabs, QList<int> leftTypes, QList<int> leftProps, int leftActiveTab,
+                          QStringList rightTabs, QList<int> rightTypes, QList<int> rightProps, int rightActiveTab,
                           bool leftSideActive ) {
   ////////////////////////////////
   // make a 1x1 mainLayout, it will auto-expand:
-  mainLayout = new QGridLayout( this, 1, 1 );
+  mainLayout = new QGridLayout( this );
+  mainLayout->setContentsMargins( 0, 0, 0, 0 );
+  mainLayout->setSpacing( 0 );
   // vertical splitter
   vert_splitter = new QSplitter( this ); // splits between panels and terminal/cmdline
-  vert_splitter->setOrientation( QObject::Vertical );
+  vert_splitter->setOrientation( Qt::Vertical );
   // horizontal splitter
   horiz_splitter = new PercentalSplitter( vert_splitter );
-  ( terminal_dock = new QHBox( vert_splitter ) ) ->hide(); // create it hidden
+  ( terminal_dock = new TerminalDock( vert_splitter ) ) ->hide(); // create it hidden
+
   // create a command line thing
   cmdLine = new KCMDLine( this );
 
@@ -84,8 +92,7 @@ void KrusaderView::start( QStringList leftTabs, QStringList leftTypes, QValueLis
   // create the function keys widget
   fnKeys = new KFnKeys( this );
   fnKeys->hide();
-  QWhatsThis::add
-    ( fnKeys, i18n( "Function keys allow performing fast "
+  fnKeys->setWhatsThis( i18n( "Function keys allow performing fast "
                     "operations on files." ) );
 
   // and insert the whole thing into the main layout... at last
@@ -95,17 +102,23 @@ void KrusaderView::start( QStringList leftTabs, QStringList leftTypes, QValueLis
   mainLayout->activate();
 
   // get the last saved sizes of the splitter
-  krConfig->setGroup( "Private" );
-  QValueList<int> lst = krConfig->readIntListEntry( "Splitter Sizes" );
-  if ( lst.isEmpty() )
+  KConfigGroup group( krConfig, "Private" );
+  QList<int> lst = group.readEntry( "Splitter Sizes", QList<int>() );
+  if ( lst.count() == 0 )
   {
-    lst = horiz_splitter->sizes();
-    int avg = (lst[ 0 ] + lst[ 1 ] )/2;
-    lst[ 0 ] = lst[ 1 ] = avg;
+    lst.push_back( 100 );
+    lst.push_back( 100 );
+  } else if( lst.count() == 2 && lst[ 0 ] == 0 && lst[ 1 ] == 0 )
+  {
+    lst[ 0 ] = 100;
+    lst[ 1 ] = 100;
   }
+
   horiz_splitter->setSizes( lst );  
 
-  verticalSplitterSizes = krConfig->readIntListEntry( "Terminal Emulator Splitter Sizes" );
+  verticalSplitterSizes = group.readEntry( "Terminal Emulator Splitter Sizes", QList<int> () );
+  if( verticalSplitterSizes.count() == 2 && verticalSplitterSizes[ 0 ] == 0 && verticalSplitterSizes[ 1 ] == 0 )
+    verticalSplitterSizes.clear();
     
   show();
 
@@ -119,10 +132,10 @@ void KrusaderView::start( QStringList leftTabs, QStringList leftTypes, QValueLis
   left->setProperties( leftProps[ 0 ] );
   right->setProperties( rightProps[ 0 ] );
      
-  for(unsigned int i = 1; i < leftTabs.count(); i++ )
+  for(int i = 1; i < leftTabs.count(); i++ )
     leftMng->slotNewTab( leftTabs[ i ], false, leftTypes[ i ], leftProps[ i ] );
 
-  for(unsigned int j = 1; j < rightTabs.count(); j++ )
+  for(int j = 1; j < rightTabs.count(); j++ )
     rightMng->slotNewTab( rightTabs[ j ], false, rightTypes[ j ], rightProps[ j ] );
        
   leftMng->setActiveTab( leftActiveTab );
@@ -138,11 +151,10 @@ void KrusaderView::start( QStringList leftTabs, QStringList leftTypes, QValueLis
 //////////////////////////////////////////////////////////
 void KrusaderView::slotCurrentChanged( QString p ) {
   cmdLine->setCurrent( p );
-  if ( konsole_part != 0L && konsole_part->widget() != 0L ) {
-	 KConfigGroupSaver grp(krConfig, "General");
-    if (krConfig->readBoolEntry("Send CDs", _SendCDs)) // hopefully, this is cached in kconfig
-        if( !konsole_part->url().equals( KURL( p ), true ) )
-           konsole_part->openURL( KURL( p ) );
+  KConfigGroup cfg = krConfig->group("General");
+  if (cfg.readEntry("Send CDs", _SendCDs)) // hopefully, this is cached in kconfig
+  {
+    terminal_dock->sendCd( p );
   }
 }
 
@@ -154,43 +166,13 @@ void KrusaderView::cmdLineUnFocus() { // return focus to the active panel
   activePanel->slotFocusOnMe();
 }
 
-/** if the KonsolePart for the Terminal Emulator is not yet loaded, load it */
-void KrusaderView::createTE() {
-  if ( konsole_part == 0L ) {  // konsole part is not yet loaded
-    KLibFactory * factory = KLibLoader::self() ->factory( "libkonsolepart" );
-    if ( factory ) {
-      QWidget *focusW = qApp->focusWidget();
-      // Create the part
-      konsole_part = ( KParts::ReadOnlyPart * )
-                          factory->create( terminal_dock, "konsolepart",
-                                           "KParts::ReadOnlyPart" );
-      if( konsole_part ) { //loaded successfully
-        connect( konsole_part, SIGNAL( destroyed() ),
-                 this, SLOT( killTerminalEmulator() ) );
-        qApp->installEventFilter( this );
-      } else {
-        qApp->removeEventFilter( this );
-      }
-      /*the Terminal Emulator may be hidden (if we are creating it only
-        to send command there and see the results later */
-      if( focusW ) {
-        focusW->setFocus();
-      }
-      else {
-        activePanel->slotFocusOnMe();    
-      }
-    } else
-      konsole_part = 0L;
-  }
-}
-
 // Tab - switch focus
 void KrusaderView::panelSwitch() { activePanel->otherPanel->slotFocusOnMe(); }
 void KrusaderView::slotSetActivePanel( ListPanel *p ) { activePanel = p; }
 
 void KrusaderView::slotTerminalEmulator( bool show ) {
-  KConfigGroupSaver grp(krConfig, "Look&Feel");
-  bool fullscreen = krConfig->readBoolEntry("Fullscreen Terminal Emulator", false);
+  KConfigGroup cfg = krConfig->group("Look&Feel");
+  bool fullscreen = cfg.readEntry("Fullscreen Terminal Emulator", false);
   static bool fnKeysShown=true; // first time init. should be overridden
   static bool cmdLineShown=true;
   static bool statusBarShown=true;
@@ -199,19 +181,11 @@ void KrusaderView::slotTerminalEmulator( bool show ) {
 
   if ( !show ) {  // hiding the terminal
     activePanel->slotFocusOnMe();
-    if( terminal_dock->isVisible() && !fullscreen )
+    if( terminal_dock->isTerminalVisible() && !fullscreen )
       verticalSplitterSizes = vert_splitter->sizes();
 
-    // BUGFIX: when the terminal emulator is toggled on, first it is shown in minimum size
-    //         then QSplitter resizes it to the desired size.
-    //         this minimum resize scrolls up the content of the konsole widget
-    // SOLUTION:
-    //         we hide the console widget while the resize ceremony happens, then reenable it
-    if( konsole_part )
-      konsole_part->widget()->hide(); // hide the widget to prevent from resize
-
     terminal_dock->hide();
-    QValueList<int> newSizes;
+    QList<int> newSizes;
     newSizes.push_back( vert_splitter->height() );
     newSizes.push_back( 0 );
     vert_splitter->setSizes( newSizes );
@@ -231,22 +205,16 @@ void KrusaderView::slotTerminalEmulator( bool show ) {
     return ;
   }
   // else implied
-  createTE();
-  if ( konsole_part ) {      // if we succeeded in creating the konsole
+  terminal_dock->initialise();
+  if ( terminal_dock->isInitialised() ) {      // if we succeeded in creating the konsole
     if( !verticalSplitterSizes.empty() )
       vert_splitter->setSizes( verticalSplitterSizes );
       
     terminal_dock->show();
     slotCurrentChanged( activePanel->realPath() );
 
-    // BUGFIX: TE scrolling bug (see upper)
-    //         show the Konsole part delayed
-    QTimer::singleShot( 0, konsole_part->widget(), SLOT( show() ) );
-
-    if( konsole_part->widget() ) {
-      konsole_part->widget()->setFocus();
-
-    }
+    terminal_dock->setFocus();
+    
     krToggleTerminal->setChecked( true );
     // in full screen mode, we hide everything else, but first, see what was actually shown
     if (fullscreen) {
@@ -272,87 +240,22 @@ void KrusaderView::slotTerminalEmulator( bool show ) {
 
 void KrusaderView::focusTerminalEmulator()
 {
-  if ( MAIN_VIEW->terminal_dock->isVisible() && MAIN_VIEW->konsole_part && MAIN_VIEW->konsole_part->widget() )
-    MAIN_VIEW->konsole_part->widget()->setFocus();
+  if ( terminal_dock->isTerminalVisible() )
+    terminal_dock->setFocus();
 }
 
 void KrusaderView::switchFullScreenTE()
 {
-  if( terminal_dock->isVisible() && konsole_part && konsole_part->widget() && konsole_part->widget()->isVisible() ) {
-    KConfigGroup grp(krConfig, "Look&Feel");
-    bool fullscreen=grp.readBoolEntry("Fullscreen Terminal Emulator", false);
+  if( terminal_dock->isTerminalVisible() ) {
+    KConfigGroup grp = krConfig->group("Look&Feel");
+    bool fullscreen=grp.readEntry("Fullscreen Terminal Emulator", false);
     slotTerminalEmulator( false );
     grp.writeEntry("Fullscreen Terminal Emulator", !fullscreen);
     slotTerminalEmulator( true );
   }
 }
 
-
-bool KrusaderView::eventFilter ( QObject * watched, QEvent * e ) {
-  if( e->type() == QEvent::AccelOverride && konsole_part && konsole_part->widget() == watched ) {
-    QKeyEvent *ke = (QKeyEvent *)e;
-    if( ( ke->key() ==  Key_Insert ) && ( ke->state()  == ShiftButton ) ) {
-      ke->accept();
-      return true;
-    }
-    if( ( ke->state() == 0 || ke->state() == ShiftButton ) && 
-        ( ke->key() >= 32 ) && (ke->key() <= 127 ) ) {
-      ke->accept();
-      return true;
-    }
-  }
-  else if( e->type() == QEvent::KeyPress && konsole_part && konsole_part->widget() == watched ) {
-    QKeyEvent *ke = (QKeyEvent *)e;
-    KKey pressedKey( ke );
-
-    if( Krusader::actToggleTerminal->shortcut().contains( pressedKey ) ) {
-        Krusader::actToggleTerminal->activate();
-        return true;
-    }
-
-    if( Krusader::actSwitchFullScreenTE->shortcut().contains( pressedKey ) ) {
-        Krusader::actSwitchFullScreenTE->activate();
-        return true;
-    }
-
-    if( ( ke->key() == Key_Enter || ke->key() == Key_Return ) && ( ( ke->state() & ~ShiftButton ) == ControlButton ) ) {
-
-      QString filename = ACTIVE_PANEL->view->getCurrentItem();
-      if( filename == QString::null || filename == ".." )
-        return true;
-      if( ke->state() & ShiftButton ) {
-        QString path=vfs::pathOrURL( ACTIVE_FUNC->files()->vfs_getOrigin(), 1 );
-        filename = path+filename;
-      }
-
-      filename = KrServices::quote( filename );
-
-      QKeyEvent keyEvent( QEvent::KeyPress, 0, -1, 0, QString( " " ) + filename + QString( " " ));
-      QApplication::sendEvent( konsole_part->widget(), &keyEvent );
-      return true;
-    } else if( ( ke->key() ==  Key_Down ) && ( ke->state() == ControlButton ) ) {
-      if( cmdLine->isVisible() )
-        cmdLine->setFocus();
-      return true;
-    } else if( ( ( ke->key() ==  Key_Up ) && ( ke->state()  == ControlButton ) ) || 
-               ( ke->state()  == ( ControlButton | ShiftButton ) ) ) {
-      ACTIVE_PANEL->slotFocusOnMe();
-      return true;
-    } else if( Krusader::actPaste->shortcut().contains( pressedKey ) ) {
-      QString text = QApplication::clipboard()->text();
-      if ( ! text.isEmpty() )
-      {
-        text.replace("\n", "\r");
-        QKeyEvent keyEvent(QEvent::KeyPress, 0,-1,0, text);
-        QApplication::sendEvent( konsole_part->widget(), &keyEvent );
-      }
-      return true;
-    }
-  }
-  return false;
-}
-
-QValueList<int> KrusaderView::getTerminalEmulatorSplitterSizes() {
+QList<int> KrusaderView::getTerminalEmulatorSplitterSizes() {
   if( terminal_dock->isVisible() )
     return vert_splitter->sizes();
   else
@@ -360,7 +263,6 @@ QValueList<int> KrusaderView::getTerminalEmulatorSplitterSizes() {
 }
 
 void KrusaderView::killTerminalEmulator() {
-  konsole_part = 0L;
   slotTerminalEmulator( false );  // hide the docking widget
   krToggleTerminal->setChecked( false );
 }
@@ -380,16 +282,12 @@ void KrusaderView::profiles( QString profileName )
 
 void KrusaderView::loadPanelProfiles( QString group )
 {
-  krConfig->setGroup( group );
-  MAIN_VIEW->leftMng->loadSettings( krConfig, "Left Tabs" );
-  krConfig->setGroup( group );
-  MAIN_VIEW->rightMng->loadSettings( krConfig, "Right Tabs" );
-  krConfig->setGroup( group );
-  MAIN_VIEW->leftMng->setActiveTab( krConfig->readNumEntry( "Left Active Tab", 0 ) );
-  krConfig->setGroup( group );
-  MAIN_VIEW->rightMng->setActiveTab( krConfig->readNumEntry( "Right Active Tab", 0 ) );
-  krConfig->setGroup( group );  
-  if( krConfig->readBoolEntry( "Left Side Is Active", true ) )
+  KConfigGroup ldg( krConfig, group );
+  MAIN_VIEW->leftMng->loadSettings( &ldg, "Left Tabs" );
+  MAIN_VIEW->rightMng->loadSettings( &ldg, "Right Tabs" );
+  MAIN_VIEW->leftMng->setActiveTab( ldg.readEntry( "Left Active Tab", 0 ) );
+  MAIN_VIEW->rightMng->setActiveTab( ldg.readEntry( "Right Active Tab", 0 ) );
+  if( ldg.readEntry( "Left Side Is Active", true ) )
     MAIN_VIEW->left->slotFocusOnMe();
   else
     MAIN_VIEW->right->slotFocusOnMe();
@@ -397,19 +295,25 @@ void KrusaderView::loadPanelProfiles( QString group )
 
 void KrusaderView::savePanelProfiles( QString group )
 {
-  krConfig->setGroup( group );
+  KConfigGroup svr( krConfig, group );
   
-  MAIN_VIEW->leftMng->saveSettings( krConfig, "Left Tabs", false );
-  krConfig->writeEntry( "Left Active Tab", MAIN_VIEW->leftMng->activeTab() );
-  MAIN_VIEW->rightMng->saveSettings( krConfig, "Right Tabs", false );
-  krConfig->writeEntry( "Right Active Tab", MAIN_VIEW->rightMng->activeTab() );
-  krConfig->writeEntry( "Left Side Is Active", MAIN_VIEW->activePanel->isLeft() );
+  MAIN_VIEW->leftMng->saveSettings( &svr, "Left Tabs", false );
+  svr.writeEntry( "Left Active Tab", MAIN_VIEW->leftMng->activeTab() );
+  MAIN_VIEW->rightMng->saveSettings( &svr, "Right Tabs", false );
+  svr.writeEntry( "Right Active Tab", MAIN_VIEW->rightMng->activeTab() );
+  svr.writeEntry( "Left Side Is Active", MAIN_VIEW->activePanel->isLeft() );
 }
 
 void KrusaderView::toggleVerticalMode() {
-	if (horiz_splitter->orientation() == QSplitter::Vertical)
-		horiz_splitter->setOrientation(QSplitter::Horizontal);
-	else horiz_splitter->setOrientation(QSplitter::Vertical);
+	if (horiz_splitter->orientation() == Qt::Vertical) {
+		horiz_splitter->setOrientation(Qt::Horizontal);
+		Krusader::actVerticalMode->setText( i18n( "Vertical Mode" ) );
+		Krusader::actVerticalMode->setIcon( KIcon( "view-split-top-bottom" ) );
+	} else {
+		horiz_splitter->setOrientation(Qt::Vertical);
+		Krusader::actVerticalMode->setText( i18n( "Horizontal Mode" ) );
+		Krusader::actVerticalMode->setIcon( KIcon( "view-split-left-right" ) );
+	}
 }
 
 #include "krusaderview.moc"
