@@ -33,9 +33,7 @@
 #define KRUSADERVIEW_H
 
 // KDE includes
-#include <klistview.h>
 #include <klocale.h>
-#include <kaccel.h>
 #include <kapplication.h>
 #include <kparts/part.h>
 
@@ -44,8 +42,8 @@
 #include <qsplitter.h>
 #include <qwidget.h>
 #include <qpushbutton.h>
-#include <qhbox.h>
-#include <qvaluelist.h>
+#include <QGridLayout>
+#include <QEvent>
 
 class PanelManager;
 class ListPanel;
@@ -53,6 +51,7 @@ class ListPanel;
 // forward declaration
 class KFnKeys;
 class KCMDLine;
+class TerminalDock;
 
 class KrusaderView : public QWidget  {
    Q_OBJECT
@@ -60,17 +59,15 @@ class KrusaderView : public QWidget  {
 public:
 	KrusaderView(QWidget *parent=0);
 	virtual ~KrusaderView(){}
-  void start(QStringList leftTabs, QStringList leftTypes, QValueList<int> leftProps, int leftActiveTab, 
-             QStringList rightTabs, QStringList rightTypes, QValueList<int> rightProps, int rightActiveTab,
+  void start(QStringList leftTabs, QList<int> leftTypes, QList<int> leftProps, int leftActiveTab,
+             QStringList rightTabs, QList<int> rightTypes, QList<int> rightProps, int rightActiveTab,
              bool leftSideActive);
   void cmdLineFocus();  // command line receive's keyboard focus
   void cmdLineUnFocus();// return focus from command line to active panel
   inline PanelManager *activeManager() const { return (activePanel==left ? leftMng : rightMng); }
   inline PanelManager *inactiveManager() const { return (activePanel==left ? rightMng : leftMng); }
-  QValueList<int> getTerminalEmulatorSplitterSizes();
-  virtual bool eventFilter ( QObject * watched, QEvent * e );
-  /** if the KonsolePart for the Terminal Emulator is not yet loaded, load it */
-  void createTE();
+  QList<int> getTerminalEmulatorSplitterSizes();
+  inline bool          isVertical() const { return horiz_splitter != 0 ? horiz_splitter->orientation() == Qt::Vertical : false; }
   
 public slots:
   void slotCurrentChanged(QString p);
@@ -85,11 +82,10 @@ public slots:
   void focusTerminalEmulator();
   void switchFullScreenTE();
   
-  void profiles( QString profileName = QString::null );  
+  void profiles( QString profileName = QString() );  
   void loadPanelProfiles( QString group );
   void savePanelProfiles( QString group );
 
-protected slots:
   void killTerminalEmulator();
 
 public:
@@ -98,10 +94,9 @@ public:
   PanelManager *leftMng, *rightMng;       // saving them for panel swaps
   KFnKeys			*fnKeys;										// function keys
   KCMDLine    *cmdLine;                   // command line widget
-  QHBox       *terminal_dock;             // docking widget for terminal emulator
-  KParts::ReadOnlyPart *konsole_part;     // the actual part pointer
+  TerminalDock  *terminal_dock;             // docking widget for terminal emulator
   QSplitter		*horiz_splitter, *vert_splitter;
-  QValueList<int> verticalSplitterSizes;
+  QList<int>		 verticalSplitterSizes;
 
 private:
   QGridLayout *mainLayout, *terminal_layout;
