@@ -1,5 +1,6 @@
-#include <qwidgetstack.h>
+#include <qstackedwidget.h>
 #include <qtoolbutton.h>
+#include <QGridLayout>
 #include <klocale.h>
 #include <qimage.h>
 #include <kdebug.h>
@@ -10,6 +11,7 @@
 #include "Panel/panelfunc.h"
 #include "krusaderview.h"
 #include "defaults.h"
+#include "Panel/krviewfactory.h"
 
 #define HIDE_ON_SINGLE_TAB  false
 
@@ -20,25 +22,29 @@
 #define _other  (*_otherPtr)
 
 PanelManager::PanelManager( QWidget *parent, bool left ) :
-QWidget( parent, "PanelManager" ), _layout( 0 ), _left( left ), 
+QWidget( parent ), _layout( 0 ), _left( left ), 
        _selfPtr( _left ? &MAIN_VIEW->left : &MAIN_VIEW->right ), 
        _otherPtr( _left ? &MAIN_VIEW->right : &MAIN_VIEW->left ) {   
-   _layout = new QGridLayout( this, 1, 1 );
-   _stack = new QWidgetStack( this );
+   _layout = new QGridLayout( this );
+   _layout->setContentsMargins( 0, 0, 0, 0 );
+   _layout->setSpacing( 0 );
+   _stack = new QStackedWidget( this );
 
    // new tab button
    _newTab = new QToolButton( this );
    _newTab->setFixedSize( 22, 22 );
-   _newTab->setTextLabel( i18n( "Open a new tab in home" ) );
-   _newTab->setIconSet( SmallIcon( "tab_new" ) );
+   _newTab->setText( i18n( "Open a new tab in home" ) );
+   _newTab->setToolTip( i18n( "Open a new tab in home" ) );
+   _newTab->setIcon( SmallIcon( "tab-new" ) );
    _newTab->adjustSize();	
    connect( _newTab, SIGNAL( clicked() ), this, SLOT( slotNewTab() ) );
 
    // close tab button
    _closeTab = new QToolButton( this );
    _closeTab->setFixedSize( 22, 22 );
-   _closeTab->setTextLabel( i18n( "Close current tab" ) );
-   _closeTab->setIconSet( SmallIcon( "tab_remove" ) );
+   _closeTab->setText( i18n( "Close current tab" ) );
+   _closeTab->setToolTip( i18n( "Close current tab" ) );
+   _closeTab->setIcon( SmallIcon( "tab-close" ) );
    _closeTab->adjustSize();   
    connect( _closeTab, SIGNAL( clicked() ), this, SLOT( slotCloseTab() ) );
    _closeTab->setEnabled( false ); // disabled when there's only 1 tab
@@ -47,13 +53,15 @@ QWidget( parent, "PanelManager" ), _layout( 0 ), _left( left ),
    _tabbar = new PanelTabBar( this );
    connect( _tabbar, SIGNAL( changePanel( ListPanel* ) ), this, SLOT( slotChangePanel( ListPanel * ) ) );
    connect( _tabbar, SIGNAL( closeCurrentTab() ), this, SLOT( slotCloseTab() ) );
-   connect( _tabbar, SIGNAL( newTab( const KURL& ) ), this, SLOT( slotNewTab( const KURL& ) ) );
+   connect( _tabbar, SIGNAL( newTab( const KUrl& ) ), this, SLOT( slotNewTab( const KUrl& ) ) );
 
-   _layout->addMultiCellWidget( _stack, 0, 0, 0, 2 );
+   _layout->addWidget( _stack, 0, 0, 1, 3 );
    _layout->addWidget( _newTab, 1, 0 );
    _layout->addWidget( _tabbar, 1, 1 );
    _layout->addWidget( _closeTab, 1, 2 );
 
+   setLayout( _layout );
+
    if ( HIDE_ON_SINGLE_TAB ) HIDE
       else SHOW
 }
@@ -63,12 +71,12 @@ void PanelManager::slotChangePanel( ListPanel *p ) {
    _self->otherPanel = _other;
    _other->otherPanel = _self;
 
-   _stack->raiseWidget( _self );
+   _stack->setCurrentWidget( _self );
    kapp->processEvents();
    _self->slotFocusOnMe();
 }
 
-ListPanel* PanelManager::createPanel( QString type, bool setCurrent ) {
+ListPanel* PanelManager::createPanel( int type, bool setCurrent ) {
    // create the panel and add it into the widgetstack
    ListPanel * p = new ListPanel( type, _stack, _left );
    _stack->addWidget( p );
@@ -82,28 +90,28 @@ ListPanel* PanelManager::createPanel( QString type, bool setCurrent ) {
       SHOW // needed if we were hidden
    }
    if( setCurrent )
-     _stack->raiseWidget( p );
+     _stack->setCurrentWidget( p );
 
    // connect the activePanelChanged signal to enable/disable actions
    connect( p, SIGNAL( activePanelChanged( ListPanel* ) ), this, SLOT( slotRefreshActions() ) );
    return p;
 }
 
-void PanelManager::startPanel( ListPanel *panel, const KURL& path ) {
+void PanelManager::startPanel( ListPanel *panel, const KUrl& path ) {
    panel->start( path );
 }
 
-void PanelManager::saveSettings( KConfig *config, const QString& key, bool localOnly ) {
+void PanelManager::saveSettings( KConfigGroup *config, const QString& key, bool localOnly ) {
    QStringList l;
-   QStringList types;
-   QValueList<int> props;
+   QList<int> types;
+   QList<int> props;
    int i=0, cnt=0;
    while (cnt < _tabbar->count()) {
-      PanelTab *t = dynamic_cast<PanelTab*>(_tabbar->tabAt(i));
-      if (t && t->panel) {
-         l << ( localOnly ? t->panel->realPath() : vfs::pathOrURL( t->panel->virtualPath() ) );
-         types << t->panel->getType();
-         props << t->panel->getProperties();
+      ListPanel *panel = _tabbar->getPanel(i);
+      if (panel) {
+         l << ( localOnly ? panel->realPath() : panel->virtualPath().pathOrUrl() );
+         types << panel->getType();
+         props << panel->getProperties();
          ++cnt;
       }
       ++i;
@@ -113,36 +121,36 @@ void PanelManager::saveSettings( KConfig *config, const QString& key, bool local
    config->writeEntry( key + " Props", props );
 }
 
-void PanelManager::loadSettings( KConfig *config, const QString& key ) {
-   QStringList l = config->readPathListEntry( key );
-   QStringList types = config->readListEntry( key + " Types" );
-   QValueList<int> props = config->readIntListEntry( key + " Props" );
+void PanelManager::loadSettings( KConfigGroup *config, const QString& key ) {
+   QStringList l = config->readPathEntry( key, QStringList() );
+   QList<int> types = config->readEntry( key + " Types", QList<int>() );
+   QList<int> props = config->readEntry( key + " Props", QList<int>() );
    
    if( l.count() < 1 )
      return;
      
    while( types.count() < l.count() )
    {
-      KConfigGroupSaver saver( config, "Look&Feel");
-      types << krConfig->readEntry( "Default Panel Type", _DefaultPanelType );
+      KConfigGroup cg( krConfig, "Look&Feel");
+      types << cg.readEntry( "Default Panel Type", KrViewFactory::defaultViewId() );
    }
    while( props.count() < l.count() )
       props << 0;
-   
+
    int i=0, totalTabs = _tabbar->count();
    
    while (i < totalTabs && i < (int)l.count() ) 
    {
-      PanelTab *t = dynamic_cast<PanelTab*>(_tabbar->tabAt(i));
-      if (t && t->panel) 
+		ListPanel *panel = _tabbar->getPanel(i);
+      if (panel) 
       {
-         if( t->panel->getType() != types[ i ] )
-           t->panel->changeType( types[ i ] );
-         t->panel->setProperties( props[ i ] );
-         t->panel->otherPanel = _other;
-         _other->otherPanel = t->panel;
-         t->panel->func->files()->vfs_enableRefresh( true );
-         t->panel->func->immediateOpenUrl( vfs::fromPathOrURL( l[ i ] ) );
+         if( panel->getType() != types[ i ] )
+         	panel->changeType( types[ i ] );
+         panel->setProperties( props[ i ] );
+         panel->otherPanel = _other;
+         _other->otherPanel = panel;
+         panel->func->files()->vfs_enableRefresh( true );
+         panel->func->immediateOpenUrl( KUrl( l[ i ] ) );
       }
       ++i;
    }
@@ -151,16 +159,15 @@ void PanelManager::loadSettings( KConfig *config, const QString& key ) {
      slotCloseTab( --totalTabs );
       
    for(; i < (int)l.count(); i++ )
-     slotNewTab( vfs::fromPathOrURL(l[i]), false, types[ i ], props[ i ] );
+     slotNewTab( KUrl(l[i]), false, types[ i ], props[ i ] );
 }
 
-void PanelManager::slotNewTab(const KURL& url, bool setCurrent, QString type, int props ) {
-   if( type.isNull() )
-   {
-       krConfig->setGroup( "Look&Feel" );
-       type = krConfig->readEntry( "Default Panel Type", _DefaultPanelType );
+void PanelManager::slotNewTab(const KUrl& url, bool setCurrent, int type, int props) {
+   if( type == -1 ) {
+       KConfigGroup group( krConfig, "Look&Feel");
+       type = group.readEntry( "Default Panel Type", KrViewFactory::defaultViewId() );
    }
-   ListPanel *p = createPanel( type, setCurrent );
+   ListPanel *p = createPanel( type, setCurrent );   
    // update left/right pointers
    p->otherPanel = _other;
    if( setCurrent )
@@ -173,7 +180,7 @@ void PanelManager::slotNewTab(const KURL& url, bool setCurrent, QString type, in
 }
 
 void PanelManager::slotNewTab() {
-   slotNewTab( QDir::home().absPath() );
+   slotNewTab( QDir::home().absolutePath() );
 }
 
 void PanelManager::slotCloseTab() {
@@ -183,7 +190,7 @@ void PanelManager::slotCloseTab() {
    // setup current one
    ListPanel * oldp;
    _self = _tabbar->removeCurrentPanel( oldp );
-   _stack->raiseWidget( _self );
+   _stack->setCurrentWidget( _self );
    _stack->removeWidget( oldp );
    deletePanel( oldp );
 
@@ -200,23 +207,23 @@ void PanelManager::slotCloseTab() {
 }
 
 void PanelManager::slotCloseTab( int index ) {
-   PanelTab *t = dynamic_cast<PanelTab*>(_tabbar->tabAt( index ));
-   if (t && t->panel) 
+   ListPanel *panel = _tabbar->getPanel(index);
+   if (panel) 
    {
-      ListPanel *oldp = t->panel;
+      ListPanel *oldp = panel;
       disconnect( oldp );
-      if( t->identifier() == _tabbar->currentTab() )
+      if( index == _tabbar->currentIndex() )
       {
-         PanelTab *newCurrent = dynamic_cast<PanelTab*>( _tabbar->tabAt( 0 ) );
-         if( newCurrent != 0 )
+			ListPanel *newCurrentPanel = _tabbar->getPanel(0);
+         if( newCurrentPanel != 0 )
          {
-            _tabbar->setCurrentTab( newCurrent );
-            _self = newCurrent->panel;
+            _tabbar->setCurrentIndex( 0 );
+            _self = newCurrentPanel;
             _self->otherPanel = _other;
             _other->otherPanel = _self;
          }
       }  
-      _tabbar->removeTab( t );
+      _tabbar->removeTab( index );
 
       _stack->removeWidget( oldp );
       deletePanel( oldp );
@@ -237,29 +244,23 @@ void PanelManager::slotRefreshActions() {
 
 int PanelManager::activeTab()
 {
-  return _tabbar->indexOf( _tabbar->currentTab() );
+  return _tabbar->currentIndex();
 }
 
 void PanelManager::setActiveTab( int panelIndex )
 {
-  QTab *current = _tabbar->tabAt( panelIndex );
-  if( current == 0 )
-    return;  
-  _tabbar->setCurrentTab( current );
-  slotChangePanel ( dynamic_cast<PanelTab*>( _tabbar->tabAt( panelIndex ) )->panel );
+	_tabbar->setCurrentIndex(panelIndex);
+	slotChangePanel ( _tabbar->getPanel(panelIndex) );
 }
 
 void PanelManager::setCurrentTab( int panelIndex )
 {
-  PanelTab *current = dynamic_cast<PanelTab*>(_tabbar->tabAt( panelIndex ) );
-  if( current == 0 )
-    return;  
-  _tabbar->setCurrentTab( current );
-  _self = current->panel;
-  _self->otherPanel = _other;
-  _other->otherPanel = _self;
-
-  _stack->raiseWidget( _self );
+	_tabbar->setCurrentIndex( panelIndex );
+	_self = _tabbar->getPanel(panelIndex);
+	_self->otherPanel = _other;
+	_other->otherPanel = _self;
+	
+	_stack->setCurrentWidget( _self );
 }
 
 void PanelManager::slotRecreatePanels() {
@@ -267,12 +268,15 @@ void PanelManager::slotRecreatePanels() {
    
    for( int i = 0; i != _tabbar->count(); i++ )
    {
-     PanelTab *updatedPanel = dynamic_cast<PanelTab*>(_tabbar->tabAt( i ) );
+     ListPanel *updatedPanel = _tabbar->getPanel(i);
      
-     ListPanel *oldPanel = updatedPanel->panel;
-     QString type = oldPanel->getType();
+     ListPanel *oldPanel = updatedPanel;
+     int type = oldPanel->getType();
+
      ListPanel *newPanel = new ListPanel( type, _stack, _left );
-     _stack->addWidget( newPanel, i );
+     _tabbar->changePanel( i, newPanel );
+
+     _stack->insertWidget( i, newPanel );
      _stack->removeWidget( oldPanel );
 
      disconnect( oldPanel );
@@ -282,7 +286,7 @@ void PanelManager::slotRecreatePanels() {
      newPanel->otherPanel = _other;
      if( _other->otherPanel == oldPanel )
        _other->otherPanel = newPanel;         
-     updatedPanel->panel = newPanel;
+     updatedPanel = newPanel;
      newPanel->start( oldPanel->virtualPath(), true );          
      if( _self == oldPanel )
      {
@@ -299,28 +303,28 @@ void PanelManager::slotRecreatePanels() {
 }
 
 void PanelManager::slotNextTab() {
-   int currTab = _tabbar->currentTab();
-	int nextInd = (_tabbar->indexOf(currTab) == _tabbar->count()-1 ? 0 : _tabbar->indexOf(currTab)+1);
-	ListPanel *nextp = dynamic_cast<PanelTab*>(_tabbar->tabAt(nextInd))->panel;
-	_tabbar->setCurrentTab(_tabbar->tabAt(nextInd));	
-	slotChangePanel(nextp);   
+   int currTab = _tabbar->currentIndex();
+	int nextInd = (currTab == _tabbar->count()-1 ? 0 : currTab+1);
+	ListPanel *nextp = _tabbar->getPanel(nextInd);
+	_tabbar->setCurrentIndex(nextInd);
+	slotChangePanel(nextp);
 }
 
 
 void PanelManager::slotPreviousTab() {
-   int currTab = _tabbar->currentTab();
-	int nextInd = (_tabbar->indexOf(currTab) == 0 ? _tabbar->count()-1 : _tabbar->indexOf(currTab)-1);
-	ListPanel *nextp = dynamic_cast<PanelTab*>(_tabbar->tabAt(nextInd))->panel;
-	_tabbar->setCurrentTab(_tabbar->tabAt(nextInd));	
+   int currTab = _tabbar->currentIndex();
+	int nextInd = (currTab == 0 ? _tabbar->count()-1 : currTab-1);
+	ListPanel *nextp = _tabbar->getPanel(nextInd);
+	_tabbar->setCurrentIndex(nextInd);	
 	slotChangePanel(nextp);   
 }
 
 void PanelManager::refreshAllTabs( bool invalidate ) {
    int i=0;
    while (i < _tabbar->count()) {
-      PanelTab *t = dynamic_cast<PanelTab*>(_tabbar->tabAt(i));
-      if (t && t->panel && t->panel->func ) {
-         vfs * vfs = t->panel->func->files();
+		ListPanel *panel = _tabbar->getPanel(i);
+      if (panel && panel->func ) {
+         vfs * vfs = panel->func->files();
          if( vfs ) {
             if( invalidate )
                vfs->vfs_invalidate();
